<!--
# Autogenerated from Broadworks XML Schemas
# Do not edit as changes will be overwritten.
# Generated on 2022-06-25T17:25:30.090188
-->
# Requests


## `AuthenticationRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
`AuthenticationRequest()` is 1st stage of the 2 stage OCI login process.


**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `AuthenticationVerifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
`AuthenticationVerifyRequest()` is used to authenticate a user using the user Id and
password.

The response is a `AuthenticationVerifyResponse()` or an `ErrorResponse()`

Replaced By: `AuthenticationVerifyRequest14sp8()`

**Attributes:**

|Name     |Type|Description|
|---------|----|-----------|
|user_id  |str |userId     |
|password |str |password   |
</div>


## `AuthenticationVerifyRequest14sp8`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
`AuthenticationVerifyRequest14sp8()` is used to authenticate a user either by
userId/password, userId/sip username/sip password, dn/passcode or a token previously
authorized with the `ExternalAuthenticationAuthorizeTokenRequest()`.

The phone number may be any DN associated with a user.

The response is a `AuthenticationVerifyResponse14sp8()` or an `ErrorResponse()`
Replaced by `AuthenticationVerifyRequest22()`.

**Attributes:**

|Name                         |Type|Description                          |
|-----------------------------|----|-------------------------------------|
|user_id                      |str |userId *Optional*                    |
|password                     |str |password *Optional*                  |
|phone_number                 |str |phoneNumber *Optional*               |
|passcode                     |str |passcode *Optional*                  |
|login_token                  |str |loginToken *Optional*                |
|sip_authentication_user_name |str |sipAuthenticationUserName *Optional* |
|sip_authentication_password  |str |sipAuthenticationPassword *Optional* |
</div>


## `AuthenticationVerifyRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
`AuthenticationVerifyRequest21sp1()` is used to authenticate a user either by
userId/password, userId/sip username/sip password, dn/passcode, lineport/password or a
token previously authorized with the `ExternalAuthenticationAuthorizeTokenRequest()`.

The phone number may be any DN associated with a user.  The lineport may be any
lineport associated with a user.  The password used for the lineport is the user's
password associated with userId.

The response is a `AuthenticationVerifyResponse21sp1()` or an `ErrorResponse()`
Replaced by `AuthenticationVerifyRequest22V2()`.

**Attributes:**

|Name                         |Type|Description                          |
|-----------------------------|----|-------------------------------------|
|user_id                      |str |userId *Optional*                    |
|password                     |str |password *Optional*                  |
|phone_number                 |str |phoneNumber *Optional*               |
|passcode                     |str |passcode *Optional*                  |
|line_port                    |str |linePort *Optional*                  |
|login_token                  |str |loginToken *Optional*                |
|sip_authentication_user_name |str |sipAuthenticationUserName *Optional* |
|sip_authentication_password  |str |sipAuthenticationPassword *Optional* |
</div>


## `AuthenticationVerifyRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
`AuthenticationVerifyRequest22()` is used to authenticate a user either by
userId/password, userId/sip username/sip password, dn/passcode, lineport/password or a
token previously authorized with the `ExternalAuthenticationAuthorizeTokenRequest()`.

The phone number may be any DN associated with a user.  The lineport may be any
lineport associated with a user.  The password used for the lineport is the user's
password associated with userId.

The response is a `AuthenticationVerifyResponse22()` or an `ErrorResponse()` Replaced
by `AuthenticationVerifyRequest22V2()`.

**Attributes:**

|Name                         |Type|Description                          |
|-----------------------------|----|-------------------------------------|
|user_id                      |str |userId *Optional*                    |
|password                     |str |password *Optional*                  |
|phone_number                 |str |phoneNumber *Optional*               |
|passcode                     |str |passcode *Optional*                  |
|line_port                    |str |linePort *Optional*                  |
|login_token                  |str |loginToken *Optional*                |
|sip_authentication_user_name |str |sipAuthenticationUserName *Optional* |
|sip_authentication_password  |str |sipAuthenticationPassword *Optional* |
</div>


## `AuthenticationVerifyRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
`AuthenticationVerifyRequest22V2()` is used to authenticate a user either by
userId/password, userId/sip username/sip password, dn/passcode, lineport/password or a
token previously authorized with the `ExternalAuthenticationAuthorizeTokenRequest()`.

The phone number may be any DN associated with a user.  The lineport may be any
lineport associated with a user.  The password used for the lineport is the user's
password associated with userId.

The response is a `AuthenticationVerifyResponse22V2()` or an `ErrorResponse()`
Replaced by `AuthenticationVerifyRequest22V3()`

**Attributes:**

|Name                         |Type|Description                          |
|-----------------------------|----|-------------------------------------|
|user_id                      |str |userId *Optional*                    |
|password                     |str |password *Optional*                  |
|phone_number                 |str |phoneNumber *Optional*               |
|passcode                     |str |passcode *Optional*                  |
|line_port                    |str |linePort *Optional*                  |
|login_token                  |str |loginToken *Optional*                |
|sip_authentication_user_name |str |sipAuthenticationUserName *Optional* |
|sip_authentication_password  |str |sipAuthenticationPassword *Optional* |
</div>


## `AuthenticationVerifyRequest22V3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
`AuthenticationVerifyRequest22V3()` is used to authenticate a user either by
userId/password, userId/sip username/sip password, dn/passcode, lineport/password or a
token previously authorized with the `ExternalAuthenticationAuthorizeTokenRequest()`.

The phone number may be any DN associated with a user.  The lineport may be any
lineport associated with a user.  The password used for the lineport is the user's
password associated with userId.

The response is a `AuthenticationVerifyResponse22V3()` or an `ErrorResponse()`
Replaced by `AuthenticationVerifyRequest22V4()`.

**Attributes:**

|Name                         |Type|Description                          |
|-----------------------------|----|-------------------------------------|
|user_id                      |str |userId *Optional*                    |
|password                     |str |password *Optional*                  |
|phone_number                 |str |phoneNumber *Optional*               |
|passcode                     |str |passcode *Optional*                  |
|line_port                    |str |linePort *Optional*                  |
|login_token                  |str |loginToken *Optional*                |
|sip_authentication_user_name |str |sipAuthenticationUserName *Optional* |
|sip_authentication_password  |str |sipAuthenticationPassword *Optional* |
</div>


## `AuthenticationVerifyRequest22V4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
`AuthenticationVerifyRequest22V4()` is used to authenticate a user either by
userId/password, userId/sip username/sip password, dn/passcode, lineport/password or a
token previously authorized with the `ExternalAuthenticationAuthorizeTokenRequest()`.

The phone number may be any DN associated with a user.  The lineport may be any
lineport associated with a user.  The password used for the lineport is the user's
password associated with userId.

The response is a `AuthenticationVerifyResponse22V4()` or an `ErrorResponse()`

**Attributes:**

|Name                         |Type|Description                          |
|-----------------------------|----|-------------------------------------|
|user_id                      |str |userId *Optional*                    |
|password                     |str |password *Optional*                  |
|phone_number                 |str |phoneNumber *Optional*               |
|passcode                     |str |passcode *Optional*                  |
|line_port                    |str |linePort *Optional*                  |
|login_token                  |str |loginToken *Optional*                |
|sip_authentication_user_name |str |sipAuthenticationUserName *Optional* |
|sip_authentication_password  |str |sipAuthenticationPassword *Optional* |
</div>


## `AvailabilityTestRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
`AvailabilityTestRequest()` is for high-availability support.

Response is either `SuccessResponse()` or `ErrorResponse()`.

</div>


## `DeviceManagementFileAuthLocationGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the address and credentials of the File Repository hosting the requested access
device file.

Also get the file name and path on the File Repository.

The response is either a `DeviceManagementFileAuthLocationGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                        |Type|Description                         |
|----------------------------|----|------------------------------------|
|device_access_protocol      |str |deviceAccessProtocol                |
|device_access_method        |str |deviceAccessMethod                  |
|device_access_uri           |str |deviceAccessURI                     |
|access_device_user_name     |str |accessDeviceUserName *Optional*     |
|access_device_user_password |str |accessDeviceUserPassword *Optional* |
|signed_password             |str |signedPassword *Optional*           |
|mac_address                 |str |macAddress *Optional*               |
|realm_name                  |str |realmName *Optional*                |
|digest_ha1_complement       |str |digestHa1Complement *Optional*      |
|digest_response             |str |digestResponse *Optional*           |
</div>


## `DeviceManagementFileAuthLocationGetRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the address and credentials of the File Repository hosting the requested access
device file.

Also get the file name and path on the File Repository.

The response is either a `DeviceManagementFileAuthLocationGetResponse17()` or an
`ErrorResponse()`. Replaced by: `DeviceManagementFileAuthLocationGetRequest18()`

**Attributes:**

|Name                        |Type|Description                         |
|----------------------------|----|------------------------------------|
|device_access_protocol      |str |deviceAccessProtocol                |
|device_access_method        |str |deviceAccessMethod                  |
|device_access_uri           |str |deviceAccessURI                     |
|access_device_user_name     |str |accessDeviceUserName *Optional*     |
|access_device_user_password |str |accessDeviceUserPassword *Optional* |
|signed_password             |str |signedPassword *Optional*           |
|mac_address                 |str |macAddress *Optional*               |
|realm_name                  |str |realmName *Optional*                |
|digest_ha1_complement       |str |digestHa1Complement *Optional*      |
|digest_response             |str |digestResponse *Optional*           |
</div>


## `DeviceManagementFileAuthLocationGetRequest18`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the address and credentials of the File Repository hosting the requested access
device file.

Also get the file name and path on the File Repository.

The response is either a `DeviceManagementFileAuthLocationGetResponse18()` or an
`ErrorResponse()`. Replaced by: `DeviceManagementFileAuthLocationGetRequest21()`.

**Attributes:**

|Name                        |Type|Description                         |
|----------------------------|----|------------------------------------|
|device_access_protocol      |str |deviceAccessProtocol                |
|device_access_method        |str |deviceAccessMethod                  |
|device_access_uri           |str |deviceAccessURI                     |
|access_device_user_name     |str |accessDeviceUserName *Optional*     |
|access_device_user_password |str |accessDeviceUserPassword *Optional* |
|signed_password             |str |signedPassword *Optional*           |
|mac_address                 |str |macAddress *Optional*               |
|realm_name                  |str |realmName *Optional*                |
|digest_ha1_complement       |str |digestHa1Complement *Optional*      |
|digest_response             |str |digestResponse *Optional*           |
</div>


## `DeviceManagementFileAuthLocationGetRequest20sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the address and credentials of the File Repository hosting the requested access
device file.

Also get the file name and path on the File Repository.

The response is either a `DeviceManagementFileAuthLocationGetResponse20sp1()` or an
`ErrorResponse()`. Replaced by: `DeviceManagementFileAuthLocationGetRequest21sp1()`.

**Attributes:**

|Name                        |Type|Description                         |
|----------------------------|----|------------------------------------|
|device_access_protocol      |str |deviceAccessProtocol                |
|device_access_method        |str |deviceAccessMethod                  |
|device_access_uri           |str |deviceAccessURI                     |
|access_device_user_name     |str |accessDeviceUserName *Optional*     |
|access_device_user_password |str |accessDeviceUserPassword *Optional* |
|signed_password             |str |signedPassword *Optional*           |
|mac_address                 |str |macAddress *Optional*               |
|realm_name                  |str |realmName *Optional*                |
|digest_ha1_complement       |str |digestHa1Complement *Optional*      |
|digest_response             |str |digestResponse *Optional*           |
</div>


## `DeviceManagementFileAuthLocationGetRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the address and credentials of the File Repository hosting the requested access
device file.

Also get the file name and path on the File Repository.

The response is either `DeviceManagementFileAuthLocationGetResponse21()` or
`ErrorResponse()`. The following elements are only used in AS data mode and will fail
in XS data mode: deviceToken Replaced by:
`DeviceManagementFileAuthLocationGetRequest21sp1()`.

**Attributes:**

|Name                        |Type|Description                         |
|----------------------------|----|------------------------------------|
|device_access_protocol      |str |deviceAccessProtocol                |
|device_access_method        |str |deviceAccessMethod                  |
|device_access_uri           |str |deviceAccessURI                     |
|access_device_user_name     |str |accessDeviceUserName *Optional*     |
|access_device_user_password |str |accessDeviceUserPassword *Optional* |
|device_token                |str |deviceToken *Optional*              |
|signed_password             |str |signedPassword *Optional*           |
|mac_address                 |str |macAddress *Optional*               |
|realm_name                  |str |realmName *Optional*                |
|digest_ha1_complement       |str |digestHa1Complement *Optional*      |
|digest_response             |str |digestResponse *Optional*           |
</div>


## `DeviceManagementFileAuthLocationGetRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the address and credentials of the File Repository hosting the requested access
device file.

Also get the file name and path on the File Repository.

The response is either `DeviceManagementFileAuthLocationGetResponse21sp1()` or
`ErrorResponse()`. The following elements are only used in AS data mode and will fail
in XS data mode: deviceToken Replaced by
`DeviceManagementFileAuthLocationGetRequest22()`

**Attributes:**

|Name                        |Type|Description                         |
|----------------------------|----|------------------------------------|
|device_access_protocol      |str |deviceAccessProtocol                |
|device_access_method        |str |deviceAccessMethod                  |
|device_access_uri           |str |deviceAccessURI                     |
|access_device_user_name     |str |accessDeviceUserName *Optional*     |
|access_device_user_password |str |accessDeviceUserPassword *Optional* |
|device_token                |str |deviceToken *Optional*              |
|signed_password             |str |signedPassword *Optional*           |
|mac_address                 |str |macAddress *Optional*               |
|realm_name                  |str |realmName *Optional*                |
|digest_ha1_complement       |str |digestHa1Complement *Optional*      |
|digest_response             |str |digestResponse *Optional*           |
</div>


## `DeviceManagementFileAuthLocationGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the address and credentials of the File Repository hosting the requested access
device file.

Also get the file name and path on the File Repository.

The response is either `DeviceManagementFileAuthLocationGetResponse22()` or
`ErrorResponse()`. The following elements are only used in AS data mode and will fail
in XS data mode: deviceToken

**Attributes:**

|Name                        |Type|Description                         |
|----------------------------|----|------------------------------------|
|device_access_protocol      |str |deviceAccessProtocol                |
|device_access_method        |str |deviceAccessMethod                  |
|device_access_uri           |str |deviceAccessURI                     |
|access_device_user_name     |str |accessDeviceUserName *Optional*     |
|access_device_user_password |str |accessDeviceUserPassword *Optional* |
|device_token                |str |deviceToken *Optional*              |
|signed_password             |str |signedPassword *Optional*           |
|mac_address                 |str |macAddress *Optional*               |
|realm_name                  |str |realmName *Optional*                |
|digest_ha1_complement       |str |digestHa1Complement *Optional*      |
|digest_response             |str |digestResponse *Optional*           |
</div>


## `DeviceManagementFileAuthLocationGetRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the address and credentials of the File Repository hosting the requested access
device file.

Also get the file name and path on the File Repository.

The response is either `DeviceManagementFileAuthLocationGetResponse22V2()` or
`ErrorResponse()`. The following elements are only used in AS data mode and will fail
in XS data mode: deviceToken The following elements are only used in XS data mode and
will be ignored in AS data mode: fileNameLookup fileNameOnDisk

**Attributes:**

|Name                        |Type |Description                         |
|----------------------------|-----|------------------------------------|
|device_access_protocol      |str  |deviceAccessProtocol                |
|device_access_method        |str  |deviceAccessMethod                  |
|device_access_uri           |str  |deviceAccessURI                     |
|access_device_user_name     |str  |accessDeviceUserName *Optional*     |
|access_device_user_password |str  |accessDeviceUserPassword *Optional* |
|device_token                |str  |deviceToken *Optional*              |
|signed_password             |str  |signedPassword *Optional*           |
|mac_address                 |str  |macAddress *Optional*               |
|realm_name                  |str  |realmName *Optional*                |
|digest_ha1_complement       |str  |digestHa1Complement *Optional*      |
|digest_response             |str  |digestResponse *Optional*           |
|file_name_lookup            |bool |fileNameLookup *Optional*           |
|file_name_on_disk           |str  |fileNameOnDisk *Optional*           |
</div>


## `DeviceManagementFileAuthLocationGetRequest22V3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the address and credentials of the File Repository hosting the requested access
device file.

Also get the file name and path on the File Repository.

The response is either `DeviceManagementFileAuthLocationGetResponse22V3()` or
`ErrorResponse()`. The following elements are only used in AS data mode and will fail
in XS data mode: deviceToken The following elements are only used in XS data mode and
will be ignored in AS data mode: fileNameLookup fileNameOnDisk

**Attributes:**

|Name                        |Type |Description                         |
|----------------------------|-----|------------------------------------|
|device_access_protocol      |str  |deviceAccessProtocol                |
|device_access_method        |str  |deviceAccessMethod                  |
|device_access_uri           |str  |deviceAccessURI                     |
|access_device_user_name     |str  |accessDeviceUserName *Optional*     |
|access_device_user_password |str  |accessDeviceUserPassword *Optional* |
|device_token                |str  |deviceToken *Optional*              |
|signed_password             |str  |signedPassword *Optional*           |
|mac_address                 |str  |macAddress *Optional*               |
|realm_name                  |str  |realmName *Optional*                |
|digest_ha1_complement       |str  |digestHa1Complement *Optional*      |
|digest_response             |str  |digestResponse *Optional*           |
|file_name_lookup            |bool |fileNameLookup *Optional*           |
|file_name_on_disk           |str  |fileNameOnDisk *Optional*           |
</div>


## `DeviceManagementPutFileRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Informs BroadWorks that a file was uploaded to the repository.

The response is always a `SuccessResponse()`.

**Attributes:**

|Name              |Type|Description     |
|------------------|----|----------------|
|device_access_uri |str |deviceAccessURI |
|ip_address        |str |ipAddress       |
</div>


## `EnterpriseBroadWorksMobileManagerActivationRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Activates or Deactivates the BroadWorks Mobile Manager.

The deactivationReason is required when isActive is set to false.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type |Description                   |
|--------------------|-----|------------------------------|
|service_provider_id |str  |serviceProviderId             |
|is_active           |bool |isActive                      |
|deactivation_reason |str  |deactivationReason *Optional* |
</div>


## `EnterpriseBroadWorksMobileManagerAddHomeZoneRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a home zone to the BroadWorks Mobile Manager.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                  |Type|Description        |
|----------------------|----|-------------------|
|service_provider_id   |str |serviceProviderId  |
|home_zone_domain_name |str |homeZoneDomainName |
|mobile_country_code   |str |mobileCountryCode  |
|mobile_network_code   |str |mobileNetworkCode  |
|location_area_code    |str |locationAreaCode   |
|cell_identity         |str |cellIdentity       |
</div>


## `EnterpriseBroadWorksMobileManagerAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add the BroadWorks Mobile Manager.

Only one BroadWorks Mobile Manager can be added per enterprise.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                            |Type |Description                  |
|--------------------------------|-----|-----------------------------|
|service_provider_id             |str  |serviceProviderId            |
|information_file                |str  |informationFile              |
|certificate_file                |str  |certificateFile              |
|is_active                       |bool |isActive                     |
|local_to_carrier                |bool |localToCarrier               |
|max_tx_per_second_enabled       |bool |maxTxPerSecondEnabled        |
|max_tx_per_second               |int  |maxTxPerSecond *Optional*    |
|tldn_enabled                    |bool |tldnEnabled                  |
|generic_number_enabled          |bool |genericNumberEnabled         |
|mobile_state_check_enabled      |bool |mobileStateCheckEnabled      |
|location_based_services_enabled |bool |locationBasedServicesEnabled |
</div>


## `EnterpriseBroadWorksMobileManagerDeleteHomeZoneListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a list of home zones from the BroadWorks Mobile Manager.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|home_zone_id        |List[str] |homeZoneId        |
</div>


## `EnterpriseBroadWorksMobileManagerDeleteHomeZoneRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a home zone from the BroadWorks Mobile Manager.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|home_zone_id        |str |homeZoneId        |
</div>


## `EnterpriseBroadWorksMobileManagerDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete the BroadWorks Mobile Manager.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `EnterpriseBroadWorksMobileManagerGetDomainListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of domains of the BroadWorks Mobile Manager.

The response is either `EnterpriseBroadWorksMobileManagerGetDomainListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `EnterpriseBroadWorksMobileManagerGetHomeZoneListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of home zones of the BroadWorks Mobile Manager.

The response is either `EnterpriseBroadWorksMobileManagerGetHomeZoneListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `EnterpriseBroadWorksMobileManagerGetHomeZoneRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a home zone from the BroadWorks Mobile Manager.

The response is either `EnterpriseBroadWorksMobileManagerGetHomeZoneResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|home_zone_id        |str |homeZoneId        |
</div>


## `EnterpriseBroadWorksMobileManagerGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the BroadWorks Mobile Manager.

The response is either `EnterpriseBroadWorksMobileManagerGetResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `EnterpriseBroadWorksMobileManagerModifyHomeZoneRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an existing home zone in the BroadWorks Mobile Manager.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                  |Type|Description                   |
|----------------------|----|------------------------------|
|service_provider_id   |str |serviceProviderId             |
|home_zone_id          |str |homeZoneId                    |
|home_zone_domain_name |str |homeZoneDomainName *Optional* |
|mobile_country_code   |str |mobileCountryCode *Optional*  |
|mobile_network_code   |str |mobileNetworkCode *Optional*  |
|location_area_code    |str |locationAreaCode *Optional*   |
|cell_identity         |str |cellIdentity *Optional*       |
</div>


## `EnterpriseBroadWorksMobileManagerModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the BroadWorks Mobile Manager settings.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                            |Type |Description                             |
|--------------------------------|-----|----------------------------------------|
|service_provider_id             |str  |serviceProviderId                       |
|information_file                |str  |informationFile *Optional*              |
|certificate_file                |str  |certificateFile *Optional*              |
|local_to_carrier                |bool |localToCarrier *Optional*               |
|max_tx_per_second_enabled       |bool |maxTxPerSecondEnabled *Optional*        |
|max_tx_per_second               |int  |maxTxPerSecond *Optional*               |
|tldn_enabled                    |bool |tldnEnabled *Optional*                  |
|generic_number_enabled          |bool |genericNumberEnabled *Optional*         |
|mobile_state_check_enabled      |bool |mobileStateCheckEnabled *Optional*      |
|location_based_services_enabled |bool |locationBasedServicesEnabled *Optional* |
</div>


## `EnterpriseBroadWorksMobileManagerSendCarrierFilesRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Sends an email with the carrier information and certificate files.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|email_to            |str |emailTo           |
</div>


## `EnterpriseBroadWorksMobilityMobileSubscriberDirectoryNumberGetAvailableListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a list of available Mobile Subscriber Directory Numbers not yet assigned to
any user.

The response is either
`EnterpriseBroadWorksMobilityMobileSubscriberDirectoryNumberGetAvailableListResponse()`
or `ErrorResponse()`. Replaced by:
`EnterpriseBroadWorksMobilityMobileSubscriberDirectoryNumberGetAvailableListRequest22()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `EnterpriseBroadWorksMobilityMobileSubscriberDirectoryNumberGetAvailableListRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a list of available Mobile Subscriber Directory Numbers not yet assigned to
any user.

The response is either
`EnterpriseBroadWorksMobilityMobileSubscriberDirectoryNumberGetAvailableListResponse22()`
or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `EnterpriseCallCenterAgentThresholdProfileAddAgentListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add agent(s) to a Agent Threshold Profile.

When an agent is assigned (added) to a profile, it is automatically unassigned
(deleted) from the previous profile it was assigned to.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|profile_name        |str       |profileName       |
|agent_user_id       |List[str] |agentUserId       |
</div>


## `EnterpriseCallCenterAgentThresholdProfileAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a new Call Center Agent Threshold Profile in an Enterprise.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                                  |Type      |Description                                                |
|------------------------------------------------------|----------|-----------------------------------------------------------|
|service_provider_id                                   |str       |serviceProviderId                                          |
|profile_name                                          |str       |profileName                                                |
|profile_description                                   |str       |profileDescription *Optional*                              |
|threshold_current_call_state_idle_time_yellow         |int       |thresholdCurrentCallStateIdleTimeYellow *Optional*         |
|threshold_current_call_state_idle_time_red            |int       |thresholdCurrentCallStateIdleTimeRed *Optional*            |
|threshold_current_call_state_on_call_time_yellow      |int       |thresholdCurrentCallStateOnCallTimeYellow *Optional*       |
|threshold_current_call_state_on_call_time_red         |int       |thresholdCurrentCallStateOnCallTimeRed *Optional*          |
|threshold_current_agent_state_unavailable_time_yellow |int       |thresholdCurrentAgentStateUnavailableTimeYellow *Optional* |
|threshold_current_agent_state_unavailable_time_red    |int       |thresholdCurrentAgentStateUnavailableTimeRed *Optional*    |
|threshold_average_busy_in_time_yellow                 |int       |thresholdAverageBusyInTimeYellow *Optional*                |
|threshold_average_busy_in_time_red                    |int       |thresholdAverageBusyInTimeRed *Optional*                   |
|threshold_average_busy_out_time_yellow                |int       |thresholdAverageBusyOutTimeYellow *Optional*               |
|threshold_average_busy_out_time_red                   |int       |thresholdAverageBusyOutTimeRed *Optional*                  |
|threshold_average_wrap_up_time_yellow                 |int       |thresholdAverageWrapUpTimeYellow *Optional*                |
|threshold_average_wrap_up_time_red                    |int       |thresholdAverageWrapUpTimeRed *Optional*                   |
|enable_notification_email                             |bool      |enableNotificationEmail                                    |
|notification_email_address                            |List[str] |notificationEmailAddress *Optional*                        |
|agent_user_id                                         |List[str] |agentUserId *Optional*                                     |
</div>


## `EnterpriseCallCenterAgentThresholdProfileDeleteAgentListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete agent(s) from a Agent Threshold Profile.

Agents cannot be unassigned (deleted) directly from the default profile, they need to
be assigned (added) to a different profile.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|profile_name        |str       |profileName       |
|agent_user_id       |List[str] |agentUserId       |
</div>


## `EnterpriseCallCenterAgentThresholdProfileDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Deletes an existing Call Center Agent Threshold Profile in an Enterprise.

The default profile cannot be deleted.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|profile_name        |str |profileName       |
</div>


## `EnterpriseCallCenterAgentThresholdProfileGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of Call Center Agent Threshold Profiles in the Enterprise.

The response is either `EnterpriseCallCenterAgentThresholdProfileGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `EnterpriseCallCenterAgentThresholdProfileGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Gets an existing non-default Call Center Agent Threshold Profile in an Enterprise.

The response is either a `EnterpriseCallCenterAgentThresholdProfileGetResponse()` or
an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|profile_name        |str |profileName       |
</div>


## `EnterpriseCallCenterAgentUnavailableCodeAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Call Center Agent Unavailable Code.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type |Description            |
|--------------------|-----|-----------------------|
|service_provider_id |str  |serviceProviderId      |
|is_active           |bool |isActive               |
|code                |str  |code                   |
|description         |str  |description *Optional* |
</div>


## `EnterpriseCallCenterAgentUnavailableCodeDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Call Center Agent Unavailable Code.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|code                |str |code              |
</div>


## `EnterpriseCallCenterAgentUnavailableCodeGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of Call Center Agent Unavailable Codes.

The response is either `EnterpriseCallCenterAgentUnavailableCodeGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `EnterpriseCallCenterAgentUnavailableCodeGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a Call Center Agent Unavailable Code.

The response is either `EnterpriseCallCenterAgentUnavailableCodeGetResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|code                |str |code              |
</div>


## `EnterpriseCallCenterAgentUnavailableCodeModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a Call Center Agent Unavailable Code.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type |Description            |
|--------------------|-----|-----------------------|
|service_provider_id |str  |serviceProviderId      |
|code                |str  |code                   |
|is_active           |bool |isActive *Optional*    |
|description         |str  |description *Optional* |
</div>


## `EnterpriseCallCenterAgentUnavailableCodeSettingsGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the enterprise level data associated with Call Center Agents Unavailable Code
Settings.

The response is either an
`EnterpriseCallCenterAgentUnavailableCodeSettingsGetResponse()` or an
`ErrorResponse()`. Replaced by
`EnterpriseCallCenterAgentUnavailableCodeSettingsGetRequest17sp4()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `EnterpriseCallCenterAgentUnavailableCodeSettingsGetRequest17sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the enterprise level data associated with Call Center Agents Unavailable Code
Settings.

The response is either an
`EnterpriseCallCenterAgentUnavailableCodeSettingsGetResponse17sp4()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `EnterpriseCallCenterCallDispositionCodeAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Call Center Call Disposition Code.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type |Description            |
|--------------------|-----|-----------------------|
|service_provider_id |str  |serviceProviderId      |
|code                |str  |code                   |
|is_active           |bool |isActive               |
|description         |str  |description *Optional* |
</div>


## `EnterpriseCallCenterCallDispositionCodeDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Call Center Call Disposition Code.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|code                |str |code              |
</div>


## `EnterpriseCallCenterCallDispositionCodeGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of Call Center Call Disposition Codes.

The response is either `EnterpriseCallCenterCallDispositionCodeGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `EnterpriseCallCenterCallDispositionCodeGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a Call Center Call Disposition Code.

The response is either `EnterpriseCallCenterCallDispositionCodeGetResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|code                |str |code              |
</div>


## `EnterpriseCallCenterCallDispositionCodeGetUsageListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of Call Centers and Route Points using the specified disposition code.

The response is either `EnterpriseCallCenterCallDispositionCodeGetUsageListResponse()`
or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|code                |str |code              |
</div>


## `EnterpriseCallCenterCallDispositionCodeModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a Call Center Call Disposition Code.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type |Description            |
|--------------------|-----|-----------------------|
|service_provider_id |str  |serviceProviderId      |
|code                |str  |code                   |
|is_active           |bool |isActive *Optional*    |
|description         |str  |description *Optional* |
</div>


## `EnterpriseCallCenterCurrentAndPastDNISGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the past and current DNIS for the Call Center for the enterprise.

The response is either `EnterpriseCallCenterCurrentAndPastDNISGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|service_user_id     |str |serviceUserId     |
</div>


## `EnterpriseCallCenterEnhancedReportingBrandingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the enterprise branding information.

The response is either `EnterpriseCallCenterEnhancedReportingBrandingGetResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `EnterpriseCallCenterEnhancedReportingGetAvailableReportTemplateListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all enabled call center report template for an enterprise.

The response is either an
`EnterpriseCallCenterEnhancedReportingGetAvailableReportTemplateListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `EnterpriseCallCenterEnhancedReportingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get an enterprise level call center enhanced reporting setting.

The response is either an `EnterpriseCallCenterEnhancedReportingGetResponse()` or an
`ErrorResponse()`. Replaced by `EnterpriseCallCenterEnhancedReportingGetRequest19()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `EnterpriseCallCenterEnhancedReportingGetRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get an enterprise level call center enhanced reporting setting.

The response is either an `EnterpriseCallCenterEnhancedReportingGetResponse19()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `EnterpriseCallCenterEnhancedReportingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify enterprise level call center enhanced reporting settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by
`EnterpriseCallCenterEnhancedReportingModifyRequest19()`

**Attributes:**

|Name                 |Type|Description                   |
|---------------------|----|------------------------------|
|service_provider_id  |str |serviceProviderId             |
|reporting_server     |str |reportingServer *Optional*    |
|web_statistic_source |str |webStatisticSource *Optional* |
</div>


## `EnterpriseCallCenterEnhancedReportingModifyRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify enterprise level call center enhanced reporting settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description                |
|--------------------|----|---------------------------|
|service_provider_id |str |serviceProviderId          |
|reporting_server    |str |reportingServer *Optional* |
</div>


## `EnterpriseCallCenterEnhancedReportingReportTemplateDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete an enterprise level call center report template.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|name                |str |name              |
</div>


## `EnterpriseCallCenterEnhancedReportingReportTemplateGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get enterprise level call center report template list.

The response is either an
`EnterpriseCallCenterEnhancedReportingReportTemplateGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `EnterpriseCallCenterEnhancedReportingReportTemplateGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get an enterprise level call center report template.

The response is either an
`EnterpriseCallCenterEnhancedReportingReportTemplateGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|name                |str |name              |
</div>


## `EnterpriseCallCenterEnhancedReportingScheduledReportDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete an enterprise level call center reporting scheduled report.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|name                |str |name              |
</div>


## `EnterpriseCallCenterEnhancedReportingScheduledReportGetReportTemplateUsageListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the call center reporting scheduled report in an enterprise that
uses a given enterprise level report template.

The response is either a
`EnterpriseCallCenterEnhancedReportingScheduledReportGetReportTemplateUsageListResponse()`
or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|name                |str |name              |
</div>


## `EnterpriseCallCenterEnhancedReportingScheduledReportGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get an enterprise level call center reporting scheduled report.

The response is either an
`EnterpriseCallCenterEnhancedReportingScheduledReportGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|name                |str |name              |
</div>


## `EnterpriseCallCenterGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the enterprise level data associated with Call Center.

The response is either an `EnterpriseCallCenterGetResponse()` or an `ErrorResponse()`.
Replaced by `EnterpriseCallCenterGetRequest17sp4()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `EnterpriseCallCenterGetRequest17sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the enterprise level data associated with Call Center.

The response is either an `EnterpriseCallCenterGetResponse17sp4()` or an
`ErrorResponse()`. Replaced by: `EnterpriseCallCenterGetResponse23()` in AS data mode

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `EnterpriseCallCenterGetRequest23`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the enterprise level data associated with Call Center.

The response is either an `EnterpriseCallCenterGetResponse23()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `EnterpriseCallCenterGetRoutingPolicyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the enterprise call center routing policy.

The response is either an `EnterpriseCallCenterGetRoutingPolicyResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `EnterpriseCallCenterModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the enterprise level data associated with Call Center The response is either a
`SuccessResponse()` or an `ErrorResponse()`.

The following elements are only used in AS data mode and ignored in XS data mode:
useSystemDefaultUnavailableSettings forceAgentUnavailableOnDNDActivation
forceAgentUnavailableOnPersonalCalls forceAgentUnavailableOnBouncedCallLimit
numberConsecutiveBouncedCallsToForceAgentUnavailable
forceAgentUnavailableOnNotReachable wrapUpDestination

**Attributes:**

|Name                                                        |Type |Description                                                     |
|------------------------------------------------------------|-----|----------------------------------------------------------------|
|service_provider_id                                         |str  |serviceProviderId                                               |
|use_system_default_guard_timer                              |bool |useSystemDefaultGuardTimer *Optional*                           |
|enable_guard_timer                                          |bool |enableGuardTimer *Optional*                                     |
|guard_timer_seconds                                         |int  |guardTimerSeconds *Optional*                                    |
|use_system_default_unavailable_settings                     |bool |useSystemDefaultUnavailableSettings *Optional*                  |
|force_agent_unavailable_on_dnd_activation                   |bool |forceAgentUnavailableOnDNDActivation *Optional*                 |
|force_agent_unavailable_on_personal_calls                   |bool |forceAgentUnavailableOnPersonalCalls *Optional*                 |
|force_agent_unavailable_on_bounced_call_limit               |bool |forceAgentUnavailableOnBouncedCallLimit *Optional*              |
|number_consecutive_bounced_calls_to_force_agent_unavailable |int  |numberConsecutiveBouncedCallsToForceAgentUnavailable *Optional* |
|force_agent_unavailable_on_not_reachable                    |bool |forceAgentUnavailableOnNotReachable *Optional*                  |
|wrap_up_destination                                         |str  |wrapUpDestination *Optional*                                    |
</div>


## `EnterpriseCallCenterMonitoringGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the enterprise level data associated with Call Center Monitoring.

The response is either an `EnterpriseCallCenterMonitoringGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `EnterpriseCallCenterMonitoringGetRequest23`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the enterprise level data associated with Call Center Monitoring.

The response is either an `EnterpriseCallCenterMonitoringGetResponse23()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `EnterpriseCallCenterMonitoringModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the enterprise level data associated with Call Center Monitoring The response
is either a `SuccessResponse()` or an `ErrorResponse()`.


**Attributes:**

|Name                                                |Type |Description                                               |
|----------------------------------------------------|-----|----------------------------------------------------------|
|service_provider_id                                 |str  |serviceProviderId                                         |
|enable_supervisor_coaching                          |bool |enableSupervisorCoaching *Optional*                       |
|bypass_enforcement_of_supervisor_agent_relationship |bool |bypassEnforcementOfSupervisorAgentRelationship *Optional* |
</div>


## `EnterpriseCallRecordingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the Call Recording attributes for a enterprise.

The response is either a `EnterpriseCallRecordingGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `EnterpriseCallRecordingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Call Recording attributes for a enterprise.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type |Description                     |
|-----------------------|-----|--------------------------------|
|service_provider_id    |str  |serviceProviderId               |
|use_cloud_pbx          |bool |useCloudPBX *Optional*          |
|use_enterprise_setting |bool |useEnterpriseSetting *Optional* |
|fqdn                   |str  |FQDN *Optional*                 |
</div>


## `EnterpriseCommonPhoneListDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete one or more entries from an enterprise's common phone list.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|entry_name          |List[str] |entryName         |
</div>


## `EnterpriseCommonPhoneListModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an entry in an enterprise's common phone list.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description             |
|--------------------|----|------------------------|
|service_provider_id |str |serviceProviderId       |
|entry_name          |str |entryName               |
|new_entry_name      |str |newEntryName *Optional* |
|phone_number        |str |phoneNumber *Optional*  |
</div>


## `EnterpriseCommunicationBarringAuthorizationCodeDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a list of Communication Barring Authorization Codes from an enterprise.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|code                |List[str] |code *Optional*   |
</div>


## `EnterpriseCommunicationBarringAuthorizationCodeGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the enterprise Communication Barring Authorization code settings.

The response is either a
`EnterpriseCommunicationBarringAuthorizationCodeGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|code                |str |code              |
</div>


## `EnterpriseCommunicationBarringAuthorizationCodeModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the enterprise Communication Barring Authorization code settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type|Description                      |
|-------------------------|----|---------------------------------|
|service_provider_id      |str |serviceProviderId                |
|code                     |str |code                             |
|description              |str |description *Optional*           |
|network_class_of_service |str |networkClassOfService *Optional* |
</div>


## `EnterpriseDepartmentDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a department from an enterprise.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description    |
|----------------|----|---------------|
|enterprise_id   |str |enterpriseId   |
|department_name |str |departmentName |
</div>


## `EnterpriseDepartmentGetAvailableParentListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of enterprise level departments in an enterprise that could be the parent
of the specified department.

The department itself and all its decendents are not eligible to be the parent
department.

The response is either `EnterpriseDepartmentGetAvailableParentListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description    |
|----------------|----|---------------|
|enterprise_id   |str |enterpriseId   |
|department_name |str |departmentName |
</div>


## `EnterpriseDepartmentGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a list of departments in an enterprise.

You may request only the list of departments defined at the enterprise-level, or you
may request the list of all departments in the enterprise including all the
departments defined within the groups inside the enterprise.

The response is either `EnterpriseDepartmentGetListResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                      |Type |Description             |
|--------------------------|-----|------------------------|
|enterprise_id             |str  |enterpriseId            |
|include_group_departments |bool |includeGroupDepartments |
</div>


## `EnterpriseEnterpriseTrunkAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add an enterprise trunk in an enterprise.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`EnterpriseEnterpriseTrunkAddRequest21()`

**Attributes:**

|Name                             |Type                        |Description                              |
|---------------------------------|----------------------------|-----------------------------------------|
|service_provider_id              |str                         |serviceProviderId                        |
|enterprise_trunk_name            |str                         |enterpriseTrunkName                      |
|maximum_reroute_attempts         |int                         |maximumRerouteAttempts                   |
|route_exhaustion_action          |str                         |routeExhaustionAction                    |
|route_exhaustion_forward_address |str                         |routeExhaustionForwardAddress *Optional* |
|ordered_routing                  |OCI.orderedRouting          |orderedRouting *Optional*                |
|priority_weighted_routing        |OCI.priorityWeightedRouting |priorityWeightedRouting *Optional*       |
</div>


## `EnterpriseEnterpriseTrunkAddRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add an enterprise trunk in an enterprise.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                  |Type                        |Description                                  |
|--------------------------------------|----------------------------|---------------------------------------------|
|service_provider_id                   |str                         |serviceProviderId                            |
|enterprise_trunk_name                 |str                         |enterpriseTrunkName                          |
|maximum_reroute_attempts              |int                         |maximumRerouteAttempts                       |
|route_exhaustion_action               |str                         |routeExhaustionAction                        |
|route_exhaustion_forward_address      |str                         |routeExhaustionForwardAddress *Optional*     |
|ordered_routing                       |OCI.orderedRouting          |orderedRouting *Optional*                    |
|priority_weighted_routing             |OCI.priorityWeightedRouting |priorityWeightedRouting *Optional*           |
|enable_capacity_management            |bool                        |enableCapacityManagement                     |
|max_active_calls                      |int                         |maxActiveCalls *Optional*                    |
|capacity_exceeded_trap_initial_calls  |int                         |capacityExceededTrapInitialCalls *Optional*  |
|capacity_exceeded_trap_offset_calls   |int                         |capacityExceededTrapOffsetCalls *Optional*   |
|maximum_active_incoming_calls_allowed |int                         |maximumActiveIncomingCallsAllowed *Optional* |
|maximum_active_outgoing_calls_allowed |int                         |maximumActiveOutgoingCallsAllowed *Optional* |
|minimum_active_calls_reserved         |int                         |minimumActiveCallsReserved *Optional*        |
</div>


## `EnterpriseEnterpriseTrunkAddUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add users to an enterprise trunk in an enterprise.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                  |Type      |Description         |
|----------------------|----------|--------------------|
|service_provider_id   |str       |serviceProviderId   |
|enterprise_trunk_name |str       |enterpriseTrunkName |
|user_id               |List[str] |userId              |
</div>


## `EnterpriseEnterpriseTrunkDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete an enterprise trunk in an enterprise.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                  |Type|Description         |
|----------------------|----|--------------------|
|service_provider_id   |str |serviceProviderId   |
|enterprise_trunk_name |str |enterpriseTrunkName |
</div>


## `EnterpriseEnterpriseTrunkDeleteUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete users from an enterprise trunk in an enterprise.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                  |Type      |Description         |
|----------------------|----------|--------------------|
|service_provider_id   |str       |serviceProviderId   |
|enterprise_trunk_name |str       |enterpriseTrunkName |
|user_id               |List[str] |userId              |
</div>


## `EnterpriseEnterpriseTrunkForceAssignUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add users to an enterprise trunk in an enterprise.

If the user is already assigned to another enterprise trunk, it will be unassigned
from the old enterprise trunk and assigned to the new enterprise trunk specified in
this request.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                  |Type      |Description         |
|----------------------|----------|--------------------|
|service_provider_id   |str       |serviceProviderId   |
|enterprise_trunk_name |str       |enterpriseTrunkName |
|user_id               |List[str] |userId              |
</div>


## `EnterpriseEnterpriseTrunkGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of all enterprise trunks defined in an enterprise.

The response is either a `EnterpriseEnterpriseTrunkGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `EnterpriseEnterpriseTrunkGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get an enterprise trunk The response is either an
`EnterpriseEnterpriseTrunkGetResponse()` or an `ErrorResponse()`.

Replaced by: `EnterpriseEnterpriseTrunkGetRequest21()`

**Attributes:**

|Name                  |Type|Description         |
|----------------------|----|--------------------|
|service_provider_id   |str |serviceProviderId   |
|enterprise_trunk_name |str |enterpriseTrunkName |
</div>


## `EnterpriseEnterpriseTrunkGetRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get an enterprise trunk The response is either an
`EnterpriseEnterpriseTrunkGetResponse21()` or an `ErrorResponse()`.


**Attributes:**

|Name                  |Type|Description         |
|----------------------|----|--------------------|
|service_provider_id   |str |serviceProviderId   |
|enterprise_trunk_name |str |enterpriseTrunkName |
</div>


## `EnterpriseEnterpriseTrunkGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get an enterprise trunk The response is either an
`EnterpriseEnterpriseTrunkGetResponse21()` or an `ErrorResponse()`.


**Attributes:**

|Name                  |Type|Description         |
|----------------------|----|--------------------|
|service_provider_id   |str |serviceProviderId   |
|enterprise_trunk_name |str |enterpriseTrunkName |
</div>


## `EnterpriseEnterpriseTrunkModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify an enterprise trunk in an enterprise.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                  |Type                        |Description                                  |
|--------------------------------------|----------------------------|---------------------------------------------|
|service_provider_id                   |str                         |serviceProviderId                            |
|enterprise_trunk_name                 |str                         |enterpriseTrunkName                          |
|new_enterprise_trunk_name             |str                         |newEnterpriseTrunkName *Optional*            |
|maximum_reroute_attempts              |int                         |maximumRerouteAttempts *Optional*            |
|route_exhaustion_action               |str                         |routeExhaustionAction *Optional*             |
|route_exhaustion_forward_address      |str                         |routeExhaustionForwardAddress *Optional*     |
|ordered_routing                       |OCI.orderedRouting          |orderedRouting *Optional*                    |
|priority_weighted_routing             |OCI.priorityWeightedRouting |priorityWeightedRouting *Optional*           |
|enable_capacity_management            |bool                        |enableCapacityManagement *Optional*          |
|max_active_calls                      |int                         |maxActiveCalls *Optional*                    |
|capacity_exceeded_trap_initial_calls  |int                         |capacityExceededTrapInitialCalls *Optional*  |
|capacity_exceeded_trap_offset_calls   |int                         |capacityExceededTrapOffsetCalls *Optional*   |
|maximum_active_incoming_calls_allowed |int                         |maximumActiveIncomingCallsAllowed *Optional* |
|maximum_active_outgoing_calls_allowed |int                         |maximumActiveOutgoingCallsAllowed *Optional* |
|minimum_active_calls_reserved         |int                         |minimumActiveCallsReserved *Optional*        |
</div>


## `EnterpriseLocalGatewayGetUsageRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get usage details of a local gateway under an enterprise.

The response is either `EnterpriseLocalGatewayGetUsageResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|trunk_group_name    |str |trunkGroupName    |
</div>


## `EnterprisePreAlertingAnnouncementGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the Enterprise pre-alerting service settings.

The response is either a `EnterprisePreAlertingAnnouncementGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `EnterpriseRouteListEnterpriseTrunkNumberPrefixGetAvailableListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a list of number prefixes that are assigned to an enterprise and still
available for assignment to users within the enterprise.

The response is either
`EnterpriseRouteListEnterpriseTrunkNumberPrefixGetAvailableListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `EnterpriseRouteListEnterpriseTrunkNumberPrefixGetSummaryListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a summary table of all enterprise trunk number prefixes in the enterprise.

The response is either
`EnterpriseRouteListEnterpriseTrunkNumberPrefixGetSummaryListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `EnterpriseRouteListEnterpriseTrunkNumberRangeGetAvailableListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a list of number ranges that are assigned to an enterprise and still available
for assignment to users within the enterprise.

The response is either
`EnterpriseRouteListEnterpriseTrunkNumberRangeGetAvailableListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `EnterpriseRouteListEnterpriseTrunkNumberRangeGetSummaryListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a summary table of all enterprise trunk number ranges in the enterprise.

The response is either
`EnterpriseRouteListEnterpriseTrunkNumberRangeGetSummaryListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `EnterpriseSecurityClassificationCustomizationGetAvailableListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the enterprise security classification list.

If it is not customized, it returns the system default list.

The response is either an
`EnterpriseSecurityClassificationCustomizationGetAvailableListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `EnterpriseSessionAdmissionControlGroupDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete one or more session admission control groups for the enterprise.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|name                |List[str] |name              |
</div>


## `EnterpriseSessionAdmissionControlGroupGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of session admission control group for the enterprise.

The response is either an `EnterpriseSessionAdmissionControlGroupGetListResponse()` or
an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `EnterpriseSessionAdmissionControlGroupGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a session admission control group for the enterprise.

The response is either an `EnterpriseSessionAdmissionControlGroupGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|name                |str |name              |
</div>


## `EnterpriseSessionAdmissionControlGroupGetRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a session admission control group for the enterprise.

The response is either an `EnterpriseSessionAdmissionControlGroupGetResponse19sp1()`
or an `ErrorResponse()`. Replaced by:
`EnterpriseSessionAdmissionControlGroupGetRequest21sp1()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|name                |str |name              |
</div>


## `EnterpriseSessionAdmissionControlGroupGetRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a session admission control group for the enterprise.

The response is either an `EnterpriseSessionAdmissionControlGroupGetResponse21sp1()`
or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|name                |str |name              |
</div>


## `EnterpriseVoiceVPNDeletePolicyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a enterprise voice VPN location.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                  |Type|Description         |
|----------------------|----|--------------------|
|service_provider_id   |str |serviceProviderId   |
|location_dialing_code |str |locationDialingCode |
</div>


## `EnterpriseVoiceVPNGetDefaultRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the Voice VPN default settings for the enterprise.

The response is `EnterpriseVoiceVPNGetDefaultResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `EnterpriseVoiceVPNGetPolicyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the enterprise level data associated with Voice VPN location code.

The response is either a `EnterpriseVoiceVPNGetPolicyResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                  |Type|Description         |
|----------------------|----|--------------------|
|service_provider_id   |str |serviceProviderId   |
|location_dialing_code |str |locationDialingCode |
</div>


## `EnterpriseVoiceVPNGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the enterprise level data associated with Voice VPN.

The response is either a `EnterpriseVoiceVPNGetResponse()` or an `ErrorResponse()`.

Replaced By: `EnterpriseVoiceVPNGetRequest14sp3()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `EnterpriseVoiceVPNGetRequest14sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the enterprise level data associated with Voice VPN.

The response is either a `EnterpriseVoiceVPNGetResponse14sp3()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `EnterpriseVoiceVPNModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the enterprise voice VPN level data associated with voice VPN.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type |Description                 |
|--------------------|-----|----------------------------|
|service_provider_id |str  |serviceProviderId           |
|is_active           |bool |isActive *Optional*         |
|default_selection   |str  |defaultSelection *Optional* |
|e164_selection      |str  |e164Selection *Optional*    |
|use_phone_context   |bool |usePhoneContext *Optional*  |
</div>


## `ExternalAuthenticationAuthorizeTokenRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
This command is part of the Portal API.

Sent when a Web or CLI user logs in using external authentication.  The password must
be hashed.  The password hashing algorithm is: 1) The message digest of the user's
plain password is calculated using the SHA algorithm.  2) For every four bits in the
160-bit digest, starting from the first bit, it is converted into a character in ASCII
Hex format (0 through 9, a through f). The result is a 40-character string, for
example, f7a9e24777ec23212c54d7a350bc5bea5477fdbb.  3) The above string then is used
to populate the password field in the request.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description         |
|------------|----|--------------------|
|user_id     |str |userId              |
|password    |str |password *Optional* |
|login_token |str |loginToken          |
</div>


## `ExternalAuthenticationAuthorizeTokenRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
This command is part of the Portal API.

Sent when a Web or CLI user logs in using external authentication.  The hashed
password value in the request is supported only when the request is sent from the
CommPilot web portal.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name               |Type |Description                 |
|-------------------|-----|----------------------------|
|user_id            |str  |userId                      |
|password           |str  |password *Optional*         |
|is_password_hashed |bool |isPasswordHashed *Optional* |
|login_token        |str  |loginToken                  |
</div>


## `ExternalAuthenticationCreateLoginTokenRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
This command allows a BroadWorks or Third-Party Client Application to create a Single
Sign-On token for a user.

The response is either `ExternalAuthenticationCreateLoginTokenResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `GroupAccessDeviceCustomTagAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a static configuration tag for a group access device.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description         |
|--------------------|----|--------------------|
|service_provider_id |str |serviceProviderId   |
|group_id            |str |groupId             |
|device_name         |str |deviceName          |
|tag_name            |str |tagName             |
|tag_value           |str |tagValue *Optional* |
</div>


## `GroupAccessDeviceCustomTagDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete static configuration tags for a group access device.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|group_id            |str       |groupId           |
|device_name         |str       |deviceName        |
|tag_name            |List[str] |tagName           |
</div>


## `GroupAccessDeviceCustomTagGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of custom configuration tags managed by the Device Management
System, on a per-device profile basis.

The response is either `GroupAccessDeviceCustomTagGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|device_name         |str |deviceName        |
</div>


## `GroupAccessDeviceCustomTagModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a static configuration tag for a group access device.

The tagValueToEncrypt element can only be used by a system administrator.  The
following elements are only used in XS data mode and ignored in AS data mode:
tagValueToEncrypt

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                 |Type|Description                  |
|---------------------|----|-----------------------------|
|service_provider_id  |str |serviceProviderId            |
|group_id             |str |groupId                      |
|device_name          |str |deviceName                   |
|tag_name             |str |tagName                      |
|tag_value            |str |tagValue *Optional*          |
|tag_value_to_encrypt |str |tagValueToEncrypt *Optional* |
</div>


## `GroupAccessDeviceDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a specified group access device.

The following elements are only used in AS data mode and ignored in XS data mode:
deviceExternalId

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description                  |
|--------------------|----|-----------------------------|
|service_provider_id |str |serviceProviderId *Optional* |
|group_id            |str |groupId *Optional*           |
|device_name         |str |deviceName *Optional*        |
|device_external_id  |str |deviceExternalId *Optional*  |
</div>


## `GroupAccessDeviceDeviceActivationGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the activation information for a device configured at the Group level.

Returns a `GroupAccessDeviceDeviceActivationGetResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|device_name         |str |deviceName        |
</div>


## `GroupAccessDeviceDeviceActivationModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Activates or deactivates a device configured at the Group level.

It is only possible for this request to activate a device which is deactivated.
Trying to activate a device in the activating state will result in an error response
since only the DAS is allowed to execute this operation.  Returns a
`SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type |Description       |
|--------------------|-----|------------------|
|service_provider_id |str  |serviceProviderId |
|group_id            |str  |groupId           |
|device_name         |str  |deviceName        |
|activate_device     |bool |activateDevice    |
</div>


## `GroupAccessDeviceFileGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of device files managed by the Device Management System, on a
per-device profile basis.

The response is either `GroupAccessDeviceFileGetListResponse()` or `ErrorResponse()`.

Replaced By: `GroupAccessDeviceFileGetListRequest14sp8()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|device_name         |str |deviceName        |
</div>


## `GroupAccessDeviceFileGetListRequest14sp8`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of device files managed by the Device Management System, on a
per-device profile basis.

The response is either `GroupAccessDeviceFileGetListResponse14sp8()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|device_name         |str |deviceName        |
</div>


## `GroupAccessDeviceFileGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a group device profile file.

The response is either `GroupAccessDeviceFileGetResponse()` or `ErrorResponse()`.

Replaced By: `GroupAccessDeviceFileGetRequest14sp8()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|device_name         |str |deviceName        |
|file_type           |str |fileType          |
</div>


## `GroupAccessDeviceFileGetRequest14sp8`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a group device profile file.

The response is either `GroupAccessDeviceFileGetResponse14sp8()` or `ErrorResponse()`.
Replaced by: `GroupAccessDeviceFileGetRequest16sp1()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|device_name         |str |deviceName        |
|file_format         |str |fileFormat        |
</div>


## `GroupAccessDeviceFileGetRequest16sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a group device profile file.

The response is either `GroupAccessDeviceFileGetResponse16sp1()` or `ErrorResponse()`.
Replaced by: `GroupAccessDeviceFileGetRequest20()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|device_name         |str |deviceName        |
|file_format         |str |fileFormat        |
</div>


## `GroupAccessDeviceFileGetRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a group device profile file.

The response is either `GroupAccessDeviceFileGetResponse20()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|device_name         |str |deviceName        |
|file_format         |str |fileFormat        |
</div>


## `GroupAccessDeviceGenerateActivationCodeRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests a new activation code for a device configured at the Group level.

Returns a `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|device_name         |str |deviceName        |
</div>


## `GroupAccessDeviceGetAvailableCustomTagListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of all available custom tags managed by the Device Management System, on
a per-device profile basis.

The response is either `GroupAccessDeviceGetAvailableCustomTagListResponse()` or
`ErrorResponse()`. The following elements are used in AS mode and ignored in XS data
mode: tagSetName

**Attributes:**

|Name                |Type|Description           |
|--------------------|----|----------------------|
|service_provider_id |str |serviceProviderId     |
|group_id            |str |groupId               |
|device_name         |str |deviceName            |
|tag_set_name        |str |tagSetName *Optional* |
</div>


## `GroupAccessDeviceGetAvailableDetailListRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of available access devices for assignment to a user within a group.

The list includes devices created at the system, service provider, and group levels.

The response is either `GroupAccessDeviceGetAvailableDetailListResponse14()` or
`ErrorResponse()`. Replaced by: `GroupAccessDeviceGetAvailableDetailListRequest19()`.

**Attributes:**

|Name                |Type |Description       |
|--------------------|-----|------------------|
|service_provider_id |str  |serviceProviderId |
|group_id            |str  |groupId           |
|is_music_on_hold    |bool |isMusicOnHold     |
|only_video_capable  |bool |onlyVideoCapable  |
</div>


## `GroupAccessDeviceGetAvailableDetailListRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of available access devices for assignment to a user within a group.

The list includes devices created at the system, service provider, and group levels.

The response is either `GroupAccessDeviceGetAvailableDetailListResponse19()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type |Description       |
|--------------------|-----|------------------|
|service_provider_id |str  |serviceProviderId |
|group_id            |str  |groupId           |
|is_music_on_hold    |bool |isMusicOnHold     |
|only_video_capable  |bool |onlyVideoCapable  |
</div>


## `GroupAccessDeviceGetEnhancedConfigurationTypeListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of configurable device types of devices that have already been added
to the group.

The response is either `GroupAccessDeviceGetEnhancedConfigurationTypeListResponse()`
or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupAccessDeviceGetEnhancedConfigurationTypeRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the details of a specified configurable device type for a group.

The response is either `GroupAccessDeviceGetEnhancedConfigurationTypeResponse14()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|device_type         |str |deviceType        |
</div>


## `GroupAccessDeviceGetLinkedLeafDeviceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of linked leaf devices for the group level tree device passed in the
request.

A tree device is a device associated with a device type that has the option
supportLinks set to "Support Links from Devices". Many leaf devices can be linked to
it.  A leaf device is a device associated with a device type that has the option
supportLinks set to "Support Link to Device". It can be linked to only one tree
device.  The list includes devices created at the system, service provider, and group
levels.

The response is either `GroupAccessDeviceGetLinkedLeafDeviceListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|device_name         |str |deviceName        |
</div>


## `GroupAccessDeviceGetLinkedTreeDeviceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the tree device linked with the group level leaf device passed in the
request.

A tree device is a device associated with a device type that has the option
supportLinks set to "Support Links from Devices". Many leaf devices can be linked to
it.  A leaf device is a device associated with a device type that has the option
supportLinks set to "Support Link to Device". It can be linked to only one tree
device.

The response is either `GroupAccessDeviceGetLinkedTreeDeviceResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|device_name         |str |deviceName        |
</div>


## `GroupAccessDeviceGetNativeTagsWithLogicListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of all native tags with logic managed by the Device Management System, on
a per-device profile basis.

The response is either `GroupAccessDeviceGetAvailableCustomTagListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|device_name         |str |deviceName        |
</div>


## `GroupAccessDeviceGetRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the configuration of a specified group access device.

The response is either `GroupAccessDeviceGetResponse14()` or `ErrorResponse()`.

Replaced By: `GroupAccessDeviceGetRequest14sp3()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|device_name         |str |deviceName        |
</div>


## `GroupAccessDeviceGetRequest14sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the configuration of a specified group access device.

The response is either `GroupAccessDeviceGetResponse14sp3()` or `ErrorResponse()`.

Replaced By: `GroupAccessDeviceGetRequest14sp6()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|device_name         |str |deviceName        |
</div>


## `GroupAccessDeviceGetRequest14sp6`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the configuration of a specified group access device.

The response is either `GroupAccessDeviceGetResponse14sp6()` or `ErrorResponse()`.
Replaced by: `GroupAccessDeviceGetRequest16()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|device_name         |str |deviceName        |
</div>


## `GroupAccessDeviceGetRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the configuration of a specified group access device.

The response is either `GroupAccessDeviceGetResponse16()` or `ErrorResponse()`.
Replaced by: `GroupAccessDeviceGetRequest18sp1()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|device_name         |str |deviceName        |
</div>


## `GroupAccessDeviceGetRequest18sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the configuration of a specified group access device.

The response is either `GroupAccessDeviceGetResponse18sp1()` or `ErrorResponse()`.
Replaced by: `GroupAccessDeviceGetRequest22()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|device_name         |str |deviceName        |
</div>


## `GroupAccessDeviceGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the configuration of a specified group access device.

The response is either `GroupAccessDeviceGetResponse22()` or `ErrorResponse()`.
Replaced by: `GroupAccessDeviceGetRequest24()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|device_name         |str |deviceName        |
</div>


## `GroupAccessDeviceGetRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the configuration of a specified group access device.

The response is either `GroupAccessDeviceGetResponse22V2()` or `ErrorResponse()`. The
following elements are only used in AS data mode and ignored in XS data mode:
deviceExternalId Replaced by: `GroupAccessDeviceGetRequest24()` in AS data mode.

**Attributes:**

|Name                |Type|Description                  |
|--------------------|----|-----------------------------|
|service_provider_id |str |serviceProviderId *Optional* |
|group_id            |str |groupId *Optional*           |
|device_name         |str |deviceName *Optional*        |
|device_external_id  |str |deviceExternalId *Optional*  |
</div>


## `GroupAccessDeviceGetRequest22V3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the configuration of a specified group access device.

The response is either `GroupAccessDeviceGetResponse22V3()` or `ErrorResponse()`.
Replaced by: `GroupAccessDeviceGetRequest24()`

**Attributes:**

|Name                |Type|Description                  |
|--------------------|----|-----------------------------|
|service_provider_id |str |serviceProviderId *Optional* |
|group_id            |str |groupId *Optional*           |
|device_name         |str |deviceName *Optional*        |
|device_external_id  |str |deviceExternalId *Optional*  |
</div>


## `GroupAccessDeviceGetRequest24`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the configuration of a specified group access device.

The response is either `GroupAccessDeviceGetResponse24()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description                  |
|--------------------|----|-----------------------------|
|service_provider_id |str |serviceProviderId *Optional* |
|group_id            |str |groupId *Optional*           |
|device_name         |str |deviceName *Optional*        |
|device_external_id  |str |deviceExternalId *Optional*  |
</div>


## `GroupAccessDeviceModifyUserRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify attributes for line/ports assigned on the group device profile.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in XS data mode and ignored in AS data mode: privateIdentity

**Attributes:**

|Name                 |Type |Description                  |
|---------------------|-----|-----------------------------|
|service_provider_id  |str  |serviceProviderId            |
|group_id             |str  |groupId                      |
|device_name          |str  |deviceName                   |
|line_port            |str  |linePort                     |
|private_identity     |str  |privateIdentity *Optional*   |
|is_primary_line_port |bool |isPrimaryLinePort *Optional* |
</div>


## `GroupAccessDeviceResetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Reset a specific group SIP device that supports the reset operation.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|device_name         |str |deviceName        |
</div>


## `GroupAccessDeviceTagSetGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the custom configuration tag set defined at the access device.

The response is either `GroupAccessDeviceTagSetGetResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|device_name         |str |deviceName        |
</div>


## `GroupAccessDeviceTagSetModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a static configuration tag set.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description           |
|--------------------|----|----------------------|
|service_provider_id |str |serviceProviderId     |
|group_id            |str |groupId               |
|device_name         |str |deviceName            |
|tag_set_name        |str |tagSetName *Optional* |
</div>


## `GroupAccountAuthorizationCodesDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a list of account/authorization codes from a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|group_id            |str       |groupId           |
|code                |List[str] |code              |
</div>


## `GroupAccountAuthorizationCodesGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the list of account/authorization codes for a group.

The response is either a `GroupAccountAuthorizationCodesGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupAccountAuthorizationCodesGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group's account/authorization codes setting.

The response is either a `GroupAccountAuthorizationCodesGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupAdminAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a group administrator.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description          |
|--------------------|----|---------------------|
|service_provider_id |str |serviceProviderId    |
|group_id            |str |groupId              |
|user_id             |str |userId               |
|first_name          |str |firstName *Optional* |
|last_name           |str |lastName *Optional*  |
|password            |str |password *Optional*  |
|language            |str |language *Optional*  |
</div>


## `GroupAdminAlternateIdAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add an alternate admin Id to a group administrator.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name              |Type|Description            |
|------------------|----|-----------------------|
|user_id           |str |userId                 |
|alternate_user_id |str |alternateUserId        |
|description       |str |description *Optional* |
</div>


## `GroupAdminAlternateIdDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete an alternate admin user id of a group administrator.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name              |Type|Description     |
|------------------|----|----------------|
|user_id           |str |userId          |
|alternate_user_id |str |alternateUserId |
</div>


## `GroupAdminAlternateIdGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the admin id and the list of alternate admin ids of an admin.

The response is either `GroupAdminAlternateIdGetListResponse()` or `ErrorResponse()`.
The "userId" can be either the admin user Id or an alternate admin user Id.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `GroupAdminAlternateIdModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify an alternate id of a group admin.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                  |Type|Description                   |
|----------------------|----|------------------------------|
|user_id               |str |userId                        |
|alternate_user_id     |str |alternateUserId               |
|new_alternate_user_id |str |newAlternateUserId *Optional* |
|description           |str |description *Optional*        |
</div>


## `GroupAdminDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a group administrator.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `GroupAdminGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of group and department administrators within the group.

The response is either a `GroupAdminGetListResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupAdminGetPolicyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the Group administrator's policy settings.

The response is either `GroupAdminGetPolicyResponse()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `GroupAdminGetPolicyRequest14sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the Group administrator's policy settings.

The response is either `GroupAdminGetPolicyResponse14sp1()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `GroupAdminGetPolicyRequest16sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the Group administrator's policy settings.

The response is either `GroupAdminGetPolicyResponse16sp1()` or `ErrorResponse()`.
Replaced by: `GroupAdminGetPolicyRequest17()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `GroupAdminGetPolicyRequest16sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the Group administrator's policy settings.

The response is either `GroupAdminGetPolicyResponse16sp2()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `GroupAdminGetPolicyRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the Group administrator's policy settings.

The response is either `GroupAdminGetPolicyResponse17()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `GroupAdminGetPolicyRequest17sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the Group administrator's policy settings.

The response is either `GroupAdminGetPolicyResponse17sp3()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `GroupAdminGetPolicyRequest18`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the Group administrator's policy settings.

The response is either `GroupAdminGetPolicyResponse18()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `GroupAdminGetPolicyRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the Group administrator's policy settings.

The response is either `GroupAdminGetPolicyResponse19sp1()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `GroupAdminGetPolicyRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the Group administrator's policy settings.

The response is either `GroupAdminGetPolicyResponse20()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `GroupAdminGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a group administrators profile.

The response is either a `GroupAdminGetResponse()` or an `ErrorResponse()`. Replaced
by `GroupAdminGetRequest21sp1()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `GroupAdminGetRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a group administrators profile.

The response is either a `GroupAdminGetResponse21sp1()` or an `ErrorResponse()`.
Replaced by: `GroupAdminGetRequest22()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `GroupAdminGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a group administrators profile.

The response is either a `GroupAdminGetResponse22()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `GroupAdminModifyPolicyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the group administrator's policy settings.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in AS data mode: dialableCallerIDAccess
verifyTranslationAndRoutingAccess communicationBarringUserProfileAccess (only
applicable to groups in an Enterprise)

**Attributes:**

|Name                                      |Type|Description                                      |
|------------------------------------------|----|-------------------------------------------------|
|user_id                                   |str |userId                                           |
|profile_access                            |str |profileAccess *Optional*                         |
|user_access                               |str |userAccess *Optional*                            |
|admin_access                              |str |adminAccess *Optional*                           |
|department_access                         |str |departmentAccess *Optional*                      |
|access_device_access                      |str |accessDeviceAccess *Optional*                    |
|enhanced_service_instance_access          |str |enhancedServiceInstanceAccess *Optional*         |
|feature_access_code_access                |str |featureAccessCodeAccess *Optional*               |
|phone_number_extension_access             |str |phoneNumberExtensionAccess *Optional*            |
|calling_line_id_number_access             |str |callingLineIdNumberAccess *Optional*             |
|service_access                            |str |serviceAccess *Optional*                         |
|trunk_group_access                        |str |trunkGroupAccess *Optional*                      |
|session_admission_control_access          |str |sessionAdmissionControlAccess *Optional*         |
|office_zone_access                        |str |officeZoneAccess *Optional*                      |
|dialable_caller_id_access                 |str |dialableCallerIDAccess *Optional*                |
|number_activation_access                  |str |numberActivationAccess *Optional*                |
|verify_translation_and_routing_access     |str |verifyTranslationAndRoutingAccess *Optional*     |
|communication_barring_user_profile_access |str |communicationBarringUserProfileAccess *Optional* |
</div>


## `GroupAdminModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a group administrator.

Since old password is not specified here, any password rule related to old password
does not apply.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name       |Type|Description          |
|-----------|----|---------------------|
|user_id    |str |userId               |
|first_name |str |firstName *Optional* |
|last_name  |str |lastName *Optional*  |
|password   |str |password *Optional*  |
|language   |str |language *Optional*  |
</div>


## `GroupAdministratorPasswordRulesGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the effective password rules setting for a group administrator.

The response is either `GroupAdministratorPasswordRulesGetResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupAdviceOfChargeGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of Advice of Charge group parameters.

The response is either `GroupAdviceOfChargeGetResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupAdviceOfChargeModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the service provider level Advice Of Charge group settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                               |Type |Description                                |
|-----------------------------------|-----|-------------------------------------------|
|service_provider_id                |str  |serviceProviderId                          |
|group_id                           |str  |groupId                                    |
|use_group_level_ao_c_settings      |bool |useGroupLevelAoCSettings *Optional*        |
|delay_between_notification_seconds |int  |delayBetweenNotificationSeconds *Optional* |
</div>


## `GroupAnnouncementRepositoryGetSettingsRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Return the disk space being used.


**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupApplicationServerSetGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the Application Server set for a group.

The response is either a `GroupApplicationServerSetGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupApplicationServerSetModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Application Server set for a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                        |Type|Description                         |
|----------------------------|----|------------------------------------|
|service_provider_id         |str |serviceProviderId                   |
|group_id                    |str |groupId                             |
|application_server_set_name |str |applicationServerSetName *Optional* |
</div>


## `GroupAutoAttendantConsolidatedDeleteInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Auto Attendant instance from a group and free up phone numbers.

If UnassignPhoneNumbersLevel is set to 'Group', the user's primary phone number, fax
number and any alternate numbers, will be un-assigned from the group if the command is
executed by a service provider administrator or above.  When set to 'Service
Provider', they will be un-assigned from the group and service provider if the command
is executed by a provisioning administrator or above.  When omitted, the number(s)
will be left assigned to the group.  An `ErrorResponse()` will be returned if any
number cannot be unassigned because of insufficient privilege.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                   |Type|Description                     |
|-----------------------|----|--------------------------------|
|service_user_id        |str |serviceUserId                   |
|unassign_phone_numbers |str |unassignPhoneNumbers *Optional* |
</div>


## `GroupAutoAttendantDeleteInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Auto Attendant instance from a group.

If UnassignPhoneNumbersLevel is set to 'Group', the user's primary phone number, fax
number and any alternate numbers, will be unassigned from the group if the command is
executed by a service provider administrator or above.  When set to 'Service
Provider', they will be unassigned from the group and service provider if the command
is executed by a provisioning administrator or above.  When omitted, the number(s)
will be left assigned to the group.  An `ErrorResponse()` with the type warning will
be returned if any number cannot be unassigned because of insufficient privilege.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupAutoAttendantGetInstanceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of Auto Attendant instances within a group.

The response is either `GroupAutoAttendantGetInstanceListResponse()` or
`ErrorResponse()`. It is possible to get the instances within a specified department.

**Attributes:**

|Name                  |Type|Description                    |
|----------------------|----|-------------------------------|
|service_provider_id   |str |serviceProviderId              |
|group_id              |str |groupId                        |
|group_department_name |str |groupDepartmentName *Optional* |
</div>


## `GroupAutoAttendantGetInstanceRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Auto Attendant instance.

The response is either `GroupAutoAttendantGetInstanceResponse()` or `ErrorResponse()`.

Replaced By: `GroupAutoAttendantGetInstanceRequest16()`

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupAutoAttendantGetInstanceRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Auto Attendant instance.

The response is either `GroupAutoAttendantGetInstanceResponse16()` or
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupAutoAttendantGetInstanceRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Auto Attendant instance.

The response is either `GroupAutoAttendantGetInstanceResponse17()` or
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupAutoAttendantGetInstanceRequest17sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Auto Attendant instance.

The response is either `GroupAutoAttendantGetInstanceResponse17sp1()` or
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupAutoAttendantGetInstanceRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Auto Attendant instance.

The response is either `GroupAutoAttendantGetInstanceResponse19()` or
`ErrorResponse()`. Replaced by: `GroupAutoAttendantGetInstanceRequest19sp1()` in AS
data mode

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupAutoAttendantGetInstanceRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Auto Attendant instance.

The response is either `GroupAutoAttendantGetInstanceResponse19sp1()` or
`ErrorResponse()`. Replaced by: `GroupAutoAttendantGetInstanceRequest20()` in AS data
mode

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupAutoAttendantGetInstanceRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Auto Attendant instance.

The response is either `GroupAutoAttendantGetInstanceResponse20()` or
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupAutoAttendantSubmenuDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a submenu form an auto attendant.

The response is either `SuccessResponse()` or `ErrorResponse()`. This request is only
valid for Standard auto attendants.

**Attributes:**

|Name            |Type      |Description   |
|----------------|----------|--------------|
|service_user_id |str       |serviceUserId |
|submenu_id      |List[str] |submenuId     |
</div>


## `GroupAutoAttendantSubmenuGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of Auto Attendant Submenus.

The response is either `GroupAutoAttendantSubmenuGetListResponse()` or
`ErrorResponse()`. This request is only valid for Standard auto attendants.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupAutoAttendantSubmenuGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get an Auto Attendant submenu instance.

The response is either `GroupAutoAttendantSubmenuGetResponse()` or `ErrorResponse()`.
This request is only valid for Standard auto attendants.  Replaced by:
`GroupAutoAttendantSubmenuGetRequest20()` in AS data mode

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
|submenu_id      |str |submenuId     |
</div>


## `GroupAutoAttendantSubmenuGetRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get an Auto Attendant submenu instance.

The response is either `GroupAutoAttendantSubmenuGetResponse20()` or
`ErrorResponse()`. This request is only valid for Standard auto attendants.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
|submenu_id      |str |submenuId     |
</div>


## `GroupAutoAttendantSubmenuGetUsageListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of Auto Attendant Business Hours Menu,After Hours Menu,Holiday Menu and
Submenus that use this submenu.

The response is either `GroupAutoAttendantSubmenuGetUsageListResponse()` or
`ErrorResponse()`. This request is only valid for Standard auto attendants.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
|submenu_id      |str |submenuId     |
</div>


## `GroupBroadWorksAnywhereDeleteInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a BroadWorks Anywhere instance from a group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupBroadWorksAnywhereGetInstanceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of BroadWorks Anywhere instances within a group.

The response is either `GroupBroadWorksAnywhereGetInstanceListResponse()` or
`ErrorResponse()`. It is possible to get the instances within a specified department.

**Attributes:**

|Name                  |Type|Description                    |
|----------------------|----|-------------------------------|
|service_provider_id   |str |serviceProviderId              |
|group_id              |str |groupId                        |
|group_department_name |str |groupDepartmentName *Optional* |
</div>


## `GroupBroadWorksAnywhereGetInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a BroadWorks Anywhere instance.

The response is either `GroupBroadWorksAnywhereGetInstanceResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupBroadWorksAnywhereGetInstanceRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a BroadWorks Anywhere instance.

The response is either `GroupBroadWorksAnywhereGetInstanceResponse17()` or
`ErrorResponse()`. Replaced by: `GroupBroadWorksAnywhereGetInstanceRequest19sp1()` in
AS data mode

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupBroadWorksAnywhereGetInstanceRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a BroadWorks Anywhere instance.

The response is either `GroupBroadWorksAnywhereGetInstanceResponse19sp1()` or
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupBroadWorksMobileManagerActivationRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Activates or Deactivates the BroadWorks Mobile Manager.

The deactivationReason is required when isActive is set to false.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type |Description                   |
|--------------------|-----|------------------------------|
|service_provider_id |str  |serviceProviderId             |
|group_id            |str  |groupId                       |
|is_active           |bool |isActive                      |
|deactivation_reason |str  |deactivationReason *Optional* |
</div>


## `GroupBroadWorksMobileManagerAddHomeZoneRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a home zone to the BroadWorks Mobile Manager.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                  |Type|Description        |
|----------------------|----|-------------------|
|service_provider_id   |str |serviceProviderId  |
|group_id              |str |groupId            |
|home_zone_domain_name |str |homeZoneDomainName |
|mobile_country_code   |str |mobileCountryCode  |
|mobile_network_code   |str |mobileNetworkCode  |
|location_area_code    |str |locationAreaCode   |
|cell_identity         |str |cellIdentity       |
</div>


## `GroupBroadWorksMobileManagerAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add the BroadWorks Mobile Manager.

Only one BroadWorks Mobile Manager can be added per group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                            |Type |Description                  |
|--------------------------------|-----|-----------------------------|
|service_provider_id             |str  |serviceProviderId            |
|group_id                        |str  |groupId                      |
|information_file                |str  |informationFile              |
|certificate_file                |str  |certificateFile              |
|is_active                       |bool |isActive                     |
|local_to_carrier                |bool |localToCarrier               |
|max_tx_per_second_enabled       |bool |maxTxPerSecondEnabled        |
|max_tx_per_second               |int  |maxTxPerSecond *Optional*    |
|tldn_enabled                    |bool |tldnEnabled                  |
|generic_number_enabled          |bool |genericNumberEnabled         |
|mobile_state_check_enabled      |bool |mobileStateCheckEnabled      |
|location_based_services_enabled |bool |locationBasedServicesEnabled |
</div>


## `GroupBroadWorksMobileManagerDeleteHomeZoneListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a list of home zones from the BroadWorks Mobile Manager.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|group_id            |str       |groupId           |
|home_zone_id        |List[str] |homeZoneId        |
</div>


## `GroupBroadWorksMobileManagerDeleteHomeZoneRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a home zone from the BroadWorks Mobile Manager.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|home_zone_id        |str |homeZoneId        |
</div>


## `GroupBroadWorksMobileManagerDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete the BroadWorks Mobile Manager.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupBroadWorksMobileManagerGetDomainListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of domains of the BroadWorks Mobile Manager.

The response is either `GroupBroadWorksMobileManagerGetDomainListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupBroadWorksMobileManagerGetHomeZoneListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of home zones of the BroadWorks Mobile Manager.

The response is either `GroupBroadWorksMobileManagerGetHomeZoneListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupBroadWorksMobileManagerGetHomeZoneRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a home zone from the BroadWorks Mobile Manager.

The response is either `GroupBroadWorksMobileManagerGetHomeZoneResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|home_zone_id        |str |homeZoneId        |
</div>


## `GroupBroadWorksMobileManagerGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the BroadWorks Mobile Manager.

The response is either `GroupBroadWorksMobileManagerGetResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupBroadWorksMobileManagerModifyHomeZoneRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an existing home zone in the BroadWorks Mobile Manager.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                  |Type|Description                   |
|----------------------|----|------------------------------|
|service_provider_id   |str |serviceProviderId             |
|group_id              |str |groupId                       |
|home_zone_id          |str |homeZoneId                    |
|home_zone_domain_name |str |homeZoneDomainName *Optional* |
|mobile_country_code   |str |mobileCountryCode *Optional*  |
|mobile_network_code   |str |mobileNetworkCode *Optional*  |
|location_area_code    |str |locationAreaCode *Optional*   |
|cell_identity         |str |cellIdentity *Optional*       |
</div>


## `GroupBroadWorksMobileManagerModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the BroadWorks Mobile Manager settings.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                            |Type |Description                             |
|--------------------------------|-----|----------------------------------------|
|service_provider_id             |str  |serviceProviderId                       |
|group_id                        |str  |groupId                                 |
|information_file                |str  |informationFile *Optional*              |
|certificate_file                |str  |certificateFile *Optional*              |
|local_to_carrier                |bool |localToCarrier *Optional*               |
|max_tx_per_second_enabled       |bool |maxTxPerSecondEnabled *Optional*        |
|max_tx_per_second               |int  |maxTxPerSecond *Optional*               |
|tldn_enabled                    |bool |tldnEnabled *Optional*                  |
|generic_number_enabled          |bool |genericNumberEnabled *Optional*         |
|mobile_state_check_enabled      |bool |mobileStateCheckEnabled *Optional*      |
|location_based_services_enabled |bool |locationBasedServicesEnabled *Optional* |
</div>


## `GroupBroadWorksMobileManagerSendCarrierFilesRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Sends an email with the carrier information and certificate files.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|email_to            |str |emailTo           |
</div>


## `GroupBroadWorksMobilityGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the groups BroadWorks Mobility settings.

The response is either a `GroupBroadWorksMobilityGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupBroadWorksMobilityGetRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the group's BroadWorks Mobility settings.

The response is either a `GroupBroadWorksMobilityGetResponse19sp1()` or an
`ErrorResponse()`. Replaced by: `GroupBroadWorksMobilityGetRequest22()` in AS data
mode

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupBroadWorksMobilityGetRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the group's BroadWorks Mobility settings.

The response is either a `GroupBroadWorksMobilityGetResponse21sp1()` or an
`ErrorResponse()`. Replaced by `GroupBroadWorksMobilityGetRequest22V2()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupBroadWorksMobilityGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the group's BroadWorks Mobility settings.

The response is either a `GroupBroadWorksMobilityGetResponse22()` or an
`ErrorResponse()`. Replaced by `GroupBroadWorksMobilityGetRequest22V2()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupBroadWorksMobilityGetRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the group's BroadWorks Mobility settings.

The response is either a `GroupBroadWorksMobilityGetResponse22V2()` or an
`ErrorResponse()`. Replaced by `GroupBroadWorksMobilityGetRequest22V3()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupBroadWorksMobilityGetRequest22V3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the group's BroadWorks Mobility settings.

The response is either a `GroupBroadWorksMobilityGetResponse22V3()` or an
`ErrorResponse()`. Replaced by `GroupBroadWorksMobilityGetRequest22V4()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupBroadWorksMobilityGetRequest22V4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the group's BroadWorks Mobility settings.

The response is either a `GroupBroadWorksMobilityGetResponse22V4()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupBroadWorksMobilityMobileSubscriberDirectoryNumberAssignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Assign Mobile Subscriber Directory Numbers to a group.

It is possible to add a single DN,or a list of DNs.  . This command is applicable only
for group in a service provider and will fail for a group in an enterprise.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                               |Type      |Description                                |
|-----------------------------------|----------|-------------------------------------------|
|service_provider_id                |str       |serviceProviderId                          |
|group_id                           |str       |groupId                                    |
|mobile_subscriber_directory_number |List[str] |mobileSubscriberDirectoryNumber *Optional* |
</div>


## `GroupBroadWorksMobilityMobileSubscriberDirectoryNumberGetAvailableListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a list of available Mobile Subscriber Directory Numbers not yet assigned to
any user.

. This command is applicable only for group in a service provider and will fail for a
group in an enterprise.

The response is either
`GroupBroadWorksMobilityMobileSubscriberDirectoryNumberGetAvailableListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupBroadWorksMobilityMobileSubscriberDirectoryNumberUnassignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Unassign Mobile Subscriber Directory Numbers from a group.

It is possible to unassign either: a single DN, or a list of DNs.  . This command is
applicable only for group in a service provider and will fail for a group in an
enterprise.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                               |Type      |Description                                |
|-----------------------------------|----------|-------------------------------------------|
|service_provider_id                |str       |serviceProviderId                          |
|group_id                           |str       |groupId                                    |
|mobile_subscriber_directory_number |List[str] |mobileSubscriberDirectoryNumber *Optional* |
</div>


## `GroupCPEConfigRebuildConfigFileRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Rebuild the group default config file for the specified device type.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type |Description       |
|--------------------|-----|------------------|
|service_provider_id |str  |serviceProviderId |
|group_id            |str  |groupId           |
|device_type         |str  |deviceType        |
|force               |bool |force *Optional*  |
</div>


## `GroupCPEConfigRebuildDeviceConfigFileRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Rebuild the config file for a specified device.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode: force

**Attributes:**

|Name                |Type |Description       |
|--------------------|-----|------------------|
|service_provider_id |str  |serviceProviderId |
|group_id            |str  |groupId           |
|device_name         |str  |deviceName        |
|force               |bool |force *Optional*  |
</div>


## `GroupCPEConfigReorderDeviceLinePortsRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Reorder the lines of a group device.

You can not add or delete line ports, only re-ordering the list is allowed.  The
ordered list of line ports can be obtained with the `GroupAccessDeviceGetRequest16()`
command.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type      |Description         |
|-----------------------|----------|--------------------|
|service_provider_id    |str       |serviceProviderId   |
|group_id               |str       |groupId             |
|device_name            |str       |deviceName          |
|ordered_line_port_list |List[str] |orderedLinePortList |
</div>


## `GroupCPEConfigResetDeviceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Reset a specific group device.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|device_name         |str |deviceName        |
</div>


## `GroupCPEConfigResetDeviceTypeRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Reset all the devices of the specified device type in a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|device_type         |str |deviceType        |
</div>


## `GroupCallCapacityManagementAddInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Adds a Call Capacity Management group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                               |Type      |Description                              |
|-----------------------------------|----------|-----------------------------------------|
|service_provider_id                |str       |serviceProviderId                        |
|group_id                           |str       |groupId                                  |
|name                               |str       |name                                     |
|max_active_calls_allowed           |int       |maxActiveCallsAllowed                    |
|max_incoming_active_calls_allowed  |int       |maxIncomingActiveCallsAllowed *Optional* |
|max_outgoing_active_calls_allowed  |int       |maxOutgoingActiveCallsAllowed *Optional* |
|become_default_group_for_new_users |bool      |becomeDefaultGroupForNewUsers            |
|user_id                            |List[str] |userId *Optional*                        |
</div>


## `GroupCallCapacityManagementAddUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Adds one or more users to a Call Capacity Management group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|group_id            |str       |groupId           |
|name                |str       |name              |
|user_id             |List[str] |userId            |
</div>


## `GroupCallCapacityManagementDeleteInstanceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Deletes one or more Call Capacity Management groups.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|group_id            |str       |groupId           |
|name                |List[str] |name              |
</div>


## `GroupCallCapacityManagementDeleteUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Deletes one or more users from a Call Capacity Management group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|group_id            |str       |groupId           |
|name                |str       |name              |
|user_id             |List[str] |userId            |
</div>


## `GroupCallCapacityManagementGetInstanceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a list of Call Capacity Management instances within a group.

The response is either `GroupCallCapacityManagementGetInstanceListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallCapacityManagementGetInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Gets a Call Capacity Management group.

The response is either `GroupCallCapacityManagementGetInstanceResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|name                |str |name              |
</div>


## `GroupCallCenterAddSupervisorListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add supervisor(s) to a call center.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name               |Type      |Description      |
|-------------------|----------|-----------------|
|service_user_id    |str       |serviceUserId    |
|supervisor_user_id |List[str] |supervisorUserId |
</div>


## `GroupCallCenterAgentThresholdProfileAddAgentListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add agent(s) to a Agent Threshold Profile.

When an agent is assigned (added )to a profile, it is automatically unassigned
(deleted) from the previous profile it was assigned to.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|group_id            |str       |groupId           |
|profile_name        |str       |profileName       |
|agent_user_id       |List[str] |agentUserId       |
</div>


## `GroupCallCenterAgentThresholdProfileAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a new Call Center Agent Threshold Profile in a Group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                                  |Type      |Description                                                |
|------------------------------------------------------|----------|-----------------------------------------------------------|
|service_provider_id                                   |str       |serviceProviderId                                          |
|group_id                                              |str       |groupId                                                    |
|profile_name                                          |str       |profileName                                                |
|profile_description                                   |str       |profileDescription *Optional*                              |
|threshold_current_call_state_idle_time_yellow         |int       |thresholdCurrentCallStateIdleTimeYellow *Optional*         |
|threshold_current_call_state_idle_time_red            |int       |thresholdCurrentCallStateIdleTimeRed *Optional*            |
|threshold_current_call_state_on_call_time_yellow      |int       |thresholdCurrentCallStateOnCallTimeYellow *Optional*       |
|threshold_current_call_state_on_call_time_red         |int       |thresholdCurrentCallStateOnCallTimeRed *Optional*          |
|threshold_current_agent_state_unavailable_time_yellow |int       |thresholdCurrentAgentStateUnavailableTimeYellow *Optional* |
|threshold_current_agent_state_unavailable_time_red    |int       |thresholdCurrentAgentStateUnavailableTimeRed *Optional*    |
|threshold_average_busy_in_time_yellow                 |int       |thresholdAverageBusyInTimeYellow *Optional*                |
|threshold_average_busy_in_time_red                    |int       |thresholdAverageBusyInTimeRed *Optional*                   |
|threshold_average_busy_out_time_yellow                |int       |thresholdAverageBusyOutTimeYellow *Optional*               |
|threshold_average_busy_out_time_red                   |int       |thresholdAverageBusyOutTimeRed *Optional*                  |
|threshold_average_wrap_up_time_yellow                 |int       |thresholdAverageWrapUpTimeYellow *Optional*                |
|threshold_average_wrap_up_time_red                    |int       |thresholdAverageWrapUpTimeRed *Optional*                   |
|enable_notification_email                             |bool      |enableNotificationEmail                                    |
|notification_email_address                            |List[str] |notificationEmailAddress *Optional*                        |
|agent_user_id                                         |List[str] |agentUserId *Optional*                                     |
</div>


## `GroupCallCenterAgentThresholdProfileDeleteAgentListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete agent(s) from a Agent Threshold Profile.

Agents cannot be unassigned (deleted) directly from the default profile, they need to
be assigned (added) to a different profile.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|group_id            |str       |groupId           |
|profile_name        |str       |profileName       |
|agent_user_id       |List[str] |agentUserId       |
</div>


## `GroupCallCenterAgentThresholdProfileDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Deletes an existing Call Center Agent Threshold Profile in a Group.

The default profile cannot be deleted.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|profile_name        |str |profileName       |
</div>


## `GroupCallCenterAgentThresholdProfileGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of Call Center Agent Threshold Profiles in the Group.

The response is either `GroupCallCenterAgentThresholdProfileGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallCenterAgentThresholdProfileGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Gets an existing non-default Call Center Agent Threshold Profile in a Group.

The response is either a `GroupCallCenterAgentThresholdProfileGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|profile_name        |str |profileName       |
</div>


## `GroupCallCenterAgentUnavailableCodeAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Call Center Agent Unavailable Code.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type |Description            |
|--------------------|-----|-----------------------|
|service_provider_id |str  |serviceProviderId      |
|group_id            |str  |groupId                |
|is_active           |bool |isActive               |
|code                |str  |code                   |
|description         |str  |description *Optional* |
</div>


## `GroupCallCenterAgentUnavailableCodeDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Call Center Agent Unavailable Code.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|code                |str |code              |
</div>


## `GroupCallCenterAgentUnavailableCodeGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of Call Center Agent Unavailable Codes.

The response is either `GroupCallCenterAgentUnavailableCodeGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallCenterAgentUnavailableCodeGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a Call Center Agent Unavailable Code.

The response is either `GroupCallCenterAgentUnavailableCodeGetResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|code                |str |code              |
</div>


## `GroupCallCenterAgentUnavailableCodeModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a Call Center Agent Unavailable Code.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type |Description            |
|--------------------|-----|-----------------------|
|service_provider_id |str  |serviceProviderId      |
|group_id            |str  |groupId                |
|code                |str  |code                   |
|is_active           |bool |isActive *Optional*    |
|description         |str  |description *Optional* |
</div>


## `GroupCallCenterAgentUnavailableCodeSettingsGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group level data associated with Call Center Agents Unavailable Code
Settings.

The response is either an `GroupCallCenterAgentUnavailableCodeSettingsGetResponse()`
or an `ErrorResponse()`. Replaced by
`GroupCallCenterAgentUnavailableCodeSettingsGetRequest17sp4()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallCenterAgentUnavailableCodeSettingsGetRequest17sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group level data associated with Call Center Agents Unavailable Code
Settings.

The response is either a
`GroupCallCenterAgentUnavailableCodeSettingsGetResponse17sp4()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallCenterBouncedCallGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's bounced call settings.

The response is either a `GroupCallCenterBouncedCallGetResponse()` or an
`ErrorResponse()`. Replaced by: `GroupCallCenterBouncedCallGetRequest17()`

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterBouncedCallGetRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's bounced call settings.

The response is either a `GroupCallCenterBouncedCallGetResponse17()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterBouncedCallModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call center's bounced call settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode: enableTransfer
transferPhoneNumber bounceCallWhenAgentUnavailable alertCallCenterCallOnHold
alertCallCenterCallOnHoldSeconds bounceCallCenterCallOnHold
bounceCallCenterCallOnHoldSeconds

**Attributes:**

|Name                                    |Type |Description                                  |
|----------------------------------------|-----|---------------------------------------------|
|service_user_id                         |str  |serviceUserId                                |
|is_active                               |bool |isActive *Optional*                          |
|number_of_rings_before_bouncing_call    |int  |numberOfRingsBeforeBouncingCall *Optional*   |
|enable_transfer                         |bool |enableTransfer *Optional*                    |
|transfer_phone_number                   |str  |transferPhoneNumber *Optional*               |
|bounce_call_when_agent_unavailable      |bool |bounceCallWhenAgentUnavailable *Optional*    |
|alert_call_center_call_on_hold          |bool |alertCallCenterCallOnHold *Optional*         |
|alert_call_center_call_on_hold_seconds  |int  |alertCallCenterCallOnHoldSeconds *Optional*  |
|bounce_call_center_call_on_hold         |bool |bounceCallCenterCallOnHold *Optional*        |
|bounce_call_center_call_on_hold_seconds |int  |bounceCallCenterCallOnHoldSeconds *Optional* |
</div>


## `GroupCallCenterCallDispositionCodeAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Call Center Call Disposition Code.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type |Description            |
|--------------------|-----|-----------------------|
|service_provider_id |str  |serviceProviderId      |
|group_id            |str  |groupId                |
|code                |str  |code                   |
|is_active           |bool |isActive               |
|description         |str  |description *Optional* |
</div>


## `GroupCallCenterCallDispositionCodeDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Call Center Call Disposition Code.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|code                |str |code              |
</div>


## `GroupCallCenterCallDispositionCodeGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of Call Center Call Disposition Codes.

The response is either `GroupCallCenterCallDispositionCodeGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallCenterCallDispositionCodeGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a Call Center Call Disposition Code.

The response is either `GroupCallCenterCallDispositionCodeGetResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|code                |str |code              |
</div>


## `GroupCallCenterCallDispositionCodeGetUsageListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of Call Centers and Route Points using the specified disposition code.

The response is either `GroupCallCenterCallDispositionCodeGetUsageListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|code                |str |code              |
</div>


## `GroupCallCenterCallDispositionCodeModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a Call Center Call Disposition Code.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type |Description            |
|--------------------|-----|-----------------------|
|service_provider_id |str  |serviceProviderId      |
|group_id            |str  |groupId                |
|code                |str  |code                   |
|is_active           |bool |isActive *Optional*    |
|description         |str  |description *Optional* |
</div>


## `GroupCallCenterComfortMessageBypassGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's comfort message bypass settings.

The response is either a `GroupCallCenterComfortMessageBypassGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterComfortMessageBypassGetRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's comfort message bypass settings.

The response is either a `GroupCallCenterComfortMessageBypassGetResponse17()` or an
`ErrorResponse()`. Replaced by: `GroupCallCenterComfortMessageBypassGetRequest20()`

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterComfortMessageBypassGetRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's comfort message bypass settings.

The response is either a `GroupCallCenterComfortMessageBypassGetResponse20()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterCurrentAndPastDNISGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the past and current DNIS for the Call Center for the group.

The response is either `GroupCallCenterCurrentAndPastDNISGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|service_user_id     |str |serviceUserId     |
</div>


## `GroupCallCenterDeleteAgentListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete agent(s) from a call center.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type      |Description   |
|----------------|----------|--------------|
|service_user_id |str       |serviceUserId |
|agent_user_id   |List[str] |agentUserId   |
</div>


## `GroupCallCenterDeleteInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Call Center instance from a group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterDeleteSupervisorListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete supervisor(s) from a call center.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name               |Type      |Description      |
|-------------------|----------|-----------------|
|service_user_id    |str       |serviceUserId    |
|supervisor_user_id |List[str] |supervisorUserId |
</div>


## `GroupCallCenterDistinctiveRingingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the distinctive ringing configuration values for call center.

The response is either a `GroupCallCenterDistinctiveRingingGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterDistinctiveRingingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the distinctive ringing configuration values for call center.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
element is only used in AS data mode and ignored in XS data mode:
distinctiveRingingForceDeliveryRingPattern

**Attributes:**

|Name                                             |Type |Description                                           |
|-------------------------------------------------|-----|------------------------------------------------------|
|service_user_id                                  |str  |serviceUserId                                         |
|distinctive_ringing_call_center_calls            |bool |distinctiveRingingCallCenterCalls *Optional*          |
|distinctive_ringing_ring_pattern_for_call_center |str  |distinctiveRingingRingPatternForCallCenter *Optional* |
|distinctive_ringing_force_delivery_ring_pattern  |str  |distinctiveRingingForceDeliveryRingPattern *Optional* |
</div>


## `GroupCallCenterEnhancedGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the Call Center Enhanced configuration data for a Call Center.

The response is either `GroupCallCenterEnhancedGetResponse()` or `ErrorResponse()`.

Replaced By: `GroupCallCenterGetInstanceResponse16()`

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterEnhancedModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Call Center Enhanced configuration data for a Call Center.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

Replaced By: `GroupCallCenterModifyInstanceRequest16()`

**Attributes:**

|Name                        |Type |Description                        |
|----------------------------|-----|-----------------------------------|
|service_user_id             |str  |serviceUserId                      |
|override_agent_wrap_up_time |bool |overrideAgentWrapUpTime *Optional* |
|wrap_up_seconds             |int  |wrapUpSeconds *Optional*           |
</div>


## `GroupCallCenterEnhancedReportingBrandingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the group branding information.

The response is either `GroupCallCenterEnhancedReportingBrandingGetResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallCenterEnhancedReportingGetAvailableReportTemplateListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all enabled call center report template for a group.

The response is either a
`GroupCallCenterEnhancedReportingGetAvailableReportTemplateListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallCenterEnhancedReportingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a group level call center enhanced reporting setting.

The response is either a `GroupCallCenterEnhancedReportingGetResponse()` or an
`ErrorResponse()`. Replaced by `GroupCallCenterEnhancedReportingGetRequest19()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallCenterEnhancedReportingGetRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a group level call center enhanced reporting setting.

The response is either a `GroupCallCenterEnhancedReportingGetResponse19()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallCenterEnhancedReportingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify group level call center enhanced reporting settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by
`GroupCallCenterEnhancedReportingModifyRequest19()`

**Attributes:**

|Name                 |Type|Description                   |
|---------------------|----|------------------------------|
|service_provider_id  |str |serviceProviderId             |
|group_id             |str |groupId                       |
|reporting_server     |str |reportingServer *Optional*    |
|web_statistic_source |str |webStatisticSource *Optional* |
</div>


## `GroupCallCenterEnhancedReportingModifyRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify group level call center enhanced reporting settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description                |
|--------------------|----|---------------------------|
|service_provider_id |str |serviceProviderId          |
|group_id            |str |groupId                    |
|reporting_server    |str |reportingServer *Optional* |
</div>


## `GroupCallCenterEnhancedReportingReportTemplateDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a group level call center report template.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|name                |str |name              |
</div>


## `GroupCallCenterEnhancedReportingReportTemplateGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get group level call center report template list.

The response is either a
`GroupCallCenterEnhancedReportingReportTemplateGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallCenterEnhancedReportingReportTemplateGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a group level call center report template.

The response is either a `GroupCallCenterEnhancedReportingReportTemplateGetResponse()`
or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|name                |str |name              |
</div>


## `GroupCallCenterEnhancedReportingScheduledReportDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a group level call center reporting scheduled report.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|name                |str |name              |
</div>


## `GroupCallCenterEnhancedReportingScheduledReportGetReportTemplateUsageListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the call center reporting scheduled report in a group that uses a
given group level report template.

The response is either a
`GroupCallCenterEnhancedReportingScheduledReportGetReportTemplateUsageListResponse()`
or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|name                |str |name              |
</div>


## `GroupCallCenterEnhancedReportingScheduledReportGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a group level call center reporting scheduled report.

The response is either a
`GroupCallCenterEnhancedReportingScheduledReportGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|name                |str |name              |
</div>


## `GroupCallCenterForcedForwardingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's forced forwarding settings.

The response is either a `GroupCallCenterForcedForwardingGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterForcedForwardingGetRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's forced forwarding settings.

The response is either a `GroupCallCenterForcedForwardingGetResponse17()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterForcedForwardingGetRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's forced forwarding settings.

The response is either a `GroupCallCenterForcedForwardingGetResponse20()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterGetAnnouncementRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's announcement settings.

The response is either a `GroupCallCenterGetAnnouncementResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterGetAnnouncementRequest14sp6`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's announcement settings.

The response is either a `GroupCallCenterGetAnnouncementResponse14sp6()` or an
`ErrorResponse()`.

Replaced By: `GroupCallCenterGetAnnouncementRequest16()`

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterGetAnnouncementRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's announcement settings.

The response is either a `GroupCallCenterGetAnnouncementResponse16()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterGetAnnouncementRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's announcement settings.

The response is either a `GroupCallCenterGetAnnouncementResponse17()` or an
`ErrorResponse()`. Replaced by `GroupCallCenterGetAnnouncementRequest17sp4()`

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterGetAnnouncementRequest17sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's announcement settings.

The response is either a `GroupCallCenterGetAnnouncementResponse17sp4()` or an
`ErrorResponse()`. Replaced by: `GroupCallCenterGetAnnouncementRequest19()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterGetAnnouncementRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's announcement settings.

The response is either a `GroupCallCenterGetAnnouncementResponse19()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterGetAnnouncementRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's announcement settings.

The response is either a `GroupCallCenterGetAnnouncementResponse20()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterGetAnnouncementRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's announcement settings.

The response is either a `GroupCallCenterGetAnnouncementResponse22()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterGetDNISListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of DNIS that are configured for a Call Center.

The response is either `GroupCallCenterGetDNISListResponse()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterGetDistinctiveRingingRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the distinctive ringing configuration values for call center.

The response is either a `GroupCallCenterGetDistinctiveRingingResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterGetInstanceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of Call Center instances within a group.

The response is either `GroupCallCenterGetInstanceListResponse()` or
`ErrorResponse()`. It is possible to get the instances within a specified department.

**Attributes:**

|Name                  |Type|Description                    |
|----------------------|----|-------------------------------|
|service_provider_id   |str |serviceProviderId              |
|group_id              |str |groupId                        |
|group_department_name |str |groupDepartmentName *Optional* |
</div>


## `GroupCallCenterGetInstanceQueueStatusRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get Call Center queue status.

The response is either `GroupCallCenterGetInstanceQueueStatusResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterGetInstanceRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Call Center instance.

The response is either `GroupCallCenterGetInstanceResponse14()` or `ErrorResponse()`.

Replaced By: `GroupCallCenterGetInstanceRequest14sp3()`

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterGetInstanceRequest14sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Call Center instance.

The response is either `GroupCallCenterGetInstanceResponse14sp3()` or
`ErrorResponse()`.

Replaced By: `GroupCallCenterGetInstanceRequest14sp9()`

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterGetInstanceRequest14sp9`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Call Center instance.

The response is either `GroupCallCenterGetInstanceResponse14sp9()` or
`ErrorResponse()`.

Replaced By: `GroupCallCenterGetInstanceRequest16()`

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterGetInstanceRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Call Center instance.

The response is either `GroupCallCenterGetInstanceResponse16()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterGetInstanceRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Call Center instance.

The response is either `GroupCallCenterGetInstanceResponse17()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterGetInstanceRequest17sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Call Center instance.

The response is either `GroupCallCenterGetInstanceResponse17sp1()` or
`ErrorResponse()`. Replaced by: `GroupCallCenterGetInstanceRequest17sp3()`

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterGetInstanceRequest17sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Call Center instance.

The response is either `GroupCallCenterGetInstanceResponse17sp3()` or
`ErrorResponse()`. Replaced by `GroupCallCenterGetInstanceRequest19()`

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterGetInstanceRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Call Center instance.

The response is either `GroupCallCenterGetInstanceResponse19()` or `ErrorResponse()`.
Replaced by: `GroupCallCenterGetInstanceRequest19sp1()`

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterGetInstanceRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Call Center instance.

The response is either `GroupCallCenterGetInstanceResponse19sp1()` or
`ErrorResponse()`. Replaced by `GroupCallCenterGetInstanceRequest22()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterGetInstanceRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Call Center instance.

The response is either `GroupCallCenterGetInstanceResponse22()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterGetInstanceStatisticsReportingRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the call center statistics reporting settings.

The response is either `GroupCallCenterGetInstanceStatisticsReportingResponse()` or
`ErrorResponse()`.

Replaced By: `GroupCallCenterGetInstanceStatisticsReportingRequest16()`

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterGetInstanceStatisticsReportingRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the call center statistics reporting settings.

The response is either `GroupCallCenterGetInstanceStatisticsReportingResponse16()` or
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterGetInstanceStatisticsReportingRequest17sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the call center statistics reporting settings.

The response is either `GroupCallCenterGetInstanceStatisticsReportingResponse17sp1()`
or `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterGetInstanceStatisticsRequest13mp8`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get Call Center queue and agent statistics.

The response is either `GroupCallCenterGetInstanceStatisticsResponse13mp8()` or
`ErrorResponse()`.

Replaced By: `GroupCallCenterGetInstanceStatisticsRequest14sp9()`

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the Group level data associated with Call Center.

The response is either a `GroupCallCenterGetResponse()` or an `ErrorResponse()`.
Replaced by `GroupCallCenterGetRequest17sp4()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallCenterGetRequest17sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the Group level data associated with Call Center.

The response is either a `GroupCallCenterGetResponse17sp4()` or an `ErrorResponse()`.
Replaced by: `GroupCallCenterGetRequest23()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallCenterGetRequest23`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the Group level data associated with Call Center.

The response is either a `GroupCallCenterGetResponse23()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallCenterGetRoutingPolicyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group call center routing policy.

The response is either a `GroupCallCenterGetRoutingPolicyResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallCenterGetSupervisorListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of supervisors assigned to a call center.

Only users in the same group or enterprise as this call center can successfully
execute this request.

The response is either a `GroupCallCenterGetSupervisorListResponse()` or an
`ErrorResponse()`.

Replaced By: `GroupCallCenterSupervisorReportingGetRequest()`

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterGetSupervisorListRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of supervisors assigned to a call center.

The response is either a `GroupCallCenterGetSupervisorListResponse16()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterGetUnlicensedAgentListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of unlicensed users who are preventing the Call Center from upgrading to
another type.

The response is either `GroupCallCenterGetUnlicensedAgentListRequest()` or
`ErrorResponse()`.

**Attributes:**

|Name             |Type|Description    |
|-----------------|----|---------------|
|service_user_id  |str |serviceUserId  |
|call_center_type |str |callCenterType |
</div>


## `GroupCallCenterHolidayServiceGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's holiday service settings.

The response is either a `GroupCallCenterHolidayServiceGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterHolidayServiceGetRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's holiday service settings.

The response is either a `GroupCallCenterHolidayServiceGetResponse17()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterHolidayServiceGetRequest17sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's holiday service settings.

The response is either a `GroupCallCenterHolidayServiceGetResponse17sp1()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterHolidayServiceGetRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's holiday service settings.

The response is either a `GroupCallCenterHolidayServiceGetResponse20()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterModifyDNISParametersRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the setting that are configured for all the DNIS in a Call Center.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                    |Type |Description                                    |
|----------------------------------------|-----|-----------------------------------------------|
|service_user_id                         |str  |serviceUserId                                  |
|display_dnis_number                     |bool |displayDNISNumber *Optional*                   |
|display_dnis_name                       |bool |displayDNISName *Optional*                     |
|promote_calls_from_priority1to0         |bool |promoteCallsFromPriority1to0 *Optional*        |
|promote_calls_from_priority2to1         |bool |promoteCallsFromPriority2to1 *Optional*        |
|promote_calls_from_priority3to2         |bool |promoteCallsFromPriority3to2 *Optional*        |
|promote_calls_from_priority1to0_seconds |int  |promoteCallsFromPriority1to0Seconds *Optional* |
|promote_calls_from_priority2to1_seconds |int  |promoteCallsFromPriority2to1Seconds *Optional* |
|promote_calls_from_priority3to2_seconds |int  |promoteCallsFromPriority3to2Seconds *Optional* |
</div>


## `GroupCallCenterModifyDistinctiveRingingRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the distinctive ringing configuration values for call center.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                             |Type |Description                                           |
|-------------------------------------------------|-----|------------------------------------------------------|
|service_user_id                                  |str  |serviceUserId                                         |
|distinctive_ringing_call_center_calls            |bool |distinctiveRingingCallCenterCalls *Optional*          |
|distinctive_ringing_ring_pattern_for_call_center |str  |distinctiveRingingRingPatternForCallCenter *Optional* |
|distinctive_ringing_force_delivery_ring_pattern  |str  |distinctiveRingingForceDeliveryRingPattern *Optional* |
</div>


## `GroupCallCenterModifyInstanceStatisticsReportingRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Call Center statistics reporting frequency and destination.

The response is either `SuccessResponse()` or `ErrorResponse()`.

Replaced By: `GroupCallCenterModifyInstanceStatisticsReportingRequest14sp9()`

**Attributes:**

|Name                      |Type |Description                        |
|--------------------------|-----|-----------------------------------|
|service_user_id           |str  |serviceUserId                      |
|clear_today_statistics    |bool |clearTodayStatistics *Optional*    |
|generate_daily_report     |bool |generateDailyReport *Optional*     |
|collection_period_minutes |int  |collectionPeriodMinutes *Optional* |
|reporting_email_address1  |str  |reportingEmailAddress1 *Optional*  |
|reporting_email_address2  |str  |reportingEmailAddress2 *Optional*  |
</div>


## `GroupCallCenterModifyInstanceStatisticsReportingRequest14sp9`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Call Center statistics reporting frequency and destination.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                      |Type |Description                        |
|--------------------------|-----|-----------------------------------|
|service_user_id           |str  |serviceUserId                      |
|generate_daily_report     |bool |generateDailyReport *Optional*     |
|collection_period_minutes |int  |collectionPeriodMinutes *Optional* |
|reporting_email_address1  |str  |reportingEmailAddress1 *Optional*  |
|reporting_email_address2  |str  |reportingEmailAddress2 *Optional*  |
|statistics_source         |str  |statisticsSource *Optional*        |
</div>


## `GroupCallCenterModifyInstanceStatisticsReportingRequest17sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Call Center statistics reporting frequency and destination.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                      |Type |Description                        |
|--------------------------|-----|-----------------------------------|
|service_user_id           |str  |serviceUserId                      |
|generate_daily_report     |bool |generateDailyReport *Optional*     |
|collection_period_minutes |int  |collectionPeriodMinutes *Optional* |
|reporting_email_address1  |str  |reportingEmailAddress1 *Optional*  |
|reporting_email_address2  |str  |reportingEmailAddress2 *Optional*  |
|statistics_source         |str  |statisticsSource *Optional*        |
</div>


## `GroupCallCenterModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the group level data associated with Call Center and the active status of Call
Center instances.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode:
useSystemDefaultUnavailableSettings forceAgentUnavailableOnDNDActivation
forceAgentUnavailableOnPersonalCalls forceAgentUnavailableOnBouncedCallLimit
numberConsecutiveBouncedCallsToForceAgentUnavailable
forceAgentUnavailableOnNotReachable wrapUpDestination

**Attributes:**

|Name                                                        |Type |Description                                                     |
|------------------------------------------------------------|-----|----------------------------------------------------------------|
|service_provider_id                                         |str  |serviceProviderId                                               |
|group_id                                                    |str  |groupId                                                         |
|use_system_default_guard_timer                              |bool |useSystemDefaultGuardTimer *Optional*                           |
|enable_guard_timer                                          |bool |enableGuardTimer *Optional*                                     |
|guard_timer_seconds                                         |int  |guardTimerSeconds *Optional*                                    |
|use_system_default_unavailable_settings                     |bool |useSystemDefaultUnavailableSettings *Optional*                  |
|force_agent_unavailable_on_dnd_activation                   |bool |forceAgentUnavailableOnDNDActivation *Optional*                 |
|force_agent_unavailable_on_personal_calls                   |bool |forceAgentUnavailableOnPersonalCalls *Optional*                 |
|force_agent_unavailable_on_bounced_call_limit               |bool |forceAgentUnavailableOnBouncedCallLimit *Optional*              |
|number_consecutive_bounced_calls_to_force_agent_unavailable |int  |numberConsecutiveBouncedCallsToForceAgentUnavailable *Optional* |
|force_agent_unavailable_on_not_reachable                    |bool |forceAgentUnavailableOnNotReachable *Optional*                  |
|wrap_up_destination                                         |str  |wrapUpDestination *Optional*                                    |
</div>


## `GroupCallCenterMonitoringGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the Group level data associated with Call Center Monitoring.

The response is either a `GroupCallCenterMonitoringGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallCenterMonitoringModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the group level data associated with Call Center Monitoring The response is
either a `SuccessResponse()` or an `ErrorResponse()`.


**Attributes:**

|Name                       |Type |Description                         |
|---------------------------|-----|------------------------------------|
|service_provider_id        |str  |serviceProviderId                   |
|group_id                   |str  |groupId                             |
|enable_supervisor_coaching |bool |enableSupervisorCoaching *Optional* |
</div>


## `GroupCallCenterNightServiceGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's night service settings.

The response is either a `GroupCallCenterNightServiceGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterNightServiceGetRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's night service settings.

The response is either a `GroupCallCenterNightServiceGetResponse17()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterNightServiceGetRequest17sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's night service settings.

The response is either a `GroupCallCenterNightServiceGetResponse17sp1()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterNightServiceGetRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's night service settings.

The response is either a `GroupCallCenterNightServiceGetResponse20()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterOverflowGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's overflow settings.

The response is either a `GroupCallCenterOverflowGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterOverflowGetRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's overflow settings.

The response is either a `GroupCallCenterOverflowGetResponse17()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterOverflowGetRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's overflow settings.

The response is either a `GroupCallCenterOverflowGetResponse20()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterQueueCallDispositionCodeAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Call Center Call Disposition Code.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type |Description            |
|----------------|-----|-----------------------|
|service_user_id |str  |serviceUserId          |
|code            |str  |code                   |
|is_active       |bool |isActive               |
|description     |str  |description *Optional* |
</div>


## `GroupCallCenterQueueCallDispositionCodeDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Call Center Call Disposition Code.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
|code            |str |code          |
</div>


## `GroupCallCenterQueueCallDispositionCodeGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of Call Center Level and Organization Level Call Disposition Codes.

The response is either `GroupCallCenterQueueCallDispositionCodeGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterQueueCallDispositionCodeGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a Call Center Call Disposition Code.

The response is either `GroupCallCenterQueueCallDispositionCodeGetResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
|code            |str |code          |
</div>


## `GroupCallCenterQueueCallDispositionCodeModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a Call Center Call Disposition Code.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type |Description            |
|----------------|-----|-----------------------|
|service_user_id |str  |serviceUserId          |
|code            |str  |code                   |
|is_active       |bool |isActive *Optional*    |
|description     |str  |description *Optional* |
</div>


## `GroupCallCenterQueueCallDispositionCodeSettingsGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Call Center Call Disposition Code
Settings.

The response is either a
`GroupCallCenterQueueCallDispositionCodeSettingsGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterQueueStatusNotificationGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the status configuration for a given call center.

The response is either a `GroupCallCenterQueueStatusNotificationGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterQueueStatusNotificationModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Set the status configuration for a given call center.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                             |Type |Description                              |
|---------------------------------|-----|-----------------------------------------|
|service_user_id                  |str  |serviceUserId                            |
|enable_queue_status_notification |bool |enableQueueStatusNotification *Optional* |
|enable_queue_depth_threshold     |bool |enableQueueDepthThreshold *Optional*     |
|enable_waiting_time_threshold    |bool |enableWaitingTimeThreshold *Optional*    |
|number_of_calls_threshold        |int  |numberOfCallsThreshold *Optional*        |
|waiting_time_of_calls_threshold  |int  |waitingTimeOfCallsThreshold *Optional*   |
</div>


## `GroupCallCenterQueueThresholdsGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's queue Thresholds settings.

The response is either a `GroupCallCenterQueueThresholdsGetRequest()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterStrandedCallGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's stranded call settings.

The response is either a `GroupCallCenterStrandedCallGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterStrandedCallGetRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's stranded call settings.

The response is either a `GroupCallCenterStrandedCallGetResponse17()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterStrandedCallGetRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's stranded call settings.

The response is either a `GroupCallCenterStrandedCallGetResponse20()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterStrandedCallUnavailableGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's stranded calls - unavailable settings.

The response is either a `GroupCallCenterStrandedCallUnavailableGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterStrandedCallUnavailableGetRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's stranded calls - unavailable settings.

The response is either a `GroupCallCenterStrandedCallUnavailableGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallCenterSupervisorReportingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of supervisors assigned to a call center.

Only users in the same group or enterprise as this call center can successfully
execute this request.

The response is either a `GroupCallCenterSupervisorReportingGetResponse()` or an
`ErrorResponse()`.

Replaced By: `GroupCallCenterGetSupervisorListRequest16()`

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCallParkAddInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Adds a Call Park group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|group_id            |str       |groupId           |
|name                |str       |name              |
|user_id             |List[str] |userId *Optional* |
</div>


## `GroupCallParkAddInstanceRequest16sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Adds a Call Park group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                     |Type      |Description                      |
|-------------------------|----------|---------------------------------|
|service_provider_id      |str       |serviceProviderId                |
|group_id                 |str       |groupId                          |
|name                     |str       |name                             |
|user_id                  |List[str] |userId *Optional*                |
|recall_alternate_user_id |str       |recallAlternateUserId *Optional* |
|recall_to                |str       |recallTo                         |
</div>


## `GroupCallParkDeleteInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Deletes a Call Park group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|name                |str |name              |
</div>


## `GroupCallParkGetInstanceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a list of Call Park group instances within a group.

The response is either `GroupCallParkGetInstanceListResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallParkGetInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Gets a Call Park group.

The response is either `GroupCallParkGetInstanceResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|name                |str |name              |
</div>


## `GroupCallParkGetInstanceRequest16sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Gets a Call Park group.

The response is either `GroupCallParkGetInstanceResponse16sp2()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|name                |str |name              |
</div>


## `GroupCallParkGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Gets the Call Park Group settings.

The response is either `GroupCallParkGetResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallParkGetRequest16sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Gets the Call Park Group settings.

The response is either `GroupCallParkGetResponse16sp2()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallParkModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the Group's Call Park settings.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                |Type |Description                                |
|------------------------------------|-----|-------------------------------------------|
|service_provider_id                 |str  |serviceProviderId                          |
|group_id                            |str  |groupId                                    |
|recall_timer_seconds                |int  |recallTimerSeconds *Optional*              |
|display_timer_seconds               |int  |displayTimerSeconds *Optional*             |
|enable_destination_announcement     |bool |enableDestinationAnnouncement *Optional*   |
|recall_alternate_user_id            |str  |recallAlternateUserId *Optional*           |
|recall_ring_pattern                 |str  |recallRingPattern *Optional*               |
|recall_to                           |str  |recallTo *Optional*                        |
|alternate_user_recall_timer_seconds |int  |alternateUserRecallTimerSeconds *Optional* |
</div>


## `GroupCallPickupAddInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Adds a Call Pickup group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|group_id            |str       |groupId           |
|name                |str       |name              |
|user_id             |List[str] |userId *Optional* |
</div>


## `GroupCallPickupDeleteInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Deletes a Call Pickup group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|name                |str |name              |
</div>


## `GroupCallPickupGetInstanceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a list of Call Pickup instances within a group.

The response is either `GroupCallPickupGetInstanceListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallPickupGetInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Gets a Call Pickup group.

The response is either `GroupCallPickupGetInstanceResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|name                |str |name              |
</div>


## `GroupCallProcessingGetPolicyRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group level data associated with Call Processing Policy.

The response is either a `GroupCallProcessingGetPolicyResponse14()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallProcessingGetPolicyRequest14sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group level data associated with Call Processing Policy.

The response is either a `GroupCallProcessingGetPolicyResponse14sp1()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallProcessingGetPolicyRequest14sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group level data associated with Call Processing Policy.

The response is either a `GroupCallProcessingGetPolicyResponse14sp4()` or an
`ErrorResponse()`.

Replaced By : `GroupCallProcessingGetPolicyRequest15()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallProcessingGetPolicyRequest14sp7`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group level data associated with Call Processing Policy.

The response is either a `GroupCallProcessingGetPolicyResponse14sp7()` or an
`ErrorResponse()`. The useGroupCLIDSetting attribute controls the CLID settings
(clidPolicy, emergencyClidPolicy, allowAlternateNumbersForRedirectingIdentity,
useGroupName) The useGroupMediaSetting attribute controls the Media settings
(medisPolicySelection, supportedMediaSetName) The useGroupCallLimitsSetting attribute
controls the Call Limits settings (useMaxSimultaneousCalls, maxSimultaneousCalls,
useMaxSimultaneousVideoCalls, maxSimultaneousVideoCalls,
useMaxCallTimeForAnsweredCalls, maxCallTimeForAnsweredCallsMinutes,
useMaxCallTimeForUnansweredCalls, maxCallTimeForUnansweredCallsMinutes,
useMaxConcurrentRedirectedCalls, useMaxFindMeFollowMeDepth, maxRedirectionDepth,
useMaxConcurrentFindMeFollowMeInvocations, maxConcurrentFindMeFollowMeInvocations) The
useGroupTranslationRoutingSetting attribute controls the routing and translation
settings (networkUsageSelection, enforceGroupCallingLineIdentityRestriction,
allowEnterpriseGroupCallTypingForPrivateDialingPlan,
allowEnterpriseGroupCallTypingForPublicDialingPlan,
overrideCLIDRestrictionForExternalCallsViaPrivateDialingPlan,
enableEnterpriseExtensionDialing)

Replaced By: `GroupCallProcessingGetPolicyRequest16()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallProcessingGetPolicyRequest15`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group level data associated with Call Processing Policy.

The response is either a `GroupCallProcessingGetPolicyResponse15()` or an
`ErrorResponse()`.

Replaced By: `GroupCallProcessingGetPolicyRequest16()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallProcessingGetPolicyRequest15sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group level data associated with Call Processing Policy.

The response is either a `GroupCallProcessingGetPolicyResponse15sp2()` or an
`ErrorResponse()`. The useGroupCLIDSetting attribute controls the CLID settings
(clidPolicy, emergencyClidPolicy, allowAlternateNumbersForRedirectingIdentity,
useGroupName) The useGroupMediaSetting attribute controls the Media settings
(medisPolicySelection, supportedMediaSetName) The useGroupCallLimitsSetting attribute
controls the Call Limits settings (useMaxSimultaneousCalls, maxSimultaneousCalls,
useMaxSimultaneousVideoCalls, maxSimultaneousVideoCalls,
useMaxCallTimeForAnsweredCalls, maxCallTimeForAnsweredCallsMinutes,
useMaxCallTimeForUnansweredCalls, maxCallTimeForUnansweredCallsMinutes,
useMaxConcurrentRedirectedCalls, useMaxFindMeFollowMeDepth, maxRedirectionDepth,
useMaxConcurrentFindMeFollowMeInvocations, maxConcurrentFindMeFollowMeInvocations) The
useGroupTranslationRoutingSetting attribute controls the routing and translation
settings (networkUsageSelection, enforceGroupCallingLineIdentityRestriction,
allowEnterpriseGroupCallTypingForPrivateDialingPlan,
allowEnterpriseGroupCallTypingForPublicDialingPlan,
overrideCLIDRestrictionForExternalCallsViaPrivateDialingPlan,
enableEnterpriseExtensionDialing)

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallProcessingGetPolicyRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group level data associated with Call Processing Policy.

The response is either a `GroupCallProcessingGetPolicyResponse16()` or an
`ErrorResponse()`. The useGroupCLIDSetting attribute controls the CLID settings
(clidPolicy, emergencyClidPolicy, allowAlternateNumbersForRedirectingIdentity,
useGroupName) The useGroupMediaSetting attribute controls the Media settings
(medisPolicySelection, supportedMediaSetName) The useGroupCallLimitsSetting attribute
controls the Call Limits settings (useMaxSimultaneousCalls, maxSimultaneousCalls,
useMaxSimultaneousVideoCalls, maxSimultaneousVideoCalls,
useMaxCallTimeForAnsweredCalls, maxCallTimeForAnsweredCallsMinutes,
useMaxCallTimeForUnansweredCalls, maxCallTimeForUnansweredCallsMinutes,
useMaxConcurrentRedirectedCalls, useMaxFindMeFollowMeDepth, maxRedirectionDepth,
useMaxConcurrentFindMeFollowMeInvocations, maxConcurrentFindMeFollowMeInvocations) The
useGroupTranslationRoutingSetting attribute controls the routing and translation
settings (networkUsageSelection, enforceGroupCallingLineIdentityRestriction,
allowEnterpriseGroupCallTypingForPrivateDialingPlan,
allowEnterpriseGroupCallTypingForPublicDialingPlan,
overrideCLIDRestrictionForExternalCallsViaPrivateDialingPlan,
enableEnterpriseExtensionDialing)

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallProcessingGetPolicyRequest16sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group level data associated with Call Processing Policy.

The response is either a `GroupCallProcessingGetPolicyResponse16sp2()` or an
`ErrorResponse()`. The useGroupCLIDSetting attribute controls the CLID settings
(clidPolicy, emergencyClidPolicy, allowAlternateNumbersForRedirectingIdentity,
useGroupName) The useGroupMediaSetting attribute controls the Media settings
(medisPolicySelection, supportedMediaSetName) The useGroupCallLimitsSetting attribute
controls the Call Limits settings (useMaxSimultaneousCalls, maxSimultaneousCalls,
useMaxSimultaneousVideoCalls, maxSimultaneousVideoCalls,
useMaxCallTimeForAnsweredCalls, maxCallTimeForAnsweredCallsMinutes,
useMaxCallTimeForUnansweredCalls, maxCallTimeForUnansweredCallsMinutes,
useMaxConcurrentRedirectedCalls, useMaxFindMeFollowMeDepth, maxRedirectionDepth,
useMaxConcurrentFindMeFollowMeInvocations, maxConcurrentFindMeFollowMeInvocations) The
useGroupTranslationRoutingSetting attribute controls the routing and translation
settings (networkUsageSelection, enforceGroupCallingLineIdentityRestriction,
allowEnterpriseGroupCallTypingForPrivateDialingPlan,
allowEnterpriseGroupCallTypingForPublicDialingPlan,
overrideCLIDRestrictionForExternalCallsViaPrivateDialingPlan,
enableEnterpriseExtensionDialing) The useGroupDCLIDSetting controls the Dialable
Caller ID settings (enableDialableCallerID)

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallProcessingGetPolicyRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group level data associated with Call Processing Policy.

The response is either a `GroupCallProcessingGetPolicyResponse17()` or an
`ErrorResponse()`. The useGroupCLIDSetting attribute controls the CLID settings
(clidPolicy, emergencyClidPolicy, allowAlternateNumbersForRedirectingIdentity,
useGroupName) The useGroupMediaSetting attribute controls the Media settings
(medisPolicySelection, supportedMediaSetName) The useGroupCallLimitsSetting attribute
controls the Call Limits settings (useMaxSimultaneousCalls, maxSimultaneousCalls,
useMaxSimultaneousVideoCalls, maxSimultaneousVideoCalls,
useMaxCallTimeForAnsweredCalls, maxCallTimeForAnsweredCallsMinutes,
useMaxCallTimeForUnansweredCalls, maxCallTimeForUnansweredCallsMinutes,
useMaxConcurrentRedirectedCalls, useMaxFindMeFollowMeDepth, maxRedirectionDepth,
useMaxConcurrentFindMeFollowMeInvocations, maxConcurrentFindMeFollowMeInvocations) The
useGroupTranslationRoutingSetting attribute controls the routing and translation
settings (networkUsageSelection, enforceGroupCallingLineIdentityRestriction,
allowEnterpriseGroupCallTypingForPrivateDialingPlan,
allowEnterpriseGroupCallTypingForPublicDialingPlan,
overrideCLIDRestrictionForExternalCallsViaPrivateDialingPlan,
enableEnterpriseExtensionDialing)

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallProcessingGetPolicyRequest17sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group level data associated with Call Processing Policy.

The response is either a `GroupCallProcessingGetPolicyResponse17sp3()` or an
`ErrorResponse()`. The useGroupCLIDSetting attribute controls the CLID settings
(clidPolicy, emergencyClidPolicy, allowAlternateNumbersForRedirectingIdentity,
useGroupName) The useGroupMediaSetting attribute controls the Media settings
(medisPolicySelection, supportedMediaSetName) The useGroupCallLimitsSetting attribute
controls the Call Limits settings (useMaxSimultaneousCalls, maxSimultaneousCalls,
useMaxSimultaneousVideoCalls, maxSimultaneousVideoCalls,
useMaxCallTimeForAnsweredCalls, maxCallTimeForAnsweredCallsMinutes,
useMaxCallTimeForUnansweredCalls, maxCallTimeForUnansweredCallsMinutes,
useMaxConcurrentRedirectedCalls, useMaxFindMeFollowMeDepth, maxRedirectionDepth,
useMaxConcurrentFindMeFollowMeInvocations, maxConcurrentFindMeFollowMeInvocations) The
useGroupTranslationRoutingSetting attribute controls the routing and translation
settings (networkUsageSelection, enforceGroupCallingLineIdentityRestriction,
allowEnterpriseGroupCallTypingForPrivateDialingPlan,
allowEnterpriseGroupCallTypingForPublicDialingPlan,
overrideCLIDRestrictionForExternalCallsViaPrivateDialingPlan,
enableEnterpriseExtensionDialing) The useGroupDCLIDSetting controls the Dialable
Caller ID settings (enableDialableCallerID) The following elements are only used in AS
data mode: useGroupDCLIDSetting enableDialableCallerID Replaced by
`GroupCallProcessingGetPolicyRequest17sp4()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallProcessingGetPolicyRequest17sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group level data associated with Call Processing Policy.

The response is either a `GroupCallProcessingGetPolicyResponse17sp4()` or an
`ErrorResponse()`. The useGroupCLIDSetting attribute controls the CLID settings
(clidPolicy, emergencyClidPolicy, allowAlternateNumbersForRedirectingIdentity,
useGroupName, allowConfigurableCLIDForRedirectingIdentity) The useGroupMediaSetting
attribute controls the Media settings (medisPolicySelection, supportedMediaSetName)
The useGroupCallLimitsSetting attribute controls the Call Limits settings
(useMaxSimultaneousCalls, maxSimultaneousCalls, useMaxSimultaneousVideoCalls,
maxSimultaneousVideoCalls, useMaxCallTimeForAnsweredCalls,
maxCallTimeForAnsweredCallsMinutes, useMaxCallTimeForUnansweredCalls,
maxCallTimeForUnansweredCallsMinutes, useMaxConcurrentRedirectedCalls,
useMaxFindMeFollowMeDepth, maxRedirectionDepth,
useMaxConcurrentFindMeFollowMeInvocations, maxConcurrentFindMeFollowMeInvocations) The
useGroupTranslationRoutingSetting attribute controls the routing and translation
settings (networkUsageSelection, enforceGroupCallingLineIdentityRestriction,
allowEnterpriseGroupCallTypingForPrivateDialingPlan,
allowEnterpriseGroupCallTypingForPublicDialingPlan,
overrideCLIDRestrictionForExternalCallsViaPrivateDialingPlan,
enableEnterpriseExtensionDialing) The following elements are only used in AS data
mode: useGroupDCLIDSetting enableDialableCallerID Replaced by
`GroupCallProcessingGetPolicyRequest18()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallProcessingGetPolicyRequest18`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group level data associated with Call Processing Policy.

The response is either a `GroupCallProcessingGetPolicyResponse18()` or an
`ErrorResponse()`. The useGroupCLIDSetting attribute controls the CLID settings
(clidPolicy, emergencyClidPolicy, allowAlternateNumbersForRedirectingIdentity,
useGroupName, allowDepartmentCLIDNameOverride) The useGroupMediaSetting attribute
controls the Media settings (medisPolicySelection, supportedMediaSetName) The
useGroupCallLimitsSetting attribute controls the Call Limits settings
(useMaxSimultaneousCalls, maxSimultaneousCalls, useMaxSimultaneousVideoCalls,
maxSimultaneousVideoCalls, useMaxCallTimeForAnsweredCalls,
maxCallTimeForAnsweredCallsMinutes, useMaxCallTimeForUnansweredCalls,
maxCallTimeForUnansweredCallsMinutes, useMaxConcurrentRedirectedCalls,
useMaxFindMeFollowMeDepth, maxRedirectionDepth,
useMaxConcurrentFindMeFollowMeInvocations, maxConcurrentFindMeFollowMeInvocations) The
useGroupTranslationRoutingSetting attribute controls the routing and translation
settings (networkUsageSelection, enforceGroupCallingLineIdentityRestriction,
allowEnterpriseGroupCallTypingForPrivateDialingPlan,
allowEnterpriseGroupCallTypingForPublicDialingPlan,
overrideCLIDRestrictionForExternalCallsViaPrivateDialingPlan,
enableEnterpriseExtensionDialing) The following elements are only used in AS data
mode: useGroupDCLIDSetting enableDialableCallerID allowDepartmentCLIDNameOverride

Replaced By : `GroupCallProcessingGetPolicyRequest18sp1()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallProcessingGetPolicyRequest18sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group level data associated with Call Processing Policy.

The response is either a `GroupCallProcessingGetPolicyResponse18sp1()` or an
`ErrorResponse()`. The useGroupCLIDSetting attribute controls the CLID settings
(clidPolicy,enterpriseCallsCLIDPolicy, groupCallsCLIDPolicy, emergencyClidPolicy,
allowAlternateNumbersForRedirectingIdentity, useGroupName,
allowDepartmentCLIDNameOverride) The useGroupMediaSetting attribute controls the Media
settings (medisPolicySelection, supportedMediaSetName) The useGroupCallLimitsSetting
attribute controls the Call Limits settings (useMaxSimultaneousCalls,
maxSimultaneousCalls, useMaxSimultaneousVideoCalls, maxSimultaneousVideoCalls,
useMaxCallTimeForAnsweredCalls, maxCallTimeForAnsweredCallsMinutes,
useMaxCallTimeForUnansweredCalls, maxCallTimeForUnansweredCallsMinutes,
useMaxConcurrentRedirectedCalls, useMaxFindMeFollowMeDepth, maxRedirectionDepth,
useMaxConcurrentFindMeFollowMeInvocations, maxConcurrentFindMeFollowMeInvocations) The
useGroupTranslationRoutingSetting attribute controls the routing and translation
settings (networkUsageSelection, enforceGroupCallingLineIdentityRestriction,
allowEnterpriseGroupCallTypingForPrivateDialingPlan,
allowEnterpriseGroupCallTypingForPublicDialingPlan,
overrideCLIDRestrictionForExternalCallsViaPrivateDialingPlan,
enableEnterpriseExtensionDialing) Replaced by:
`GroupCallProcessingGetPolicyRequest19sp1()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallProcessingGetPolicyRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group level data associated with Call Processing Policy.

The response is either a `GroupCallProcessingGetPolicyResponse19sp1()` or an
`ErrorResponse()`. The useGroupCLIDSetting attribute controls the CLID settings
(clidPolicy,enterpriseCallsCLIDPolicy, groupCallsCLIDPolicy, emergencyClidPolicy,
allowAlternateNumbersForRedirectingIdentity, useGroupName,
allowDepartmentCLIDNameOverride) The useGroupMediaSetting attribute controls the Media
settings (medisPolicySelection, supportedMediaSetName) The useGroupCallLimitsSetting
attribute controls the Call Limits settings (useMaxSimultaneousCalls,
maxSimultaneousCalls, useMaxSimultaneousVideoCalls, maxSimultaneousVideoCalls,
useMaxCallTimeForAnsweredCalls, maxCallTimeForAnsweredCallsMinutes,
useMaxCallTimeForUnansweredCalls, maxCallTimeForUnansweredCallsMinutes,
useMaxConcurrentRedirectedCalls, useMaxFindMeFollowMeDepth, maxRedirectionDepth,
useMaxConcurrentFindMeFollowMeInvocations, maxConcurrentFindMeFollowMeInvocations) The
useGroupTranslationRoutingSetting attribute controls the routing and translation
settings (networkUsageSelection, enforceGroupCallingLineIdentityRestriction,
allowEnterpriseGroupCallTypingForPrivateDialingPlan,
allowEnterpriseGroupCallTypingForPublicDialingPlan,
overrideCLIDRestrictionForExternalCallsViaPrivateDialingPlan,
enableEnterpriseExtensionDialing) Replaced by:
`GroupCallProcessingGetPolicyRequest21sp1()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallProcessingGetPolicyRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group level data associated with Call Processing Policy.

The response is either a `GroupCallProcessingGetPolicyResponse21sp1()` or an
`ErrorResponse()`. The useGroupCLIDSetting attribute controls the CLID settings
(clidPolicy,enterpriseCallsCLIDPolicy, groupCallsCLIDPolicy, emergencyClidPolicy,
allowAlternateNumbersForRedirectingIdentity, useGroupName,
allowDepartmentCLIDNameOverride) The useGroupMediaSetting attribute controls the Media
settings (medisPolicySelection, supportedMediaSetName) The useGroupCallLimitsSetting
attribute controls the Call Limits settings (useMaxSimultaneousCalls,
maxSimultaneousCalls, useMaxSimultaneousVideoCalls, maxSimultaneousVideoCalls,
useMaxCallTimeForAnsweredCalls, maxCallTimeForAnsweredCallsMinutes,
useMaxCallTimeForUnansweredCalls, maxCallTimeForUnansweredCallsMinutes,
useMaxConcurrentRedirectedCalls, useMaxFindMeFollowMeDepth, maxRedirectionDepth,
useMaxConcurrentFindMeFollowMeInvocations, maxConcurrentFindMeFollowMeInvocations) The
useGroupTranslationRoutingSetting attribute controls the routing and translation
settings (networkUsageSelection, enforceGroupCallingLineIdentityRestriction,
allowEnterpriseGroupCallTypingForPrivateDialingPlan,
allowEnterpriseGroupCallTypingForPublicDialingPlan,
overrideCLIDRestrictionForExternalCallsViaPrivateDialingPlan,
enableEnterpriseExtensionDialing) Replaced by:
`GroupCallProcessingGetPolicyRequest21sp2()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallProcessingGetPolicyRequest21sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group level data associated with Call Processing Policy.

The response is either a `GroupCallProcessingGetPolicyResponse21sp2()` or an
`ErrorResponse()`. The useGroupCLIDSetting attribute controls the CLID settings
(clidPolicy,enterpriseCallsCLIDPolicy, groupCallsCLIDPolicy, emergencyClidPolicy,
allowAlternateNumbersForRedirectingIdentity, useGroupName,
allowDepartmentCLIDNameOverride) The useGroupMediaSetting attribute controls the Media
settings (medisPolicySelection, supportedMediaSetName) The useGroupCallLimitsSetting
attribute controls the Call Limits settings (useMaxSimultaneousCalls,
maxSimultaneousCalls, useMaxSimultaneousVideoCalls, maxSimultaneousVideoCalls,
useMaxCallTimeForAnsweredCalls, maxCallTimeForAnsweredCallsMinutes,
useMaxCallTimeForUnansweredCalls, maxCallTimeForUnansweredCallsMinutes,
useMaxConcurrentRedirectedCalls, useMaxFindMeFollowMeDepth, maxRedirectionDepth,
useMaxConcurrentFindMeFollowMeInvocations, maxConcurrentFindMeFollowMeInvocations) The
useGroupTranslationRoutingSetting attribute controls the routing and translation
settings (networkUsageSelection, enforceGroupCallingLineIdentityRestriction,
allowEnterpriseGroupCallTypingForPrivateDialingPlan,
allowEnterpriseGroupCallTypingForPublicDialingPlan,
overrideCLIDRestrictionForExternalCallsViaPrivateDialingPlan,
enableEnterpriseExtensionDialing, routeOverrideDomain, routeOverridePrefix) Replaced
by: `GroupCallProcessingGetPolicyRequest22()` in AS data mode

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallProcessingGetPolicyRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group level data associated with Call Processing Policy.

The response is either a `GroupCallProcessingGetPolicyResponse22()` or an
`ErrorResponse()`. The useGroupCLIDSetting attribute controls the CLID settings
(clidPolicy,enterpriseCallsCLIDPolicy, groupCallsCLIDPolicy, emergencyClidPolicy,
allowAlternateNumbersForRedirectingIdentity, useGroupName,
allowDepartmentCLIDNameOverride) The useGroupMediaSetting attribute controls the Media
settings (medisPolicySelection, supportedMediaSetName) The useGroupCallLimitsSetting
attribute controls the Call Limits settings (useMaxSimultaneousCalls,
maxSimultaneousCalls, useMaxSimultaneousVideoCalls, maxSimultaneousVideoCalls,
useMaxCallTimeForAnsweredCalls, maxCallTimeForAnsweredCallsMinutes,
useMaxCallTimeForUnansweredCalls, maxCallTimeForUnansweredCallsMinutes,
useMaxConcurrentRedirectedCalls, useMaxFindMeFollowMeDepth, maxRedirectionDepth,
useMaxConcurrentFindMeFollowMeInvocations, maxConcurrentFindMeFollowMeInvocations,
useMaxConcurrentTerminatingAlertingRequests, maxConcurrentTerminatingAlertingRequests)
The useGroupTranslationRoutingSetting attribute controls the routing and translation
settings (networkUsageSelection, enforceGroupCallingLineIdentityRestriction,
allowEnterpriseGroupCallTypingForPrivateDialingPlan,
allowEnterpriseGroupCallTypingForPublicDialingPlan,
overrideCLIDRestrictionForExternalCallsViaPrivateDialingPlan,
enableEnterpriseExtensionDialing) Replaced by:
`GroupCallProcessingGetPolicyRequest22V2()` in AS data mode.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallProcessingGetPolicyRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group level data associated with Call Processing Policy.

The response is either a `GroupCallProcessingGetPolicyResponse22V2()` or an
`ErrorResponse()`. The useGroupCLIDSetting attribute controls the CLID settings
(clidPolicy,enterpriseCallsCLIDPolicy, groupCallsCLIDPolicy, emergencyClidPolicy,
allowAlternateNumbersForRedirectingIdentity, useGroupName,
allowDepartmentCLIDNameOverride) The useGroupMediaSetting attribute controls the Media
settings (medisPolicySelection, supportedMediaSetName) The useGroupCallLimitsSetting
attribute controls the Call Limits settings (useMaxSimultaneousCalls,
maxSimultaneousCalls, useMaxSimultaneousVideoCalls, maxSimultaneousVideoCalls,
useMaxCallTimeForAnsweredCalls, maxCallTimeForAnsweredCallsMinutes,
useMaxCallTimeForUnansweredCalls, maxCallTimeForUnansweredCallsMinutes,
useMaxConcurrentRedirectedCalls, useMaxFindMeFollowMeDepth, maxRedirectionDepth,
useMaxConcurrentFindMeFollowMeInvocations, maxConcurrentFindMeFollowMeInvocations,
useMaxConcurrentTerminatingAlertingRequests, maxConcurrentTerminatingAlertingRequests)
The useGroupTranslationRoutingSetting attribute controls the routing and translation
settings (networkUsageSelection, enforceGroupCallingLineIdentityRestriction,
allowEnterpriseGroupCallTypingForPrivateDialingPlan,
allowEnterpriseGroupCallTypingForPublicDialingPlan,
overrideCLIDRestrictionForExternalCallsViaPrivateDialingPlan,
enableEnterpriseExtensionDialing) Replaced by:
`GroupCallProcessingGetPolicyRequest22V3()` in AS data mode.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallProcessingGetPolicyRequest22V3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group level data associated with Call Processing Policy.

The response is either a `GroupCallProcessingGetPolicyResponse22V3()` or an
`ErrorResponse()`. The useGroupCLIDSetting attribute controls the CLID settings
(clidPolicy,enterpriseCallsCLIDPolicy, groupCallsCLIDPolicy, emergencyClidPolicy,
allowAlternateNumbersForRedirectingIdentity, useGroupName,
allowDepartmentCLIDNameOverride) The useGroupMediaSetting attribute controls the Media
settings (medisPolicySelection, supportedMediaSetName) The useGroupCallLimitsSetting
attribute controls the Call Limits settings (useMaxSimultaneousCalls,
maxSimultaneousCalls, useMaxSimultaneousVideoCalls, maxSimultaneousVideoCalls,
useMaxCallTimeForAnsweredCalls, maxCallTimeForAnsweredCallsMinutes,
useMaxCallTimeForUnansweredCalls, maxCallTimeForUnansweredCallsMinutes,
useMaxConcurrentRedirectedCalls, useMaxFindMeFollowMeDepth, maxRedirectionDepth,
useMaxConcurrentFindMeFollowMeInvocations, maxConcurrentFindMeFollowMeInvocations,
useMaxConcurrentTerminatingAlertingRequests, maxConcurrentTerminatingAlertingRequests)
The useGroupTranslationRoutingSetting attribute controls the routing and translation
settings (networkUsageSelection, enforceGroupCallingLineIdentityRestriction,
allowEnterpriseGroupCallTypingForPrivateDialingPlan,
allowEnterpriseGroupCallTypingForPublicDialingPlan,
overrideCLIDRestrictionForExternalCallsViaPrivateDialingPlan,
enableEnterpriseExtensionDialing)

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallProcessingModifyPolicyRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the group level data associated with Call Processing Policy.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

Replaced By : `GroupCallProcessingModifyPolicyRequest15()`

**Attributes:**

|Name                                                                  |Type |Description                                                             |
|----------------------------------------------------------------------|-----|------------------------------------------------------------------------|
|service_provider_id                                                   |str  |serviceProviderId                                                       |
|group_id                                                              |str  |groupId                                                                 |
|use_group_setting                                                     |bool |useGroupSetting *Optional*                                              |
|use_max_simultaneous_calls                                            |bool |useMaxSimultaneousCalls *Optional*                                      |
|max_simultaneous_calls                                                |int  |maxSimultaneousCalls *Optional*                                         |
|use_max_simultaneous_video_calls                                      |bool |useMaxSimultaneousVideoCalls *Optional*                                 |
|max_simultaneous_video_calls                                          |int  |maxSimultaneousVideoCalls *Optional*                                    |
|use_max_call_time_for_answered_calls                                  |bool |useMaxCallTimeForAnsweredCalls *Optional*                               |
|max_call_time_for_answered_calls_minutes                              |int  |maxCallTimeForAnsweredCallsMinutes *Optional*                           |
|use_max_call_time_for_unanswered_calls                                |bool |useMaxCallTimeForUnansweredCalls *Optional*                             |
|max_call_time_for_unanswered_calls_minutes                            |int  |maxCallTimeForUnansweredCallsMinutes *Optional*                         |
|media_policy_selection                                                |str  |mediaPolicySelection *Optional*                                         |
|supported_media_set_name                                              |str  |supportedMediaSetName *Optional*                                        |
|network_usage_selection                                               |str  |networkUsageSelection *Optional*                                        |
|enforce_group_calling_line_identity_restriction                       |bool |enforceGroupCallingLineIdentityRestriction *Optional*                   |
|allow_enterprise_group_call_typing_for_private_dialing_plan           |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan *Optional*          |
|allow_enterprise_group_call_typing_for_public_dialing_plan            |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan *Optional*           |
|override_clid_restriction_for_external_calls_via_private_dialing_plan |bool |overrideCLIDRestrictionForExternalCallsViaPrivateDialingPlan *Optional* |
|enable_enterprise_extension_dialing                                   |bool |enableEnterpriseExtensionDialing *Optional*                             |
|use_max_concurrent_redirected_calls                                   |bool |useMaxConcurrentRedirectedCalls *Optional*                              |
|max_concurrent_redirected_calls                                       |int  |maxConcurrentRedirectedCalls *Optional*                                 |
|use_max_find_me_follow_me_depth                                       |bool |useMaxFindMeFollowMeDepth *Optional*                                    |
|max_find_me_follow_me_depth                                           |int  |maxFindMeFollowMeDepth *Optional*                                       |
|max_redirection_depth                                                 |int  |maxRedirectionDepth *Optional*                                          |
|use_max_concurrent_find_me_follow_me_invocations                      |bool |useMaxConcurrentFindMeFollowMeInvocations *Optional*                    |
|max_concurrent_find_me_follow_me_invocations                          |int  |maxConcurrentFindMeFollowMeInvocations *Optional*                       |
</div>


## `GroupCallProcessingModifyPolicyRequest14sp7`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the group level data associated with Call Processing Policy.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The
useGroupCLIDSetting attribute controls the CLID settings (clidPolicy,
emergencyClidPolicy, allowAlternateNumbersForRedirectingIdentity, useGroupName) The
useGroupMediaSetting attribute controls the Media settings (medisPolicySelection,
supportedMediaSetName) The useGroupCallLimitsSetting attribute controls the Call
Limits settings (useMaxSimultaneousCalls, maxSimultaneousCalls,
useMaxSimultaneousVideoCalls, maxSimultaneousVideoCalls,
useMaxCallTimeForAnsweredCalls, maxCallTimeForAnsweredCallsMinutes,
useMaxCallTimeForUnansweredCalls, maxCallTimeForUnansweredCallsMinutes,
useMaxConcurrentRedirectedCalls, useMaxFindMeFollowMeDepth, maxRedirectionDepth,
useMaxConcurrentFindMeFollowMeInvocations, maxConcurrentFindMeFollowMeInvocations) The
useGroupTranslationRoutingSetting attribute controls the routing and translation
settings (networkUsageSelection, enforceGroupCallingLineIdentityRestriction,
allowEnterpriseGroupCallTypingForPrivateDialingPlan,
allowEnterpriseGroupCallTypingForPublicDialingPlan,
overrideCLIDRestrictionForExternalCallsViaPrivateDialingPlan,
enableEnterpriseExtensionDialing)

Replaced By: `GroupCallProcessingModifyPolicyRequest15sp2()`

**Attributes:**

|Name                                                                  |Type |Description                                                             |
|----------------------------------------------------------------------|-----|------------------------------------------------------------------------|
|service_provider_id                                                   |str  |serviceProviderId                                                       |
|group_id                                                              |str  |groupId                                                                 |
|use_group_clid_setting                                                |bool |useGroupCLIDSetting *Optional*                                          |
|use_group_media_setting                                               |bool |useGroupMediaSetting *Optional*                                         |
|use_group_call_limits_setting                                         |bool |useGroupCallLimitsSetting *Optional*                                    |
|use_group_translation_routing_setting                                 |bool |useGroupTranslationRoutingSetting *Optional*                            |
|use_max_simultaneous_calls                                            |bool |useMaxSimultaneousCalls *Optional*                                      |
|max_simultaneous_calls                                                |int  |maxSimultaneousCalls *Optional*                                         |
|use_max_simultaneous_video_calls                                      |bool |useMaxSimultaneousVideoCalls *Optional*                                 |
|max_simultaneous_video_calls                                          |int  |maxSimultaneousVideoCalls *Optional*                                    |
|use_max_call_time_for_answered_calls                                  |bool |useMaxCallTimeForAnsweredCalls *Optional*                               |
|max_call_time_for_answered_calls_minutes                              |int  |maxCallTimeForAnsweredCallsMinutes *Optional*                           |
|use_max_call_time_for_unanswered_calls                                |bool |useMaxCallTimeForUnansweredCalls *Optional*                             |
|max_call_time_for_unanswered_calls_minutes                            |int  |maxCallTimeForUnansweredCallsMinutes *Optional*                         |
|media_policy_selection                                                |str  |mediaPolicySelection *Optional*                                         |
|supported_media_set_name                                              |str  |supportedMediaSetName *Optional*                                        |
|network_usage_selection                                               |str  |networkUsageSelection *Optional*                                        |
|enforce_group_calling_line_identity_restriction                       |bool |enforceGroupCallingLineIdentityRestriction *Optional*                   |
|allow_enterprise_group_call_typing_for_private_dialing_plan           |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan *Optional*          |
|allow_enterprise_group_call_typing_for_public_dialing_plan            |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan *Optional*           |
|override_clid_restriction_for_external_calls_via_private_dialing_plan |bool |overrideCLIDRestrictionForExternalCallsViaPrivateDialingPlan *Optional* |
|enable_enterprise_extension_dialing                                   |bool |enableEnterpriseExtensionDialing *Optional*                             |
|use_max_concurrent_redirected_calls                                   |bool |useMaxConcurrentRedirectedCalls *Optional*                              |
|max_concurrent_redirected_calls                                       |int  |maxConcurrentRedirectedCalls *Optional*                                 |
|use_max_find_me_follow_me_depth                                       |bool |useMaxFindMeFollowMeDepth *Optional*                                    |
|max_find_me_follow_me_depth                                           |int  |maxFindMeFollowMeDepth *Optional*                                       |
|max_redirection_depth                                                 |int  |maxRedirectionDepth *Optional*                                          |
|use_max_concurrent_find_me_follow_me_invocations                      |bool |useMaxConcurrentFindMeFollowMeInvocations *Optional*                    |
|max_concurrent_find_me_follow_me_invocations                          |int  |maxConcurrentFindMeFollowMeInvocations *Optional*                       |
|clid_policy                                                           |str  |clidPolicy *Optional*                                                   |
|emergency_clid_policy                                                 |str  |emergencyClidPolicy *Optional*                                          |
|allow_alternate_numbers_for_redirecting_identity                      |bool |allowAlternateNumbersForRedirectingIdentity *Optional*                  |
|use_group_name                                                        |bool |useGroupName *Optional*                                                 |
</div>


## `GroupCallProcessingModifyPolicyRequest15`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the group level data associated with Call Processing Policy.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

Replaced By: `GroupCallProcessingModifyPolicyRequest15sp2()`

**Attributes:**

|Name                                                        |Type |Description                                                    |
|------------------------------------------------------------|-----|---------------------------------------------------------------|
|service_provider_id                                         |str  |serviceProviderId                                              |
|group_id                                                    |str  |groupId                                                        |
|use_group_setting                                           |bool |useGroupSetting *Optional*                                     |
|use_max_simultaneous_calls                                  |bool |useMaxSimultaneousCalls *Optional*                             |
|max_simultaneous_calls                                      |int  |maxSimultaneousCalls *Optional*                                |
|use_max_simultaneous_video_calls                            |bool |useMaxSimultaneousVideoCalls *Optional*                        |
|max_simultaneous_video_calls                                |int  |maxSimultaneousVideoCalls *Optional*                           |
|use_max_call_time_for_answered_calls                        |bool |useMaxCallTimeForAnsweredCalls *Optional*                      |
|max_call_time_for_answered_calls_minutes                    |int  |maxCallTimeForAnsweredCallsMinutes *Optional*                  |
|use_max_call_time_for_unanswered_calls                      |bool |useMaxCallTimeForUnansweredCalls *Optional*                    |
|max_call_time_for_unanswered_calls_minutes                  |int  |maxCallTimeForUnansweredCallsMinutes *Optional*                |
|media_policy_selection                                      |str  |mediaPolicySelection *Optional*                                |
|supported_media_set_name                                    |str  |supportedMediaSetName *Optional*                               |
|network_usage_selection                                     |str  |networkUsageSelection *Optional*                               |
|enforce_group_calling_line_identity_restriction             |bool |enforceGroupCallingLineIdentityRestriction *Optional*          |
|allow_enterprise_group_call_typing_for_private_dialing_plan |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan *Optional* |
|allow_enterprise_group_call_typing_for_public_dialing_plan  |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan *Optional*  |
|override_clid_restriction_for_private_call_category         |bool |overrideCLIDRestrictionForPrivateCallCategory *Optional*       |
|use_enterprise_clid_for_private_call_category               |bool |useEnterpriseCLIDForPrivateCallCategory *Optional*             |
|enable_enterprise_extension_dialing                         |bool |enableEnterpriseExtensionDialing *Optional*                    |
|use_max_concurrent_redirected_calls                         |bool |useMaxConcurrentRedirectedCalls *Optional*                     |
|max_concurrent_redirected_calls                             |int  |maxConcurrentRedirectedCalls *Optional*                        |
|use_max_find_me_follow_me_depth                             |bool |useMaxFindMeFollowMeDepth *Optional*                           |
|max_find_me_follow_me_depth                                 |int  |maxFindMeFollowMeDepth *Optional*                              |
|max_redirection_depth                                       |int  |maxRedirectionDepth *Optional*                                 |
|use_max_concurrent_find_me_follow_me_invocations            |bool |useMaxConcurrentFindMeFollowMeInvocations *Optional*           |
|max_concurrent_find_me_follow_me_invocations                |int  |maxConcurrentFindMeFollowMeInvocations *Optional*              |
</div>


## `GroupCallProcessingModifyPolicyRequest15sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the group level data associated with Call Processing Policy.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The
useGroupCLIDSetting attribute controls the CLID settings
(clidPolicy,enterpriseCallsCLIDPolicy, groupCallsCLIDPolicy, emergencyClidPolicy,
allowAlternateNumbersForRedirectingIdentity, useGroupName,
allowConfigurableCLIDForRedirectingIdentity, allowDepartmentCLIDNameOverride
useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable,
useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailabl) The
allowDepartmentCLID attribute is automatically set to false when the useGroupName
attribute is set to false.  The useGroupMediaSetting attribute controls the Media
settings (medisPolicySelection, supportedMediaSetName) The useGroupCallLimitsSetting
attribute controls the Call Limits settings (useMaxSimultaneousCalls,
maxSimultaneousCalls, useMaxSimultaneousVideoCalls, maxSimultaneousVideoCalls,
useMaxCallTimeForAnsweredCalls, maxCallTimeForAnsweredCallsMinutes,
useMaxCallTimeForUnansweredCalls, maxCallTimeForUnansweredCallsMinutes,
useMaxConcurrentRedirectedCalls, useMaxFindMeFollowMeDepth, maxRedirectionDepth,
useMaxConcurrentFindMeFollowMeInvocations, maxConcurrentFindMeFollowMeInvocations,
useMaxConcurrentTerminatingAlertingRequests, maxConcurrentTerminatingAlertingRequests,
includeRedirectionsInMaximumNumberOfConcurrentCalls) The
useGroupTranslationRoutingSetting attribute controls the routing and translation
settings (networkUsageSelection, enforceGroupCallingLineIdentityRestriction,
allowEnterpriseGroupCallTypingForPrivateDialingPlan,
allowEnterpriseGroupCallTypingForPublicDialingPlan,
overrideCLIDRestrictionForExternalCallsViaPrivateDialingPlan,
enableEnterpriseExtensionDialing, routeOverrideDomain, routeOverridePrefix) The
useGroupDCLIDSetting controls the Dialable Caller ID settings (enableDialableCallerID)
The useGroupPhoneListLookupSetting controls whether or not to use the
enterprise/service provider setting for the Phone List Lookup policy
(enablePhoneListLookup) The following elements are only used in AS data mode:
useGroupDCLIDSetting enableDialableCallerID
allowConfigurableCLIDForRedirectingIdentity allowDepartmentCLIDNameOverride
allowConfigurableCLIDForRedirectingIdentity enterpriseCallsCLIDPolicy
groupCallsCLIDPolicy The following elements are only used in AS data mode and ignored
in XS data mode: useGroupPhoneListLookupSetting enablePhoneListLookup
useMaxConcurrentTerminatingAlertingRequests maxConcurrentTerminatingAlertingRequests
includeRedirectionsInMaximumNumberOfConcurrentCalls
useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable
useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable
allowMobileDNForRedirectingIdentity enableGatewayRoutePolicy
networkCallsGatewayRouteIdentity networkURLCallsGatewayRouteIdentity
emergencyCallsGatewayRouteIdentity repairCallsGatewayRouteIdentity
callTypingErrorsGatewayRouteIdentity The following elements are only used in XS data
mode and ignored in AS data mode: routeOverrideDomain routeOverridePrefix

**Attributes:**

|Name                                                                      |Type |Description                                                                |
|--------------------------------------------------------------------------|-----|---------------------------------------------------------------------------|
|service_provider_id                                                       |str  |serviceProviderId                                                          |
|group_id                                                                  |str  |groupId                                                                    |
|use_group_clid_setting                                                    |bool |useGroupCLIDSetting *Optional*                                             |
|use_group_media_setting                                                   |bool |useGroupMediaSetting *Optional*                                            |
|use_group_call_limits_setting                                             |bool |useGroupCallLimitsSetting *Optional*                                       |
|use_group_translation_routing_setting                                     |bool |useGroupTranslationRoutingSetting *Optional*                               |
|use_group_dclid_setting                                                   |bool |useGroupDCLIDSetting *Optional*                                            |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls *Optional*                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls *Optional*                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls *Optional*                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls *Optional*                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls *Optional*                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes *Optional*                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls *Optional*                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes *Optional*                            |
|media_policy_selection                                                    |str  |mediaPolicySelection *Optional*                                            |
|supported_media_set_name                                                  |str  |supportedMediaSetName *Optional*                                           |
|network_usage_selection                                                   |str  |networkUsageSelection *Optional*                                           |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction *Optional*                      |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan *Optional*             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan *Optional*              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory *Optional*                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory *Optional*                         |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing *Optional*                                |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls *Optional*                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls *Optional*                                    |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth *Optional*                                       |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth *Optional*                                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth *Optional*                                             |
|use_max_concurrent_find_me_follow_me_invocations                          |bool |useMaxConcurrentFindMeFollowMeInvocations *Optional*                       |
|max_concurrent_find_me_follow_me_invocations                              |int  |maxConcurrentFindMeFollowMeInvocations *Optional*                          |
|clid_policy                                                               |str  |clidPolicy *Optional*                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy *Optional*                                             |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity *Optional*                     |
|use_group_name                                                            |bool |useGroupName *Optional*                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls *Optional*                                |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID *Optional*                                          |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity *Optional*                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride *Optional*                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy *Optional*                                       |
|group_calls_clid_policy                                                   |str  |groupCallsCLIDPolicy *Optional*                                            |
|use_group_phone_list_lookup_setting                                       |bool |useGroupPhoneListLookupSetting *Optional*                                  |
|enable_phone_list_lookup                                                  |bool |enablePhoneListLookup *Optional*                                           |
|use_max_concurrent_terminating_alerting_requests                          |bool |useMaxConcurrentTerminatingAlertingRequests *Optional*                     |
|max_concurrent_terminating_alerting_requests                              |int  |maxConcurrentTerminatingAlertingRequests *Optional*                        |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls *Optional*             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable *Optional*      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable *Optional* |
|route_override_domain                                                     |str  |routeOverrideDomain *Optional*                                             |
|route_override_prefix                                                     |str  |routeOverridePrefix *Optional*                                             |
|allow_mobile_dn_for_redirecting_identity                                  |bool |allowMobileDNForRedirectingIdentity *Optional*                             |
|enable_gateway_route_policy                                               |bool |enableGatewayRoutePolicy *Optional*                                        |
|network_calls_gateway_route_identity                                      |str  |networkCallsGatewayRouteIdentity *Optional*                                |
|network_url_calls_gateway_route_identity                                  |str  |networkURLCallsGatewayRouteIdentity *Optional*                             |
|emergency_calls_gateway_route_identity                                    |str  |emergencyCallsGatewayRouteIdentity *Optional*                              |
|repair_calls_gateway_route_identity                                       |str  |repairCallsGatewayRouteIdentity *Optional*                                 |
|call_typing_errors_gateway_route_identity                                 |str  |callTypingErrorsGatewayRouteIdentity *Optional*                            |
</div>


## `GroupCallRecordingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the Call Recording platform for a group.

The response is either a `GroupCallRecordingGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallRecordingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Call Recording platform assignment for a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|name                |str |name *Optional*   |
</div>


## `GroupCallingLineIdGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the calling line id settings for a group.

The response is either a `GroupCallingLineIdGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallingLineIdModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the calling line id settings for a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                         |Type |Description                         |
|-----------------------------|-----|------------------------------------|
|service_provider_id          |str  |serviceProviderId                   |
|group_id                     |str  |groupId                             |
|use_group_number             |bool |useGroupNumber *Optional*           |
|use_group_name               |bool |useGroupName *Optional*             |
|calling_line_id_phone_number |str  |callingLineIdPhoneNumber *Optional* |
</div>


## `GroupCallingPlanAddDigitPatternRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a new calling plan digit string.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|name                |str |name              |
|digit_pattern       |str |digitPattern      |
</div>


## `GroupCallingPlanDeleteDigitPatternListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete one or more calling plan digit strings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|group_id            |str       |groupId           |
|name                |List[str] |name              |
</div>


## `GroupCallingPlanGetDigitPatternListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of calling plan digit strings for a group.

The response is either a `GroupCallingPlanGetDigitPatternListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCallingPlanModifyDigitPatternRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a calling plan digit string.

The name is a key; it cannot be changed.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description             |
|--------------------|----|------------------------|
|service_provider_id |str |serviceProviderId       |
|group_id            |str |groupId                 |
|name                |str |name                    |
|digit_pattern       |str |digitPattern *Optional* |
</div>


## `GroupCollaborateBridgeConsolidatedDeleteInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a collaborate bridge from a group.

The request fails when attempting to delete the default collaborate bridge.  If
UnassignPhoneNumbersLevel is set to 'Group', the user's primary phone number, fax
number and any alternate numbers, will be un-assigned from the group if the command is
executed by a service provider administrator or above.  When set to 'Service
Provider', they will be un-assigned from the group and service provider if the command
is executed by a provisioning administrator or above.  When omitted, the number(s)
will be left assigned to the group.  An `ErrorResponse()` will be returned if any
number cannot be unassigned because of insufficient privilege.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                   |Type|Description                     |
|-----------------------|----|--------------------------------|
|service_user_id        |str |serviceUserId                   |
|unassign_phone_numbers |str |unassignPhoneNumbers *Optional* |
</div>


## `GroupCollaborateBridgeDeleteInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a collaborate bridge from a group.

The request fails when attempting to delete the default collaborate bridge.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCollaborateBridgeGetInstanceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of collaborate bridges within a group.

The response is either `GroupCollaborateBridgeGetInstanceListResponse()` or
`ErrorResponse()`. It is possible to get the instances within a specified department.

**Attributes:**

|Name                |Type|Description               |
|--------------------|----|--------------------------|
|service_provider_id |str |serviceProviderId         |
|group_id            |str |groupId                   |
|department_name     |str |departmentName *Optional* |
</div>


## `GroupCollaborateBridgeGetInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a collaborate bridge.

The response is either `GroupCollaborateBridgeGetInstanceResponse()` or
`ErrorResponse()`. Replaced by: `GroupCollaborateBridgeGetInstanceRequest20sp1()`

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCollaborateBridgeGetInstanceRequest20sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a collaborate bridge.

The response is either `GroupCollaborateBridgeGetInstanceResponse20sp1()` or
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupCommonPhoneListDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete one or more entries from a group's common phone list.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|group_id            |str       |groupId           |
|entry_name          |List[str] |entryName         |
</div>


## `GroupCommonPhoneListModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an entry in a group's common phone list.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description             |
|--------------------|----|------------------------|
|service_provider_id |str |serviceProviderId       |
|group_id            |str |groupId                 |
|entry_name          |str |entryName               |
|new_entry_name      |str |newEntryName *Optional* |
|phone_number        |str |phoneNumber *Optional*  |
</div>


## `GroupCommunicationBarringAuthorizationCodeDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a list of Communication Barring Authorization codes from a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|group_id            |str       |groupId           |
|code                |List[str] |code              |
</div>


## `GroupCommunicationBarringAuthorizationCodeGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of Communication Barring Authorization Codes for a group.

The response is either a `GroupCommunicationBarringAuthorizationCodeGetListResponse()`
or an `ErorResponse()`. Replaced by:
`GroupCommunicationBarringAuthorizationCodeGetListRequest21sp1()` in AS data mode

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCommunicationBarringAuthorizationCodeGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group Communication Barring Authorization Code setting.

The response is either a `GroupCommunicationBarringAuthorizationCodeGetResponse()` or
an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|code                |str |code              |
</div>


## `GroupCommunicationBarringAuthorizationCodeModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the group Communication Barring Authorization Code settings The response is
either a `SuccessResponse()` or an `ErrorResponse()`.


**Attributes:**

|Name                     |Type|Description                      |
|-------------------------|----|---------------------------------|
|service_provider_id      |str |serviceProviderId                |
|group_id                 |str |groupId                          |
|code                     |str |code                             |
|description              |str |description *Optional*           |
|network_class_of_service |str |networkClassOfService *Optional* |
</div>


## `GroupCommunicationBarringGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Gets Communication Barring setting for a group.

The response is either a `GroupCommunicationBarringGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCommunicationBarringModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Gets Communication Barring setting for a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                 |Type |Description                                 |
|-------------------------------------|-----|--------------------------------------------|
|service_provider_id                  |str  |serviceProviderId                           |
|group_id                             |str  |groupId                                     |
|use_default_service_provider_profile |bool |useDefaultServiceProviderProfile *Optional* |
|profile                              |str  |profile *Optional*                          |
</div>


## `GroupCommunicationBarringProfileGetAssignedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of all communication barring profiles assigned to the group.

The response is either a `GroupCommunicationBarringProfileGetAssignedListResponse()`
or an `ErrorResponse()`. This command only applies to groups in an Enterprise.  This
command will fail for groups in a Service Provider.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCustomContactDirectoryAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Adds a Custom Contact Directory to a group.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replace by:
`GroupCustomContactDirectoryAddRequest17()`

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|group_id            |str       |groupId           |
|name                |str       |name              |
|user_id             |List[str] |userId *Optional* |
</div>


## `GroupCustomContactDirectoryDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Deletes a Custom Contact Directory to a group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|name                |str |name              |
</div>


## `GroupCustomContactDirectoryGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Gets the list of Custom Contact Directories for a group.

The response is either `GroupCustomContactDirectoryGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCustomContactDirectoryGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Gets a Custom Contact Directory in a group.

The response is either `GroupCustomContactDirectoryGetResponse()` or
`ErrorResponse()`. Replace by: `GroupCustomContactDirectoryGetRequest17()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|name                |str |name              |
</div>


## `GroupCustomRingbackGroupGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the group's custom ring back service settings.

The response is either a `GroupCustomRingbackGroupGetResponse()` or an
`ErrorResponse()`.

Replaced By: `GroupCustomRingbackGroupGetRequest16()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCustomRingbackGroupGetRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the group's custom ring back service settings.

The response is either a `GroupCustomRingbackGroupGetResponse16()` or an
`ErrorResponse()`. Replaced by: `GroupCustomRingbackGroupGetRequest20()` in AS data
mode

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupCustomRingbackGroupGetRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the group's custom ring back service settings.

The response is either a `GroupCustomRingbackGroupGetResponse20()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupDepartmentAdminDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a group department administrator.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `GroupDepartmentAdminGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a group department administrators profile.

The response is either a `GroupDepartmentAdminGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `GroupDepartmentAdminModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a group department administrator.

Since old password is not specified here, any password rule related to old password
does not apply.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name       |Type|Description          |
|-----------|----|---------------------|
|user_id    |str |userId               |
|first_name |str |firstName *Optional* |
|last_name  |str |lastName *Optional*  |
|password   |str |password *Optional*  |
|language   |str |language *Optional*  |
</div>


## `GroupDepartmentDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a department from a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|department_name     |str |departmentName    |
</div>


## `GroupDepartmentGetAvailableParentListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of departments that could be the parent department of the specified
department.

The department itself and all its descendents are not eligible to be the parent
department.  If the group belongs to an enterprise, it also returns the departments
defined in the enterprise it belongs to.

The response is either `GroupDepartmentGetAvailableParentListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|department_name     |str |departmentName    |
</div>


## `GroupDepartmentGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a list of departments in a group.

You may request only the list of departments defined at the group-level, or you may
request the list of all departments in the group including all the departments defined
within the enterprise the group belongs to.

The response is either `GroupDepartmentGetListResponse()` or `ErrorResponse()`.
Replaced by: `GroupDepartmentGetListRequest18()`

**Attributes:**

|Name                           |Type |Description                  |
|-------------------------------|-----|-----------------------------|
|service_provider_id            |str  |serviceProviderId            |
|group_id                       |str  |groupId                      |
|include_enterprise_departments |bool |includeEnterpriseDepartments |
</div>


## `GroupDepartmentGetListRequest18`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a list of departments in a group.

You may request only the list of departments defined at the group-level, or you may
request the list of all departments in the group including all the departments defined
within the enterprise the group belongs to.

The response is either `GroupDepartmentGetListResponse18()` or `ErrorResponse()`.

**Attributes:**

|Name                           |Type |Description                  |
|-------------------------------|-----|-----------------------------|
|service_provider_id            |str  |serviceProviderId            |
|group_id                       |str  |groupId                      |
|include_enterprise_departments |bool |includeEnterpriseDepartments |
</div>


## `GroupDepartmentGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the attributes of a department.

The response is either a `GroupDepartmentGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|department_name     |str |departmentName    |
</div>


## `GroupDeviceActivationPolicyGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the Device Activation policy of a group.

The response is either a `GroupDeviceActivationPolicyGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupDeviceActivationPolicyModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Device Activation policy of a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                  |Type |Description                                 |
|--------------------------------------|-----|--------------------------------------------|
|service_provider_id                   |str  |serviceProviderId                           |
|group_id                              |str  |groupId                                     |
|use_group_settings                    |bool |useGroupSettings *Optional*                 |
|allow_activation_code_request_by_user |bool |allowActivationCodeRequestByUser *Optional* |
|send_activation_code_in_email         |bool |sendActivationCodeInEmail *Optional*        |
</div>


## `GroupDeviceManagementGetAccessDeviceCountForDeviceTypeGroupRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the number of access device of a particular device type and group.

If countOnlyResetSupportedDevice is true, count only access devices if the device type
supports reset.  By default unmanaged device types are not allowed and devices are
counted only if their device type supports Device Management.  An error is returned if
deviceType is specified but does not support device management.  When
allowUnmanagedDeviceType is true, unmanaged device type will be counted and a
successful response is returned.

The response is either
`GroupDeviceManagementGetAccessDeviceCountForDeviceTypeGroupResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                              |Type |Description                              |
|----------------------------------|-----|-----------------------------------------|
|service_provider_id               |str  |serviceProviderId                        |
|group_id                          |str  |groupId                                  |
|device_type                       |str  |deviceType                               |
|count_only_reset_supported_device |bool |countOnlyResetSupportedDevice *Optional* |
|allow_unmanaged_device_type       |bool |allowUnmanagedDeviceType *Optional*      |
</div>


## `GroupDeviceManagementInProgressAndPendingEventCancelRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Cancel pending and in progress events.

A list of individual events can be canceled.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|group_id            |str       |groupId           |
|event_id            |List[int] |eventId           |
</div>


## `GroupDeviceTypeCustomTagAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a static configuration tag for an access device type used in a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description         |
|--------------------|----|--------------------|
|service_provider_id |str |serviceProviderId   |
|group_id            |str |groupId             |
|device_type         |str |deviceType          |
|tag_name            |str |tagName             |
|tag_value           |str |tagValue *Optional* |
</div>


## `GroupDeviceTypeCustomTagDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete static configuration tags for an access device type used in a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|group_id            |str       |groupId           |
|device_type         |str       |deviceType        |
|tag_name            |List[str] |tagName           |
</div>


## `GroupDeviceTypeCustomTagGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of custom configuration tags managed by the Device Management
System, on a per-device type basis for a group.

The response is either `GroupDeviceTypeCustomTagGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|device_type         |str |deviceType        |
</div>


## `GroupDeviceTypeCustomTagModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a static configuration tag for an access device type used in a
group.

The tagValueToEncrypt element can only be used by a system administrator.  The
following elements are only used in XS data mode and ignored in AS data mode:
tagValueToEncrypt

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                 |Type|Description                  |
|---------------------|----|-----------------------------|
|service_provider_id  |str |serviceProviderId            |
|group_id             |str |groupId                      |
|device_type          |str |deviceType                   |
|tag_name             |str |tagName                      |
|tag_value            |str |tagValue *Optional*          |
|tag_value_to_encrypt |str |tagValueToEncrypt *Optional* |
</div>


## `GroupDeviceTypeFileGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of device type files managed by the Device Management System,
on a per-group basis.

The response is either `GroupDeviceTypeFileGetListResponse()` or `ErrorResponse()`.

Replaced By: `GroupDeviceTypeFileGetListRequest14sp8()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|device_type         |str |deviceType        |
</div>


## `GroupDeviceTypeFileGetListRequest14sp8`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of device type files managed by the Device Management System,
on a per-group basis.

The response is either `GroupDeviceTypeFileGetListResponse14sp8()` or
`ErrorResponse()`. Replaced by: `GroupDeviceTypeFileGetListRequest21()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|device_type         |str |deviceType        |
</div>


## `GroupDeviceTypeFileGetListRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of device type files managed by the Device Management System,
on a per-group basis.

The response is either `GroupDeviceTypeFileGetListResponse21()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|device_type         |str |deviceType        |
</div>


## `GroupDeviceTypeFileGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a group device type file.

The response is either `GroupDeviceTypeFileGetResponse()` or `ErrorResponse()`.

Replaced By: `GroupDeviceTypeFileGetRequest14sp8()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|device_type         |str |deviceType        |
|file_type           |str |fileType          |
</div>


## `GroupDeviceTypeFileGetRequest14sp8`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a group device type file.

The response is either `GroupDeviceTypeFileGetResponse14sp8()` or `ErrorResponse()`.
Replaced by: `GroupDeviceTypeFileGetRequest16sp1()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|device_type         |str |deviceType        |
|file_format         |str |fileFormat        |
</div>


## `GroupDeviceTypeFileGetRequest16sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a group device type file.

The response is either `GroupDeviceTypeFileGetResponse16sp1()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|device_type         |str |deviceType        |
|file_format         |str |fileFormat        |
</div>


## `GroupDeviceTypeTagSetGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the custom configuration tag set defined for the group and device type.

The response is either `GroupDeviceTypeTagSetGetResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|device_type         |str |deviceType        |
</div>


## `GroupDeviceTypeTagSetModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a static configuration tag set.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description           |
|--------------------|----|----------------------|
|service_provider_id |str |serviceProviderId     |
|group_id            |str |groupId               |
|device_type         |str |deviceType            |
|tag_set_name        |str |tagSetName *Optional* |
</div>


## `GroupDialPlanPolicyAddAccessCodeRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a Group level Dial Plan Access Code and its all attribues.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                              |Type |Description                                 |
|--------------------------------------------------|-----|--------------------------------------------|
|service_provider_id                               |str  |serviceProviderId                           |
|group_id                                          |str  |groupId                                     |
|access_code                                       |str  |accessCode                                  |
|include_code_for_network_translations_and_routing |bool |includeCodeForNetworkTranslationsAndRouting |
|include_code_for_screening_services               |bool |includeCodeForScreeningServices             |
|enable_secondary_dial_tone                        |bool |enableSecondaryDialTone                     |
|description                                       |str  |description *Optional*                      |
</div>


## `GroupDialPlanPolicyDeleteAccessCodeRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a Group level Dial Plan Access Code and its all attribues.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|access_code         |str |accessCode        |
</div>


## `GroupDialPlanPolicyGetAccessCodeListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the Group level data associated with Dial Plan Policy.

The response is either a `GroupDialPlanPolicyGetAccessCodeListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupDialPlanPolicyGetAccessCodeRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request access code data associated with Group level Dial Plan Policy access codes.

The response is either a `GroupDialPlanPolicyGetAccessCodeResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|access_code         |str |accessCode        |
</div>


## `GroupDialPlanPolicyGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the Group level data associated with Dial Plan Policy.

The response is either a `GroupDialPlanPolicyGetResponse()` or an `ErrorResponse()`.
Replaced by: `GroupDialPlanPolicyGetRequest17()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupDialPlanPolicyGetRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the Group level data associated with Dial Plan Policy.

The response is either a `GroupDialPlanPolicyGetResponse17()` or an `ErrorResponse()`.
Replaced by: `GroupDialPlanPolicyGetRequest22()` in AS data mode.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupDialPlanPolicyGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the Group level data associated with Dial Plan Policy.

The response is either a `GroupDialPlanPolicyGetResponse22()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupDialPlanPolicyModifyAccessCodeRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a Group level Dial Plan Access Code and its attribues.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                              |Type |Description                                            |
|--------------------------------------------------|-----|-------------------------------------------------------|
|service_provider_id                               |str  |serviceProviderId                                      |
|group_id                                          |str  |groupId                                                |
|access_code                                       |str  |accessCode                                             |
|include_code_for_network_translations_and_routing |bool |includeCodeForNetworkTranslationsAndRouting *Optional* |
|include_code_for_screening_services               |bool |includeCodeForScreeningServices *Optional*             |
|enable_secondary_dial_tone                        |bool |enableSecondaryDialTone *Optional*                     |
|description                                       |str  |description *Optional*                                 |
</div>


## `GroupDialPlanPolicyModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Group level data associated with Dial Plan Policy.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode:
overrideResolvedDeviceDigitMap deviceDigitMap

**Attributes:**

|Name                                            |Type |Description                                          |
|------------------------------------------------|-----|-----------------------------------------------------|
|service_provider_id                             |str  |serviceProviderId                                    |
|group_id                                        |str  |groupId                                              |
|use_setting                                     |str  |useSetting *Optional*                                |
|requires_access_code_for_public_calls           |bool |requiresAccessCodeForPublicCalls *Optional*          |
|allow_e164_public_calls                         |bool |allowE164PublicCalls *Optional*                      |
|prefer_e164_number_format_for_callback_services |bool |preferE164NumberFormatForCallbackServices *Optional* |
|public_digit_map                                |str  |publicDigitMap *Optional*                            |
|private_digit_map                               |str  |privateDigitMap *Optional*                           |
|override_resolved_device_digit_map              |bool |overrideResolvedDeviceDigitMap *Optional*            |
|device_digit_map                                |str  |deviceDigitMap *Optional*                            |
</div>


## `GroupDialableCallerIDCriteriaAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a new Dialable Caller ID Criteria.

Criteria are added at the bottom of the list with the lowest priority.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                           |Type      |Description                            |
|-------------------------------|----------|---------------------------------------|
|service_provider_id            |str       |serviceProviderId                      |
|group_id                       |str       |groupId                                |
|name                           |str       |name                                   |
|description                    |str       |description *Optional*                 |
|prefix_digits                  |str       |prefixDigits *Optional*                |
|match_call_type                |List[str] |matchCallType *Optional*               |
|match_alternate_call_indicator |List[str] |matchAlternateCallIndicator *Optional* |
|match_local_category           |bool      |matchLocalCategory                     |
|match_national_category        |bool      |matchNationalCategory                  |
|match_interlata_category       |bool      |matchInterlataCategory                 |
|match_intralata_category       |bool      |matchIntralataCategory                 |
|match_international_category   |bool      |matchInternationalCategory             |
|match_private_category         |bool      |matchPrivateCategory                   |
|match_emergency_category       |bool      |matchEmergencyCategory                 |
|match_other_category           |bool      |matchOtherCategory                     |
</div>


## `GroupDialableCallerIDCriteriaDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Dialable Caller ID Criteria.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|name                |str |name              |
</div>


## `GroupDialableCallerIDCriteriaGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get an existing Dialable Caller ID Criteria.

The response is either a `GroupDialableCallerIDCriteriaGetRequest()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|name                |str |name              |
</div>


## `GroupDialableCallerIDGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the Group's Dialable Caller ID settings and criteria list.

The response is either a `GroupDialableCallerIDGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupDigitCollectionGetRequest13mp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group's digit collection attributes.

The response is either a `GroupDigitCollectionGetResponse13mp4()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupDigitCollectionModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the group's digit collection attributes.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description                |
|--------------------|----|---------------------------|
|service_provider_id |str |serviceProviderId          |
|group_id            |str |groupId                    |
|use_setting         |str |useSetting *Optional*      |
|access_code         |str |accessCode *Optional*      |
|public_digit_map    |str |publicDigitMap *Optional*  |
|private_digit_map   |str |privateDigitMap *Optional* |
</div>


## `GroupDirectoryNumberHuntingGetAvailableUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the agents of a call center or hunt group that are available to be
assigned to a directory number hunting group.

They are agents that are not already assigned to any other directory number hunting
group.

The response is either `GroupDirectoryNumberHuntingGetAvailableUserListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupDirectoryNumberHuntingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the properties of the DNH service for a specified serviceUserId.

It gets the agents of a call center or hunt group that are members of a directory
number hunting group.  They are agents that are not already assigned to any other
directory number hunting group.

The response is either `GroupDirectoryNumberHuntingGetResponse()` or
`ErrorResponse()`. Replaced by: `GroupDirectoryNumberHuntingGetRequest17sp1()`

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupDirectoryNumberHuntingGetRequest17sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the properties of the DNH service for a specified serviceUserId.

It gets the agents of a call center or hunt group that are members of a directory
number hunting group.  They are agents that are not already assigned to any other
directory number hunting group.

The response is either `GroupDirectoryNumberHuntingGetResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupDnGetActivationListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of activated and deactivated DNs in a group.

Ranges of DNs with identical assignment and activation properties are coalesced to a
single table row entry.  Only DNs assigned to a users are listed in the response when
the number activation Mode is set to "User Activation Enabled" Dns assigned to the
IMRN pool are not listed in the response.

The response is either a `GroupDnGetActivationListResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupDnGetAvailableListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of DNs that are assigned to a group and still available for assignment to
users or service instances within the group.

Dns assigned to the IMRN pool are not listed in the response.

The response is either a `GroupDnGetAvailableListResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupDnGetAvailableRangesListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of group DNs that are not assigned to user, service instances or IMRN pool.

The Dns are returned in a list of DNs or DN ranges and formated in E164 format for
display.

The response is either a `GroupDnGetAvailableRangeListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupDnGetDetailedAvailableListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of DNs that are assigned to a group and still available for assignment to
users within the group with the department name, if the DN is assigned to the
department.

Dns assigned to the IMRN pool are not listed in the response.

The response is either a `GroupDnGetDetailedAvailableListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupDnGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of DNs that are assigned to a group.

Dns assigned to the IMRN pool are not listed in the response.

The response is either a `GroupDnGetListResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupDnGetStatusListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Validates DNs given in the request The response is `GroupDnGetStatusListResponse()`.


**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|group_id            |str       |groupId           |
|dn                  |List[str] |dn                |
</div>


## `GroupDnGetSummaryListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of assigned and unassigned DN ranges in a group.

Dns assigned to the IMRN pool are not listed in the response.

The response is either a `GroupDnGetSummaryListResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupDomainAssignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Assign a list of domains to a group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|group_id            |str       |groupId           |
|domain              |List[str] |domain            |
</div>


## `GroupDomainGetAssignedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of all domains assigned to a group.

The response is either `GroupDomainGetAssignedListResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupDomainUnassignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Unassign a list of domains from a group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|group_id            |str       |groupId           |
|domain              |List[str] |domain            |
</div>


## `GroupEmergencyCallNotificationGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group level data associated with Emergency Call Notification.

The response is either a `GroupEmergencyCallNotificationGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupEmergencyCallNotificationModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the group level data associated with Emergency Call Notification.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                   |Type |Description                                   |
|---------------------------------------|-----|----------------------------------------------|
|service_provider_id                    |str  |serviceProviderId                             |
|group_id                               |str  |groupId                                       |
|send_emergency_call_notification_email |bool |sendEmergencyCallNotificationEmail *Optional* |
|emergency_call_notify_email_address    |str  |emergencyCallNotifyEmailAddress *Optional*    |
</div>


## `GroupEmergencyZonesGetHomeZoneListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group level data associated with Emergency Zones.

The response is either a `GroupEmergencyZonesGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupEmergencyZonesGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group level data associated with Emergency Zones.

The response is either a `GroupEmergencyZonesGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupEmergencyZonesModifyHomeZoneListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a list of home zones and/or home zone ranges.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                            |Type                                 |Description                           |
|--------------------------------|-------------------------------------|--------------------------------------|
|service_provider_id             |str                                  |serviceProviderId                     |
|group_id                        |str                                  |groupId                               |
|home_zone_ip_address_list       |List[OCI.homeZoneIpAddressList]      |homeZoneIpAddressList *Optional*      |
|home_zone_ip_address_range_list |List[OCI.homeZoneIpAddressRangeList] |homeZoneIpAddressRangeList *Optional* |
</div>


## `GroupEmergencyZonesModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the group level data associated with Emergency Zones.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                |Type |Description                                |
|------------------------------------|-----|-------------------------------------------|
|service_provider_id                 |str  |serviceProviderId                          |
|group_id                            |str  |groupId                                    |
|is_active                           |bool |isActive *Optional*                        |
|emergency_zones_prohibition         |str  |emergencyZonesProhibition *Optional*       |
|send_emergency_call_notify_email    |bool |sendEmergencyCallNotifyEmail *Optional*    |
|emergency_call_notify_email_address |str  |emergencyCallNotifyEmailAddress *Optional* |
</div>


## `GroupEnhancedCallLogsSchemaInstanceGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the enhanced call log database schema instance associated with a group of a
service provider.

The response is either a `GroupEnhancedCallLogsSchemaInstanceGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupEnhancedCallLogsSchemaInstanceModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Enhanced Call Logs schema instance associated with a group of a service
provider.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|name                |str |name *Optional*   |
</div>


## `GroupEnterpriseTrunkAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add an enterprise trunk in a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`GroupEnterpriseTrunkAddRequest21()`.

**Attributes:**

|Name                             |Type                        |Description                              |
|---------------------------------|----------------------------|-----------------------------------------|
|service_provider_id              |str                         |serviceProviderId                        |
|group_id                         |str                         |groupId                                  |
|enterprise_trunk_name            |str                         |enterpriseTrunkName                      |
|maximum_reroute_attempts         |int                         |maximumRerouteAttempts                   |
|route_exhaustion_action          |str                         |routeExhaustionAction                    |
|route_exhaustion_forward_address |str                         |routeExhaustionForwardAddress *Optional* |
|ordered_routing                  |OCI.orderedRouting          |orderedRouting *Optional*                |
|priority_weighted_routing        |OCI.priorityWeightedRouting |priorityWeightedRouting *Optional*       |
</div>


## `GroupEnterpriseTrunkAddRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add an enterprise trunk in a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                  |Type                        |Description                                  |
|--------------------------------------|----------------------------|---------------------------------------------|
|service_provider_id                   |str                         |serviceProviderId                            |
|group_id                              |str                         |groupId                                      |
|enterprise_trunk_name                 |str                         |enterpriseTrunkName                          |
|maximum_reroute_attempts              |int                         |maximumRerouteAttempts                       |
|route_exhaustion_action               |str                         |routeExhaustionAction                        |
|route_exhaustion_forward_address      |str                         |routeExhaustionForwardAddress *Optional*     |
|ordered_routing                       |OCI.orderedRouting          |orderedRouting *Optional*                    |
|priority_weighted_routing             |OCI.priorityWeightedRouting |priorityWeightedRouting *Optional*           |
|enable_capacity_management            |bool                        |enableCapacityManagement                     |
|max_active_calls                      |int                         |maxActiveCalls *Optional*                    |
|capacity_exceeded_trap_initial_calls  |int                         |capacityExceededTrapInitialCalls *Optional*  |
|capacity_exceeded_trap_offset_calls   |int                         |capacityExceededTrapOffsetCalls *Optional*   |
|maximum_active_incoming_calls_allowed |int                         |maximumActiveIncomingCallsAllowed *Optional* |
|maximum_active_outgoing_calls_allowed |int                         |maximumActiveOutgoingCallsAllowed *Optional* |
|minimum_active_calls_reserved         |int                         |minimumActiveCallsReserved *Optional*        |
</div>


## `GroupEnterpriseTrunkAddUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add users to an enterprise trunk in a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                  |Type      |Description         |
|----------------------|----------|--------------------|
|service_provider_id   |str       |serviceProviderId   |
|group_id              |str       |groupId             |
|enterprise_trunk_name |str       |enterpriseTrunkName |
|user_id               |List[str] |userId              |
</div>


## `GroupEnterpriseTrunkDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete an enterprise trunk in a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                  |Type|Description         |
|----------------------|----|--------------------|
|service_provider_id   |str |serviceProviderId   |
|group_id              |str |groupId             |
|enterprise_trunk_name |str |enterpriseTrunkName |
</div>


## `GroupEnterpriseTrunkDeleteUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete users from an enterprise trunk in a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                  |Type      |Description         |
|----------------------|----------|--------------------|
|service_provider_id   |str       |serviceProviderId   |
|group_id              |str       |groupId             |
|enterprise_trunk_name |str       |enterpriseTrunkName |
|user_id               |List[str] |userId              |
</div>


## `GroupEnterpriseTrunkForceAssignUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add users to an enterprise trunk in a group.

If the user is already assigned to another enterprise trunk, it will be unassigned
from the old enterprise trunk and assigned to the new enterprise trunk specified in
this request.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                  |Type      |Description         |
|----------------------|----------|--------------------|
|service_provider_id   |str       |serviceProviderId   |
|group_id              |str       |groupId             |
|enterprise_trunk_name |str       |enterpriseTrunkName |
|user_id               |List[str] |userId              |
</div>


## `GroupEnterpriseTrunkGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of all enterprise trunks defined in a group.

The response is either a `GroupEnterpriseTrunkGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupEnterpriseTrunkGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get an enterprise trunk The response is either an
`GroupEnterpriseTrunkGetResponse()` or an `ErrorResponse()`.

Replaced by: `GroupEnterpriseTrunkGetRequest21()`.

**Attributes:**

|Name                  |Type|Description         |
|----------------------|----|--------------------|
|service_provider_id   |str |serviceProviderId   |
|group_id              |str |groupId             |
|enterprise_trunk_name |str |enterpriseTrunkName |
</div>


## `GroupEnterpriseTrunkGetRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get an enterprise trunk The response is either an
`GroupEnterpriseTrunkGetResponse21()` or an `ErrorResponse()`.


**Attributes:**

|Name                  |Type|Description         |
|----------------------|----|--------------------|
|service_provider_id   |str |serviceProviderId   |
|group_id              |str |groupId             |
|enterprise_trunk_name |str |enterpriseTrunkName |
</div>


## `GroupEnterpriseTrunkGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get an enterprise trunk The response is either an
`GroupEnterpriseTrunkGetResponse22()` or an `ErrorResponse()`.


**Attributes:**

|Name                  |Type|Description         |
|----------------------|----|--------------------|
|service_provider_id   |str |serviceProviderId   |
|group_id              |str |groupId             |
|enterprise_trunk_name |str |enterpriseTrunkName |
</div>


## `GroupEnterpriseTrunkModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify an enterprise trunk in a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                  |Type                        |Description                                  |
|--------------------------------------|----------------------------|---------------------------------------------|
|service_provider_id                   |str                         |serviceProviderId                            |
|group_id                              |str                         |groupId                                      |
|enterprise_trunk_name                 |str                         |enterpriseTrunkName                          |
|new_enterprise_trunk_name             |str                         |newEnterpriseTrunkName *Optional*            |
|maximum_reroute_attempts              |int                         |maximumRerouteAttempts *Optional*            |
|route_exhaustion_action               |str                         |routeExhaustionAction *Optional*             |
|route_exhaustion_forward_address      |str                         |routeExhaustionForwardAddress *Optional*     |
|ordered_routing                       |OCI.orderedRouting          |orderedRouting *Optional*                    |
|priority_weighted_routing             |OCI.priorityWeightedRouting |priorityWeightedRouting *Optional*           |
|enable_capacity_management            |bool                        |enableCapacityManagement *Optional*          |
|max_active_calls                      |int                         |maxActiveCalls *Optional*                    |
|capacity_exceeded_trap_initial_calls  |int                         |capacityExceededTrapInitialCalls *Optional*  |
|capacity_exceeded_trap_offset_calls   |int                         |capacityExceededTrapOffsetCalls *Optional*   |
|maximum_active_incoming_calls_allowed |int                         |maximumActiveIncomingCallsAllowed *Optional* |
|maximum_active_outgoing_calls_allowed |int                         |maximumActiveOutgoingCallsAllowed *Optional* |
|minimum_active_calls_reserved         |int                         |minimumActiveCallsReserved *Optional*        |
</div>


## `GroupExchangeIntegrationGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group level configuration for Exchange Integration.

The response is either a `GroupExchangeIntegrationGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupExistingUsersAssignUserServiceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to assign the user services and service packs to all existing users within the
group.

BroadSoft recommends using this command only for small groups with less than 100
users.  This command will return an error if the group has over 500 users.  The
recommended way to bulk assign/unassign services is Service Pack Migration.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description                |
|--------------------|----------|---------------------------|
|service_provider_id |str       |serviceProviderId          |
|group_id            |str       |groupId                    |
|service_name        |List[str] |serviceName *Optional*     |
|service_pack_name   |List[str] |servicePackName *Optional* |
</div>


## `GroupExistingUsersUnassignUserServiceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests to unassign the user services and service packs for all existing users within
the group.

BroadSoft recommends using this command only for small groups with less than 100
users.  This command will return an error if the group has over 500 users.  The
recommended way to bulk assign/unassign services is Service Pack Migration.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description                |
|--------------------|----------|---------------------------|
|service_provider_id |str       |serviceProviderId          |
|group_id            |str       |groupId                    |
|service_name        |List[str] |serviceName *Optional*     |
|service_pack_name   |List[str] |servicePackName *Optional* |
</div>


## `GroupExtensionLengthGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group's extension length.

The response is either a `GroupExtensionLengthGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupExtensionLengthGetRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group's extension length.

The response is either a `GroupExtensionLengthGetResponse17()` or an
`ErrorResponse()`. Replaced by: `GroupExtensionLengthGetRequest22()` in AS data mode

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupExtensionLengthGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group's extension length.

The response is either a `GroupExtensionLengthGetResponse22()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupExtensionLengthModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the group's extension length.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description                |
|--------------------|----|---------------------------|
|service_provider_id |str |serviceProviderId          |
|group_id            |str |groupId                    |
|extension_length    |int |extensionLength *Optional* |
</div>


## `GroupExtensionLengthModifyRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the group's extension length range.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode:
useExterpriseExtensionLengthSetting

**Attributes:**

|Name                                    |Type |Description                                    |
|----------------------------------------|-----|-----------------------------------------------|
|service_provider_id                     |str  |serviceProviderId                              |
|group_id                                |str  |groupId                                        |
|min_extension_length                    |int  |minExtensionLength *Optional*                  |
|max_extension_length                    |int  |maxExtensionLength *Optional*                  |
|default_extension_length                |int  |defaultExtensionLength *Optional*              |
|use_enterprise_extension_length_setting |bool |useEnterpriseExtensionLengthSetting *Optional* |
</div>


## `GroupFeatureAccessCodeGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of feature access codes for a group.

The response is either a `GroupFeatureAccessCodeGetListResponse()` or an
`ErrorResponse()`. Replaced by: `GroupFeatureAccessCodeGetRequest()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupFeatureAccessCodeGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get group FAC code level and the list of feature access codes for a group.

The response is either a `GroupFeatureAccessCodeGetResponse()` or an
`ErrorResponse()`. Returned Feature Access Codes may be group specific, or Service
Provider Feature Access Codes, depending on FAC code level.  Replaced by:
`GroupFeatureAccessCodeGetRequest21()` in AS data mode

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupFeatureAccessCodeGetRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get group FAC code level and the list of feature access codes for a group.

The response is either a `GroupFeatureAccessCodeGetResponse20()` or an
`ErrorResponse()`. Returned Feature Access Codes may be group specific, or Service
Provider Feature Access Codes, depending on FAC code level.  In release 20 the "Call
Recording" FAC name is changed to "Call Recording - Start". Replaced by:
`GroupFeatureAccessCodeGetRequest21()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupFeatureAccessCodeGetRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get group FAC code level and the list of feature access codes for a group.

The response is either a `GroupFeatureAccessCodeGetResponse21()` or an
`ErrorResponse()`. Returned Feature Access Codes may be group specific, or Service
Provider Feature Access Codes, depending on FAC code level.  In release 20 the "Call
Recording" FAC name is changed to "Call Recording - Start".

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupFileRepositoryDeviceUserAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a new group file repository user.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                 |Type |Description        |
|---------------------|-----|-------------------|
|service_provider_id  |str  |serviceProviderId  |
|group_id             |str  |groupId            |
|file_repository_name |str  |fileRepositoryName |
|user_name            |str  |userName           |
|password             |str  |password           |
|allow_put            |bool |allowPut           |
|allow_delete         |bool |allowDelete        |
|allow_get            |bool |allowGet           |
</div>


## `GroupFileRepositoryDeviceUserDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a group file repository user.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                 |Type|Description        |
|---------------------|----|-------------------|
|service_provider_id  |str |serviceProviderId  |
|group_id             |str |groupId            |
|file_repository_name |str |fileRepositoryName |
|user_name            |str |userName           |
</div>


## `GroupFileRepositoryDeviceUserGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the list of group users for a file repository in the system.

The response is either a `GroupFileRepositoryDeviceUserGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                 |Type|Description        |
|---------------------|----|-------------------|
|service_provider_id  |str |serviceProviderId  |
|group_id             |str |groupId            |
|file_repository_name |str |fileRepositoryName |
</div>


## `GroupFileRepositoryDeviceUserModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a group file repository user.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                 |Type |Description            |
|---------------------|-----|-----------------------|
|service_provider_id  |str  |serviceProviderId      |
|group_id             |str  |groupId                |
|file_repository_name |str  |fileRepositoryName     |
|user_name            |str  |userName               |
|password             |str  |password *Optional*    |
|allow_put            |bool |allowPut *Optional*    |
|allow_delete         |bool |allowDelete *Optional* |
|allow_get            |bool |allowGet *Optional*    |
</div>


## `GroupFindMeFollowMeAddAlertingGroupRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add an alerting group to a Find-me/Follow-me instance.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                         |Type |Description                         |
|-----------------------------|-----|------------------------------------|
|service_user_id              |str  |serviceUserId                       |
|alerting_group_name          |str  |alertingGroupName                   |
|alerting_group_description   |str  |alertingGroupDescription *Optional* |
|use_diversion_inhibitor      |bool |useDiversionInhibitor               |
|answer_confirmation_required |bool |answerConfirmationRequired          |
|number_of_rings              |int  |numberOfRings                       |
|phone_number                 |str  |phoneNumber *Optional*              |
|user_id                      |str  |userId *Optional*                   |
</div>


## `GroupFindMeFollowMeDeleteAlertingGroupRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete an alerting group from a Find-me/Follow-me instance.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_user_id     |str |serviceUserId     |
|alerting_group_name |str |alertingGroupName |
</div>


## `GroupFindMeFollowMeDeleteAlertingGroupSelectiveCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a criteria from the Find-me/Follow-me alerting group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_user_id     |str |serviceUserId     |
|alerting_group_name |str |alertingGroupName |
|criteria_name       |str |criteriaName      |
</div>


## `GroupFindMeFollowMeDeleteInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Find-me/Follow-me instance from a group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupFindMeFollowMeGetAlertingGroupListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of Find-me/Follow-me alerting groups within a group.

The response is either `GroupFindMeFollowMeGetAlertingGroupListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupFindMeFollowMeGetAlertingGroupRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Find-me/Follow-me alerting group.

The response is either `GroupFindMeFollowMeGetAlertingGroupResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_user_id     |str |serviceUserId     |
|alerting_group_name |str |alertingGroupName |
</div>


## `GroupFindMeFollowMeGetAlertingGroupSelectiveCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a specific Find-me/Follow-me alerting group
selective criteria.

The response is either `GroupFindMeFollowMeGetAlertingGroupResponse()` or
`ErrorResponse()`. Replaced by:
`GroupFindMeFollowMeGetAlertingGroupSelectiveCriteriaRequest21()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_user_id     |str |serviceUserId     |
|alerting_group_name |str |alertingGroupName |
|criteria_name       |str |criteriaName      |
</div>


## `GroupFindMeFollowMeGetAlertingGroupSelectiveCriteriaRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a specific Find-me/Follow-me alerting group
selective criteria.

The response is either `GroupFindMeFollowMeGetAlertingGroupResponse21()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_user_id     |str |serviceUserId     |
|alerting_group_name |str |alertingGroupName |
|criteria_name       |str |criteriaName      |
</div>


## `GroupFindMeFollowMeGetInstanceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of Find-me/Follow-me instances within a group.

The response is either `GroupFindMeFollowMeGetInstanceListResponse()` or
`ErrorResponse()`. It is possible to get the instances within a specified department.

**Attributes:**

|Name                  |Type|Description                    |
|----------------------|----|-------------------------------|
|service_provider_id   |str |serviceProviderId              |
|group_id              |str |groupId                        |
|group_department_name |str |groupDepartmentName *Optional* |
</div>


## `GroupFindMeFollowMeGetInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Find-me/Follow-me instance.

The response is either `GroupFindMeFollowMeGetInstanceResponse()` or
`ErrorResponse()`. Replaced by: `GroupFindMeFollowMeGetInstanceRequest19sp1()`

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupFindMeFollowMeGetInstanceRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Find-me/Follow-me instance.

The response is either `GroupFindMeFollowMeGetInstanceResponse19sp1()` or
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupFindMeFollowMeModifyAlertingGroupListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the priorities assigned to alerting groups The response is either a
`SuccessResponse()` or an `ErrorResponse()`.

NOTE: The command fails if all the alerting groups defined for the user are not
provided.

**Attributes:**

|Name                |Type      |Description                  |
|--------------------|----------|-----------------------------|
|service_user_id     |str       |serviceUserId                |
|alerting_group_name |List[str] |alertingGroupName *Optional* |
</div>


## `GroupFlexibleSeatingAccessDeviceGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of access devices available for assignment to a flexible seating
host or guest.

The list includes devices created at the system, service provider, and group levels
that support device management.

The response is either `GroupFlexibleSeatingAccessDeviceGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupFlexibleSeatingHostDeleteInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a flexible seating host instance from a group.

Host cannot be deleted when a guest is associated to a host.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupFlexibleSeatingHostGetInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a flexible seating host instance.

The response is either `GroupFlexibleSeatingHostGetInstanceResponse()` or
`ErrorResponse()`. Replaced by: `GroupFlexibleSeatingHostGetInstanceRequest22()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupFlexibleSeatingHostGetInstanceRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a flexible seating host instance.

The response is either `GroupFlexibleSeatingHostGetInstanceResponse22()` or
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupFlexibleSeatingHostGuestAssociationGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the flexible seating host guest association details.

The response is either a `GroupFlexibleSeatingHostGuestAssociationGetResponse()` or an
`ErrorResponse()`. accessLevel is always set to Group for a Service Provider

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupFlexibleSeatingHostGuestAssociationModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the flexible seating host’s guest association attributes.

The request fails if enforceAssociationLimit or associationLimitHours are changed when
the host is associated to a guest.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                      |Type |Description                        |
|--------------------------|-----|-----------------------------------|
|service_user_id           |str  |serviceUserId                      |
|enforce_association_limit |bool |enforceAssociationLimit *Optional* |
|association_limit_hours   |int  |associationLimitHours *Optional*   |
|access_level              |str  |accessLevel *Optional*             |
|remove_guest_association  |bool |removeGuestAssociation *Optional*  |
</div>


## `GroupFlexibleSeatingHostRoutingPoliciesGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a flexible seating host’s routing policies The response is either a
`GroupFlexibleSeatingHostRoutingPoliciesGetResponse()` or an `ErrorResponse()`.


**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupFlexibleSeatingHostRoutingPoliciesModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a flexible seating host’s routing policies The response is either a
`SuccessResponse()` or an `ErrorResponse()`.


**Attributes:**

|Name                        |Type |Description                        |
|----------------------------|-----|-----------------------------------|
|service_user_id             |str  |serviceUserId                      |
|allow_emergency_calls       |bool |allowEmergencyCalls *Optional*     |
|allow_calls_to_voice_portal |bool |allowCallsToVoicePortal *Optional* |
</div>


## `GroupGetAvailableLeafDeviceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of available leaf devices that can be linked to a tree device within
a specific group.

A leaf device is a device associated with a device type that has the option
supportLinks set to "Support Link to Device". It can be linked to only one tree
device.  The list returned includes devices created at the system, service provider,
and group levels.

The response is either `GroupGetAvailableLeafDeviceListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupGetAvailableTreeDeviceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of available tree devices to which leaf devices can be linked to
within a specific group.

A tree device is a device associated with a device type that has the option
supportLinks set to "Support Links from Devices". Many leaf devices can be linked to
it.  The list returned includes devices created at the system, service provider, and
group levels.

The response is either `GroupGetAvailableTreeDeviceListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupGetDefaultRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the default profile for a group.

The response is either a `GroupGetDefaultResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `GroupGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the profile for a group.

The response is either a `GroupGetResponse()` or an `ErrorResponse()`.

Replaced By: `GroupGetRequest14sp7()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupGetRequest14sp7`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the profile for a group.

The response is either a `GroupGetResponse14sp7()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the profile for a group.

The response is either a `GroupGetResponse22()` or an `ErrorResponse()`. Replaced by
`GroupGetRequest22V2()` in AS data mode.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupGetRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the profile for a group.

The response is either a `GroupGetResponse22V2()` or an `ErrorResponse()`. Replaced
by: `GroupGetRequest22V3()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupGetRequest22V3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the profile for a group.

The response is either a `GroupGetResponse22V3()` or an `ErrorResponse()`. Replaced by
`GroupGetRequest22V4()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupGetRequest22V4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the profile for a group.

The response is either a `GroupGetResponse22V4()` or an `ErrorResponse()`. Replaced
by: `GroupGetRequest22V5()` in AS data mode.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupGetRequest22V5`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the profile for a group.

The response is either a `GroupGetResponse22V5()` or an `ErrorResponse()`. The
following elements are only used in AS data mode and ignored in XS data mode:
groupExternalId

**Attributes:**

|Name                |Type|Description                  |
|--------------------|----|-----------------------------|
|service_provider_id |str |serviceProviderId *Optional* |
|group_id            |str |groupId *Optional*           |
|group_external_id   |str |groupExternalId *Optional*   |
</div>


## `GroupGetUserServiceAssignedUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of users assigned the user service or service pack.

The response is either a `GroupGetUserServiceAssignedUserListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description                |
|--------------------|----|---------------------------|
|service_provider_id |str |serviceProviderId          |
|group_id            |str |groupId                    |
|service_name        |str |serviceName *Optional*     |
|service_pack_name   |str |servicePackName *Optional* |
</div>


## `GroupGroupNightForwardingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the Group Night Forwarding group parameters.

The response is either `GroupGroupNightForwardingGetResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupGroupPagingAddOriginatorListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add originator(s) to a paging group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name               |Type      |Description      |
|-------------------|----------|-----------------|
|service_user_id    |str       |serviceUserId    |
|originator_user_id |List[str] |originatorUserId |
</div>


## `GroupGroupPagingAddTargetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add target(s) to a paging group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type      |Description   |
|----------------|----------|--------------|
|service_user_id |str       |serviceUserId |
|target_user_id  |List[str] |targetUserId  |
</div>


## `GroupGroupPagingDeleteInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Group Paging instance from a group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupGroupPagingDeleteOriginatorListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete originator(s) from a paging group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name               |Type      |Description      |
|-------------------|----------|-----------------|
|service_user_id    |str       |serviceUserId    |
|originator_user_id |List[str] |originatorUserId |
</div>


## `GroupGroupPagingDeleteTargetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete target(s) from a paging group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type      |Description   |
|----------------|----------|--------------|
|service_user_id |str       |serviceUserId |
|target_user_id  |List[str] |targetUserId  |
</div>


## `GroupGroupPagingGetInstanceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of Paging Groups instances within a group.

The response is either `GroupGroupPagingGetInstanceListResponse()` or
`ErrorResponse()`. It is possible to get the instances within a specified department.

**Attributes:**

|Name                  |Type|Description                    |
|----------------------|----|-------------------------------|
|service_provider_id   |str |serviceProviderId              |
|group_id              |str |groupId                        |
|group_department_name |str |groupDepartmentName *Optional* |
</div>


## `GroupGroupPagingGetInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Replaced By `GroupGroupPagingGetInstanceRequest17sp3()` Request to get all the
information of a Group Paging instance.

The response is either `GroupGroupPagingGetInstanceResponse()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupGroupPagingGetInstanceRequest17sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Group Paging instance.

The response is either `GroupGroupPagingGetInstanceResponse17sp3()` or
`ErrorResponse()`. Replaced by: `GroupGroupPagingGetInstanceRequest19sp1()`

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupGroupPagingGetInstanceRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Group Paging instance.

The response is either `GroupGroupPagingGetInstanceResponse19sp1()` or
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupGroupPagingGetOriginatorListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of originators assigned to a paging group.

The response is either a `GroupGroupPagingGetOriginatorListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupGroupPagingGetTargetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of targets assigned to a paging group.

The response is either a `GroupGroupPagingGetTargetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupGroupPagingTargetsCapacityGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the maximum number of target users per paging group configured for a group.

The response is either a `GroupGroupPagingTargetsCapacityGetResponse()` or an
`ErrorResponse()`. Replaced by: `GroupGroupPagingTargetsCapacityGetRequest22()` in AS
data mode.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupGroupPagingTargetsCapacityGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the maximum number of target users per paging group configured for a group.

The response is either a `GroupGroupPagingTargetsCapacityGetResponse22()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupGroupPagingTargetsCapacityModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the maximum number of target users per paging group configured for a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`GroupGroupPagingTargetsCapacityModifyRequest22()` in AS data mode.

**Attributes:**

|Name                 |Type|Description                   |
|---------------------|----|------------------------------|
|service_provider_id  |str |serviceProviderId             |
|group_id             |str |groupId                       |
|maximum_target_users |int |maximumTargetUsers *Optional* |
</div>


## `GroupGroupPagingTargetsCapacityModifyRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the maximum number of target users per paging group configured for a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                 |Type|Description                   |
|---------------------|----|------------------------------|
|service_provider_id  |str |serviceProviderId             |
|group_id             |str |groupId                       |
|maximum_target_users |int |maximumTargetUsers *Optional* |
</div>


## `GroupHolidayScheduleDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a holiday schedule from a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                  |Type|Description         |
|----------------------|----|--------------------|
|service_provider_id   |str |serviceProviderId   |
|group_id              |str |groupId             |
|holiday_schedule_name |str |holidayScheduleName |
</div>


## `GroupHolidayScheduleGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a holiday schedule in a group.

The response is either a `GroupHolidayScheduleGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupHolidayScheduleGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a holiday schedule in a group.

The response is either a `GroupHolidayScheduleGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                  |Type|Description         |
|----------------------|----|--------------------|
|service_provider_id   |str |serviceProviderId   |
|group_id              |str |groupId             |
|holiday_schedule_name |str |holidayScheduleName |
</div>


## `GroupHuntGroupConsolidatedDeleteInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Hunt Group instance from a group.

If UnassignPhoneNumbersLevel is set to 'Group', the user's primary phone number, fax
number and any alternate numbers, will be un-assigned from the group if the command is
executed by a service provider administrator or above.  When set to 'Service
Provider', they will be un-assigned from the group and service provider if the command
is executed by a provisioning administrator or above.  When omitted, the number(s)
will be left assigned to the group.  An `ErrorResponse()` will be returned if any
number cannot be unassigned because of insufficient privilege.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                   |Type|Description                     |
|-----------------------|----|--------------------------------|
|service_user_id        |str |serviceUserId                   |
|unassign_phone_numbers |str |unassignPhoneNumbers *Optional* |
</div>


## `GroupHuntGroupDeleteInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Hunt Group instance from a group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupHuntGroupGetInstanceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of Hunt Group instances within a group.

The response is either `GroupHuntGroupGetInstanceListResponse()` or `ErrorResponse()`.
It is possible to get the instances within a specified department.

**Attributes:**

|Name                  |Type|Description                    |
|----------------------|----|-------------------------------|
|service_provider_id   |str |serviceProviderId              |
|group_id              |str |groupId                        |
|group_department_name |str |groupDepartmentName *Optional* |
</div>


## `GroupHuntGroupGetInstanceRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Hunt Group instance.

The response is either `GroupHuntGroupGetInstanceResponse14()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupHuntGroupGetInstanceRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Hunt Group instance.

The response is either `GroupHuntGroupGetInstanceResponse17()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupHuntGroupGetInstanceRequest17sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Hunt Group instance.

The response is either `GroupHuntGroupGetInstanceResponse17sp3()` or
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupHuntGroupGetInstanceRequest17sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Hunt Group instance.

The response is either `GroupHuntGroupGetInstanceResponse17sp4()` or
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupHuntGroupGetInstanceRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Hunt Group instance.

The response is either `GroupHuntGroupGetInstanceResponse19()` or `ErrorResponse()`.
Replaced by: `GroupHuntGroupGetInstanceRequest19sp1()` in AS data mode

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupHuntGroupGetInstanceRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Hunt Group instance.

The response is either `GroupHuntGroupGetInstanceResponse19sp1()` or
`ErrorResponse()`. Replaced by: `GroupHuntGroupGetInstanceRequest20()`

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupHuntGroupGetInstanceRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Hunt Group instance.

The response is either `GroupHuntGroupGetInstanceResponse20()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupIMRNGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a summary table of all DNs in a group IMRN pool.

The response is either `GroupIMRNGetListResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupIncomingCallingPlanGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group's incoming calling plan settings.

The response is either a `GroupIncomingCallingPlanGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupInstantGroupCallDeleteInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete an Instant Group Call service instance from a group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupInstantGroupCallGetInstanceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a list of Instant Group Call service instances within a group.

The response is either `GroupInstantGroupCallGetInstanceListResponse()` or
`ErrorResponse()`. It is possible to get the service instances within a specified
department.

**Attributes:**

|Name                  |Type|Description                    |
|----------------------|----|-------------------------------|
|service_provider_id   |str |serviceProviderId              |
|group_id              |str |groupId                        |
|group_department_name |str |groupDepartmentName *Optional* |
</div>


## `GroupInstantGroupCallGetInstanceRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of an Instant Group Call service instance.

The response is either `GroupInstantGroupCallGetInstanceResponse14()` or
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupInstantGroupCallGetInstanceRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of an Instant Group Call service instance.

The response is either `GroupInstantGroupCallGetInstanceResponse17()` or
`ErrorResponse()`. Replaced by: `GroupInstantGroupCallGetInstanceRequest19sp1()`

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupInstantGroupCallGetInstanceRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of an Instant Group Call service instance.

The response is either `GroupInstantGroupCallGetInstanceResponse19sp1()` or
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupIntegratedIMPGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the Integrated IMP service attributes for the group.

The response is either `GroupIntegratedIMPGetResponse()` or `ErrorResponse()`.
Replaced by: `GroupIntegratedIMPGetRequest21sp1()` in AS data mode

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupIntegratedIMPGetRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the Integrated IMP service attributes for the group.

The response is either `GroupIntegratedIMPGetResponse21sp1()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupIntegratedIMPModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Integrated IMP service attributes for the group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                         |Type |Description                          |
|-----------------------------|-----|-------------------------------------|
|service_provider_id          |str  |serviceProviderId                    |
|group_id                     |str  |groupId                              |
|use_service_provider_setting |bool |useServiceProviderSetting *Optional* |
|service_domain               |str  |serviceDomain *Optional*             |
</div>


## `GroupInterceptGroupGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the group's intercept group service settings.

The response is either a `GroupInterceptGroupGetResponse()` or an `ErrorResponse()`.

Replaced By: `GroupInterceptGroupGetRequest16()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupInterceptGroupGetRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the group's intercept group service settings.

The response is either a `GroupInterceptGroupGetResponse16()` or an `ErrorResponse()`.

Replaced By: `GroupInterceptGroupGetRequest16sp1()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupInterceptGroupGetRequest16sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the group's intercept group service settings.

The response is either a `GroupInterceptGroupGetResponse16sp1()` or an
`ErrorResponse()`. Replaced by: `GroupInterceptGroupGetRequest21sp1()` in AS data mode

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupInterceptGroupGetRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the group's intercept group service settings.

The response is either a `GroupInterceptGroupGetResponse21sp1()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupInventoryReportGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group's inventory report.

The response is either a `GroupInventoryReportGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                          |Type |Description                           |
|------------------------------|-----|--------------------------------------|
|service_provider_id           |str  |serviceProviderId                     |
|group_id                      |str  |groupId                               |
|include_users                 |bool |includeUsers                          |
|include_services              |bool |includeServices                       |
|include_dns                   |bool |includeDns                            |
|include_access_devices        |bool |includeAccessDevices                  |
|include_departments           |bool |includeDepartments                    |
|report_delivery_email_address |str  |reportDeliveryEmailAddress *Optional* |
</div>


## `GroupMWIDeliveryToMobileEndpointCustomTemplateDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a MWI Delivery to Mobile Endpoint Custom Template.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|language            |str |language          |
|type                |str |type              |
</div>


## `GroupMWIDeliveryToMobileEndpointCustomTemplateGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a MWI Delivery to Mobile Endpoint Custom Template.

The response is either a `GroupMWIDeliveryToMobileEndpointCustomTemplateGetResponse()`
or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|language            |str |language          |
|type                |str |type              |
</div>


## `GroupMWIDeliveryToMobileEndpointGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests group MWI custom notifications settings.

The response is either a `GroupMWIDeliveryToMobileEndpointGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupMeetMeConferencingDeleteInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Meet-Me Conferencing bridge from a group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupMeetMeConferencingGetInstanceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of Meet-Me Conferencing instances within a group.

The response is either `GroupMeetMeConferencingGetInstanceListResponse()` or
`ErrorResponse()`. It is possible to get the instances within a specified department.

**Attributes:**

|Name                |Type|Description               |
|--------------------|----|--------------------------|
|service_provider_id |str |serviceProviderId         |
|group_id            |str |groupId                   |
|department_name     |str |departmentName *Optional* |
</div>


## `GroupMeetMeConferencingGetInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Meet-Me Conferencing bridge.

The response is either `GroupMeetMeConferencingGetInstanceResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupMeetMeConferencingGetInstanceRequest17sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Meet-Me Conferencing bridge.

The response is either `GroupMeetMeConferencingGetInstanceResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupMeetMeConferencingGetInstanceRequest17sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Meet-Me Conferencing bridge.

The response is either `GroupMeetMeConferencingGetInstanceResponse17sp4()` or
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupMeetMeConferencingGetInstanceRequest18`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Meet-Me Conferencing bridge.

The response is either `GroupMeetMeConferencingGetInstanceResponse18()` or
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupMeetMeConferencingGetInstanceRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Meet-Me Conferencing bridge.

The response is either `GroupMeetMeConferencingGetInstanceResponse19()` or
`ErrorResponse()`. Replaced by: `GroupMeetMeConferencingGetInstanceRequest19sp1()`

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupMeetMeConferencingGetInstanceRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Meet-Me Conferencing bridge.

The response is either `GroupMeetMeConferencingGetInstanceResponse19sp1()` or
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupMeetMeConferencingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group level data associated with Meet-Me Conferencing functions.

The response is either a `GroupMeetMeConferencingGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupMusicOnHoldGetDepartmentListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Returns a list of all departments that have a Music On Hold instance.

The response is either `GroupMusicOnHoldGetDepartmentListResponse()` or
`ErrorResponse()`. It is possible to get the instances within a specified department.

**Attributes:**

|Name                  |Type|Description                    |
|----------------------|----|-------------------------------|
|service_provider_id   |str |serviceProviderId              |
|group_id              |str |groupId                        |
|group_department_name |str |groupDepartmentName *Optional* |
</div>


## `GroupNetworkClassOfServiceAssignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Assign a list of Network Classes of Service to a group.

The Element defaultNetworkClassOfService is required only for the first assignment,
for subsequent assignments it is optional.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                             |Type      |Description                             |
|---------------------------------|----------|----------------------------------------|
|service_provider_id              |str       |serviceProviderId                       |
|group_id                         |str       |groupId                                 |
|network_class_of_service         |List[str] |networkClassOfService *Optional*        |
|default_network_class_of_service |str       |defaultNetworkClassOfService *Optional* |
</div>


## `GroupNetworkClassOfServiceAssignToAllUsersRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Assign a Network Classes of Service to all users with in a group.

The Network Classes of Service must be currently assigned to the group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type|Description           |
|-------------------------|----|----------------------|
|service_provider_id      |str |serviceProviderId     |
|group_id                 |str |groupId               |
|network_class_of_service |str |networkClassOfService |
</div>


## `GroupNetworkClassOfServiceGetAssignedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of Network Classes of Service assigned to a group.

The response is either a `GroupNetworkClassOfServiceGetAssignedListResponse()` or an
`ErorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupNetworkClassOfServiceModifyDefaultRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the default Network Classes of Service of a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type|Description           |
|-------------------------|----|----------------------|
|service_provider_id      |str |serviceProviderId     |
|group_id                 |str |groupId               |
|network_class_of_service |str |networkClassOfService |
</div>


## `GroupNetworkClassOfServiceUnassignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Unassign a list of Network Classes of Service from a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                             |Type      |Description                             |
|---------------------------------|----------|----------------------------------------|
|service_provider_id              |str       |serviceProviderId                       |
|group_id                         |str       |groupId                                 |
|network_class_of_service         |List[str] |networkClassOfService *Optional*        |
|default_network_class_of_service |str       |defaultNetworkClassOfService *Optional* |
</div>


## `GroupNewUserTemplateAssignUserServiceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to assign the user services and service packs to all new users created within
the group after the completion of this request.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description                |
|--------------------|----------|---------------------------|
|service_provider_id |str       |serviceProviderId          |
|group_id            |str       |groupId                    |
|service_name        |List[str] |serviceName *Optional*     |
|service_pack_name   |List[str] |servicePackName *Optional* |
</div>


## `GroupNewUserTemplateUnassignUserServiceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests to unassign the user services and service packs for all new users created
within the group after the completion of this request.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description                |
|--------------------|----------|---------------------------|
|service_provider_id |str       |serviceProviderId          |
|group_id            |str       |groupId                    |
|service_name        |List[str] |serviceName *Optional*     |
|service_pack_name   |List[str] |servicePackName *Optional* |
</div>


## `GroupOfficeZoneAssignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Assign a list of Office Zones to a group.

The Element defaultOfficeZone is required only for the first assignment, for
subsequent assignments it is optional.  Office Zones can only be assigned if the
Location-Based Calling Restrictions has been authorized to the group otherwise the
request will fail.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type      |Description                      |
|-------------------------|----------|---------------------------------|
|service_provider_id      |str       |serviceProviderId                |
|group_id                 |str       |groupId                          |
|office_zone_name         |List[str] |officeZoneName *Optional*        |
|default_office_zone_name |str       |defaultOfficeZoneName *Optional* |
</div>


## `GroupOfficeZoneGetAssignedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of Office Zones assigned to a group.

The response is either a `GroupOfficeZoneGetAssignedListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupOfficeZoneUnassignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Unassign a list of OfficeZones from a group.

Note: a new default must be provided if unassigning the current default.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type      |Description                      |
|-------------------------|----------|---------------------------------|
|service_provider_id      |str       |serviceProviderId                |
|group_id                 |str       |groupId                          |
|office_zone_name         |List[str] |officeZoneName *Optional*        |
|default_office_zone_name |str       |defaultOfficeZoneName *Optional* |
</div>


## `GroupOutgoingCallingPlanAuthorizationCodeGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the list of authorization codes for a group default and it's departments.

The response is either a `GroupOutgoingCallingPlanAuthorizationCodeGetListResponse()`
or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupOutgoingCallingPlanCallMeNowGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the Call Me Now call permissions for a group default and it's departments.

The response is either a `GroupOutgoingCallingPlanCallMeNowGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupOutgoingCallingPlanDigitPlanCallMeNowGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the Call Me Now call permissions for digit patterns for a group default and
it's departments.

The response is either a `GroupOutgoingCallingPlanDigitPlanCallMeNowGetListResponse()`
or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupOutgoingCallingPlanDigitPlanOriginatingGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the originating permissions for digit patterns for a group default and it's
departments.

The response is either a
`GroupOutgoingCallingPlanDigitPlanOriginatingGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupOutgoingCallingPlanDigitPlanRedirectingGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the redirecting permissions for digit patterns for a group default and it's
departments.

The response is either a
`GroupOutgoingCallingPlanDigitPlanRedirectingGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupOutgoingCallingPlanOriginatingGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the originating permissions for a group default and it's departments.

The response is either a `GroupOutgoingCallingPlanOriginatingGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupOutgoingCallingPlanPinholeDigitPatternAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a new calling plan Pinhole digit string.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|name                |str |name              |
|digit_pattern       |str |digitPattern      |
</div>


## `GroupOutgoingCallingPlanPinholeDigitPatternDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete one or more calling plan Pinhole digit strings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|group_id            |str       |groupId           |
|name                |List[str] |name              |
</div>


## `GroupOutgoingCallingPlanPinholeDigitPatternGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of calling plan Pinhole digit strings for a group.

The response is either a
`GroupOutgoingCallingPlanPinholeDigitPatternGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupOutgoingCallingPlanPinholeDigitPatternModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a calling plan Pinhole digit string.

The name is a key; it cannot be changed.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description             |
|--------------------|----|------------------------|
|service_provider_id |str |serviceProviderId       |
|group_id            |str |groupId                 |
|name                |str |name                    |
|digit_pattern       |str |digitPattern *Optional* |
</div>


## `GroupOutgoingCallingPlanPinholeDigitPlanCallMeNowGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the Call Me Now permissions for Pinhole digit patterns for a group default and
its departments.

The response is either a
`GroupOutgoingCallingPlanPinholeDigitPlanCallMeNowGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupOutgoingCallingPlanPinholeDigitPlanOriginatingGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the originating permissions for Pinhole digit patterns for a group default and
its departments.

The response is either a
`GroupOutgoingCallingPlanPinholeDigitPlanOriginatingGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupOutgoingCallingPlanPinholeDigitPlanRedirectingGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the redirecting permissions for Pinhole digit patterns for a group default and
its departments.

The response is either a
`GroupOutgoingCallingPlanPinholeDigitPlanRedirectingGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupOutgoingCallingPlanRedirectedGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the call forwarded/transferred permissions for a group default and it's
departments.

The response is either a `GroupOutgoingCallingPlanRedirectedGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupOutgoingCallingPlanRedirectingGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the initiating call forwards/transfer permissions for a group default and it's
departments.

The response is either a `GroupOutgoingCallingPlanRedirectingGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupOutgoingCallingPlanTransferNumbersGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the list of transfer numbers for a group default and it's departments.

The response is either a `GroupOutgoingCallingPlanTransferNumbersGetListResponse()` or
an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupPasswordRulesGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the group's password rules setting that is applicable to users within the
group.

The response is either `GroupPasswordRulesGetResponse()` or `ErrorResponse()`.
Replaced by: `GroupPasswordRulesGetRequest16()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupPasswordRulesGetRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the group's password rules setting that is applicable to users within the
group.

The response is either `GroupPasswordRulesGetResponse16()` or `ErrorResponse()`.
Replaced by: `GroupPasswordRulesGetRequest22()` in AS data mode.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupPasswordRulesGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the group's password rules setting that is applicable to users within the
group.

The response is either `GroupPasswordRulesGetResponse22()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupPasswordRulesModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the group's password rules setting that apply to the users within
the group.

The following elements are only used in AS data mode and ignored in XS data mode:
forcePasswordChangeAfterReset

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                     |Type |Description                                     |
|-----------------------------------------|-----|------------------------------------------------|
|service_provider_id                      |str  |serviceProviderId                               |
|group_id                                 |str  |groupId                                         |
|disallow_user_id                         |bool |disallowUserId *Optional*                       |
|disallow_old_password                    |bool |disallowOldPassword *Optional*                  |
|disallow_reversed_old_password           |bool |disallowReversedOldPassword *Optional*          |
|restrict_min_digits                      |bool |restrictMinDigits *Optional*                    |
|min_digits                               |int  |minDigits *Optional*                            |
|restrict_min_upper_case_letters          |bool |restrictMinUpperCaseLetters *Optional*          |
|min_upper_case_letters                   |int  |minUpperCaseLetters *Optional*                  |
|restrict_min_lower_case_letters          |bool |restrictMinLowerCaseLetters *Optional*          |
|min_lower_case_letters                   |int  |minLowerCaseLetters *Optional*                  |
|restrict_min_non_alphanumeric_characters |bool |restrictMinNonAlphanumericCharacters *Optional* |
|min_non_alphanumeric_characters          |int  |minNonAlphanumericCharacters *Optional*         |
|min_length                               |int  |minLength *Optional*                            |
|max_failed_login_attempts                |int  |maxFailedLoginAttempts *Optional*               |
|password_expires_days                    |int  |passwordExpiresDays *Optional*                  |
|send_login_disabled_notify_email         |bool |sendLoginDisabledNotifyEmail *Optional*         |
|login_disabled_notify_email_address      |str  |loginDisabledNotifyEmailAddress *Optional*      |
|disallow_previous_passwords              |bool |disallowPreviousPasswords *Optional*            |
|number_of_previous_passwords             |int  |numberOfPreviousPasswords *Optional*            |
|force_password_change_after_reset        |bool |forcePasswordChangeAfterReset *Optional*        |
</div>


## `GroupPolicyGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the Group's policy settings.

The response is either `GroupPolicyGetResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupPolicyGetRequest14sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the Group's policy settings.

The response is either `GroupPolicyGetResponse14sp1()` or `ErrorResponse()`.

Replaced By : `GroupPolicyGetRequest14sp4()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupPolicyGetRequest14sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the Group's policy settings.

The response is either `GroupPolicyGetResponse14sp4()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupPolicyGetRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the Group's policy settings.

The response is either `GroupPolicyGetResponse17()` or `ErrorResponse()`. Replaced by:
`GroupPolicyGetRequest20()` in AS data mode

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupPolicyGetRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the Group's policy settings.

The response is either `GroupPolicyGetResponse20()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupPolicyGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the Group's policy settings.

The response is either `GroupPolicyGetResponse22()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupPolicyModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the policies for a Group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode: userAutoAttendantNameDialingAccess Replaced
by: `GroupPolicyModifyRequest22()` in AS data mode

**Attributes:**

|Name                                           |Type|Description                                          |
|-----------------------------------------------|----|-----------------------------------------------------|
|service_provider_id                            |str |serviceProviderId                                    |
|group_id                                       |str |groupId                                              |
|calling_plan_access                            |str |callingPlanAccess *Optional*                         |
|extension_access                               |str |extensionAccess *Optional*                           |
|ldap_integration_access                        |str |ldapIntegrationAccess *Optional*                     |
|voice_messaging_access                         |str |voiceMessagingAccess *Optional*                      |
|department_admin_user_access                   |str |departmentAdminUserAccess *Optional*                 |
|department_admin_trunk_group_access            |str |departmentAdminTrunkGroupAccess *Optional*           |
|department_admin_phone_number_extension_access |str |departmentAdminPhoneNumberExtensionAccess *Optional* |
|department_admin_calling_line_id_number_access |str |departmentAdminCallingLineIdNumberAccess *Optional*  |
|user_authentication_access                     |str |userAuthenticationAccess *Optional*                  |
|user_group_directory_access                    |str |userGroupDirectoryAccess *Optional*                  |
|user_profile_access                            |str |userProfileAccess *Optional*                         |
|user_enhanced_call_log_access                  |str |userEnhancedCallLogAccess *Optional*                 |
|user_auto_attendant_name_dialing_access        |str |userAutoAttendantNameDialingAccess *Optional*        |
</div>


## `GroupPolicyModifyRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the policies for a Group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode: userAutoAttendantNameDialingAccess

**Attributes:**

|Name                                           |Type|Description                                          |
|-----------------------------------------------|----|-----------------------------------------------------|
|service_provider_id                            |str |serviceProviderId                                    |
|group_id                                       |str |groupId                                              |
|calling_plan_access                            |str |callingPlanAccess *Optional*                         |
|extension_access                               |str |extensionAccess *Optional*                           |
|voice_messaging_access                         |str |voiceMessagingAccess *Optional*                      |
|department_admin_user_access                   |str |departmentAdminUserAccess *Optional*                 |
|department_admin_trunk_group_access            |str |departmentAdminTrunkGroupAccess *Optional*           |
|department_admin_phone_number_extension_access |str |departmentAdminPhoneNumberExtensionAccess *Optional* |
|department_admin_calling_line_id_number_access |str |departmentAdminCallingLineIdNumberAccess *Optional*  |
|user_authentication_access                     |str |userAuthenticationAccess *Optional*                  |
|user_group_directory_access                    |str |userGroupDirectoryAccess *Optional*                  |
|user_profile_access                            |str |userProfileAccess *Optional*                         |
|user_enhanced_call_log_access                  |str |userEnhancedCallLogAccess *Optional*                 |
|user_auto_attendant_name_dialing_access        |str |userAutoAttendantNameDialingAccess *Optional*        |
</div>


## `GroupPolycomPhoneServicesGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group's Polycom Phone Services attributes.

The response is either a `GroupPolycomPhoneServicesGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupPolycomPhoneServicesModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the group's Polycom Phone Services attributes.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                                |Type |Description                                              |
|----------------------------------------------------|-----|---------------------------------------------------------|
|service_provider_id                                 |str  |serviceProviderId                                        |
|group_id                                            |str  |groupId                                                  |
|include_group_common_phone_list_in_directory        |bool |includeGroupCommonPhoneListInDirectory *Optional*        |
|include_group_custom_contact_directory_in_directory |bool |includeGroupCustomContactDirectoryInDirectory *Optional* |
|group_custom_contact_directory                      |str  |groupCustomContactDirectory *Optional*                   |
</div>


## `GroupPortalPasscodeRulesGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the group's passcode rules setting.

The response is either `GroupPortalPasscodeRulesGetResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupPortalPasscodeRulesGetRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the group's passcode rules setting.

The response is either `GroupPortalPasscodeRulesGetResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupPortalPasscodeRulesModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the group's passcode rules setting.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in AS data mode: numberOfRepeatedDigits
disallowRepeatedPatterns disallowContiguousSequences numberOfAscendingDigits
numberOfDescendingDigits numberOfPreviousPasscodes

**Attributes:**

|Name                                          |Type |Description                                        |
|----------------------------------------------|-----|---------------------------------------------------|
|service_provider_id                           |str  |serviceProviderId                                  |
|group_id                                      |str  |groupId                                            |
|use_rule_level                                |str  |useRuleLevel *Optional*                            |
|disallow_repeated_digits                      |bool |disallowRepeatedDigits *Optional*                  |
|number_of_repeated_digits                     |int  |numberOfRepeatedDigits *Optional*                  |
|disallow_repeated_patterns                    |bool |disallowRepeatedPatterns *Optional*                |
|disallow_contiguous_sequences                 |bool |disallowContiguousSequences *Optional*             |
|number_of_ascending_digits                    |int  |numberOfAscendingDigits *Optional*                 |
|number_of_descending_digits                   |int  |numberOfDescendingDigits *Optional*                |
|disallow_user_number                          |bool |disallowUserNumber *Optional*                      |
|disallow_reversed_user_number                 |bool |disallowReversedUserNumber *Optional*              |
|disallow_old_passcode                         |bool |disallowOldPasscode *Optional*                     |
|number_of_previous_passcodes                  |int  |numberOfPreviousPasscodes *Optional*               |
|disallow_reversed_old_passcode                |bool |disallowReversedOldPasscode *Optional*             |
|min_code_length                               |int  |minCodeLength *Optional*                           |
|max_code_length                               |int  |maxCodeLength *Optional*                           |
|disable_login_after_max_failed_login_attempts |bool |disableLoginAfterMaxFailedLoginAttempts *Optional* |
|max_failed_login_attempts                     |int  |maxFailedLoginAttempts *Optional*                  |
|expire_password                               |bool |expirePassword *Optional*                          |
|passcode_expires_days                         |int  |passcodeExpiresDays *Optional*                     |
|send_login_disabled_notify_email              |bool |sendLoginDisabledNotifyEmail *Optional*            |
|login_disabled_notify_email_address           |str  |loginDisabledNotifyEmailAddress *Optional*         |
</div>


## `GroupPreAlertingAnnouncementGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the group PreAlertingservice settings.

The response is either a `GroupPreAlertingAnnouncementGetResponse()` or an
`ErrorResponse()`. Replaced by: `GroupPreAlertingAnnouncementGetRequest20()` in AS
data mode

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupPreAlertingAnnouncementGetRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the group’s PreAlertingservice settings.

The response is either a `GroupPreAlertingAnnouncementGetResponse20()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupPreferredCarrierGroupGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the currently configured carriers for a group.

The response is either a `GroupPreferredCarrierGroupGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupRouteListEnterpriseTrunkNumberPrefixAssignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Assign a list of service provider number prefixes to a group.

The number prefixes must have previously been added to the service provider.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description             |
|--------------------|----------|------------------------|
|service_provider_id |str       |serviceProviderId       |
|group_id            |str       |groupId                 |
|number_prefix       |List[str] |numberPrefix *Optional* |
</div>


## `GroupRouteListEnterpriseTrunkNumberPrefixGetAvailableListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a list of number prefixess that are assigned to a group and still available
for assignment to users within the group.

The response is either
`GroupRouteListEnterpriseTrunkNumberPrefixGetAvailableListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupRouteListEnterpriseTrunkNumberPrefixGetSummaryListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of assigned and unassigned enterprise trunknumber prefixes in a group.

The response is either
`GroupRouteListEnterpriseTrunkNumberPrefixGetSummaryListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupRouteListEnterpriseTrunkNumberPrefixUnassignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Unassign a list of service provider number prefixes from a group.

The number prefixes then become available for assignment to other groups.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description             |
|--------------------|----------|------------------------|
|service_provider_id |str       |serviceProviderId       |
|group_id            |str       |groupId                 |
|number_prefix       |List[str] |numberPrefix *Optional* |
</div>


## `GroupRouteListEnterpriseTrunkNumberRangeAssignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Assign a list of service provider number ranges to a group.

The number ranges must have previously been added to the service provider.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description                 |
|--------------------|----------|----------------------------|
|service_provider_id |str       |serviceProviderId           |
|group_id            |str       |groupId                     |
|number_range_start  |List[str] |numberRangeStart *Optional* |
</div>


## `GroupRouteListEnterpriseTrunkNumberRangeGetAvailableListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a list of number ranges that are assigned to a group and still available for
assignment to users within the group.

The response is either
`GroupRouteListEnterpriseTrunkNumberRangeGetAvailableListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupRouteListEnterpriseTrunkNumberRangeGetSummaryListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of assigned and unassigned enterprise trunknumber ranges in a group.

The response is either
`GroupRouteListEnterpriseTrunkNumberRangeGetSummaryListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupRouteListEnterpriseTrunkNumberRangeUnassignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Unassign a list of service provider number ranges from a group.

The number ranges then become available for assignment to other groups.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description                 |
|--------------------|----------|----------------------------|
|service_provider_id |str       |serviceProviderId           |
|group_id            |str       |groupId                     |
|number_range_start  |List[str] |numberRangeStart *Optional* |
</div>


## `GroupRoutePointBouncedCallGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a route point's bounced call settings.

The response is either a `GroupRoutePointBouncedCallGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupRoutePointBouncedCallModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a route point's bounced call settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                 |Type |Description                                |
|-------------------------------------|-----|-------------------------------------------|
|service_user_id                      |str  |serviceUserId                              |
|is_active                            |bool |isActive *Optional*                        |
|number_of_rings_before_bouncing_call |int  |numberOfRingsBeforeBouncingCall *Optional* |
|enable_transfer                      |bool |enableTransfer *Optional*                  |
|transfer_phone_number                |str  |transferPhoneNumber *Optional*             |
|bounce_call_when_agent_unavailable   |bool |bounceCallWhenAgentUnavailable *Optional*  |
</div>


## `GroupRoutePointDeleteInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Route Point instance from a group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupRoutePointDistinctiveRingingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the distinctive ringing configuration values for route point.

The response is either a `GroupRoutePointDistinctiveRingingGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupRoutePointDistinctiveRingingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the distinctive ringing configuration values for route point.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                            |Type |Description                                           |
|------------------------------------------------|-----|------------------------------------------------------|
|service_user_id                                 |str  |serviceUserId                                         |
|enable_distinctive_ringing                      |bool |enableDistinctiveRinging *Optional*                   |
|distinctive_ringing_ring_pattern                |str  |distinctiveRingingRingPattern *Optional*              |
|distinctive_ringing_force_delivery_ring_pattern |str  |distinctiveRingingForceDeliveryRingPattern *Optional* |
</div>


## `GroupRoutePointExternalSystemAssignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Assign a list of route point external systems to a group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                        |Type      |Description                         |
|----------------------------|----------|------------------------------------|
|service_provider_id         |str       |serviceProviderId                   |
|group_id                    |str       |groupId                             |
|route_point_external_system |List[str] |routePointExternalSystem *Optional* |
</div>


## `GroupRoutePointExternalSystemGetAssignedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of all Route Point External Systems assigned to a group.

The response is either `GroupRoutePointExternalSystemGetAssignedListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupRoutePointExternalSystemUnassignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Unassign a list of route point external systems from a group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                        |Type      |Description                         |
|----------------------------|----------|------------------------------------|
|service_provider_id         |str       |serviceProviderId                   |
|group_id                    |str       |groupId                             |
|route_point_external_system |List[str] |routePointExternalSystem *Optional* |
</div>


## `GroupRoutePointForcedForwardingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a route point's forced forwarding settings.

The response is either a `GroupRoutePointForcedForwardingGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupRoutePointForcedForwardingGetRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a route point's forced forwarding settings.

The response is either a `GroupRoutePointForcedForwardingGetResponse20()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupRoutePointGetAnnouncementRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a route point's announcement settings.

The response is either a `GroupRoutePointGetAnnouncementResponse()` or an
`ErrorResponse()`. Replaced by: `GroupRoutePointGetAnnouncementRequest19()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupRoutePointGetAnnouncementRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a route point's announcement settings.

The response is either a `GroupRoutePointGetAnnouncementResponse19()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupRoutePointGetAnnouncementRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a route point's announcement settings.

The response is either a `GroupRoutePointGetAnnouncementResponse20()` or an
`ErrorResponse()`. Replaced by: `GroupRoutePointGetAnnouncementRequest22()`

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupRoutePointGetAnnouncementRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a route point's announcement settings.

The response is either a `GroupRoutePointGetAnnouncementResponse22()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupRoutePointGetDNISListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of DNIS that are configured for a Route Point.

The response is either `GroupRoutePointGetDNISListResponse()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupRoutePointGetFailoverPolicyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the route point failover policy.

The response is either a `GroupRoutePointGetFailoverPolicyResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupRoutePointGetInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Route Point instance.

The response is either `GroupRoutePointGetInstanceResponse()` or `ErrorResponse()`.
Replaced by: `GroupRoutePointGetInstanceRequest19sp1()`

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupRoutePointGetInstanceRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Route Point instance.

The response is either `GroupRoutePointGetInstanceResponse19sp1()` or
`ErrorResponse()`. Replace by `GroupRoutePointGetInstanceRequest22()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupRoutePointGetInstanceRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Route Point instance.

The response is either `GroupRoutePointGetInstanceResponse19sp1()` or
`ErrorResponse()`. Replaced by `GroupRoutePointGetInstanceRequest23()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupRoutePointGetInstanceRequest23`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a Route Point instance.

The response is either `GroupRoutePointGetInstanceResponse19sp1()` or
`ErrorResponse()`. The Following elements are only used in AS data mode and ignored in
XS data mode: - sendCallAdmissionNotification, use value ‘false’ in XS data mode.  -
callAdmissionTimerSeconds, use value ‘3’ in XS data mode.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupRoutePointHolidayServiceGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a route point's holiday service settings.

The response is either a `GroupRoutePointHolidayServiceGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupRoutePointHolidayServiceGetRequest17sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a route point's holiday service settings.

The response is either a `GroupRoutePointHolidayServiceGetResponse17sp1()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupRoutePointHolidayServiceGetRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a route point's holiday service settings.

The response is either a `GroupRoutePointHolidayServiceGetResponse20()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupRoutePointManualFailoverRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Initiate manual failover for the Route Point.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupRoutePointModifyDNISParametersRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the setting that are configured for all the DNIS in a Route Point.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type |Description                  |
|--------------------|-----|-----------------------------|
|service_user_id     |str  |serviceUserId                |
|display_dnis_number |bool |displayDNISNumber *Optional* |
|display_dnis_name   |bool |displayDNISName *Optional*   |
</div>


## `GroupRoutePointModifyFailoverPolicyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the route point failover policy.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                           |Type |Description                                         |
|-----------------------------------------------|-----|----------------------------------------------------|
|service_user_id                                |str  |serviceUserId                                       |
|enable_failover_support                        |bool |enableFailoverSupport *Optional*                    |
|external_system                                |str  |externalSystem *Optional*                           |
|failover_phone_number                          |str  |failoverPhoneNumber *Optional*                      |
|per_call_enable_failover_support               |bool |perCallEnableFailoverSupport *Optional*             |
|per_call_call_failure_timeout_seconds          |int  |perCallCallFailureTimeoutSeconds *Optional*         |
|per_call_outbound_call_failure_timeout_seconds |int  |perCallOutboundCallFailureTimeoutSeconds *Optional* |
|per_call_failover_phone_number                 |str  |perCallFailoverPhoneNumber *Optional*               |
</div>


## `GroupRoutePointNightServiceGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a route point's night service settings.

The response is either a `GroupRoutePointNightServiceGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupRoutePointNightServiceGetRequest17sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a route point's night service settings.

The response is either a `GroupRoutePointNightServiceGetResponse17sp1()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupRoutePointNightServiceGetRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a route point's night service settings.

The response is either a `GroupRoutePointNightServiceGetResponse20()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupRoutePointOverflowGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a route point's overflow settings.

The response is either a `GroupRoutePointOverflowGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupRoutePointOverflowGetRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a route point's overflow settings.

The response is either a `GroupRoutePointOverflowGetResponse20()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupRoutePointQueueCallDispositionCodeAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Route Point Call Disposition Code.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type |Description            |
|----------------|-----|-----------------------|
|service_user_id |str  |serviceUserId          |
|code            |str  |code                   |
|is_active       |bool |isActive               |
|description     |str  |description *Optional* |
</div>


## `GroupRoutePointQueueCallDispositionCodeDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Route Point Call Disposition Code.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
|code            |str |code          |
</div>


## `GroupRoutePointQueueCallDispositionCodeGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of Route Point Level and Organization Level Call Disposition Codes.

The response is either `GroupRoutePointQueueCallDispositionCodeGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupRoutePointQueueCallDispositionCodeGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a Route Point Call Disposition Code.

The response is either `GroupRoutePointQueueCallDispositionCodeGetResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
|code            |str |code          |
</div>


## `GroupRoutePointQueueCallDispositionCodeModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a Route Point Call Disposition Code.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type |Description            |
|----------------|-----|-----------------------|
|service_user_id |str  |serviceUserId          |
|code            |str  |code                   |
|is_active       |bool |isActive *Optional*    |
|description     |str  |description *Optional* |
</div>


## `GroupRoutePointQueueCallDispositionCodeSettingsGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the queue level data associated with Route Point Call Disposition Code
Settings.

The response is either an
`GroupRoutePointQueueCallDispositionCodeSettingsGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupRoutingProfileGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the routing profile for the group.

The response is either a `GroupRoutingProfileGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupRoutingProfileModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests to modify the routing profile for a group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description               |
|--------------------|----|--------------------------|
|service_provider_id |str |serviceProviderId         |
|group_id            |str |groupId                   |
|routing_profile     |str |routingProfile *Optional* |
</div>


## `GroupScheduleAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a group schedule.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|schedule_name       |str |scheduleName      |
|schedule_type       |str |scheduleType      |
</div>


## `GroupScheduleGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of a group schedules.

The list can be filtered by schedule type.

The response is either a `GroupScheduleGetListResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description             |
|--------------------|----|------------------------|
|service_provider_id |str |serviceProviderId       |
|group_id            |str |groupId                 |
|schedule_type       |str |scheduleType *Optional* |
</div>


## `GroupScheduleGetListRequest17sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of schedules viewable by a group.

The list can be filtered by schedule type.

The response is either a `GroupScheduleGetListResponse17sp1()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description             |
|--------------------|----|------------------------|
|service_provider_id |str |serviceProviderId       |
|group_id            |str |groupId                 |
|schedule_type       |str |scheduleType *Optional* |
</div>


## `GroupSecurityClassificationCustomizationGetAvailableListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the available group security classification list.

If it is not customized, it returns the system default list.

The response is either an
`GroupSecurityClassificationCustomizationGetAvailableListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupSeriesCompletionAddInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Adds a Series Completion group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|group_id            |str       |groupId           |
|name                |str       |name              |
|user_id             |List[str] |userId *Optional* |
</div>


## `GroupSeriesCompletionDeleteInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Deletes a Series Completion group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|name                |str |name              |
</div>


## `GroupSeriesCompletionGetInstanceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a list of Series Completion instances within a group.

The response is either `GroupSeriesCompletionGetInstanceListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupSeriesCompletionGetInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Gets a Series Completion group.

The response is either `GroupSeriesCompletionGetInstanceResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|name                |str |name              |
</div>


## `GroupServiceAssignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Assign one or more group services to the group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|group_id            |str       |groupId           |
|service_name        |List[str] |serviceName       |
</div>


## `GroupServiceGetAuthorizationListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the group's service authorization status.

The response is either `GroupServiceGetAuthorizationListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupServiceGetAuthorizationRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the group's service authorization information for a specific service or
service pack.

The response is either `GroupServiceGetAuthorizationResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description                 |
|--------------------|----|----------------------------|
|service_provider_id |str |serviceProviderId           |
|group_id            |str |groupId                     |
|user_service_name   |str |userServiceName *Optional*  |
|group_service_name  |str |groupServiceName *Optional* |
|service_pack_name   |str |servicePackName *Optional*  |
</div>


## `GroupServiceGetAuthorizedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of services and service packs authorized to a group.

The response is either `GroupServiceGetAuthorizedListResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupServiceInstancePrivacyGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the data associated with Privacy for a service instance.

The response is either a `GroupServiceInstancePrivacyGetResponse()`. Replaced by:
`GroupServiceInstancePrivacyGetRequest17sp4()`

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupServiceInstancePrivacyGetRequest17sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the data associated with Privacy for a service instance.

The response is either a `GroupServiceInstancePrivacyGetResponse17sp4()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupServiceInstancePrivacyModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the data associated with Privacy for a service instance.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                            |Type |Description                                           |
|------------------------------------------------|-----|------------------------------------------------------|
|service_user_id                                 |str  |serviceUserId                                         |
|enable_directory_privacy                        |bool |enableDirectoryPrivacy *Optional*                     |
|enable_auto_attendant_extension_dialing_privacy |bool |enableAutoAttendantExtensionDialingPrivacy *Optional* |
|enable_auto_attendant_name_dialing_privacy      |bool |enableAutoAttendantNameDialingPrivacy *Optional*      |
</div>


## `GroupServiceIsAssignedRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to determine if a GroupService is assigned to the group.


**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|service_name        |str |serviceName       |
</div>


## `GroupServicePhoneNumberLookupRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Lookup if the given number is defined in the specified service in the group.

The response is `GroupServicePhoneNumberLookupResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|service_type        |str |serviceType       |
|phone_number        |str |phoneNumber       |
</div>


## `GroupServiceUnassignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Unassign one or more of the group's assigned services.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|group_id            |str       |groupId           |
|service_name        |List[str] |serviceName       |
</div>


## `GroupSessionAdmissionControlGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the session admission control capacity for the group.

The response is either a `GroupSessionAdmissionControlGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupSessionAdmissionControlGroupDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete one or more session admission control groups for the group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|group_id            |str       |groupId           |
|name                |List[str] |name              |
</div>


## `GroupSessionAdmissionControlGroupGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of session admission control group for the group.

The response is either a `GroupSessionAdmissionControlGroupGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupSessionAdmissionControlGroupGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a session admission control group for the group.

The response is either a `GroupSessionAdmissionControlGroupGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|name                |str |name              |
</div>


## `GroupSessionAdmissionControlGroupGetRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a session admission control group for the group.

The response is either a `GroupSessionAdmissionControlGroupGetResponse19sp1()` or an
`ErrorResponse()`. Replaced by: `GroupSessionAdmissionControlGroupGetRequest21sp1()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|name                |str |name              |
</div>


## `GroupSessionAdmissionControlGroupGetRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a session admission control group for the group.

The response is either a `GroupSessionAdmissionControlGroupGetResponse21sp1()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|name                |str |name              |
</div>


## `GroupSessionAdmissionControlModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify session admission control capacity for the group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                          |Type |Description                           |
|------------------------------|-----|--------------------------------------|
|service_provider_id           |str  |serviceProviderId                     |
|group_id                      |str  |groupId                               |
|restrict_aggregate_sessions   |bool |restrictAggregateSessions *Optional*  |
|max_sessions                  |int  |maxSessions *Optional*                |
|max_user_originating_sessions |int  |maxUserOriginatingSessions *Optional* |
|max_user_terminating_sessions |int  |maxUserTerminatingSessions *Optional* |
|count_intra_group_sessions    |bool |countIntraGroupSessions *Optional*    |
</div>


## `GroupShInterfaceGetUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Returns a list of all Public User Identities and associated data in a group.

The response is either a `GroupShInterfaceGetUserListResponse()` or an
`ErrorResponse()`. Replaced by: `GroupShInterfaceGetUserListRequest21sp1()` in AS data
mode.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupShInterfaceGetUserListRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Returns a list of all Public User Identities and associated data in a group.

The response is either a `GroupShInterfaceGetUserListResponse21sp1()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupSpeedDial100GetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the speed dial 100 service settings for a group.

The response is either a `GroupSpeedDial100GetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupSpeedDial100GetRequest17sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the speed dial 100 service settings for a group.

The response is either a `GroupSpeedDial100GetResponse17sp1()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupSpeedDial100ModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the speed dial 100 prefix setting for a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|prefix              |str |prefix *Optional* |
</div>


## `GroupStirShakenGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get Group Stir Shaken service settings.

The response is either `GroupStirShakenGetResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupStirShakenModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify Group Stir Shaken service settings.


**Attributes:**

|Name                                                   |Type |Description                                                 |
|-------------------------------------------------------|-----|------------------------------------------------------------|
|service_provider_id                                    |str  |serviceProviderId                                           |
|group_id                                               |str  |groupId                                                     |
|use_parent_level_settings                              |bool |useParentLevelSettings *Optional*                           |
|signing_policy                                         |str  |signingPolicy *Optional*                                    |
|tagging_policy                                         |str  |taggingPolicy *Optional*                                    |
|signing_service_url                                    |str  |signingServiceURL *Optional*                                |
|tag_from_or_pai                                        |str  |tagFromOrPAI *Optional*                                     |
|verstat_tag                                            |str  |verstatTag *Optional*                                       |
|use_os_value_for_orig_id                               |bool |useOSValueForOrigId *Optional*                              |
|orig_uuid                                              |str  |origUUID *Optional*                                         |
|attestation_level                                      |str  |attestationLevel *Optional*                                 |
|enable_verification                                    |bool |enableVerification *Optional*                               |
|verification_service_url                               |str  |verificationServiceURL *Optional*                           |
|verification_error_handling                            |str  |verificationErrorHandling *Optional*                        |
|proxy_verstat_to_cnam_subscribe                        |bool |proxyVerstatToCNAMSubscribe *Optional*                      |
|use_unknown_headers_from_cnam_notify                   |bool |useUnknownHeadersFromCNAMNotify *Optional*                  |
|enable_signing_for_unscreened_trunk_group_originations |bool |enableSigningForUnscreenedTrunkGroupOriginations *Optional* |
|enable_tagging_for_unscreened_trunk_group_originations |bool |enableTaggingForUnscreenedTrunkGroupOriginations *Optional* |
|unscreened_trunk_group_origination_attestation_level   |str  |unscreenedTrunkGroupOriginationAttestationLevel *Optional*  |
</div>


## `GroupTemplateOnlyDeviceFileGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of template files used to support a VDM device defined at
group level.

The response is either `GroupTemplateOnlyDeviceFileGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|device_name         |str |deviceName        |
</div>


## `GroupThirdPartyEmergencyCallingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the third-party emergency call service settings for the Group.

The response is either a `GroupThirdPartyEmergencyCallingGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupThirdPartyEmergencyCallingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the third-party emergency call service settings for the Group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type |Description                       |
|-------------------------|-----|----------------------------------|
|service_provider_id      |str  |serviceProviderId                 |
|group_id                 |str  |groupId                           |
|enable_device_management |bool |enableDeviceManagement *Optional* |
|enable_routing           |bool |enableRouting *Optional*          |
</div>


## `GroupThirdPartyVoiceMailSupportGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the group level data associated with Third-Party Voice Mail Support.

The response is either a `GroupThirdPartyVoiceMailSupportGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupThirdPartyVoiceMailSupportModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Third Party Voice Mail Support settings for a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type |Description            |
|--------------------|-----|-----------------------|
|service_provider_id |str  |serviceProviderId      |
|group_id            |str  |groupId                |
|is_active           |bool |isActive *Optional*    |
|group_server        |str  |groupServer *Optional* |
</div>


## `GroupTimeScheduleDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a time schedule from a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|time_schedule_name  |str |timeScheduleName  |
</div>


## `GroupTimeScheduleGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a list of all time schedules in a group.

The response is either a `GroupTimeScheduleGetListResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupTimeScheduleGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a group time schedule.

The response is either a `GroupTimeScheduleGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|time_schedule_name  |str |timeScheduleName  |
</div>


## `GroupTrunkGroupDeleteInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Trunk Group Instance from a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|service_user_id     |str |serviceUserId     |
</div>


## `GroupTrunkGroupGetAvailableDetailListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of available trunk groups within a group.

The response is either `GroupTrunkGroupGetAvailableDetailListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupTrunkGroupGetInstanceListRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of Trunk Groups for the group or enterprise.

It is possible to restrict the results to a particular department, or expand the list
to the entire enterprise.

The response is either a `GroupTrunkGroupGetInstanceListResponse14()` or an
`ErrorResponse()`.

**Attributes:**

|Name                            |Type |Description                             |
|--------------------------------|-----|----------------------------------------|
|service_provider_id             |str  |serviceProviderId                       |
|group_id                        |str  |groupId                                 |
|group_department_name           |str  |groupDepartmentName *Optional*          |
|include_enterprise_trunk_groups |bool |includeEnterpriseTrunkGroups *Optional* |
|only_trunk_groups_with_device   |bool |onlyTrunkGroupsWithDevice *Optional*    |
</div>


## `GroupTrunkGroupGetInstanceListRequest14sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of Trunk Groups for the group or enterprise.

It is possible to restrict the results to a particular department, or expand the list
to the entire enterprise.

The response is either a `GroupTrunkGroupGetInstanceListResponse14sp4()` or an
`ErrorResponse()`.

**Attributes:**

|Name                            |Type |Description                             |
|--------------------------------|-----|----------------------------------------|
|service_provider_id             |str  |serviceProviderId                       |
|group_id                        |str  |groupId                                 |
|group_department_name           |str  |groupDepartmentName *Optional*          |
|include_enterprise_trunk_groups |bool |includeEnterpriseTrunkGroups *Optional* |
|only_trunk_groups_with_device   |bool |onlyTrunkGroupsWithDevice *Optional*    |
</div>


## `GroupTrunkGroupGetInstanceRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a Trunk Group Instance's profile.

The response is either a `GroupTrunkGroupGetInstanceResponse14()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupTrunkGroupGetInstanceRequest14sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a Trunk Group Instance's profile.

The response is either a `GroupTrunkGroupGetInstanceResponse14sp1()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupTrunkGroupGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the maximum permissible active trunk group calls for the group.

The response is either a `GroupTrunkGroupGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupTrunkGroupGetRequest14sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the maximum and bursting maximum permissible active trunk group calls for the
group.

The response is either a `GroupTrunkGroupGetResponse14sp1()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupTrunkGroupGetRequest14sp9`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the maximum and bursting maximum permissible active trunk group calls for the
group.

The response is either a `GroupTrunkGroupGetResponse14sp9()` or an `ErrorResponse()`.
Deprecated by `GroupTrunkGroupGetRequest23()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupTrunkGroupGetRequest23`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the maximum and bursting maximum permissible active trunk group calls for the
group.

The response is either a `GroupTrunkGroupGetResponse23()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupTrunkGroupUserCreationTaskAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a user creation task for a trunk group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name               |Type                 |Description                 |
|-------------------|---------------------|----------------------------|
|service_user_id    |str                  |serviceUserId               |
|task_name          |str                  |taskName                    |
|user_id_format     |str                  |userIdFormat                |
|user_id_domain     |str                  |userIdDomain                |
|populate_extension |bool                 |populateExtension           |
|line_port_format   |str                  |linePortFormat              |
|line_port_domain   |str                  |linePortDomain              |
|populate_contact   |bool                 |populateContact             |
|contact_format     |str                  |contactFormat *Optional*    |
|contact_domain     |str                  |contactDomain *Optional*    |
|user_phone_numbers |OCI.userPhoneNumbers |userPhoneNumbers *Optional* |
|user_extensions    |OCI.userExtensions   |userExtensions *Optional*   |
|service_pack_name  |List[str]            |servicePackName *Optional*  |
|user_service       |List[str]            |userService *Optional*      |
</div>


## `GroupTrunkGroupUserCreationTaskDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a user creation task for a trunk group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
|task_name       |str |taskName      |
</div>


## `GroupTrunkGroupUserCreationTaskGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of user creation tasks for a trunk group.

The response is either `GroupTrunkGroupUserCreationTaskGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupTrunkGroupUserCreationTaskGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the details of a specified user creation task for a trunk group.

The response is either `GroupTrunkGroupUserCreationTaskGetResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
|task_name       |str |taskName      |
</div>


## `GroupUserLanguageModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify language of the users within a group.

If neither applyToUsers nor applyToServiceInstances is specified in the request,
language is not changed for any user in the group.  If applyToUsers is specified,
regular users within the group have the language modified.  If applyToServiceInstances
is specified, the service instance users within the group have the language modified.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                       |Type |Description                        |
|---------------------------|-----|-----------------------------------|
|service_provider_id        |str  |serviceProviderId                  |
|group_id                   |str  |groupId                            |
|language                   |str  |language                           |
|apply_to_users             |bool |applyToUsers *Optional*            |
|apply_to_service_instances |bool |applyToServiceInstances *Optional* |
</div>


## `GroupVirtualOnNetEnterpriseExtensionsDeleteUserRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete an existing Virtual On-Net user from a Group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|phone_number        |str |phoneNumber       |
</div>


## `GroupVirtualOnNetEnterpriseExtensionsGetUserRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get an existing Virtual On-Net user from a Group.

The response is either a `GroupVirtualOnNetEnterpriseExtensionsGetUserResponse()` or
an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|phone_number        |str |phoneNumber       |
</div>


## `GroupVirtualOnNetEnterpriseExtensionsModifyUserRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an existing Virtual On-Net user of a Group.

The serviceProviderId, groupId and phoneNumber combination uniquely identifies a
Virtual On-Net User.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                          |Type|Description                         |
|------------------------------|----|------------------------------------|
|service_provider_id           |str |serviceProviderId                   |
|group_id                      |str |groupId                             |
|phone_number                  |str |phoneNumber                         |
|extension                     |str |extension *Optional*                |
|first_name                    |str |firstName *Optional*                |
|last_name                     |str |lastName *Optional*                 |
|calling_line_id_first_name    |str |callingLineIdFirstName *Optional*   |
|calling_line_id_last_name     |str |callingLineIdLastName *Optional*    |
|virtual_on_net_call_type_name |str |virtualOnNetCallTypeName *Optional* |
</div>


## `GroupVisualDeviceManagementGetDeviceInfoRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the information for a specified device supporting visual device management.

The response is either a `GroupVisualDeviceManagementGetDeviceInfoResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|device_name         |str |deviceName        |
</div>


## `GroupVoiceMessagingGroupGetPasscodeRulesRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the group's voice portal passcode rules setting.

The response is either `GroupVoiceMessagingGroupGetPasscodeRulesResponse()` or
`ErrorResponse()`.

Replaced By: `GroupPortalPasscodeRulesGetRequest()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupVoiceMessagingGroupGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the group's Voice Messaging settings.

The response is either `GroupVoiceMessagingGroupGetResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupVoiceMessagingGroupGetVoicePortalBrandingRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the group's voice portal branding settings.

The response is either a `GroupVoiceMessagingGroupGetVoicePortalBrandingResponse()` or
an `ErrorResponse()`.

Replaced By: `GroupVoiceMessagingGroupGetVoicePortalBrandingRequest16()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupVoiceMessagingGroupGetVoicePortalBrandingRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the group's voice portal branding settings.

The response is either a `GroupVoiceMessagingGroupGetVoicePortalBrandingResponse16()`
or an `ErrorResponse()`. Replaced by:
`GroupVoiceMessagingGroupGetVoicePortalBrandingRequest20()` in AS data mode

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupVoiceMessagingGroupGetVoicePortalBrandingRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the group's voice portal branding settings.

The response is either a `GroupVoiceMessagingGroupGetVoicePortalBrandingResponse20()`
or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupVoiceMessagingGroupGetVoicePortalRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the group's voice messaging settings The response is either
`GroupVoiceMessagingGroupGetVoicePortalResponse14()` or `ErrorResponse()`.

Replaced by `GroupVoiceMessagingGroupGetVoicePortalRequest15()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupVoiceMessagingGroupGetVoicePortalRequest15`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the group voice portal information for a voice messaging group.

The response is either `GroupVoiceMessagingGroupGetVoicePortalResponse15()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupVoiceMessagingGroupGetVoicePortalRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the group voice portal information for a voice messaging group.

The response is either `GroupVoiceMessagingGroupGetVoicePortalResponse17()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupVoiceMessagingGroupGetVoicePortalRequest17sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the group voice portal information for a voice messaging group.

The response is either `GroupVoiceMessagingGroupGetVoicePortalResponse17sp4()` or
`ErrorResponse()`. Replaced by: `GroupVoiceMessagingGroupGetVoicePortalRequest19sp1()`
in AS data mode

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupVoiceMessagingGroupGetVoicePortalRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the group voice portal information for a voice messaging group.

The response is either `GroupVoiceMessagingGroupGetVoicePortalResponse19sp1()` or
`ErrorResponse()`. Replaced by: `GroupVoiceMessagingGroupGetVoicePortalRequest21sp1()`
in AS data mode.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupVoiceMessagingGroupGetVoicePortalRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the group voice portal information for a voice messaging group.

The response is either `GroupVoiceMessagingGroupGetVoicePortalResponse21sp1()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
</div>


## `GroupVoiceMessagingGroupModifyPasscodeRulesRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the group's voice portal passcode rules setting.

The response is either `SuccessResponse()` or `ErrorResponse()`.

Replaced By: `GroupPortalPasscodeRulesModifyRequest()`

**Attributes:**

|Name                                          |Type |Description                                        |
|----------------------------------------------|-----|---------------------------------------------------|
|service_provider_id                           |str  |serviceProviderId                                  |
|group_id                                      |str  |groupId                                            |
|use_rule_level                                |str  |useRuleLevel *Optional*                            |
|disallow_repeated_digits                      |bool |disallowRepeatedDigits *Optional*                  |
|disallow_user_number                          |bool |disallowUserNumber *Optional*                      |
|disallow_reversed_user_number                 |bool |disallowReversedUserNumber *Optional*              |
|disallow_old_passcode                         |bool |disallowOldPasscode *Optional*                     |
|disallow_reversed_old_passcode                |bool |disallowReversedOldPasscode *Optional*             |
|min_code_length                               |int  |minCodeLength *Optional*                           |
|max_code_length                               |int  |maxCodeLength *Optional*                           |
|disable_login_after_max_failed_login_attempts |bool |disableLoginAfterMaxFailedLoginAttempts *Optional* |
|max_failed_login_attempts                     |int  |maxFailedLoginAttempts *Optional*                  |
|expire_password                               |bool |expirePassword *Optional*                          |
|passcode_expires_days                         |int  |passcodeExpiresDays *Optional*                     |
|send_login_disabled_notify_email              |bool |sendLoginDisabledNotifyEmail *Optional*            |
|login_disabled_notify_email_address           |str  |loginDisabledNotifyEmailAddress *Optional*         |
</div>


## `GroupVoiceMessagingGroupModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the group's voice messaging settings.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                             |Type |Description                                          |
|-------------------------------------------------|-----|-----------------------------------------------------|
|service_provider_id                              |str  |serviceProviderId                                    |
|group_id                                         |str  |groupId                                              |
|use_mail_server_setting                          |str  |useMailServerSetting *Optional*                      |
|warn_caller_before_recording_voice_message       |bool |warnCallerBeforeRecordingVoiceMessage *Optional*     |
|allow_users_configuring_advanced_settings        |bool |allowUsersConfiguringAdvancedSettings *Optional*     |
|allow_compose_or_forward_message_to_entire_group |bool |allowComposeOrForwardMessageToEntireGroup *Optional* |
|mail_server_net_address                          |str  |mailServerNetAddress *Optional*                      |
|mail_server_protocol                             |str  |mailServerProtocol *Optional*                        |
|real_delete_for_imap                             |bool |realDeleteForImap *Optional*                         |
|max_mailbox_length_minutes                       |int  |maxMailboxLengthMinutes *Optional*                   |
|does_message_age                                 |bool |doesMessageAge *Optional*                            |
|hold_period_days                                 |int  |holdPeriodDays *Optional*                            |
</div>


## `GroupVoiceXmlDeleteInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a VoiceXML instance from a group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupVoiceXmlGetInstanceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of VoiceXML instances within a group.

The response is either `GroupVoiceXmlGetInstanceListResponse()` or `ErrorResponse()`.
It is possible to get the instances within a specified department.

**Attributes:**

|Name                  |Type|Description                    |
|----------------------|----|-------------------------------|
|service_provider_id   |str |serviceProviderId              |
|group_id              |str |groupId                        |
|group_department_name |str |groupDepartmentName *Optional* |
</div>


## `GroupVoiceXmlGetInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a VoiceXML instance.

The response is either `GroupVoiceXmlGetInstanceResponse()` or `ErrorResponse()`.
Replaced by: `GroupVoiceXmlGetInstanceRequest19sp1()` in AS data mode

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupVoiceXmlGetInstanceRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a VoiceXML instance.

The response is either `GroupVoiceXmlGetInstanceResponse19sp1()` or `ErrorResponse()`.
Replaced by: `GroupVoiceXmlGetInstanceRequest22()` in AS mode

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupVoiceXmlGetInstanceRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the information of a VoiceXML instance.

The response is either `GroupVoiceXmlGetInstanceResponse22()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `GroupXsiPolicyProfileGetAssignedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of Xsi policy profile assigned.

The response is either a `GroupXsiPolicyProfileGetAssignedListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|group_id            |str |groupId           |
|level               |str |level *Optional*  |
</div>


## `GroupXsiPolicyProfileModifyDefaultRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the default Xsi policy profile for a group.

It can only modify the user level default Xsi policy profile.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                            |Type|Description                            |
|--------------------------------|----|---------------------------------------|
|service_provider_id             |str |serviceProviderId                      |
|group_id                        |str |groupId                                |
|user_default_xsi_policy_profile |str |userDefaultXsiPolicyProfile *Optional* |
</div>


## `LoginRequest13mp10`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
`LoginRequest13mp10()` is 2nd stage of the 2 stage OCI login process.

The signedPassword is not required for external authentication login from a trusted
host (ACL).

**Attributes:**

|Name            |Type|Description               |
|----------------|----|--------------------------|
|user_id         |str |userId                    |
|signed_password |str |signedPassword *Optional* |
</div>


## `LoginRequest14sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
`LoginRequest14sp4()` is 2nd stage of the 2 stage OCI login process.

The signedPassword is not required for external authentication login from a trusted
host (ACL).

**Attributes:**

|Name                |Type|Description                  |
|--------------------|----|-----------------------------|
|user_id             |str |userId                       |
|signed_password     |str |signedPassword *Optional*    |
|plain_text_password |str |plainTextPassword *Optional* |
</div>


## `LoginRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
`LoginRequest21sp1()` is 2nd stage of the 2 stage OCI login process.

The signedPassword is not required for external authentication login from a trusted
host (ACL). Replaced by `LoginRequest22V3()` in AS data mode.

**Attributes:**

|Name                |Type|Description                  |
|--------------------|----|-----------------------------|
|user_id             |str |userId                       |
|signed_password     |str |signedPassword *Optional*    |
|plain_text_password |str |plainTextPassword *Optional* |
</div>


## `LoginRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to login to OCI.

password is not required for external authentication login from a trusted host (ACL).
Replaced by `LoginRequest22V2()` in AS data mode.

**Attributes:**

|Name     |Type|Description         |
|---------|----|--------------------|
|user_id  |str |userId              |
|password |str |password *Optional* |
</div>


## `LoginRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to login to OCI.

password is not required for external authentication login from a trusted host (ACL).
Replaced by `LoginRequest22V3()` in AS data mode.

**Attributes:**

|Name     |Type|Description         |
|---------|----|--------------------|
|user_id  |str |userId              |
|password |str |password *Optional* |
</div>


## `LoginRequest22V3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to login to OCI.

password is not required for external authentication login from a trusted host (ACL).
Replaced by `LoginRequest22V4()` in AS data mode.

**Attributes:**

|Name     |Type|Description         |
|---------|----|--------------------|
|user_id  |str |userId              |
|password |str |password *Optional* |
</div>


## `LoginRequest22V4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to login to OCI.

password is not required for external authentication login from a trusted host (ACL).
The following data element is only used in XS data mode and will be ignored in AS data
mode: signedPassword Replaced by: `LoginRequest22V5()`.

**Attributes:**

|Name            |Type|Description               |
|----------------|----|--------------------------|
|user_id         |str |userId                    |
|password        |str |password *Optional*       |
|signed_password |str |signedPassword *Optional* |
</div>


## `LoginRequest22V5`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to login to OCI.

password is not required for external authentication login from a trusted host (ACL).
The following data element is only used in XS data mode and will be ignored in AS data
mode: signedPassword

**Attributes:**

|Name            |Type|Description               |
|----------------|----|--------------------------|
|user_id         |str |userId                    |
|password        |str |password *Optional*       |
|signed_password |str |signedPassword *Optional* |
</div>


## `LogoutRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
`LogoutRequest()` is sent when an OCI user logs out or when connection is lost.

This command can be sent either to the server, or to the client from OCS. Response is
either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description       |
|--------|----|------------------|
|user_id |str |userId            |
|reason  |str |reason *Optional* |
</div>


## `LongLivedTokenRevokeRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Revoke all previously issued long lived tokens.

If the userId is not specified, revoke all tokens in the system.  If the userId is
specified, revoke all tokens issued to the user.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description       |
|--------|----|------------------|
|user_id |str |userId *Optional* |
</div>


## `PasswordModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the password for a user/administrator.

When oldPassword is specified, password rule applies.  If oldPassword in not
specified, any password rule related to old password does not apply.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type|Description            |
|-------------|----|-----------------------|
|user_id      |str |userId                 |
|old_password |str |oldPassword *Optional* |
|new_password |str |newPassword            |
</div>


## `PlaceModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to configure a WebEx room/place to have the primary endpoint of WebEx Teams
device.

placeUserId refers to a WebEx room/place.  webExSIPAddress specifies the WebEx SIP
address of the place.  The format of this parameter is: user@domain.  The user part
specified in webExSIPAddress will be set to the lineport of the place’s primary
endpoint.  The endpoint will have a static address with URI set to "sip:user@domain".
The domain specified in webExSIPAddress will be: - added to the system if it does not
exist yet.  - assigned to the service provider/enterprise which the place belongs to,
if it has not been assigned yet.  - assigned to the group which the place belongs to,
if it has not been assigned yet.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name               |Type|Description                |
|-------------------|----|---------------------------|
|place_user_id      |str |placeUserId                |
|web_ex_sip_address |str |webExSIPAddress *Optional* |
</div>


## `PrimaryInfoGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests information about the primary server for high-availability support.


**Attributes:**

|Name                      |Type |Description            |
|--------------------------|-----|-----------------------|
|is_private                |bool |isPrivate              |
|is_address_info_requested |bool |isAddressInfoRequested |
</div>


## `PublicClusterGetFullyQualifiedDomainNameRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the public cluster fully qualified domain name (FQDN).

The response is either a `PublicClusterGetFullyQualifiedDomainNameResponse()` or an
`ErrorResponse()`.

</div>


## `ResellerAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a reseller.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                 |Type|Description                   |
|---------------------|----|------------------------------|
|reseller_id          |str |resellerId                    |
|reseller_name        |str |resellerName *Optional*       |
|reseller_external_id |str |resellerExternalId *Optional* |
</div>


## `ResellerAdminAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a reseller administrator.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description          |
|------------|----|---------------------|
|reseller_id |str |resellerId           |
|user_id     |str |userId               |
|first_name  |str |firstName *Optional* |
|last_name   |str |lastName *Optional*  |
|password    |str |password *Optional*  |
|language    |str |language *Optional*  |
</div>


## `ResellerAdminAlternateIdAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add an alternate Id to a reseller admin.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name              |Type|Description            |
|------------------|----|-----------------------|
|user_id           |str |userId                 |
|alternate_user_id |str |alternateUserId        |
|description       |str |description *Optional* |
</div>


## `ResellerAdminAlternateIdDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete an alternate admin user id of a reseller admin.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name              |Type|Description     |
|------------------|----|----------------|
|user_id           |str |userId          |
|alternate_user_id |str |alternateUserId |
</div>


## `ResellerAdminAlternateIdGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the admin id and the list of alternate admin ids of an admin.

The response is either `ResellerAdminAlternateIdGetListResponse()` or
`ErrorResponse()`. The "userId" can be either the admin user Id or an alternate admin
user Id.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `ResellerAdminAlternateIdModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify an alternate id of a reseller admin.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                  |Type|Description                   |
|----------------------|----|------------------------------|
|user_id               |str |userId                        |
|alternate_user_id     |str |alternateUserId               |
|new_alternate_user_id |str |newAlternateUserId *Optional* |
|description           |str |description *Optional*        |
</div>


## `ResellerAdminDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a reseller administrator.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `ResellerAdminGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of reseller administrators.

The response is either a `ResellerAdminGetListResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|reseller_id |str |resellerId |
</div>


## `ResellerAdminGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a reseller administrators profile.

The response is either a `ResellerAdminGetResponse()` or an `ErrorResponse()`.
Replaced by `ResellerAdminGetRequest22()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `ResellerAdminGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a reseller administrators profile.

The response is either a `ResellerAdminGetResponse22()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `ResellerAdminModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the profile for a reseller administrator.

Since old password is not specified here, any password rule related to old password
does not apply.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name       |Type|Description          |
|-----------|----|---------------------|
|user_id    |str |userId               |
|first_name |str |firstName *Optional* |
|last_name  |str |lastName *Optional*  |
|password   |str |password *Optional*  |
|language   |str |language *Optional*  |
</div>


## `ResellerCallAdmissionControlPoliciesGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a reseller call admission control policies.

The response is either a `ResellerCallAdmissionControlPoliciesGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|reseller_id |str |resellerId |
</div>


## `ResellerCallAdmissionControlPoliciesModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the reseller call admission control policies.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                              |Type |Description                                             |
|--------------------------------------------------|-----|--------------------------------------------------------|
|reseller_id                                       |str  |resellerId                                              |
|enable_call_admission_control                     |bool |enableCallAdmissionControl *Optional*                   |
|max_concurrent_network_sessions                   |int  |maxConcurrentNetworkSessions *Optional*                 |
|max_concurrent_network_sessions_threshold         |int  |maxConcurrentNetworkSessionsThreshold *Optional*        |
|max_network_calls_per_second                      |int  |maxNetworkCallsPerSecond *Optional*                     |
|max_network_calls_per_second_threshold            |int  |maxNetworkCallsPerSecondThreshold *Optional*            |
|max_concurrent_external_siprec_sessions           |int  |maxConcurrentExternalSIPRECSessions *Optional*          |
|max_concurrent_external_siprec_sessions_threshold |int  |maxConcurrentExternalSIPRECSessionsThreshold *Optional* |
</div>


## `ResellerCallCenterGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the reseller level data associated with Call Center.

The response is either a `ResellerCallCenterGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|reseller_id |str |resellerId |
</div>


## `ResellerCallCenterModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the reseller level data associated with Call Center.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                 |Type|Description                   |
|---------------------|----|------------------------------|
|reseller_id          |str |resellerId                    |
|default_from_address |str |defaultFromAddress *Optional* |
</div>


## `ResellerCallNotifyGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the reseller level data associated with Call Notify.

The response is either a `ResellerCallNotifyGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|reseller_id |str |resellerId |
</div>


## `ResellerCallNotifyModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the reseller level data associated with Call Notify.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                 |Type|Description                   |
|---------------------|----|------------------------------|
|reseller_id          |str |resellerId                    |
|default_from_address |str |defaultFromAddress *Optional* |
</div>


## `ResellerCallPoliciesGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the reseller level data associated with Call Policies.

The response is either a `ResellerCallPoliciesGetResponse()` or an `ErrorResponse()`.
Replaced by: `ResellerCallPoliciesGetRequest22()` in AS data mode.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|reseller_id |str |resellerId |
</div>


## `ResellerCallPoliciesGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the reseller level data associated with Call Policies.

The response is either a `ResellerCallPoliciesGetResponse22()` or an
`ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|reseller_id |str |resellerId |
</div>


## `ResellerCallPoliciesModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the reseller level data associated with Call Policies.

The following elements are only used in AS data mode:
forceRedirectingUserIdentityForRedirectedCalls
applyRedirectingUserIdentityToNetworkLocations

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                                 |Type |Description                                               |
|-----------------------------------------------------|-----|----------------------------------------------------------|
|reseller_id                                          |str  |resellerId                                                |
|force_redirecting_user_identity_for_redirected_calls |bool |forceRedirectingUserIdentityForRedirectedCalls *Optional* |
|apply_redirecting_user_identity_to_network_locations |bool |applyRedirectingUserIdentityToNetworkLocations *Optional* |
</div>


## `ResellerCallRecordingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the Call Recording attribute for a reseller.

The response is either a `ResellerCallRecordingGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|reseller_id |str |resellerId |
</div>


## `ResellerCallRecordingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Call Recording attribute for a reseller.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description     |
|------------|----|----------------|
|reseller_id |str |resellerId      |
|fqdn        |str |FQDN *Optional* |
</div>


## `ResellerCollaborateGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the reseller level data associated with Collaborate.

The response is either a `ResellerCollaborateGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|reseller_id |str |resellerId |
</div>


## `ResellerCollaborateModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the reseller level data associated with Collaborate.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type|Description                       |
|-------------------------|----|----------------------------------|
|reseller_id              |str |resellerId                        |
|collaborate_from_address |str |collaborateFromAddress *Optional* |
</div>


## `ResellerDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a reseller.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                 |Type|Description                   |
|---------------------|----|------------------------------|
|reseller_id          |str |resellerId *Optional*         |
|reseller_external_id |str |resellerExternalId *Optional* |
</div>


## `ResellerDeviceActivationPolicyGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the Device Activation policy of a reseller.

The response is either a `ResellerDeviceActivationPolicyGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|reseller_id |str |resellerId |
</div>


## `ResellerDeviceActivationPolicyModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Device Activation policy of a reseller.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                  |Type |Description                                 |
|--------------------------------------|-----|--------------------------------------------|
|reseller_id                           |str  |resellerId                                  |
|use_reseller_settings                 |bool |useResellerSettings *Optional*              |
|allow_activation_code_request_by_user |bool |allowActivationCodeRequestByUser *Optional* |
|send_activation_code_in_email         |bool |sendActivationCodeInEmail *Optional*        |
</div>


## `ResellerEmergencyCallNotificationGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the reseller level data associated with Emergency Call Notification.

The response is either a `ResellerEmergencyCallNotificationGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|reseller_id |str |resellerId |
</div>


## `ResellerEmergencyCallNotificationModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the reseller level data associated with Emergency Call Notification.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                 |Type|Description                   |
|---------------------|----|------------------------------|
|reseller_id          |str |resellerId                    |
|default_from_address |str |defaultFromAddress *Optional* |
</div>


## `ResellerEmergencyZonesGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the reseller level data associated with Emergency Zones.

The response is either a `ResellerEmergencyZonesGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|reseller_id |str |resellerId |
</div>


## `ResellerEmergencyZonesModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the reseller level data associated with Emergency Zones.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                 |Type|Description                   |
|---------------------|----|------------------------------|
|reseller_id          |str |resellerId                    |
|default_from_address |str |defaultFromAddress *Optional* |
</div>


## `ResellerGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the profile for a reseller.

The response is either `ResellerGetResponse()` or `ErrorResponse()`. Replaced by:
`ResellerGetRequest22()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|reseller_id |str |resellerId |
</div>


## `ResellerGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the profile for a reseller.

The response is either `ResellerGetResponse22()` or `ErrorResponse()`. Replaced by:
`ResellerGetRequest22V2()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|reseller_id |str |resellerId |
</div>


## `ResellerGetRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the profile for a reseller.

The response is either `ResellerGetResponse22V2()` or `ErrorResponse()`.

**Attributes:**

|Name                 |Type|Description                   |
|---------------------|----|------------------------------|
|reseller_id          |str |resellerId *Optional*         |
|reseller_external_id |str |resellerExternalId *Optional* |
</div>


## `ResellerIntegratedIMPGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the Integrated IMP service attributes for the reseller.

The response is either `ResellerIntegratedIMPGetResponse()` or `ErrorResponse()`.
Replaced by: `ResellerIntegratedIMPGetRequest22()` in AS data mode

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|reseller_id |str |resellerId |
</div>


## `ResellerIntegratedIMPGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the Integrated IMP service attributes for the reseller.

The response is either `ResellerIntegratedIMPGetResponse22()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|reseller_id |str |resellerId |
</div>


## `ResellerIntegratedIMPModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Integrated IMP service attributes for the reseller.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                        |Type |Description                         |
|----------------------------|-----|------------------------------------|
|reseller_id                 |str  |resellerId                          |
|use_system_service_domain   |bool |useSystemServiceDomain *Optional*   |
|service_domain              |str  |serviceDomain *Optional*            |
|service_port                |int  |servicePort *Optional*              |
|use_system_messaging_server |bool |useSystemMessagingServer *Optional* |
|provisioning_url            |str  |provisioningUrl *Optional*          |
|provisioning_user_id        |str  |provisioningUserId *Optional*       |
|provisioning_password       |str  |provisioningPassword *Optional*     |
|bosh_url                    |str  |boshURL *Optional*                  |
|default_imp_id_type         |str  |defaultImpIdType *Optional*         |
</div>


## `ResellerMailParametersGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the reseller Mail parameters.

The response is either a `ResellerMailParametersGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|reseller_id |str |resellerId |
</div>


## `ResellerMailParametersModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the reseller Mail parameters.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                 |Type|Description                   |
|---------------------|----|------------------------------|
|reseller_id          |str |resellerId                    |
|default_from_address |str |defaultFromAddress *Optional* |
</div>


## `ResellerMeetMeConferencingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the reseller level data associated with Meet-Me Conferencing functions.

The response is either a `ResellerMeetMeConferencingGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|reseller_id |str |resellerId |
</div>


## `ResellerMeetMeConferencingGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the reseller level data associated with Meet-Me Conferencing functions.

The response is either a `ResellerMeetMeConferencingGetResponse22()` or an
`ErrorResponse()`. The following data elements are only returned for System and
Provisioning Administrators: maxAllocatedPorts.  The following data elements are only
returned for System and Provisioning Administrators and AS Mode Only:
disableUnlimitedMeetMePorts, enableMaxAllocatedPorts.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|reseller_id |str |resellerId |
</div>


## `ResellerMeetMeConferencingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the reseller level data associated with Meet-Me Conferencing functions.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
data elements are only modified for System and Provisioning Administrators:
maxAllocatedPorts.  The following data elements are only modified for System and
Provisioning Administrators and AS Mode only: disableUnlimitedMeetMePorts,
enableMaxAllocatedPorts.

**Attributes:**

|Name                            |Type |Description                            |
|--------------------------------|-----|---------------------------------------|
|reseller_id                     |str  |resellerId                             |
|conference_from_address         |str  |conferenceFromAddress *Optional*       |
|max_allocated_ports             |int  |maxAllocatedPorts *Optional*           |
|disable_unlimited_meet_me_ports |bool |disableUnlimitedMeetMePorts *Optional* |
|enable_max_allocated_ports      |bool |enableMaxAllocatedPorts *Optional*     |
</div>


## `ResellerModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the reseller profile.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                 |Type|Description                   |
|---------------------|----|------------------------------|
|reseller_id          |str |resellerId *Optional*         |
|reseller_external_id |str |resellerExternalId *Optional* |
|reseller_name        |str |resellerName *Optional*       |
</div>


## `ResellerNetworkClassOfServiceGetAssignedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of Network Classes of Service assigned to a reseller.

The response is either a `ResellerNetworkClassOfServiceGetAssignedListResponse()` or
an `ErorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|reseller_id |str |resellerId |
</div>


## `ResellerNetworkClassOfServiceModifyDefaultRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the default Network Classes of Service of a reseller.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type|Description                      |
|-------------------------|----|---------------------------------|
|reseller_id              |str |resellerId                       |
|network_class_of_service |str |networkClassOfService *Optional* |
</div>


## `ResellerResourcePriorityGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the Resource Priority service attributes for the reseller.

The response is either `ResellerResourcePriorityGetResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|reseller_id |str |resellerId |
</div>


## `ResellerResourcePriorityModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Resource Priority service attributes for the reseller.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                              |Type |Description                              |
|----------------------------------|-----|-----------------------------------------|
|reseller_id                       |str  |resellerId                               |
|use_system_settings               |bool |useSystemSettings *Optional*             |
|send_resource_priority_to_network |bool |sendResourcePriorityToNetwork *Optional* |
|resource_priority                 |str  |resourcePriority *Optional*              |
</div>


## `ResellerServiceAuthorizationGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the reseller service authorization The response is either
`ResellerServiceAuthorizationGetResponse()` or `ErrorResponse()`.


**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|reseller_id |str |resellerId |
</div>


## `ResellerStirShakenGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get Reseller Stir Shaken service settings.

The response is either `ResellerStirShakenGetResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|reseller_id |str |resellerId |
</div>


## `ResellerStirShakenModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify reseller Stir Shaken service settings.


**Attributes:**

|Name                                                   |Type |Description                                                 |
|-------------------------------------------------------|-----|------------------------------------------------------------|
|reseller_id                                            |str  |resellerId                                                  |
|use_parent_level_settings                              |bool |useParentLevelSettings *Optional*                           |
|signing_policy                                         |str  |signingPolicy *Optional*                                    |
|tagging_policy                                         |str  |taggingPolicy *Optional*                                    |
|sign_emergency_calls                                   |bool |signEmergencyCalls *Optional*                               |
|tag_emergency_calls                                    |bool |tagEmergencyCalls *Optional*                                |
|signing_service_url                                    |str  |signingServiceURL *Optional*                                |
|tag_from_or_pai                                        |str  |tagFromOrPAI *Optional*                                     |
|verstat_tag                                            |str  |verstatTag *Optional*                                       |
|use_os_value_for_orig_id                               |bool |useOSValueForOrigId *Optional*                              |
|orig_uuid                                              |str  |origUUID *Optional*                                         |
|attestation_level                                      |str  |attestationLevel *Optional*                                 |
|enable_verification                                    |bool |enableVerification *Optional*                               |
|verification_service_url                               |str  |verificationServiceURL *Optional*                           |
|verification_error_handling                            |str  |verificationErrorHandling *Optional*                        |
|proxy_verstat_to_cnam_subscribe                        |bool |proxyVerstatToCNAMSubscribe *Optional*                      |
|use_unknown_headers_from_cnam_notify                   |bool |useUnknownHeadersFromCNAMNotify *Optional*                  |
|enable_signing_for_unscreened_trunk_group_originations |bool |enableSigningForUnscreenedTrunkGroupOriginations *Optional* |
|enable_tagging_for_unscreened_trunk_group_originations |bool |enableTaggingForUnscreenedTrunkGroupOriginations *Optional* |
|unscreened_trunk_group_origination_attestation_level   |str  |unscreenedTrunkGroupOriginationAttestationLevel *Optional*  |
|verify_gets_calls                                      |bool |verifyGETSCalls *Optional*                                  |
</div>


## `ResellerVoiceMessagingGroupGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the reseller level data associated with Voice Messaging.

The response is either a `ResellerVoiceMessagingGroupGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|reseller_id |str |resellerId |
</div>


## `ResellerVoiceMessagingGroupModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the reseller level data associated with Voice Messaging.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                              |Type|Description                              |
|----------------------------------|----|-----------------------------------------|
|reseller_id                       |str |resellerId                               |
|delivery_from_address             |str |deliveryFromAddress *Optional*           |
|notification_from_address         |str |notificationFromAddress *Optional*       |
|voice_portal_lockout_from_address |str |voicePortalLockoutFromAddress *Optional* |
</div>


## `ResellerXsiPolicyProfileGetAssignedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of Xsi policy profile assigned.

The response is either a `XsiPolicyProfileGetAssignedListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name        |Type|Description      |
|------------|----|-----------------|
|reseller_id |str |resellerId       |
|level       |str |level *Optional* |
</div>


## `ResellerXsiPolicyProfileModifyDefaultRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the default Xsi policy profile for a reseller.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                             |Type|Description                             |
|---------------------------------|----|----------------------------------------|
|reseller_id                      |str |resellerId                              |
|sp_default_xsi_policy_profile    |str |spDefaultXsiPolicyProfile *Optional*    |
|group_default_xsi_policy_profile |str |groupDefaultXsiPolicyProfile *Optional* |
|user_default_xsi_policy_profile  |str |userDefaultXsiPolicyProfile *Optional*  |
</div>


## `ServiceProviderAccessDeviceCustomTagAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a static configuration tag for a service provider access device.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description         |
|--------------------|----|--------------------|
|service_provider_id |str |serviceProviderId   |
|device_name         |str |deviceName          |
|tag_name            |str |tagName             |
|tag_value           |str |tagValue *Optional* |
</div>


## `ServiceProviderAccessDeviceCustomTagDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete static configuration tags for a service provider access device.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|device_name         |str       |deviceName        |
|tag_name            |List[str] |tagName           |
</div>


## `ServiceProviderAccessDeviceCustomTagGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of custom configuration tags managed by the Device Management
System, on a per-device profile basis.

The response is either `ServiceProviderAccessDeviceCustomTagGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|device_name         |str |deviceName        |
</div>


## `ServiceProviderAccessDeviceCustomTagModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a static configuration tag for a service provider access device.

The tagValueToEncrypt element can only be used by a system administrator.  The
following elements are only used in XS data mode and ignored in AS data mode:
tagValueToEncrypt

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                 |Type|Description                  |
|---------------------|----|-----------------------------|
|service_provider_id  |str |serviceProviderId            |
|device_name          |str |deviceName                   |
|tag_name             |str |tagName                      |
|tag_value            |str |tagValue *Optional*          |
|tag_value_to_encrypt |str |tagValueToEncrypt *Optional* |
</div>


## `ServiceProviderAccessDeviceDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a specified service provider access device.

The following elements are only used in AS data mode and ignored in XS data mode:
deviceExternalId

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description                  |
|--------------------|----|-----------------------------|
|service_provider_id |str |serviceProviderId *Optional* |
|device_name         |str |deviceName *Optional*        |
|device_external_id  |str |deviceExternalId *Optional*  |
</div>


## `ServiceProviderAccessDeviceDeviceActivationGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the activation information for a device configured at the Service Provider
level.

Returns a `ServiceProviderAccessDeviceDeviceActivationGetResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|device_name         |str |deviceName        |
</div>


## `ServiceProviderAccessDeviceDeviceActivationModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Activates or deactivates a device configured at the Service Provider level.

It is only possible for this request to activate a device which is deactivated.
Trying to activate a device in the activating state will result in an error response
since only the DAS is allowed to execute this operation.  Returns a
`SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type |Description       |
|--------------------|-----|------------------|
|service_provider_id |str  |serviceProviderId |
|device_name         |str  |deviceName        |
|activate_device     |bool |activateDevice    |
</div>


## `ServiceProviderAccessDeviceFileGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of device files managed by the Device Management System, on a
per-device profile basis.

The response is either `ServiceProviderAccessDeviceFileGetListResponse()` or
`ErrorResponse()`.

Replaced By: `ServiceProviderAccessDeviceFileGetListRequest14sp8()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|device_name         |str |deviceName        |
</div>


## `ServiceProviderAccessDeviceFileGetListRequest14sp8`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of device files managed by the Device Management System, on a
per-device profile basis.

The response is either `ServiceProviderAccessDeviceFileGetListResponse14sp8()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|device_name         |str |deviceName        |
</div>


## `ServiceProviderAccessDeviceFileGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a service provider device profile file.

The response is either `ServiceProviderAccessDeviceFileGetResponse()` or
`ErrorResponse()`.

Replaced By: `ServiceProviderAccessDeviceFileGetRequest14sp8()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|device_name         |str |deviceName        |
|file_type           |str |fileType          |
</div>


## `ServiceProviderAccessDeviceFileGetRequest14sp8`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a service provider device profile file.

The response is either `ServiceProviderAccessDeviceFileGetResponse14sp8()` or
`ErrorResponse()`. Replaced by: `ServiceProviderAccessDeviceFileGetRequest16sp1()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|device_name         |str |deviceName        |
|file_format         |str |fileFormat        |
</div>


## `ServiceProviderAccessDeviceFileGetRequest16sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a service provider device profile file.

The response is either `ServiceProviderAccessDeviceFileGetResponse16sp1()` or
`ErrorResponse()`. Replaced by: `ServiceProviderAccessDeviceFileGetRequest20()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|device_name         |str |deviceName        |
|file_format         |str |fileFormat        |
</div>


## `ServiceProviderAccessDeviceFileGetRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a service provider device profile file.

The response is either `ServiceProviderAccessDeviceFileGetResponse20()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|device_name         |str |deviceName        |
|file_format         |str |fileFormat        |
</div>


## `ServiceProviderAccessDeviceGenerateActivationCodeRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests a new activation code for a device configured at the Service Provider level.

Returns a `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|device_name         |str |deviceName        |
</div>


## `ServiceProviderAccessDeviceGetAvailableCustomTagListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of all available custom tags managed by the Device Management System, on
a per-device profile basis.

The response is either
`ServiceProviderAccessDeviceGetAvailableCustomTagListResponse()` or `ErrorResponse()`.
The following elements are used in AS mode and ignored in XS data mode: tagSetName

**Attributes:**

|Name                |Type|Description           |
|--------------------|----|----------------------|
|service_provider_id |str |serviceProviderId     |
|device_name         |str |deviceName            |
|tag_set_name        |str |tagSetName *Optional* |
</div>


## `ServiceProviderAccessDeviceGetEnhancedConfigurationTypeListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of configurable device types of devices that have already been added
to the service provider.

The response is either
`ServiceProviderAccessDeviceGetEnhancedConfigurationTypeListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderAccessDeviceGetEnhancedConfigurationTypeRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the details of a specified configurable device type for a service provider.

The response is either
`ServiceProviderAccessDeviceGetEnhancedConfigurationTypeResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|device_type         |str |deviceType        |
</div>


## `ServiceProviderAccessDeviceGetLinkedLeafDeviceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of linked leaf devices for the service provider level tree device
passed in the request.

A tree device is a device associated with a device type that has the option
supportLinks set to "Support Links from Devices". Many leaf devices can be linked to
it.  A leaf device is a device associated with a device type that has the option
supportLinks set to "Support Link to Device". It can be linked to only one tree
device.  The list includes devices created at the system, service provider, and group
levels.

The response is either `ServiceProviderAccessDeviceGetLinkedLeafDeviceListResponse()`
or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|device_name         |str |deviceName        |
</div>


## `ServiceProviderAccessDeviceGetLinkedTreeDeviceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the tree device linked with the service provider level leaf device passed in
the request.

A tree device is a device associated with a device type that has the option
supportLinks set to "Support Links from Devices". Many leaf devices can be linked to
it.  A leaf device is a device associated with a device type that has the option
supportLinks set to "Support Link to Device". It can be linked to only one tree
device.

The response is either `ServiceProviderAccessDeviceGetLinkedTreeDeviceResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|device_name         |str |deviceName        |
</div>


## `ServiceProviderAccessDeviceGetNativeTagsWithLogicListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of all native tags with logic managed by the Device Management System, on
a per-device profile basis.

The response is either
`ServiceProviderAccessDeviceGetNativeTagsWithLogicListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|device_name         |str |deviceName        |
</div>


## `ServiceProviderAccessDeviceGetRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the configuration of a specified service provider access device.

The response is either `ServiceProviderAccessDeviceGetResponse14()` or
`ErrorResponse()`.

Replaced By: `ServiceProviderAccessDeviceGetRequest14sp3()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|device_name         |str |deviceName        |
</div>


## `ServiceProviderAccessDeviceGetRequest14sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the configuration of a specified service provider access device.

The response is either `ServiceProviderAccessDeviceGetResponse14sp3()` or
`ErrorResponse()`.

Replaced By: `ServiceProviderAccessDeviceGetRequest14sp6()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|device_name         |str |deviceName        |
</div>


## `ServiceProviderAccessDeviceGetRequest14sp6`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the configuration of a specified service provider access device.

The response is either `ServiceProviderAccessDeviceGetResponse14sp6()` or
`ErrorResponse()`. Replaced by: `ServiceProviderAccessDeviceGetRequest16()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|device_name         |str |deviceName        |
</div>


## `ServiceProviderAccessDeviceGetRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the configuration of a specified service provider access device.

The response is either `ServiceProviderAccessDeviceGetResponse16()` or
`ErrorResponse()`. Replaced by: `ServiceProviderAccessDeviceGetRequest19()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|device_name         |str |deviceName        |
</div>


## `ServiceProviderAccessDeviceGetRequest18sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the configuration of a specified service provider access device.

The response is either `ServiceProviderAccessDeviceGetResponse18sp1()` or
`ErrorResponse()`. Replaced by: `ServiceProviderAccessDeviceGetRequest22()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|device_name         |str |deviceName        |
</div>


## `ServiceProviderAccessDeviceGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the configuration of a specified service provider access device.

The response is either `ServiceProviderAccessDeviceGetResponse22()` or
`ErrorResponse()`. Replaced by: `ServiceProviderAccessDeviceGetRequest24()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|device_name         |str |deviceName        |
</div>


## `ServiceProviderAccessDeviceGetRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the configuration of a specified service provider access device.

The following elements are only used in AS data mode and ignored in XS data mode:
deviceExternalId

The response is either `ServiceProviderAccessDeviceGetResponse22V2()` or
`ErrorResponse()`.

Replaced By: `ServiceProviderAccessDeviceGetRequest24()`

**Attributes:**

|Name                |Type|Description                  |
|--------------------|----|-----------------------------|
|service_provider_id |str |serviceProviderId *Optional* |
|device_name         |str |deviceName *Optional*        |
|device_external_id  |str |deviceExternalId *Optional*  |
</div>


## `ServiceProviderAccessDeviceGetRequest22V3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the configuration of a specified service provider access device.

The response is either `ServiceProviderAccessDeviceGetResponse22V3()` or
`ErrorResponse()`. The following elements are only used in AS data mode and ignored in
XS data mode: deviceExternalId Replaced by:
`ServiceProviderAccessDeviceGetRequest24()`

**Attributes:**

|Name                |Type|Description                  |
|--------------------|----|-----------------------------|
|service_provider_id |str |serviceProviderId *Optional* |
|device_name         |str |deviceName *Optional*        |
|device_external_id  |str |deviceExternalId *Optional*  |
</div>


## `ServiceProviderAccessDeviceGetRequest24`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the configuration of a specified service provider access device.

The following elements are only used in AS data mode and ignored in XS data mode:
deviceExternalId

The response is either `ServiceProviderAccessDeviceGetResponse24()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description                  |
|--------------------|----|-----------------------------|
|service_provider_id |str |serviceProviderId *Optional* |
|device_name         |str |deviceName *Optional*        |
|device_external_id  |str |deviceExternalId *Optional*  |
</div>


## `ServiceProviderAccessDeviceModifyUserRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify attributes for line/ports assigned on the service provider device
profile.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in XS data mode and ignored in AS data mode: privateIdentity

**Attributes:**

|Name                 |Type |Description                  |
|---------------------|-----|-----------------------------|
|service_provider_id  |str  |serviceProviderId            |
|device_name          |str  |deviceName                   |
|line_port            |str  |linePort                     |
|private_identity     |str  |privateIdentity *Optional*   |
|is_primary_line_port |bool |isPrimaryLinePort *Optional* |
</div>


## `ServiceProviderAccessDeviceResetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Reset a specific service provider SIP device that supports the reset operation.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|device_name         |str |deviceName        |
</div>


## `ServiceProviderAccessDeviceTagSetGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the custom configuration tag set defined at the access device.

The response is either `ServiceProviderAccessDeviceTagSetGetResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|device_name         |str |deviceName        |
</div>


## `ServiceProviderAccessDeviceTagSetModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a static configuration tag set.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description           |
|--------------------|----|----------------------|
|service_provider_id |str |serviceProviderId     |
|device_name         |str |deviceName            |
|tag_set_name        |str |tagSetName *Optional* |
</div>


## `ServiceProviderAdminAddRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a service provider administrator.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description          |
|--------------------|----|---------------------|
|service_provider_id |str |serviceProviderId    |
|user_id             |str |userId               |
|first_name          |str |firstName *Optional* |
|last_name           |str |lastName *Optional*  |
|password            |str |password *Optional*  |
|language            |str |language *Optional*  |
|administrator_type  |str |administratorType    |
</div>


## `ServiceProviderAdminAlternateIdAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add an alternate admin Id to a service provider administrator.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name              |Type|Description            |
|------------------|----|-----------------------|
|user_id           |str |userId                 |
|alternate_user_id |str |alternateUserId        |
|description       |str |description *Optional* |
</div>


## `ServiceProviderAdminAlternateIdDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete an alternate admin user id of a user.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name              |Type|Description     |
|------------------|----|----------------|
|user_id           |str |userId          |
|alternate_user_id |str |alternateUserId |
</div>


## `ServiceProviderAdminAlternateIdGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the admin id and the list of alternate admin ids of an admin.

The response is either `ServiceProviderAdminAlternateIdGetListResponse()` or
`ErrorResponse()`. The "userId" can be either the admin user Id or an alternate admin
user Id.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `ServiceProviderAdminAlternateIdModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify an alternate id of a service provider admin.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                  |Type|Description                   |
|----------------------|----|------------------------------|
|user_id               |str |userId                        |
|alternate_user_id     |str |alternateUserId               |
|new_alternate_user_id |str |newAlternateUserId *Optional* |
|description           |str |description *Optional*        |
</div>


## `ServiceProviderAdminDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a service provider administrator.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `ServiceProviderAdminGetListRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of service provider administrators.

The response is either a `ServiceProviderAdminGetListResponse14()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderAdminGetPolicyRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the service provider administrator's policy settings.

The response is either `ServiceProviderAdminGetPolicyResponse14()` or
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `ServiceProviderAdminGetPolicyRequest16sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the service provider administrator's policy settings.

The response is either `ServiceProviderAdminGetPolicyResponse16sp1()` or
`ErrorResponse()`. Replaced by: `ServiceProviderAdminGetPolicyRequest17()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `ServiceProviderAdminGetPolicyRequest16sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the service provider administrator's policy settings.

The response is either `ServiceProviderAdminGetPolicyResponse16sp2()` or
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `ServiceProviderAdminGetPolicyRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the service provider administrator's policy settings.

The response is either `ServiceProviderAdminGetPolicyResponse17()` or
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `ServiceProviderAdminGetPolicyRequest17sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the service provider administrator's policy settings.

The response is either `ServiceProviderAdminGetPolicyResponse17sp1()` or
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `ServiceProviderAdminGetPolicyRequest17sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the service provider administrator's policy settings.

The response is either `ServiceProviderAdminGetPolicyResponse17sp3()` or
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `ServiceProviderAdminGetPolicyRequest18`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the service provider administrator's policy settings.

The response is either `ServiceProviderAdminGetPolicyResponse18()` or
`ErrorResponse()`. Replaced by: `ServiceProviderAdminGetPolicyRequest20()` in AS data
mode

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `ServiceProviderAdminGetPolicyRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the service provider administrator's policy settings.

The response is either `ServiceProviderAdminGetPolicyResponse20()` or
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `ServiceProviderAdminGetRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a service provider administrators profile.

The response is either a `ServiceProviderAdminGetResponse14()` or an
`ErrorResponse()`. Replaced by `ServiceProviderAdminGetRequest21sp1()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `ServiceProviderAdminGetRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a service provider administrators profile.

The response is either a `ServiceProviderAdminGetResponse21sp1()` or an
`ErrorResponse()`. Replaced by: `ServiceProviderAdminGetRequest22()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `ServiceProviderAdminGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a service provider administrators profile.

The response is either a `ServiceProviderAdminGetResponse22()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `ServiceProviderAdminModifyPolicyRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the service provider administrator's policy settings.

The response is either `SuccessResponse()` or `ErrorResponse()`. The
networkPolicyAccess is only modified for the enterprise administrator.  The following
elements are only used in AS data mode: dialableCallerIDAccess
verifyTranslationAndroutingAccess

**Attributes:**

|Name                                  |Type|Description                                  |
|--------------------------------------|----|---------------------------------------------|
|user_id                               |str |userId                                       |
|profile_access                        |str |profileAccess *Optional*                     |
|group_access                          |str |groupAccess *Optional*                       |
|user_access                           |str |userAccess *Optional*                        |
|admin_access                          |str |adminAccess *Optional*                       |
|department_access                     |str |departmentAccess *Optional*                  |
|access_device_access                  |str |accessDeviceAccess *Optional*                |
|phone_number_extension_access         |str |phoneNumberExtensionAccess *Optional*        |
|calling_line_id_number_access         |str |callingLineIdNumberAccess *Optional*         |
|service_access                        |str |serviceAccess *Optional*                     |
|service_pack_access                   |str |servicePackAccess *Optional*                 |
|session_admission_control_access      |str |sessionAdmissionControlAccess *Optional*     |
|web_branding_access                   |str |webBrandingAccess *Optional*                 |
|office_zone_access                    |str |officeZoneAccess *Optional*                  |
|communication_barring_access          |str |communicationBarringAccess *Optional*        |
|network_policy_access                 |str |networkPolicyAccess *Optional*               |
|number_activation_access              |str |numberActivationAccess *Optional*            |
|dialable_caller_id_access             |str |dialableCallerIDAccess *Optional*            |
|verify_translation_and_routing_access |str |verifyTranslationAndRoutingAccess *Optional* |
</div>


## `ServiceProviderAdminModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a service provider administrator.

Since old password is not specified here, any password rule related to old password
does not apply.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name       |Type|Description          |
|-----------|----|---------------------|
|user_id    |str |userId               |
|first_name |str |firstName *Optional* |
|last_name  |str |lastName *Optional*  |
|password   |str |password *Optional*  |
|language   |str |language *Optional*  |
</div>


## `ServiceProviderAdministratorPasswordRulesGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the effective password rules setting for a service provider administrator The
response is either `ServiceProviderAdministratorPasswordRulesGetResponse()` or
`ErrorResponse()`.


**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderAdviceOfChargeGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of Advice of Charge service provider parameters.

The response is either `ServiceProviderAdviceOfChargeGetResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderAdviceOfChargeModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the service provider level Advice Of Charge service provider settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                               |Type |Description                                |
|-----------------------------------|-----|-------------------------------------------|
|service_provider_id                |str  |serviceProviderId                          |
|use_sp_level_ao_c_settings         |bool |useSPLevelAoCSettings *Optional*           |
|delay_between_notification_seconds |int  |delayBetweenNotificationSeconds *Optional* |
</div>


## `ServiceProviderAnswerConfirmationGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a service provider or enterprise's answer confirmation settings.

The response is either a `ServiceProviderAnswerConfirmationGetResponse()` or an
`ErrorResponse()`.

Replaced By: `ServiceProviderAnswerConfirmationGetRequest16()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderAnswerConfirmationGetRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a service provider or enterprise's answer confirmation settings.

The response is either a `ServiceProviderAnswerConfirmationGetResponse16()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderApplicationServerSetGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the Application Server set for a service provider or enterprise.

The response is either a `ServiceProviderApplicationServerSetGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderApplicationServerSetModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Application Server set assigned to the service provider or enterprise.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                        |Type|Description                         |
|----------------------------|----|------------------------------------|
|service_provider_id         |str |serviceProviderId                   |
|application_server_set_name |str |applicationServerSetName *Optional* |
</div>


## `ServiceProviderBroadWorksCommunicatorGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get Configuration Server for a specified service provider.

The response is either a `ServiceProviderBroadWorksCommunicatorGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderBroadWorksCommunicatorModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the Configuration URL.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type|Description                       |
|-------------------------|----|----------------------------------|
|service_provider_id      |str |serviceProviderId *Optional*      |
|configuration_server_url |str |configurationServerURL *Optional* |
</div>


## `ServiceProviderBroadWorksMobilityGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the service provider BroadWorks Mobility service settings.

The response is either a `ServiceProviderBroadWorksMobilityGetResponse()` or an
`ErrorResponse()`. Replaced by: `ServiceProviderBroadWorksMobilityGetRequest19sp1()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderBroadWorksMobilityGetRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the service provider BroadWorks Mobility service settings.

The response is either a `ServiceProviderBroadWorksMobilityGetResponse19sp1()` or an
`ErrorResponse()`. Replaced by: `ServiceProviderBroadWorksMobilityGetRequest22()` in
AS data mode

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderBroadWorksMobilityGetRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the service provider BroadWorks Mobility service settings.

The response is either a `ServiceProviderBroadWorksMobilityGetResponse21sp1()` or an
`ErrorResponse()`. Replaced by `ServiceProviderBroadWorksMobilityGetRequest22V2()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderBroadWorksMobilityGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the service provider BroadWorks Mobility service settings.

The response is either a `ServiceProviderBroadWorksMobilityGetResponse22()` or an
`ErrorResponse()`. Replaced by `ServiceProviderBroadWorksMobilityGetRequest22V2()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderBroadWorksMobilityGetRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the service provider BroadWorks Mobility service settings.

The response is either a `ServiceProviderBroadWorksMobilityGetResponse22V2()` or an
`ErrorResponse()`. Replaced by `ServiceProviderBroadWorksMobilityGetRequest22V3()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderBroadWorksMobilityGetRequest22V3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the service provider BroadWorks Mobility service settings.

The response is either a `ServiceProviderBroadWorksMobilityGetResponse22V3()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderBroadWorksMobilityMobileSubscriberDirectoryNumberAddListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Adds Mobile Subscriber Directory Numbers to a service provider.

It is possible to add a single DN, or a list of DNs.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by
`ServiceProviderBroadWorksMobilityMobileSubscriberDirectoryNumberAddListRequest21()`.

**Attributes:**

|Name                               |Type      |Description                                |
|-----------------------------------|----------|-------------------------------------------|
|service_provider_id                |str       |serviceProviderId                          |
|mobile_subscriber_directory_number |List[str] |mobileSubscriberDirectoryNumber *Optional* |
</div>


## `ServiceProviderBroadWorksMobilityMobileSubscriberDirectoryNumberAddListRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Adds Mobile Subscriber Directory Numbers to a service provider-mobile network
combination.

It is possible to add a single DN, or a list of DNs.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                               |Type      |Description                                |
|-----------------------------------|----------|-------------------------------------------|
|service_provider_id                |str       |serviceProviderId                          |
|mobile_network_name                |str       |mobileNetworkName                          |
|mobile_subscriber_directory_number |List[str] |mobileSubscriberDirectoryNumber *Optional* |
</div>


## `ServiceProviderBroadWorksMobilityMobileSubscriberDirectoryNumberDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Deletes Mobile Subscriber Directory Numbers from a service provider.

It is possible to delete either: a single number, or a list of numbers.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                               |Type      |Description                                |
|-----------------------------------|----------|-------------------------------------------|
|service_provider_id                |str       |serviceProviderId                          |
|mobile_subscriber_directory_number |List[str] |mobileSubscriberDirectoryNumber *Optional* |
</div>


## `ServiceProviderBroadWorksMobilityMobileSubscriberDirectoryNumberGetAvailableListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a list of available Mobile Subscriber Directory Numbers not yet assigned to
any group.

This command is applicable only for service providers and will fail for enterprises.

The response is either
`ServiceProviderBroadWorksMobilityMobileSubscriberDirectoryNumberGetAvailableListResponse()`
or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderBroadWorksMobilityModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the service provider level BroadWorks Mobility service settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                           |Type |Description                                          |
|-----------------------------------------------|-----|-----------------------------------------------------|
|service_provider_id                            |str  |serviceProviderId                                    |
|use_setting_level                              |str  |useSettingLevel *Optional*                           |
|enable_location_services                       |bool |enableLocationServices *Optional*                    |
|enable_msrn_lookup                             |bool |enableMSRNLookup *Optional*                          |
|enable_mobile_state_checking                   |bool |enableMobileStateChecking *Optional*                 |
|deny_call_originations                         |bool |denyCallOriginations *Optional*                      |
|deny_call_terminations                         |bool |denyCallTerminations *Optional*                      |
|enable_announcement_suppression                |bool |enableAnnouncementSuppression *Optional*             |
|enable_internal_clid_delivery                  |bool |enableInternalCLIDDelivery *Optional*                |
|enable_internal_clid_delivery_access_locations |bool |enableInternalCLIDDeliveryAccessLocations *Optional* |
|enable_enhanced_unreachable_state_checking     |bool |enableEnhancedUnreachableStateChecking *Optional*    |
|enable_network_call_barring_status_check       |bool |enableNetworkCallBarringStatusCheck *Optional*       |
|network_translation_index                      |str  |networkTranslationIndex *Optional*                   |
</div>


## `ServiceProviderCPEConfigRebuildConfigFileRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Rebuild the service provider default config file for the specified device type.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type |Description       |
|--------------------|-----|------------------|
|service_provider_id |str  |serviceProviderId |
|device_type         |str  |deviceType        |
|force               |bool |force *Optional*  |
</div>


## `ServiceProviderCPEConfigRebuildDeviceConfigFileRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Rebuild the config file for a specified device.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type |Description       |
|--------------------|-----|------------------|
|service_provider_id |str  |serviceProviderId |
|device_name         |str  |deviceName        |
|force               |bool |force *Optional*  |
</div>


## `ServiceProviderCPEConfigReorderDeviceLinePortsRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Reorder the lines of a Service Provider device.

You can not add or delete line ports, only re-ordering the list is allowed.  The
ordered list of line ports can be obtained with the
`ServiceProviderAccessDeviceGetRequest()` command.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type      |Description         |
|-----------------------|----------|--------------------|
|service_provider_id    |str       |serviceProviderId   |
|device_name            |str       |deviceName          |
|ordered_line_port_list |List[str] |orderedLinePortList |
</div>


## `ServiceProviderCPEConfigResetDeviceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Reset a specific service provider or enterprise device.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type |Description       |
|--------------------|-----|------------------|
|service_provider_id |str  |serviceProviderId |
|device_name         |str  |deviceName        |
|force               |bool |force *Optional*  |
</div>


## `ServiceProviderCPEConfigResetDeviceTypeRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Reset all the devices of the specified device type in a service provider.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|device_type         |str |deviceType        |
</div>


## `ServiceProviderCallProcessingGetPolicyRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the service provider level data associated with Call Processing Policy.

The response is either a `ServiceProviderCallProcessingGetPolicyResponse14()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderCallProcessingGetPolicyRequest14sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the service provider level data associated with Call Processing Policy.

The response is either a `ServiceProviderCallProcessingGetPolicyResponse14sp1()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderCallProcessingGetPolicyRequest14sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the service provider level data associated with Call Processing Policy.

The response is either a `ServiceProviderCallProcessingGetPolicyResponse14sp4()` or an
`ErrorResponse()`.

Replaced By : `ServiceProviderCallProcessingGetPolicyRequest15()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderCallProcessingGetPolicyRequest14sp7`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the service provider level data associated with Call Processing Policy.

The response is either a `ServiceProviderCallProcessingGetPolicyResponse14sp7()` or an
`ErrorResponse()`.

Replaced By: `ServiceProviderCallProcessingGetPolicyRequest16()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderCallProcessingGetPolicyRequest15`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the service provider level data associated with Call Processing Policy.

The response is either a `ServiceProviderCallProcessingGetPolicyResponse15()` or an
`ErrorResponse()`.

Replaced By: `ServiceProviderCallProcessingGetPolicyRequest16()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderCallProcessingGetPolicyRequest15sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the service provider level data associated with Call Processing Policy.

The response is either a `ServiceProviderCallProcessingGetPolicyResponse15sp2()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderCallProcessingGetPolicyRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the service provider level data associated with Call Processing Policy.

The response is either a `ServiceProviderCallProcessingGetPolicyResponse16()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderCallProcessingGetPolicyRequest16sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the service provider level data associated with Call Processing Policy.

The response is either a `ServiceProviderCallProcessingGetPolicyResponse16sp2()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderCallProcessingGetPolicyRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the service provider level data associated with Call Processing Policy.

The response is either a `ServiceProviderCallProcessingGetPolicyResponse17()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderCallProcessingGetPolicyRequest17sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the service provider level data associated with Call Processing Policy.

The response is either a `ServiceProviderCallProcessingGetPolicyResponse17sp3()` or an
`ErrorResponse()`. Replaced by `ServiceProviderCallProcessingGetPolicyResponse17sp4()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderCallProcessingGetPolicyRequest17sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the service provider level data associated with Call Processing Policy.

The response is either a `ServiceProviderCallProcessingGetPolicyResponse17sp4()` or an
`ErrorResponse()`.

Replaced By : `ServiceProviderCallProcessingGetPolicyRequest18sp1()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderCallProcessingGetPolicyRequest18sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the service provider level data associated with Call Processing Policy.

The response is either a `ServiceProviderCallProcessingGetPolicyResponse18sp1()` or an
`ErrorResponse()`. Replaced by: `ServiceProviderCallProcessingGetPolicyRequest19sp1()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderCallProcessingGetPolicyRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the service provider level data associated with Call Processing Policy.

The response is either a `ServiceProviderCallProcessingGetPolicyResponse19sp1()` or an
`ErrorResponse()`. Replaced by: `ServiceProviderCallProcessingGetPolicyRequest21sp1()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderCallProcessingGetPolicyRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the service provider level data associated with Call Processing Policy.

The response is either a `ServiceProviderCallProcessingGetPolicyResponse21sp1()` or an
`ErrorResponse()`. Replaced by: `ServiceProviderCallProcessingGetPolicyRequest21sp2()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderCallProcessingGetPolicyRequest21sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the service provider level data associated with Call Processing Policy.

The response is either a `ServiceProviderCallProcessingGetPolicyResponse21sp2()` or an
`ErrorResponse()`. Replaced by: `ServiceProviderCallProcessingGetPolicyRequest22()` in
AS data mode

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderCallProcessingGetPolicyRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the service provider level data associated with Call Processing Policy.

The response is either a `ServiceProviderCallProcessingGetPolicyResponse22()` or an
`ErrorResponse()`. Replaced by: `ServiceProviderCallProcessingGetPolicyRequest22V2()`
in AS data mode.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderCallProcessingGetPolicyRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the service provider level data associated with Call Processing Policy.

The response is either a `ServiceProviderCallProcessingGetPolicyResponse22V2()` or an
`ErrorResponse()`. Replaced by: `ServiceProviderCallProcessingGetPolicyRequest22V3()`
in AS data mode.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderCallProcessingGetPolicyRequest22V3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the service provider level data associated with Call Processing Policy.

The response is either a `ServiceProviderCallProcessingGetPolicyResponse22V3()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderCallProcessingModifyPolicyRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the service provider level data associated with Call Processing Policy.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                                                  |Type |Description                                                             |
|----------------------------------------------------------------------|-----|------------------------------------------------------------------------|
|service_provider_id                                                   |str  |serviceProviderId                                                       |
|use_max_simultaneous_calls                                            |bool |useMaxSimultaneousCalls *Optional*                                      |
|max_simultaneous_calls                                                |int  |maxSimultaneousCalls *Optional*                                         |
|use_max_simultaneous_video_calls                                      |bool |useMaxSimultaneousVideoCalls *Optional*                                 |
|max_simultaneous_video_calls                                          |int  |maxSimultaneousVideoCalls *Optional*                                    |
|use_max_call_time_for_answered_calls                                  |bool |useMaxCallTimeForAnsweredCalls *Optional*                               |
|max_call_time_for_answered_calls_minutes                              |int  |maxCallTimeForAnsweredCallsMinutes *Optional*                           |
|use_max_call_time_for_unanswered_calls                                |bool |useMaxCallTimeForUnansweredCalls *Optional*                             |
|max_call_time_for_unanswered_calls_minutes                            |int  |maxCallTimeForUnansweredCallsMinutes *Optional*                         |
|media_policy_selection                                                |str  |mediaPolicySelection *Optional*                                         |
|supported_media_set_name                                              |str  |supportedMediaSetName *Optional*                                        |
|network_usage_selection                                               |str  |networkUsageSelection *Optional*                                        |
|enforce_group_calling_line_identity_restriction                       |bool |enforceGroupCallingLineIdentityRestriction *Optional*                   |
|allow_enterprise_group_call_typing_for_private_dialing_plan           |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan *Optional*          |
|allow_enterprise_group_call_typing_for_public_dialing_plan            |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan *Optional*           |
|override_clid_restriction_for_external_calls_via_private_dialing_plan |bool |overrideCLIDRestrictionForExternalCallsViaPrivateDialingPlan *Optional* |
|enable_enterprise_extension_dialing                                   |bool |enableEnterpriseExtensionDialing *Optional*                             |
|enforce_enterprise_calling_line_identity_restriction                  |bool |enforceEnterpriseCallingLineIdentityRestriction *Optional*              |
|use_setting_level                                                     |str  |useSettingLevel *Optional*                                              |
|conference_uri                                                        |str  |conferenceURI *Optional*                                                |
|use_max_concurrent_redirected_calls                                   |bool |useMaxConcurrentRedirectedCalls *Optional*                              |
|max_concurrent_redirected_calls                                       |int  |maxConcurrentRedirectedCalls *Optional*                                 |
|use_max_find_me_follow_me_depth                                       |bool |useMaxFindMeFollowMeDepth *Optional*                                    |
|max_find_me_follow_me_depth                                           |int  |maxFindMeFollowMeDepth *Optional*                                       |
|max_redirection_depth                                                 |int  |maxRedirectionDepth *Optional*                                          |
|use_max_concurrent_find_me_follow_me_invocations                      |bool |useMaxConcurrentFindMeFollowMeInvocations *Optional*                    |
|max_concurrent_find_me_follow_me_invocations                          |int  |maxConcurrentFindMeFollowMeInvocations *Optional*                       |
|clid_policy                                                           |str  |clidPolicy *Optional*                                                   |
|emergency_clid_policy                                                 |str  |emergencyClidPolicy *Optional*                                          |
|allow_alternate_numbers_for_redirecting_identity                      |bool |allowAlternateNumbersForRedirectingIdentity *Optional*                  |
</div>


## `ServiceProviderCallProcessingModifyPolicyRequest15`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the service provider level data associated with Call Processing Policy.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode: useServiceProviderDCLIDSetting
enableDialableCallerID allowConfigurableCLIDForRedirectingIdentity
enterpriseCallsCLIDPolicy groupCallsCLIDPolicy The following elements are only used in
AS data mode and ignored in XS data mode: enablePhoneListLookup
useMaxConcurrentTerminatingAlertingRequests maxConcurrentTerminatingAlertingRequests
includeRedirectionsInMaximumNumberOfConcurrentCalls
useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable
useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable
allowMobileDNForRedirectingIdentity enableGatewayRoutePolicy
networkCallsGatewayRouteIdentity networkURLCallsGatewayRouteIdentity
emergencyCallsGatewayRouteIdentity repairCallsGatewayRouteIdentity
callTypingErrorsGatewayRouteIdentity The following elements are only used in XS data
mode and ignored in AS data mode: routeOverrideDomain routeOverridePrefix

**Attributes:**

|Name                                                                      |Type |Description                                                                |
|--------------------------------------------------------------------------|-----|---------------------------------------------------------------------------|
|service_provider_id                                                       |str  |serviceProviderId                                                          |
|use_service_provider_dclid_setting                                        |bool |useServiceProviderDCLIDSetting *Optional*                                  |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls *Optional*                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls *Optional*                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls *Optional*                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls *Optional*                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls *Optional*                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes *Optional*                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls *Optional*                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes *Optional*                            |
|media_policy_selection                                                    |str  |mediaPolicySelection *Optional*                                            |
|supported_media_set_name                                                  |str  |supportedMediaSetName *Optional*                                           |
|network_usage_selection                                                   |str  |networkUsageSelection *Optional*                                           |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction *Optional*                      |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan *Optional*             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan *Optional*              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory *Optional*                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory *Optional*                         |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing *Optional*                                |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction *Optional*                 |
|use_setting_level                                                         |str  |useSettingLevel *Optional*                                                 |
|conference_uri                                                            |str  |conferenceURI *Optional*                                                   |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls *Optional*                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls *Optional*                                    |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth *Optional*                                       |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth *Optional*                                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth *Optional*                                             |
|use_max_concurrent_find_me_follow_me_invocations                          |bool |useMaxConcurrentFindMeFollowMeInvocations *Optional*                       |
|max_concurrent_find_me_follow_me_invocations                              |int  |maxConcurrentFindMeFollowMeInvocations *Optional*                          |
|clid_policy                                                               |str  |clidPolicy *Optional*                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy *Optional*                                             |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity *Optional*                     |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID *Optional*                                          |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls *Optional*                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity *Optional*                     |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy *Optional*                                       |
|group_calls_clid_policy                                                   |str  |groupCallsCLIDPolicy *Optional*                                            |
|enable_phone_list_lookup                                                  |bool |enablePhoneListLookup *Optional*                                           |
|use_max_concurrent_terminating_alerting_requests                          |bool |useMaxConcurrentTerminatingAlertingRequests *Optional*                     |
|max_concurrent_terminating_alerting_requests                              |int  |maxConcurrentTerminatingAlertingRequests *Optional*                        |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls *Optional*             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable *Optional*      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable *Optional* |
|route_override_domain                                                     |str  |routeOverrideDomain *Optional*                                             |
|route_override_prefix                                                     |str  |routeOverridePrefix *Optional*                                             |
|allow_mobile_dn_for_redirecting_identity                                  |bool |allowMobileDNForRedirectingIdentity *Optional*                             |
|enable_gateway_route_policy                                               |bool |enableGatewayRoutePolicy *Optional*                                        |
|network_calls_gateway_route_identity                                      |str  |networkCallsGatewayRouteIdentity *Optional*                                |
|network_url_calls_gateway_route_identity                                  |str  |networkURLCallsGatewayRouteIdentity *Optional*                             |
|emergency_calls_gateway_route_identity                                    |str  |emergencyCallsGatewayRouteIdentity *Optional*                              |
|repair_calls_gateway_route_identity                                       |str  |repairCallsGatewayRouteIdentity *Optional*                                 |
|call_typing_errors_gateway_route_identity                                 |str  |callTypingErrorsGatewayRouteIdentity *Optional*                            |
</div>


## `ServiceProviderCommunicationBarringCriteriaAssignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Assign a list of Communication Barring Criteria to a service provider.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description             |
|--------------------|----------|------------------------|
|service_provider_id |str       |serviceProviderId       |
|criteria_name       |List[str] |criteriaName *Optional* |
</div>


## `ServiceProviderCommunicationBarringCriteriaGetAssignedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of Communication Barring Criteria assigned to a service provider.

The response is either a
`ServiceProviderCommunicationBarringCriteriaGetAssignedListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderCommunicationBarringCriteriaUnassignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Unassign a list of Communication Barring Criteria from a service provider.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description             |
|--------------------|----------|------------------------|
|service_provider_id |str       |serviceProviderId       |
|criteria_name       |List[str] |criteriaName *Optional* |
</div>


## `ServiceProviderCommunicationBarringDigitPatternCriteriaAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a new Communication Barring Digit Pattern Criteria.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description                  |
|--------------------|----------|-----------------------------|
|service_provider_id |str       |serviceProviderId            |
|name                |str       |name                         |
|description         |str       |description *Optional*       |
|match_digit_pattern |List[str] |matchDigitPattern *Optional* |
</div>


## `ServiceProviderCommunicationBarringDigitPatternCriteriaDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete an existing Communication Barring Digit Pattern Criteria.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|name                |str |name              |
</div>


## `ServiceProviderCommunicationBarringDigitPatternCriteriaGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of all Digit Pattern Criteria defined for the service provider.

The response is either a
`ServiceProviderCommunicationBarringDigitPatternCriteriaGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderCommunicationBarringDigitPatternCriteriaGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get an existing Digit Pattern Criteria.

The response is either a
`ServiceProviderCommunicationBarringDigitPatternCriteriaGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|name                |str |name              |
</div>


## `ServiceProviderCommunicationBarringDigitPatternCriteriaModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an existing Communication Barring Digit Pattern Criteria.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                       |Type      |Description                        |
|---------------------------|----------|-----------------------------------|
|service_provider_id        |str       |serviceProviderId                  |
|name                       |str       |name                               |
|new_name                   |str       |newName *Optional*                 |
|description                |str       |description *Optional*             |
|add_match_digit_pattern    |List[str] |addMatchDigitPattern *Optional*    |
|delete_match_digit_pattern |List[str] |deleteMatchDigitPattern *Optional* |
</div>


## `ServiceProviderCommunicationBarringIncomingCriteriaAssignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Assign a list of Communication Barring Incoming Criteria to a service provider.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|criteria_name       |List[str] |criteriaName      |
</div>


## `ServiceProviderCommunicationBarringIncomingCriteriaGetAssignedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of Communication Barring Incoming Criteria assigned to a service provider.

The response is either a
`ServiceProviderCommunicationBarringIncomingCriteriaGetAssignedListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderCommunicationBarringIncomingCriteriaUnassignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Unassign a list of Communication Barring Incoming Criteria from a service provider.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|criteria_name       |List[str] |criteriaName      |
</div>


## `ServiceProviderCommunicationBarringProfileDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Deletes an existing Communication Barring Profile.

Optionally, a new default profile can be chosen if the current default profile is
being deleted.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description               |
|--------------------|----|--------------------------|
|service_provider_id |str |serviceProviderId         |
|name                |str |name                      |
|default_profile     |str |defaultProfile *Optional* |
</div>


## `ServiceProviderCommunicationBarringProfileGetCriteriaUsageListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of Communication Barring profiles within a service provider that have a
given Communication Barring Criteria assigned.

The response is either a ServiceProviderCommunicationBarring
`ProfileGetCriteriaUsageListResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|criteria_name       |str |criteriaName      |
</div>


## `ServiceProviderCommunicationBarringProfileGetDigitPatternCriteriaUsageListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of Profiles that use a specific Digit Pattern Criteria.

The response is either a
`ServiceProviderCommunicationBarringProfileGetDigitPatternCriteriaUsageListResponse()`
or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|name                |str |name              |
</div>


## `ServiceProviderCommunicationBarringProfileGetIncomingCriteriaUsageListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of Communication Barring profiles within a service provider that have a
given Communication Barring Incoming Criteria assigned.

The response is either a ServiceProviderCommunicationBarring
`ProfileGetIncomingCriteriaUsageListResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|criteria_name       |str |criteriaName      |
</div>


## `ServiceProviderCommunicationBarringProfileGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of all Communication Barring Profiles.

The response is either a `ServiceProviderCommunicationBarringProfileGetListResponse()`
or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderCommunicationBarringProfileGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get an existing Communication Barring Profile.

The response is either a `ServiceProviderCommunicationBarringProfileGetResponse()` or
an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|name                |str |name              |
</div>


## `ServiceProviderCommunicationBarringProfileGetRequest17sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get an existing Communication Barring Profile.

The response is either a
`ServiceProviderCommunicationBarringProfileGetResponse17sp3()` or an
`ErrorResponse()`.

Replaced By : ServiceProviderCommunicationBarringProfileGetRequest19sp1V2 in AS data
mode

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|name                |str |name              |
</div>


## `ServiceProviderCommunicationBarringProfileGetRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get an existing Communication Barring Profile.

The response is either a
`ServiceProviderCommunicationBarringProfileGetResponse19sp1()` or an
`ErrorResponse()`.

Replaced By : ServiceProviderCommunicationBarringProfileGetRequest19sp1V2 in AS data
mode

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|name                |str |name              |
</div>


## `ServiceProviderCommunicationBarringProfileModifyDefaultRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the default Communication Barring Profile of a Service Provider.

If a default has been previously selected, this command will swap the default profile
with the profile provided.  Selecting a nil profile will cause the service provider to
not have a default Communicaton Barring Profile.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|name                |str |name              |
</div>


## `ServiceProviderDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a service provider or enterprise.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderDeviceActivationPolicyGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the Device Activation policy of a service provider or an enterprise.

The response is either a `ServiceProviderDeviceActivationPolicyGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderDeviceActivationPolicyModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Device Activation policy of a service provider or an enterprise.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                  |Type |Description                                 |
|--------------------------------------|-----|--------------------------------------------|
|service_provider_id                   |str  |serviceProviderId                           |
|use_service_provider_settings         |bool |useServiceProviderSettings *Optional*       |
|allow_activation_code_request_by_user |bool |allowActivationCodeRequestByUser *Optional* |
|send_activation_code_in_email         |bool |sendActivationCodeInEmail *Optional*        |
</div>


## `ServiceProviderDeviceManagementGetAccessDeviceCountForDeviceTypeServiceProviderRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the number of access device of a particular device type and service provider.

If countOnlyResetSupportedDevice is true, count only access devices if the device type
supports reset.  By default unmanaged device types are not allowed and devices are
counted only if their device type supports Device Management.  An error is returned if
deviceType is specified but does not support device management.  When
allowUnmanagedDeviceType is true, unmanaged device type will be counted and a
successful response is returned.

The response is either
`ServiceProviderDeviceManagementGetAccessDeviceCountForDeviceTypeServiceProviderResponse()`
or `ErrorResponse()`.

**Attributes:**

|Name                              |Type |Description                              |
|----------------------------------|-----|-----------------------------------------|
|service_provider_id               |str  |serviceProviderId                        |
|device_type                       |str  |deviceType                               |
|count_only_reset_supported_device |bool |countOnlyResetSupportedDevice *Optional* |
|allow_unmanaged_device_type       |bool |allowUnmanagedDeviceType *Optional*      |
</div>


## `ServiceProviderDeviceManagementInProgressAndPendingEventCancelRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Cancel pending and in progress events.

A list of individual events can be canceled.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|event_id            |List[int] |eventId           |
</div>


## `ServiceProviderDeviceProfileAuthenticationPasswordRulesGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the service provider level device profile authentication password rule
settings.

The response is either a
`ServiceProviderDeviceProfileAuthenticationPasswordRulesGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderDeviceProfileAuthenticationPasswordRulesModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the service provider level device profile authentication password
rule settings.

The useServiceProviderSettings element can only be modified by a system administrator
or a provisioning administrator.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                       |Type |Description                                       |
|-------------------------------------------|-----|--------------------------------------------------|
|service_provider_id                        |str  |serviceProviderId                                 |
|use_service_provider_settings              |bool |useServiceProviderSettings *Optional*             |
|disallow_authentication_name               |bool |disallowAuthenticationName *Optional*             |
|disallow_old_password                      |bool |disallowOldPassword *Optional*                    |
|disallow_reversed_old_password             |bool |disallowReversedOldPassword *Optional*            |
|restrict_min_digits                        |bool |restrictMinDigits *Optional*                      |
|min_digits                                 |int  |minDigits *Optional*                              |
|restrict_min_upper_case_letters            |bool |restrictMinUpperCaseLetters *Optional*            |
|min_upper_case_letters                     |int  |minUpperCaseLetters *Optional*                    |
|restrict_min_lower_case_letters            |bool |restrictMinLowerCaseLetters *Optional*            |
|min_lower_case_letters                     |int  |minLowerCaseLetters *Optional*                    |
|restrict_min_non_alphanumeric_characters   |bool |restrictMinNonAlphanumericCharacters *Optional*   |
|min_non_alphanumeric_characters            |int  |minNonAlphanumericCharacters *Optional*           |
|min_length                                 |int  |minLength *Optional*                              |
|send_permanent_lockout_notification        |bool |sendPermanentLockoutNotification *Optional*       |
|permanent_lockout_notify_email_address     |str  |permanentLockoutNotifyEmailAddress *Optional*     |
|device_profile_authentication_lockout_type |str  |deviceProfileAuthenticationLockoutType *Optional* |
|device_profile_temporary_lockout_threshold |int  |deviceProfileTemporaryLockoutThreshold *Optional* |
|device_profile_wait_algorithm              |str  |deviceProfileWaitAlgorithm *Optional*             |
|device_profile_lockout_fixed_minutes       |str  |deviceProfileLockoutFixedMinutes *Optional*       |
|device_profile_permanent_lockout_threshold |int  |deviceProfilePermanentLockoutThreshold *Optional* |
</div>


## `ServiceProviderDeviceTypeCustomTagAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a static configuration tag for an access device type used in a service
provider.

The following elements are only used in XS data mode: isTagValueEncrypted, use value
"false" in AS data mode The following elements are only used in XS data mode and
ignored in AS data mode: tagValueToEncrypt The tagValueToEncrypt element can only be
used by a system administrator.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type |Description                  |
|-----------------------|-----|-----------------------------|
|service_provider_id    |str  |serviceProviderId            |
|device_type            |str  |deviceType                   |
|tag_name               |str  |tagName                      |
|is_tag_value_encrypted |bool |isTagValueEncrypted          |
|tag_value              |str  |tagValue *Optional*          |
|tag_value_to_encrypt   |str  |tagValueToEncrypt *Optional* |
</div>


## `ServiceProviderDeviceTypeCustomTagDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete static configuration tags for an access device type used in a
service provider.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|device_type         |str       |deviceType        |
|tag_name            |List[str] |tagName           |
</div>


## `ServiceProviderDeviceTypeCustomTagGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of custom configuration tags managed by the Device Management
System, on a per-device type basis for a service provider.

The response is either `ServiceProviderDeviceTypeCustomTagGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|device_type         |str |deviceType        |
</div>


## `ServiceProviderDeviceTypeCustomTagModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a static configuration tag for an access device type used in a
service provider.

The tagValueToEncrypt element can only be used by a system administrator.  The
following elements are only used in XS data mode and ignored in AS data mode:
tagValueToEncrypt

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                 |Type|Description                  |
|---------------------|----|-----------------------------|
|service_provider_id  |str |serviceProviderId            |
|device_type          |str |deviceType                   |
|tag_name             |str |tagName                      |
|tag_value            |str |tagValue *Optional*          |
|tag_value_to_encrypt |str |tagValueToEncrypt *Optional* |
</div>


## `ServiceProviderDeviceTypeFileGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of device type files managed by the Device Management System,
on a per-service provider basis.

The response is either `ServiceProviderDeviceTypeFileGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|device_type         |str |deviceType        |
</div>


## `ServiceProviderDeviceTypeFileGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a service provider device type file.

The response is either `ServiceProviderDeviceTypeFileGetResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|device_type         |str |deviceType        |
|file_format         |str |fileFormat        |
</div>


## `ServiceProviderDeviceTypeTagSetGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the custom configuration tag set defined for the service provider and
device type.

The response is either `ServiceProviderDeviceTypeTagSetGetResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|device_type         |str |deviceType        |
</div>


## `ServiceProviderDeviceTypeTagSetModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a static configuration tag set.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description           |
|--------------------|----|----------------------|
|service_provider_id |str |serviceProviderId     |
|device_type         |str |deviceType            |
|tag_set_name        |str |tagSetName *Optional* |
</div>


## `ServiceProviderDialPlanPolicyAddAccessCodeRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a Service Provider level Dial Plan Access Code and its all attribues.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                              |Type |Description                                 |
|--------------------------------------------------|-----|--------------------------------------------|
|service_provider_id                               |str  |serviceProviderId                           |
|access_code                                       |str  |accessCode                                  |
|include_code_for_network_translations_and_routing |bool |includeCodeForNetworkTranslationsAndRouting |
|include_code_for_screening_services               |bool |includeCodeForScreeningServices             |
|enable_secondary_dial_tone                        |bool |enableSecondaryDialTone                     |
|description                                       |str  |description *Optional*                      |
</div>


## `ServiceProviderDialPlanPolicyDeleteAccessCodeRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a Service Provider level Dial Plan Access Code and its all
attribues.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|access_code         |str |accessCode        |
</div>


## `ServiceProviderDialPlanPolicyGetAccessCodeListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the Service Provider level data associated with Dial Plan Policy.

The response is either a `ServiceProviderDialPlanPolicyGetAccessCodeListResponse()` or
an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderDialPlanPolicyGetAccessCodeRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request access code data associated with Service Provider level Dial Plan Policy
access codes.

The response is either a `ServiceProviderDialPlanPolicyGetAccessCodeResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|access_code         |str |accessCode        |
</div>


## `ServiceProviderDialPlanPolicyGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the Service Provider level data associated with Dial Plan Policy.

The response is either a `ServiceProviderDialPlanPolicyGetResponse()` or an
`ErrorResponse()`. Replaced by: `ServiceProviderDialPlanPolicyGetRequest17()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderDialPlanPolicyGetRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the Service Provider level data associated with Dial Plan Policy.

The response is either a `ServiceProviderDialPlanPolicyGetResponse17()` or an
`ErrorResponse()`. Replaced by: `ServiceProviderDialPlanPolicyGetRequest22()` in AS
data mode.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderDialPlanPolicyGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the Service Provider level data associated with Dial Plan Policy.

The response is either a `ServiceProviderDialPlanPolicyGetResponse22()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderDialPlanPolicyModifyAccessCodeRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a Service Provider level Dial Plan Access Code and its attribues.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                              |Type |Description                                            |
|--------------------------------------------------|-----|-------------------------------------------------------|
|service_provider_id                               |str  |serviceProviderId                                      |
|access_code                                       |str  |accessCode                                             |
|include_code_for_network_translations_and_routing |bool |includeCodeForNetworkTranslationsAndRouting *Optional* |
|include_code_for_screening_services               |bool |includeCodeForScreeningServices *Optional*             |
|enable_secondary_dial_tone                        |bool |enableSecondaryDialTone *Optional*                     |
|description                                       |str  |description *Optional*                                 |
</div>


## `ServiceProviderDialPlanPolicyModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Service Provider level data associated with Dial Plan Policy.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode:
overrideResolvedDeviceDigitMap deviceDigitMap

**Attributes:**

|Name                                            |Type |Description                                          |
|------------------------------------------------|-----|-----------------------------------------------------|
|service_provider_id                             |str  |serviceProviderId                                    |
|requires_access_code_for_public_calls           |bool |requiresAccessCodeForPublicCalls *Optional*          |
|allow_e164_public_calls                         |bool |allowE164PublicCalls *Optional*                      |
|prefer_e164_number_format_for_callback_services |bool |preferE164NumberFormatForCallbackServices *Optional* |
|public_digit_map                                |str  |publicDigitMap *Optional*                            |
|private_digit_map                               |str  |privateDigitMap *Optional*                           |
|override_resolved_device_digit_map              |bool |overrideResolvedDeviceDigitMap *Optional*            |
|device_digit_map                                |str  |deviceDigitMap *Optional*                            |
</div>


## `ServiceProviderDialableCallerIDCriteriaAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a new Dialable Caller ID Criteria.

Criteria are added at the bottom of the list with the lowest priority.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                           |Type      |Description                            |
|-------------------------------|----------|---------------------------------------|
|service_provider_id            |str       |serviceProviderId                      |
|name                           |str       |name                                   |
|description                    |str       |description *Optional*                 |
|prefix_digits                  |str       |prefixDigits *Optional*                |
|match_call_type                |List[str] |matchCallType *Optional*               |
|match_alternate_call_indicator |List[str] |matchAlternateCallIndicator *Optional* |
|match_local_category           |bool      |matchLocalCategory                     |
|match_national_category        |bool      |matchNationalCategory                  |
|match_interlata_category       |bool      |matchInterlataCategory                 |
|match_intralata_category       |bool      |matchIntralataCategory                 |
|match_international_category   |bool      |matchInternationalCategory             |
|match_private_category         |bool      |matchPrivateCategory                   |
|match_emergency_category       |bool      |matchEmergencyCategory                 |
|match_other_category           |bool      |matchOtherCategory                     |
</div>


## `ServiceProviderDialableCallerIDCriteriaDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Dialable Caller ID Criteria.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|name                |str |name              |
</div>


## `ServiceProviderDialableCallerIDCriteriaGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get an existing Dialable Caller ID Criteria.

The response is either a `ServiceProviderDialableCallerIDCriteriaGetRequest()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|name                |str |name              |
</div>


## `ServiceProviderDialableCallerIDGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the service provider?s Dialable Caller ID settings and criteria list.

The response is either a `ServiceProviderDialableCallerIDGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderDigitCollectionGetRequest13mp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the service provider's digit collection attributes.

The response is either a `ServiceProviderDigitCollectionGetResponse13mp4()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderDigitCollectionModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the service provider's digit collection attributes.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description                |
|--------------------|----|---------------------------|
|service_provider_id |str |serviceProviderId          |
|access_code         |str |accessCode *Optional*      |
|public_digit_map    |str |publicDigitMap *Optional*  |
|private_digit_map   |str |privateDigitMap *Optional* |
</div>


## `ServiceProviderDnGetAvailableListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a list of available DNs not yet assigned to any group.

Dns assigned to the IMRN pool are not listed in the response.

The response is either `ServiceProviderDnGetAvailableListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderDnGetStatusListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Validates DNs given in the request The response is
`ServiceProviderDnGetStatusListResponse()`.


**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|dn                  |List[str] |dn                |
</div>


## `ServiceProviderDomainAssignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Assign a list of domains to a service provider.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|domain              |List[str] |domain            |
</div>


## `ServiceProviderDomainGetAssignedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of all matching domains assigned to a service provider .

The response is either `ServiceProviderDomainGetAssignedListResponse()` or
`ErrorResponse()`. Replaced by `ServiceProviderDomainGetAssignedListRequest22()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderDomainUnassignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Unassign a list of domains from a service provider.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|domain              |List[str] |domain            |
</div>


## `ServiceProviderEmergencyCallNotificationGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the service provider level data associated with Emergency Call Notification.

The response is either a `ServiceProviderEmergencyCallNotificationGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderEmergencyCallNotificationModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the service provider or enterprise level data associated with Emergency Call
Notification.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                   |Type |Description                                   |
|---------------------------------------|-----|----------------------------------------------|
|service_provider_id                    |str  |serviceProviderId                             |
|send_emergency_call_notification_email |bool |sendEmergencyCallNotificationEmail *Optional* |
|emergency_call_notify_email_address    |str  |emergencyCallNotifyEmailAddress *Optional*    |
|allow_group_override                   |bool |allowGroupOverride *Optional*                 |
</div>


## `ServiceProviderEnhancedCallLogsGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the service provider's enhanced call log settings.

The response is either a `ServiceProviderEnhancedCallLogsGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderEnhancedCallLogsGetRequest17sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the service provider's enhanced call log settings.

The response is either a `ServiceProviderEnhancedCallLogsGetResponse17sp4()` or an
`ErrorResponse()`. This command will return an `ErrorResponse()` if DBS is used as the
call log server.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderEnhancedCallLogsModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Service Provider level data associated with Enhanced Call Logs.

Configures the maximum number of logged calls and maximum age of your user's call
logs.  Log entries are deleted when either of the two limits is reached.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                 |Type|Description                   |
|---------------------|----|------------------------------|
|service_provider_id  |str |serviceProviderId             |
|max_logged_calls     |int |maxLoggedCalls *Optional*     |
|call_expiration_days |int |callExpirationDays *Optional* |
</div>


## `ServiceProviderEnhancedCallLogsSchemaInstanceGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the enhanced call log database schema instance associated with this service
provider.

The response is either a `ServiceProviderEnhancedCallLogsSchemaInstanceGetResponse()`
or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderEnhancedCallLogsSchemaInstanceModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Enhanced Call Logs schema instance associated with this Service Provider.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|name                |str |name *Optional*   |
</div>


## `ServiceProviderExtensionLengthGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the service provider's extension length.

The response is either a `ServiceProviderExtensionLengthGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderExtensionLengthModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the service provider's extension length range.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                          |Type|Description                           |
|------------------------------|----|--------------------------------------|
|service_provider_id           |str |serviceProviderId                     |
|default_extension_length      |int |defaultExtensionLength *Optional*     |
|location_routing_prefix_digit |int |locationRoutingPrefixDigit *Optional* |
|location_code_length          |int |locationCodeLength *Optional*         |
</div>


## `ServiceProviderExternalCustomRingbackGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the service provider level data associated with External Custom Ringback.

The response is either a `ServiceProviderExternalCustomRingbackGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderExternalCustomRingbackModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the service provider level data associated with External Custom Ringback.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description                 |
|--------------------|----|----------------------------|
|service_provider_id |str |serviceProviderId           |
|prefix_digits       |str |prefixDigits *Optional*     |
|server_net_address  |str |serverNetAddress *Optional* |
|server_port         |int |serverPort *Optional*       |
|timeout_seconds     |int |timeoutSeconds *Optional*   |
</div>


## `ServiceProviderFeatureAccessCodeGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of feature access codes for a service provider or enterprise.

The response is either a `ServiceProviderFeatureAccessCodeGetListResponse()` or an
`ErrorResponse()`.

Replaced By : `ServiceProviderFeatureAccessCodeGetListRequest20()` in AS data mode

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderFeatureAccessCodeGetListRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of feature access codes for a service provider or enterprise.

The response is either a `ServiceProviderFeatureAccessCodeGetListResponse20()` or an
`ErrorResponse()`. In release 20 the "Call Recording" FAC name is changed to "Call
Recording - Start". Replaced by: `ServiceProviderFeatureAccessCodeGetListRequest21()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderFeatureAccessCodeGetListRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of feature access codes for a service provider or enterprise.

The response is either a `ServiceProviderFeatureAccessCodeGetListResponse21()` or an
`ErrorResponse()`. In release 20 the "Call Recording" FAC name is changed to "Call
Recording - Start".

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderFileRepositoryDeviceUserAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a new service provider file repository user.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                 |Type |Description        |
|---------------------|-----|-------------------|
|service_provider_id  |str  |serviceProviderId  |
|file_repository_name |str  |fileRepositoryName |
|user_name            |str  |userName           |
|password             |str  |password           |
|allow_put            |bool |allowPut           |
|allow_delete         |bool |allowDelete        |
|allow_get            |bool |allowGet           |
</div>


## `ServiceProviderFileRepositoryDeviceUserDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a service provider file repository user.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                 |Type|Description        |
|---------------------|----|-------------------|
|service_provider_id  |str |serviceProviderId  |
|file_repository_name |str |fileRepositoryName |
|user_name            |str |userName           |
</div>


## `ServiceProviderFileRepositoryDeviceUserGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the list of service provider users for a file repository in the system.

The response is either a `ServiceProviderFileRepositoryDeviceUserGetListResponse()` or
an `ErrorResponse()`.

**Attributes:**

|Name                 |Type|Description        |
|---------------------|----|-------------------|
|service_provider_id  |str |serviceProviderId  |
|file_repository_name |str |fileRepositoryName |
</div>


## `ServiceProviderFileRepositoryDeviceUserModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a service provider file repository user.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                 |Type |Description            |
|---------------------|-----|-----------------------|
|service_provider_id  |str  |serviceProviderId      |
|file_repository_name |str  |fileRepositoryName     |
|user_name            |str  |userName               |
|password             |str  |password *Optional*    |
|allow_put            |bool |allowPut *Optional*    |
|allow_delete         |bool |allowDelete *Optional* |
|allow_get            |bool |allowGet *Optional*    |
</div>


## `ServiceProviderGetAvailableLeafDeviceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of available leaf devices that can be linked to a tree device within
a specific service provider.

A leaf device is a device associated with a device type that has the option
supportLinks set to "Support Link to Device". It can be linked to only one tree
device.  The list returned includes devices created at the system, service provider,
and group levels.

The response is either `ServiceProviderGetAvailableLeafDeviceListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderGetAvailableTreeDeviceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of available tree devices to which a leaf device can be linked to
within a specific service provider.

A tree device is a device associated with a device type that has the option
supportLinks set to "Support Links from Devices". Many leaf devices can be linked to
it.  The list returned includes devices created at the system, service provider, and
group levels.

The response is either `ServiceProviderGetAvailableTreeDeviceListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderGetDefaultRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the default profile for a service provider or enterprise.

The response is either a `ServiceProviderGetDefaultResponse()` or an
`ErrorResponse()`.

</div>


## `ServiceProviderGetRequest13mp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the profile for a service provider or enterprise.

The response is either a `ServiceProviderGetResponse13mp2()` or an `ErrorResponse()`.
Replaced by: `ServiceProviderGetRequest17sp1()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderGetRequest17sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the profile for a service provider or enterprise.

The response is either a `ServiceProviderGetResponse17sp1()` or an `ErrorResponse()`.
Replaced by: `ServiceProviderGetRequest22()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the profile for a service provider or enterprise.

The response is either a `ServiceProviderGetResponse22()` or an `ErrorResponse()`.
Replaced by `ServiceProviderGetRequest22V2()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderGetRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the profile for a service provider or enterprise.

The response is either a `ServiceProviderGetResponse22V2()` or an `ErrorResponse()`.
Replaced by `ServiceProviderGetRequest22V3()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderGetRequest22V3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the profile for a service provider or enterprise.

The response is either a `ServiceProviderGetResponse22V3()` or an `ErrorResponse()`.
Replaced by: `ServiceProviderGetRequest22V4()` in AS data mode.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderGetRequest22V4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the profile for a service provider or enterprise.

The response is either a `ServiceProviderGetResponse22V4()` or an `ErrorResponse()`.
The following elements are only used in AS data mode and ignored in XS data mode:
serviceProviderExtenalId

**Attributes:**

|Name                         |Type|Description                          |
|-----------------------------|----|-------------------------------------|
|service_provider_id          |str |serviceProviderId *Optional*         |
|service_provider_external_id |str |serviceProviderExternalId *Optional* |
</div>


## `ServiceProviderGroupPagingTargetsCapacityGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the maximum number of target users per paging group configured for a service
provider.

The response is either a `ServiceProviderGroupPagingTargetsCapacityGetResponse()` or
an `ErrorResponse()`. Replaced by:
`ServiceProviderGroupPagingTargetsCapacityGetRequest22()` in AS data mode.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderGroupPagingTargetsCapacityGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the maximum number of target users per paging group configured for a service
provider.

The response is either a `ServiceProviderGroupPagingTargetsCapacityGetResponse22()` or
an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderGroupPagingTargetsCapacityModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the maximum number of target users per paging group configured for a service
provider.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`ServiceProviderGroupPagingTargetsCapacityModifyRequest22()` in AS data mode.

**Attributes:**

|Name                 |Type|Description                   |
|---------------------|----|------------------------------|
|service_provider_id  |str |serviceProviderId             |
|maximum_target_users |int |maximumTargetUsers *Optional* |
</div>


## `ServiceProviderGroupPagingTargetsCapacityModifyRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the maximum number of target users per paging group configured for a service
provider.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                 |Type|Description                   |
|---------------------|----|------------------------------|
|service_provider_id  |str |serviceProviderId             |
|maximum_target_users |int |maximumTargetUsers *Optional* |
</div>


## `ServiceProviderHPBXAlternateCarrierSelectionGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the Alternate Carrier Selection parameters.

The response is either a `ServiceProviderHPBXAlternateCarrierSelectionGetResponse()`
or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderHPBXAlternateCarrierSelectionModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the Alternate Carrier Selection parameters.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                          |Type |Description                           |
|------------------------------|-----|--------------------------------------|
|service_provider_id           |str  |serviceProviderId                     |
|process_cbc_carrier_selection |bool |processCbcCarrierSelection *Optional* |
|preselected_local_carrier     |str  |preselectedLocalCarrier *Optional*    |
|preselected_distant_carrier   |str  |preselectedDistantCarrier *Optional*  |
</div>


## `ServiceProviderIMRNGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Returns a list of dns or dn ranges in a service provider IMRN pool.

The response is either `ServiceProviderIMRNGetListResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderInCallServiceActivationGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the service provider's DTMF based in-call service activation trigger
attributes.

The response is either a `ServiceProviderInCallServiceActivationGetResponse()` or an
`ErrorResponse()`. Replaced by: `ServiceProviderInCallServiceActivationGetRequest17()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderInCallServiceActivationGetRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the service provider's DTMF based in-call service activation trigger
attributes.

The response is either a `ServiceProviderInCallServiceActivationGetResponse17()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderInCallServiceActivationModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the service provider's DTMF based in-call service activation trigger
attributes.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`ServiceProviderInCallServiceActivationModifyRequest17()`

**Attributes:**

|Name                |Type|Description                 |
|--------------------|----|----------------------------|
|service_provider_id |str |serviceProviderId           |
|activation_digits   |str |activationDigits *Optional* |
</div>


## `ServiceProviderInCallServiceActivationModifyRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the service provider's DTMF based in-call service activation trigger
attributes.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                            |Type|Description                             |
|--------------------------------|----|----------------------------------------|
|service_provider_id             |str |serviceProviderId                       |
|flash_activation_digits         |str |flashActivationDigits *Optional*        |
|call_transfer_activation_digits |str |callTransferActivationDigits *Optional* |
</div>


## `ServiceProviderIntegratedIMPGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the Integrated IMP service attributes for the service provider.

The response is either `ServiceProviderIntegratedIMPGetResponse()` or
`ErrorResponse()`. Replaced by: `ServiceProviderIntegratedIMPGetRequest21()` in AS
data mode

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderIntegratedIMPGetRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the Integrated IMP service attributes for the service provider.

The response is either `ServiceProviderIntegratedIMPGetResponse21()` or
`ErrorResponse()`. Replaced by: `ServiceProviderIntegratedIMPGetRequest21sp1()` in AS
data mode

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderIntegratedIMPGetRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the Integrated IMP service attributes for the service provider.

The response is either `ServiceProviderIntegratedIMPGetResponse21sp1()` or
`ErrorResponse()`. Replaced by: `ServiceProviderIntegratedIMPGetRequest22()` in AS
data mode

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderIntegratedIMPGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the Integrated IMP service attributes for the service provider.

The response is either `ServiceProviderIntegratedIMPGetResponse22()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderIntegratedIMPModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Integrated IMP service attributes for the service provider.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. If the service
provider is within a reseller, useSystemServiceDomain means using reseller level
service domain setting.  And useSystemMessagingServer means using the reseller level
messaging server setting.  The following elements are only used in AS data mode:
servicePort useSystemMessagingServer provisioningUrl provisioningUserId
provisioningPassword boshURL defaultImpIdType useResellerIMPIdSetting The element
useResellerIMPIdSetting is only applicable for a service provider within a reseller.

**Attributes:**

|Name                        |Type |Description                         |
|----------------------------|-----|------------------------------------|
|service_provider_id         |str  |serviceProviderId                   |
|use_system_service_domain   |bool |useSystemServiceDomain *Optional*   |
|service_domain              |str  |serviceDomain *Optional*            |
|service_port                |int  |servicePort *Optional*              |
|use_system_messaging_server |bool |useSystemMessagingServer *Optional* |
|provisioning_url            |str  |provisioningUrl *Optional*          |
|provisioning_user_id        |str  |provisioningUserId *Optional*       |
|provisioning_password       |str  |provisioningPassword *Optional*     |
|bosh_url                    |str  |boshURL *Optional*                  |
|default_imp_id_type         |str  |defaultImpIdType *Optional*         |
|use_reseller_imp_id_setting |bool |useResellerIMPIdSetting *Optional*  |
</div>


## `ServiceProviderLanguageAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a language for a service provder.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|language            |str |language          |
</div>


## `ServiceProviderLanguageDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a language from a service provider supported languages.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|language            |str |language          |
</div>


## `ServiceProviderLanguageGetAvailableListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the list of languages that a user or admin in a service provider is allowed to
use.

The list will either be the system or service provider languages list, depending on
the useServiceProviderLanguages flag.

The response is either a `ServiceProviderLanguageGetAvailableListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderLanguageGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the defined languages for a service provider.

The response is either a `ServiceProviderLanguageGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderLanguageModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a language properties for a service provider/enterprise.

If the becomeDefaultLanguage element is present, the language in this request Becomes
the default language for the service provider/enterprise.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                    |Type |Description                      |
|------------------------|-----|---------------------------------|
|service_provider_id     |str  |serviceProviderId                |
|language                |str  |language                         |
|become_default_language |bool |becomeDefaultLanguage *Optional* |
</div>


## `ServiceProviderMWIDeliveryToMobileEndpointCustomTemplateDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a MWI Delivery to Mobile Endpoint Custom Template.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|language            |str |language          |
|type                |str |type              |
</div>


## `ServiceProviderMWIDeliveryToMobileEndpointCustomTemplateGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a MWI Delivery to Mobile Endpoint Custom Template.

The response is either a
`ServiceProviderMWIDeliveryToMobileEndpointCustomTemplateGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|language            |str |language          |
|type                |str |type              |
</div>


## `ServiceProviderMWIDeliveryToMobileEndpointGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the service provider level data associated with MWI Delivery to Mobile
Endpoint service.

The response is either a `ServiceProviderMWIDeliveryToMobileEndpointGetResponse()` or
an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderMaliciousCallTraceGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the service provider's Malicious Call Trace settings.

The response is either a `ServiceProviderMaliciousCallTraceGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderMaliciousCallTraceModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the service provider's Malicious Call Trace settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                     |Type |Description                                    |
|-----------------------------------------|-----|-----------------------------------------------|
|service_provider_id                      |str  |serviceProviderId                              |
|use_system_play_mct_warning_announcement |bool |useSystemPlayMCTWarningAnnouncement *Optional* |
|play_mct_warning_announcement            |bool |playMCTWarningAnnouncement *Optional*          |
</div>


## `ServiceProviderMeetMeConferencingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the service provider/enterprise level data associated with Meet-Me
Conferencing functions.

The response is either a `ServiceProviderMeetMeConferencingGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderNetworkClassOfServiceAssignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Assign a list of Network Classes of Service to a service provider.

The Element defaultNetworkClassOfService is required only for the first assignment,
for subsequent assignments it is optional.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

Replaced By : `ServiceProviderNetworkClassOfServiceAssignListRequest21()` in AS data
mode

**Attributes:**

|Name                             |Type      |Description                             |
|---------------------------------|----------|----------------------------------------|
|service_provider_id              |str       |serviceProviderId                       |
|network_class_of_service         |List[str] |networkClassOfService *Optional*        |
|default_network_class_of_service |str       |defaultNetworkClassOfService *Optional* |
</div>


## `ServiceProviderNetworkClassOfServiceAssignListToAllGroupsRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Assign a list of Network Classes of Service to all groups with in a service provider.

If it is the first assigned Network Class of Service in the group, it will be set as
the default one.  The Network Classes of Service must be currently assigned to the
service provider.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type      |Description           |
|-------------------------|----------|----------------------|
|service_provider_id      |str       |serviceProviderId     |
|network_class_of_service |List[str] |networkClassOfService |
</div>


## `ServiceProviderNetworkClassOfServiceAssignToAllUsersRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Assign a Network Classes of Service to all users with in a service provider.

This will also assign the Network Class of Service to all the groups in the service
provider if it is not assigned yet.  If it is the first assigned Network Class of
Service in the group, it will be set as the default one.  However, the Network Classes
of Service must be currently assigned to the service provider.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type|Description           |
|-------------------------|----|----------------------|
|service_provider_id      |str |serviceProviderId     |
|network_class_of_service |str |networkClassOfService |
</div>


## `ServiceProviderNetworkClassOfServiceGetAssignedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of Network Classes of Service assigned to a service provider.

The response is either a
`ServiceProviderNetworkClassOfServiceGetAssignedListResponse()` or an
`ErorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderNetworkClassOfServiceModifyDefaultRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the default Network Classes of Service of a Service Provider.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type|Description           |
|-------------------------|----|----------------------|
|service_provider_id      |str |serviceProviderId     |
|network_class_of_service |str |networkClassOfService |
</div>


## `ServiceProviderNetworkClassOfServiceUnassignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Unassign a list of Network Classes of Service from a service provider.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

Replaced By : `ServiceProviderNetworkClassOfServiceUnassignListRequest21()` in AS data
mode

**Attributes:**

|Name                             |Type      |Description                             |
|---------------------------------|----------|----------------------------------------|
|service_provider_id              |str       |serviceProviderId                       |
|network_class_of_service         |List[str] |networkClassOfService *Optional*        |
|default_network_class_of_service |str       |defaultNetworkClassOfService *Optional* |
</div>


## `ServiceProviderNumberPortabilityQueryAddListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a list of the Service Provider Number Portability Query Digit Patterns.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|digit_pattern       |List[str] |digitPattern      |
</div>


## `ServiceProviderNumberPortabilityQueryModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Service Provider Number Portability Query information.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                                   |Type      |Description                                                |
|-------------------------------------------------------|----------|-----------------------------------------------------------|
|service_provider_id                                    |str       |serviceProviderId                                          |
|enable_number_portability_query_for_outgoing_calls     |bool      |enableNumberPortabilityQueryForOutgoingCalls *Optional*    |
|enable_number_portability_query_for_incoming_calls     |bool      |enableNumberPortabilityQueryForIncomingCalls *Optional*    |
|enable_number_portability_query_for_network_calls_only |bool      |enableNumberPortabilityQueryForNetworkCallsOnly *Optional* |
|delete_digit_pattern                                   |List[str] |deleteDigitPattern *Optional*                              |
</div>


## `ServiceProviderOfficeZoneAssignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Assign a list of Office Zones to a service provider.

The Element defaultOfficeZone is required only for the first assignment, for
subsequent assignments it is optional.  Office Zones can only be assigned if the
Location-Based Calling Restrictions has been authorized to the service provider
otherwise the request will fail.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type      |Description                      |
|-------------------------|----------|---------------------------------|
|service_provider_id      |str       |serviceProviderId                |
|office_zone_name         |List[str] |officeZoneName *Optional*        |
|default_office_zone_name |str       |defaultOfficeZoneName *Optional* |
</div>


## `ServiceProviderOfficeZoneGetAssignedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of Office Zones assigned to a service provider.

The response is either a `ServiceProviderOfficeZoneGetAssignedListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderOfficeZoneUnassignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Unassign a list of OfficeZones from a service provider.

Note: a new default must be provided if unassigning the current default.  Office Zones
can only be unassigned if the Location-Based Calling Restrictions has been authorized
to the service provider otherwise the request will fail.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type      |Description                      |
|-------------------------|----------|---------------------------------|
|service_provider_id      |str       |serviceProviderId                |
|office_zone_name         |List[str] |officeZoneName *Optional*        |
|default_office_zone_name |str       |defaultOfficeZoneName *Optional* |
</div>


## `ServiceProviderPasswordRulesGetRequest13mp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the service provider's password rules setting applicable to Administrators
(Group and Department) and Users.

The response is either `ServiceProviderPasswordRulesGetResponse13mp2()` or
`ErrorResponse()`.

Replaced By: `ServiceProviderPasswordRulesGetRequest16()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderPasswordRulesGetRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the service provider's password rules setting applicable to Administrators
(Group and Department) and Users.

The response is either `ServiceProviderPasswordRulesGetResponse16()` or
`ErrorResponse()`. Replaced by: `ServiceProviderPasswordRulesGetRequest22()` in AS
data mode.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderPasswordRulesGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the service provider's password rules setting applicable to Administrators
(Group and Department) and Users.

The response is either `ServiceProviderPasswordRulesGetResponse22()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderPasswordRulesModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the service provider's password rules settings setting applicable to
Administrators (Group and Department) and Users.

The response is either `SuccessResponse()` or `ErrorResponse()`.

Replaced By: `ServiceProviderPasswordRulesModifyRequest14sp3()`

**Attributes:**

|Name                                        |Type |Description                                       |
|--------------------------------------------|-----|--------------------------------------------------|
|service_provider_id                         |str  |serviceProviderId                                 |
|rules_apply_to                              |str  |rulesApplyTo *Optional*                           |
|allow_web_add_external_authentication_users |bool |allowWebAddExternalAuthenticationUsers *Optional* |
|disallow_user_id                            |bool |disallowUserId *Optional*                         |
|disallow_old_password                       |bool |disallowOldPassword *Optional*                    |
|disallow_reversed_old_password              |bool |disallowReversedOldPassword *Optional*            |
|restrict_min_digits                         |bool |restrictMinDigits *Optional*                      |
|min_digits                                  |int  |minDigits *Optional*                              |
|restrict_min_upper_case_letters             |bool |restrictMinUpperCaseLetters *Optional*            |
|min_upper_case_letters                      |int  |minUpperCaseLetters *Optional*                    |
|restrict_min_lower_case_letters             |bool |restrictMinLowerCaseLetters *Optional*            |
|min_lower_case_letters                      |int  |minLowerCaseLetters *Optional*                    |
|restrict_min_non_alphanumeric_characters    |bool |restrictMinNonAlphanumericCharacters *Optional*   |
|min_non_alphanumeric_characters             |int  |minNonAlphanumericCharacters *Optional*           |
|min_length                                  |int  |minLength *Optional*                              |
|max_failed_login_attempts                   |int  |maxFailedLoginAttempts *Optional*                 |
|password_expires_days                       |int  |passwordExpiresDays *Optional*                    |
|send_login_disabled_notify_email            |bool |sendLoginDisabledNotifyEmail *Optional*           |
|login_disabled_notify_email_address         |str  |loginDisabledNotifyEmailAddress *Optional*        |
|disallow_rules_modification                 |bool |disallowRulesModification *Optional*              |
</div>


## `ServiceProviderPasswordRulesModifyRequest14sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the service provider's password rules settings setting applicable to
Administrators (Group and Department) and Users.

The following elements are only used in AS data mode and ignored in XS data mode:
forcePasswordChangeAfterReset

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                        |Type |Description                                       |
|--------------------------------------------|-----|--------------------------------------------------|
|service_provider_id                         |str  |serviceProviderId                                 |
|rules_apply_to                              |str  |rulesApplyTo *Optional*                           |
|allow_web_add_external_authentication_users |bool |allowWebAddExternalAuthenticationUsers *Optional* |
|disallow_user_id                            |bool |disallowUserId *Optional*                         |
|disallow_old_password                       |bool |disallowOldPassword *Optional*                    |
|disallow_reversed_old_password              |bool |disallowReversedOldPassword *Optional*            |
|restrict_min_digits                         |bool |restrictMinDigits *Optional*                      |
|min_digits                                  |int  |minDigits *Optional*                              |
|restrict_min_upper_case_letters             |bool |restrictMinUpperCaseLetters *Optional*            |
|min_upper_case_letters                      |int  |minUpperCaseLetters *Optional*                    |
|restrict_min_lower_case_letters             |bool |restrictMinLowerCaseLetters *Optional*            |
|min_lower_case_letters                      |int  |minLowerCaseLetters *Optional*                    |
|restrict_min_non_alphanumeric_characters    |bool |restrictMinNonAlphanumericCharacters *Optional*   |
|min_non_alphanumeric_characters             |int  |minNonAlphanumericCharacters *Optional*           |
|min_length                                  |int  |minLength *Optional*                              |
|max_failed_login_attempts                   |int  |maxFailedLoginAttempts *Optional*                 |
|password_expires_days                       |int  |passwordExpiresDays *Optional*                    |
|send_login_disabled_notify_email            |bool |sendLoginDisabledNotifyEmail *Optional*           |
|login_disabled_notify_email_address         |str  |loginDisabledNotifyEmailAddress *Optional*        |
|disallow_previous_passwords                 |bool |disallowPreviousPasswords *Optional*              |
|number_of_previous_passwords                |int  |numberOfPreviousPasswords *Optional*              |
|force_password_change_after_reset           |bool |forcePasswordChangeAfterReset *Optional*          |
</div>


## `ServiceProviderPortalPasscodeRulesGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the service provider's passcode rules setting.

The response is either `ServiceProviderPortalPasscodeRulesGetResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderPortalPasscodeRulesGetRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the service provider's passcode rules setting.

The response is either `ServiceProviderPortalPasscodeRulesGetResponse19()` or
`ErrorResponse()`. Replaced by: `ServiceProviderPortalPasscodeRulesGetRequest22()` in
AS data mode.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderPortalPasscodeRulesGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the service provider's passcode rules setting.

The response is either `ServiceProviderPortalPasscodeRulesGetResponse22()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderPortalPasscodeRulesModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the service provider's passcode rules setting.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in AS data mode: numberOfRepeatedDigits
disallowRepeatedPatterns disallowContiguousSequences numberOfAscendingDigits
numberOfDescendingDigits numberOfPreviousPasscodes The following elements are only
used in AS data mode and ignored in XS data mode: enableDefaultPasscode
defaultPasscode

**Attributes:**

|Name                                          |Type |Description                                        |
|----------------------------------------------|-----|---------------------------------------------------|
|service_provider_id                           |str  |serviceProviderId                                  |
|disallow_repeated_digits                      |bool |disallowRepeatedDigits *Optional*                  |
|number_of_repeated_digits                     |int  |numberOfRepeatedDigits *Optional*                  |
|disallow_repeated_patterns                    |bool |disallowRepeatedPatterns *Optional*                |
|disallow_contiguous_sequences                 |bool |disallowContiguousSequences *Optional*             |
|number_of_ascending_digits                    |int  |numberOfAscendingDigits *Optional*                 |
|number_of_descending_digits                   |int  |numberOfDescendingDigits *Optional*                |
|disallow_user_number                          |bool |disallowUserNumber *Optional*                      |
|disallow_reversed_user_number                 |bool |disallowReversedUserNumber *Optional*              |
|disallow_old_passcode                         |bool |disallowOldPasscode *Optional*                     |
|number_of_previous_passcodes                  |int  |numberOfPreviousPasscodes *Optional*               |
|disallow_reversed_old_passcode                |bool |disallowReversedOldPasscode *Optional*             |
|min_code_length                               |int  |minCodeLength *Optional*                           |
|max_code_length                               |int  |maxCodeLength *Optional*                           |
|disable_login_after_max_failed_login_attempts |bool |disableLoginAfterMaxFailedLoginAttempts *Optional* |
|max_failed_login_attempts                     |int  |maxFailedLoginAttempts *Optional*                  |
|expire_password                               |bool |expirePassword *Optional*                          |
|passcode_expires_days                         |int  |passcodeExpiresDays *Optional*                     |
|send_login_disabled_notify_email              |bool |sendLoginDisabledNotifyEmail *Optional*            |
|login_disabled_notify_email_address           |str  |loginDisabledNotifyEmailAddress *Optional*         |
|enable_default_passcode                       |bool |enableDefaultPasscode *Optional*                   |
|default_passcode                              |str  |defaultPasscode *Optional*                         |
</div>


## `ServiceProviderPreferredCarrierAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add the country code preferred carriers for a service provider or enterprise.

For each combination of service provider and country code, you can assign an intra-
lata, inter-lata, and international carrier.  Each of the three types of carriers is
optional.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Note: At the
system level, more than one carrier may be assigned to each country code.  At the
service provider level, you must choose from the carriers assigned at the system
level.

**Attributes:**

|Name                  |Type|Description                     |
|----------------------|----|--------------------------------|
|service_provider_id   |str |serviceProviderId               |
|country_code          |str |countryCode                     |
|intra_lata_carrier    |str |intraLataCarrier *Optional*     |
|inter_lata_carrier    |str |interLataCarrier *Optional*     |
|international_carrier |str |internationalCarrier *Optional* |
</div>


## `ServiceProviderPreferredCarrierDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete the country code preferred carriers for a service provider or enterprise.

Note that this is different from unassigning all 3 types of carriers with the
`ServiceProviderPreferredCarrierModifyRequest()`.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. An
`ErrorResponse()` will be returned if the country code preferred carriers were never
added or were already deleted.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|country_code        |str |countryCode       |
</div>


## `ServiceProviderPreferredCarrierGetAvailableCountryCodeListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the default country code and the list of unused country codes for a service
provider / enterprise.

The response is either a
`ServiceProviderPreferredCarrierGetAvailableCountryCodeListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderPreferredCarrierGetCarrierListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the lists of carriers for a specified country code for a service provider /
enterprise.

The response is either a `ServiceProviderPreferredCarrierGetCarrierListResponse()` or
an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|country_code        |str |countryCode       |
</div>


## `ServiceProviderPreferredCarrierGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests a table of all the carriers defined in a specified service provider or
enterprise.

The response is either a `ServiceProviderPreferredCarrierGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderPreferredCarrierGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the currently configured carriers for a specified country code for a service
provider / enterprise.

The response is either a `ServiceProviderPreferredCarrierGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|country_code        |str |countryCode       |
</div>


## `ServiceProviderPreferredCarrierModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the country code preferred carriers for a service provider or enterprise.

For each combination of service provider and country code, you can assign an intra-
lata, inter-lata, and international carrier.  Each of the 3 types of carriers is
optional.  If an optional carrier is not specified, the assignment will not change.
To clear a preferred carrier, set the value to an empty string.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Note: At the
system level, more than one carrier may be assigned to each country code.  At the
service provider level, you must choose from the carriers assigned at the system
level.

**Attributes:**

|Name                  |Type|Description                     |
|----------------------|----|--------------------------------|
|service_provider_id   |str |serviceProviderId               |
|country_code          |str |countryCode                     |
|intra_lata_carrier    |str |intraLataCarrier *Optional*     |
|inter_lata_carrier    |str |interLataCarrier *Optional*     |
|international_carrier |str |internationalCarrier *Optional* |
</div>


## `ServiceProviderRouteListEnterpriseTrunkNumberPrefixActivateListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Activate number prefixes in a service provider.

It is not an error to activate an already activated number prefix.  The command fails
if executed when system level enterprise trunk number prefix activation is disabled.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|number_prefix       |List[str] |numberPrefix      |
</div>


## `ServiceProviderRouteListEnterpriseTrunkNumberPrefixAddListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add number prefixes to a service provider.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|prefix              |List[str] |prefix            |
</div>


## `ServiceProviderRouteListEnterpriseTrunkNumberPrefixDeactivateListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Deactivate number prefixes in a service provider.

It is not an error to deactivate an already deactivated number prefix.  The command
fails if executed when system level enterprise trunk number prefix activation is
disabled.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|number_prefix       |List[str] |numberPrefix      |
</div>


## `ServiceProviderRouteListEnterpriseTrunkNumberPrefixDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete number prefixes from a service provider.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|number_prefix       |List[str] |numberPrefix      |
</div>


## `ServiceProviderRouteListEnterpriseTrunkNumberPrefixGetAvailableListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a list of available number prefixes not yet assigned to any group.

The response is either
`ServiceProviderRouteListEnterpriseTrunkNumberPrefixGetAvailableListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderRouteListEnterpriseTrunkNumberPrefixGetSummaryListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a summary table of all enterprise trunk number prefixes in the service
provider.

The response is either
`ServiceProviderRouteListEnterpriseTrunkPrefixGetSummaryListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderRouteListEnterpriseTrunkNumberRangeActivateListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Activate number ranges in a service provider.

It is not an error to activate an already activated number range.  The command fails
if executed when system level enterprise trunk number range activation is disabled.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description                 |
|--------------------|----------|----------------------------|
|service_provider_id |str       |serviceProviderId           |
|number_range_start  |List[str] |numberRangeStart *Optional* |
</div>


## `ServiceProviderRouteListEnterpriseTrunkNumberRangeDeactivateListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Deactivate number ranges in a service provider.

It is not an error to deactivate an already deactivated number range.  The command
fails if executed when system level enterprise trunk number range activation is
disabled.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description                 |
|--------------------|----------|----------------------------|
|service_provider_id |str       |serviceProviderId           |
|number_range_start  |List[str] |numberRangeStart *Optional* |
</div>


## `ServiceProviderRouteListEnterpriseTrunkNumberRangeDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete number ranges from a service provider.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description                 |
|--------------------|----------|----------------------------|
|service_provider_id |str       |serviceProviderId           |
|number_range_start  |List[str] |numberRangeStart *Optional* |
</div>


## `ServiceProviderRouteListEnterpriseTrunkNumberRangeGetAvailableListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a list of available number ranges not yet assigned to any group.

The response is either
`ServiceProviderRouteListEnterpriseTrunkNumberRangeGetAvailableListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderRouteListEnterpriseTrunkNumberRangeGetSummaryListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a summary table of all enterprise trunk number ranges in the service provider.

The response is either
`ServiceProviderRouteListEnterpriseTrunkNumberRangeGetSummaryListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderRoutePointExternalSystemAssignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Assign a list of route point external systems to a service provider.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                        |Type      |Description                         |
|----------------------------|----------|------------------------------------|
|service_provider_id         |str       |serviceProviderId                   |
|route_point_external_system |List[str] |routePointExternalSystem *Optional* |
</div>


## `ServiceProviderRoutePointExternalSystemGetAssignedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of all Route Point External Systems assigned to a service provider.

The response is either
`ServiceProviderRoutePointExternalSystemGetAssignedListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderRoutePointExternalSystemUnassignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Unassign a list of route point external systems from a service provider.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                        |Type      |Description                         |
|----------------------------|----------|------------------------------------|
|service_provider_id         |str       |serviceProviderId                   |
|route_point_external_system |List[str] |routePointExternalSystem *Optional* |
</div>


## `ServiceProviderRoutingProfileGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the routing profile for the service provider/enterprise.

The response is either a `ServiceProviderRoutingProfileGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderRoutingProfileModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests to modify the routing profile for a service provider.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description               |
|--------------------|----|--------------------------|
|service_provider_id |str |serviceProviderId         |
|routing_profile     |str |routingProfile *Optional* |
</div>


## `ServiceProviderSIPAuthenticationPasswordRulesGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the service provider level SIP authentication password rule settings.

The response is either a `ServiceProviderSIPAuthenticationPasswordRulesGetResponse()`
or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderSIPAuthenticationPasswordRulesModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the service provider level SIP authentication password rule
settings.

The useServiceProviderSettings element can only be modified by a system administrator
or a provisioning administrator.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                     |Type |Description                                     |
|-----------------------------------------|-----|------------------------------------------------|
|service_provider_id                      |str  |serviceProviderId                               |
|use_service_provider_settings            |bool |useServiceProviderSettings *Optional*           |
|disallow_authentication_name             |bool |disallowAuthenticationName *Optional*           |
|disallow_old_password                    |bool |disallowOldPassword *Optional*                  |
|disallow_reversed_old_password           |bool |disallowReversedOldPassword *Optional*          |
|restrict_min_digits                      |bool |restrictMinDigits *Optional*                    |
|min_digits                               |int  |minDigits *Optional*                            |
|restrict_min_upper_case_letters          |bool |restrictMinUpperCaseLetters *Optional*          |
|min_upper_case_letters                   |int  |minUpperCaseLetters *Optional*                  |
|restrict_min_lower_case_letters          |bool |restrictMinLowerCaseLetters *Optional*          |
|min_lower_case_letters                   |int  |minLowerCaseLetters *Optional*                  |
|restrict_min_non_alphanumeric_characters |bool |restrictMinNonAlphanumericCharacters *Optional* |
|min_non_alphanumeric_characters          |int  |minNonAlphanumericCharacters *Optional*         |
|min_length                               |int  |minLength *Optional*                            |
|send_permanent_lockout_notification      |bool |sendPermanentLockoutNotification *Optional*     |
|permanent_lockout_notify_email_address   |str  |permanentLockoutNotifyEmailAddress *Optional*   |
|endpoint_authentication_lockout_type     |str  |endpointAuthenticationLockoutType *Optional*    |
|endpoint_temporary_lockout_threshold     |int  |endpointTemporaryLockoutThreshold *Optional*    |
|endpoint_wait_algorithm                  |str  |endpointWaitAlgorithm *Optional*                |
|endpoint_lockout_fixed_minutes           |str  |endpointLockoutFixedMinutes *Optional*          |
|endpoint_permanent_lockout_threshold     |int  |endpointPermanentLockoutThreshold *Optional*    |
|trunk_group_authentication_lockout_type  |str  |trunkGroupAuthenticationLockoutType *Optional*  |
|trunk_group_temporary_lockout_threshold  |int  |trunkGroupTemporaryLockoutThreshold *Optional*  |
|trunk_group_wait_algorithm               |str  |trunkGroupWaitAlgorithm *Optional*              |
|trunk_group_lockout_fixed_minutes        |str  |trunkGroupLockoutFixedMinutes *Optional*        |
|trunk_group_permanent_lockout_threshold  |int  |trunkGroupPermanentLockoutThreshold *Optional*  |
</div>


## `ServiceProviderScheduleAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a service provider schedule.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|schedule_name       |str |scheduleName      |
|schedule_type       |str |scheduleType      |
</div>


## `ServiceProviderScheduleGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of a service provider schedules.

The list can be filtered by schedule type.

The response is either a `ServiceProviderScheduleGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description             |
|--------------------|----|------------------------|
|service_provider_id |str |serviceProviderId       |
|schedule_type       |str |scheduleType *Optional* |
</div>


## `ServiceProviderServiceGetAuthorizationListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the service provider's service authorization status.

The response is either `ServiceProviderServiceGetAuthorizationListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderServiceGetAuthorizationRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the service provider's service authorization information for a specific
service or service pack.

The response is either `ServiceProviderServiceGetAuthorizationResponse()` or
`ErrorResponse()`. The following element is used in AS mode and triggers an
`ErrorResponse()` in XS data mode: servicePackName

**Attributes:**

|Name                |Type|Description                 |
|--------------------|----|----------------------------|
|service_provider_id |str |serviceProviderId           |
|user_service_name   |str |userServiceName *Optional*  |
|group_service_name  |str |groupServiceName *Optional* |
|service_pack_name   |str |servicePackName *Optional*  |
</div>


## `ServiceProviderServiceGetUserAssignableListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of all user services assignable to users in the specified service
provider.

The response is either `ServiceProviderServiceGetUserAssignableListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderServicePackAddServiceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add services to a service pack if the pack has not been authorized to a
group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|service_pack_name   |str       |servicePackName   |
|service_name        |List[str] |serviceName       |
</div>


## `ServiceProviderServicePackDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a service pack from a service provider.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|service_pack_name   |str |servicePackName   |
</div>


## `ServiceProviderServicePackGetDetailListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a service pack details.

The response is either `ServiceProviderServicePackGetDetailListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|service_pack_name   |str |servicePackName   |
</div>


## `ServiceProviderServicePackGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a list of defined service packs for a service provider.

The response is either `ServiceProviderServicePackGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderServicePackGetServiceUsageListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of service packs containing a specified service.

The response is either `ServiceProviderServicePackGetServiceUsageListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|service_name        |str |serviceName       |
</div>


## `ServiceProviderServicePackGetUtilizationListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the service pack utilization for a service provider.

For each service pack, a table of groups utilizing the pack is returned.

The response is either `ServiceProviderServicePackGetUtilizationListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderServicePackMigrationTaskAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Create a service pack migration task.

The response is either `SuccessResponse()` or `ErrorResponse()`.

Replaced By: `ServiceProviderServicePackMigrationTaskAddRequest21()` in AS data mode

**Attributes:**

|Name                                     |Type |Description                           |
|-----------------------------------------|-----|--------------------------------------|
|service_provider_id                      |str  |serviceProviderId                     |
|task_name                                |str  |taskName                              |
|start_timestamp                          |str  |startTimestamp                        |
|max_duration_hours                       |int  |maxDurationHours                      |
|send_report_email                        |bool |sendReportEmail                       |
|report_delivery_email_address            |str  |reportDeliveryEmailAddress *Optional* |
|abort_on_error                           |bool |abortOnError                          |
|abort_error_threshold                    |int  |abortErrorThreshold *Optional*        |
|report_all_users                         |bool |reportAllUsers                        |
|automatically_increment_service_quantity |bool |automaticallyIncrementServiceQuantity |
</div>


## `ServiceProviderServicePackMigrationTaskAddRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Create a service pack migration task.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                     |Type |Description                           |
|-----------------------------------------|-----|--------------------------------------|
|service_provider_id                      |str  |serviceProviderId                     |
|task_name                                |str  |taskName                              |
|start_timestamp                          |str  |startTimestamp                        |
|expire_after_num_hours                   |int  |expireAfterNumHours                   |
|max_duration_hours                       |int  |maxDurationHours                      |
|send_report_email                        |bool |sendReportEmail                       |
|report_delivery_email_address            |str  |reportDeliveryEmailAddress *Optional* |
|abort_on_error                           |bool |abortOnError                          |
|abort_error_threshold                    |int  |abortErrorThreshold *Optional*        |
|report_all_users                         |bool |reportAllUsers                        |
|automatically_increment_service_quantity |bool |automaticallyIncrementServiceQuantity |
</div>


## `ServiceProviderServicePackMigrationTaskCopyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Makes a copy of one or more existing service pack migration tasks.

A copied task can be edited with other commands and scheduled for future execution.
The name of the new task is chosen automatically.  The name will be "Copy (number) of
taskName".

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|service_provider_id |str       |serviceProviderId |
|task_name           |List[str] |taskName          |
</div>


## `ServiceProviderServicePackMigrationTaskDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Deletes a service pack migration task.

It is not possible to delete a task while it is currently executing.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|task_name           |str |taskName          |
</div>


## `ServiceProviderServicePackMigrationTaskGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests a list of all service pack migration task for a service provider.

The response is either `ServiceProviderServicePackMigrationTaskGetListResponse()` or
`ErrorResponse()`.

Replaced By: `ServiceProviderServicePackMigrationTaskGetListRequest21()` in AS data
mode

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderServicePackMigrationTaskGetListRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests a list of all service pack migration tasks for a service provider.

The response is either `ServiceProviderServicePackMigrationTaskGetListResponse21()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderServicePackMigrationTaskGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the details of a specified service pack migration task.

The response is either `ServiceProviderServicePackMigrationTaskGetResponse()` or
`ErrorResponse()`.

Replaced By: `ServiceProviderServicePackMigrationTaskGetRequest14sp4()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|task_name           |str |taskName          |
</div>


## `ServiceProviderServicePackMigrationTaskGetRequest14sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the details of a specified service pack migration task.

The response is either `ServiceProviderServicePackMigrationTaskGetResponse14sp4()` or
`ErrorResponse()`.

Replaced By: `ServiceProviderServicePackMigrationTaskGetRequest21()` in AS data mode

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|task_name           |str |taskName          |
</div>


## `ServiceProviderServicePackMigrationTaskGetRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the details of a specified service pack migration task.

The response is either `ServiceProviderServicePackMigrationTaskGetResponse21()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|task_name           |str |taskName          |
</div>


## `ServiceProviderServicePackMigrationTaskModifyGroupListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Replace the list of groups to be migrated for a specified service pack migration task.

Modification is only allowed prior to task execution.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type            |Description                 |
|--------------------|----------------|----------------------------|
|service_provider_id |str             |serviceProviderId           |
|task_name           |str             |taskName                    |
|migrate_all_groups  |bool            |migrateAllGroups *Optional* |
|group_id_list       |OCI.groupIdList |groupIdList *Optional*      |
</div>


## `ServiceProviderServicePackMigrationTaskModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the properties of a specified service pack migration task.

Modification is only allowed prior to task execution.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                     |Type |Description                                      |
|-----------------------------------------|-----|-------------------------------------------------|
|service_provider_id                      |str  |serviceProviderId                                |
|task_name                                |str  |taskName                                         |
|new_task_name                            |str  |newTaskName *Optional*                           |
|start_timestamp                          |str  |startTimestamp *Optional*                        |
|expire_after_num_hours                   |int  |expireAfterNumHours *Optional*                   |
|max_duration_hours                       |int  |maxDurationHours *Optional*                      |
|send_report_email                        |bool |sendReportEmail *Optional*                       |
|report_delivery_email_address            |str  |reportDeliveryEmailAddress *Optional*            |
|abort_on_error                           |bool |abortOnError *Optional*                          |
|abort_error_threshold                    |int  |abortErrorThreshold *Optional*                   |
|report_all_users                         |bool |reportAllUsers *Optional*                        |
|automatically_increment_service_quantity |bool |automaticallyIncrementServiceQuantity *Optional* |
</div>


## `ServiceProviderServicePackMigrationTaskTerminateRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Terminates a service pack migration task that is currently executing.

Modification is only allowed prior to task execution.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|task_name           |str |taskName          |
</div>


## `ServiceProviderServicePhoneNumberLookupRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Lookup if the given number is defined in the specified service in the service
provider.

The response is `ServiceProviderServicePhoneNumberLookupResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|service_type        |str |serviceType       |
|phone_number        |str |phoneNumber       |
</div>


## `ServiceProviderSessionAdmissionControlGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the session admission control capacity for the service provider.

The response is either a `ServiceProviderSessionAdmissionControlGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderSessionAdmissionControlModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify session admission control capacity for the service provider.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                  |Type |Description                                  |
|--------------------------------------|-----|---------------------------------------------|
|service_provider_id                   |str  |serviceProviderId                            |
|restrict_aggregate_sessions           |bool |restrictAggregateSessions *Optional*         |
|max_sessions                          |int  |maxSessions *Optional*                       |
|max_user_originating_sessions         |int  |maxUserOriginatingSessions *Optional*        |
|max_user_terminating_sessions         |int  |maxUserTerminatingSessions *Optional*        |
|count_intra_service_provider_sessions |bool |countIntraServiceProviderSessions *Optional* |
</div>


## `ServiceProviderSessionAdmissionControlWhiteListGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the Service Provider Session Admission White List information.

The response is either a
`ServiceProviderSessionAdmissionControlWhiteListGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderSessionAdmissionControlWhiteListModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Service Provider Session Admission Control White List information.

The number of digit pattern entries is limited to 100.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                       |Type      |Description                        |
|---------------------------|----------|-----------------------------------|
|service_provider_id        |str       |serviceProviderId                  |
|add_match_digit_pattern    |List[str] |addMatchDigitPattern *Optional*    |
|delete_match_digit_pattern |List[str] |deleteMatchDigitPattern *Optional* |
|enable_white_list          |bool      |enableWhiteList *Optional*         |
</div>


## `ServiceProviderStirShakenGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get service provider Stir Shaken service settings.

The response is either `ServiceProviderStirShakenGetResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderStirShakenModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify service provider Stir Shaken service settings.


**Attributes:**

|Name                                                   |Type |Description                                                 |
|-------------------------------------------------------|-----|------------------------------------------------------------|
|service_provider_id                                    |str  |serviceProviderId                                           |
|use_parent_level_settings                              |bool |useParentLevelSettings *Optional*                           |
|signing_policy                                         |str  |signingPolicy *Optional*                                    |
|tagging_policy                                         |str  |taggingPolicy *Optional*                                    |
|signing_service_url                                    |str  |signingServiceURL *Optional*                                |
|tag_from_or_pai                                        |str  |tagFromOrPAI *Optional*                                     |
|verstat_tag                                            |str  |verstatTag *Optional*                                       |
|use_os_value_for_orig_id                               |bool |useOSValueForOrigId *Optional*                              |
|orig_uuid                                              |str  |origUUID *Optional*                                         |
|attestation_level                                      |str  |attestationLevel *Optional*                                 |
|enable_verification                                    |bool |enableVerification *Optional*                               |
|verification_service_url                               |str  |verificationServiceURL *Optional*                           |
|verification_error_handling                            |str  |verificationErrorHandling *Optional*                        |
|proxy_verstat_to_cnam_subscribe                        |bool |proxyVerstatToCNAMSubscribe *Optional*                      |
|use_unknown_headers_from_cnam_notify                   |bool |useUnknownHeadersFromCNAMNotify *Optional*                  |
|enable_signing_for_unscreened_trunk_group_originations |bool |enableSigningForUnscreenedTrunkGroupOriginations *Optional* |
|enable_tagging_for_unscreened_trunk_group_originations |bool |enableTaggingForUnscreenedTrunkGroupOriginations *Optional* |
|unscreened_trunk_group_origination_attestation_level   |str  |unscreenedTrunkGroupOriginationAttestationLevel *Optional*  |
</div>


## `ServiceProviderTemplateOnlyDeviceFileGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of template files used to support a VDM device defined at
service provider level.

The response is either `ServiceProviderTemplateOnlyDeviceFileGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|device_name         |str |deviceName        |
</div>


## `ServiceProviderThirdPartyEmergencyCallingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the third-party emergency call service settings for the service provider.

The response is either a `ServiceProviderThirdPartyEmergencyCallingGetResponse()` or
an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderThirdPartyEmergencyCallingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the third-party emergency call service settings for the service provider.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type |Description                |
|--------------------|-----|---------------------------|
|service_provider_id |str  |serviceProviderId          |
|allow_activation    |bool |allowActivation *Optional* |
|customer_id         |str  |customerId *Optional*      |
</div>


## `ServiceProviderTrunkGroupGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the maximum permissible active Trunk Group calls for the service provider.

The response is either a `ServiceProviderTrunkGroupGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderTrunkGroupGetRequest14sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the maximum and bursting maximum permissible active Trunk Group calls for the
service provider.

The response is either a `ServiceProviderTrunkGroupGetResponse14sp1()` or an
`ErrorResponse()`. Deprecated by `ServiceProviderTrunkGroupGetRequest23()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderTrunkGroupGetRequest23`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the maximum and bursting maximum permissible active Trunk Group calls for the
service provider.

The response is either a `ServiceProviderTrunkGroupGetResponse23()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderVisualDeviceManagementGetDeviceInfoRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the information for a specified device supporting visual device management.

The response is either a
`ServiceProviderVisualDeviceManagementGetDeviceInfoResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|device_name         |str |deviceName        |
</div>


## `ServiceProviderVoiceMessagingGroupGetPasscodeRulesRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the service provider's voice portal passcode rules setting.

The response is either `ServiceProviderVoiceMessagingGroupGetPasscodeRulesResponse()`
or `ErrorResponse()`.

Replaced By: `ServiceProviderPortalPasscodeRulesGetRequest()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderVoiceMessagingGroupGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the service provider's or enterprise's voice messaging settings.

The response is either `ServiceProviderVoiceMessagingGroupGetResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderVoiceMessagingGroupGetVoicePortalBrandingRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the service provider's voice portal branding settings.

The response is either a
`ServiceProviderVoiceMessagingGroupGetVoicePortalBrandingResponse()` or an
`ErrorResponse()`.

Replaced By: `ServiceProviderVoiceMessagingGroupGetVoicePortalBrandingRequest16()`

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderVoiceMessagingGroupGetVoicePortalBrandingRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the service provider's voice portal branding settings.

The response is either a
`ServiceProviderVoiceMessagingGroupGetVoicePortalBrandingResponse16()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderVoiceMessagingGroupGetVoicePortalRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the service provider's or enterprise's voice portal settings.

The response is either `ServiceProviderVoiceMessagingGroupGetVoicePortalResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderVoiceMessagingGroupModifyPasscodeRulesRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the service provider's voice portal passcode rules setting.

The response is either `SuccessResponse()` or `ErrorResponse()`.

Replaced By: `ServiceProviderPortalPasscodeRulesModifyRequest()`

**Attributes:**

|Name                                          |Type |Description                                        |
|----------------------------------------------|-----|---------------------------------------------------|
|service_provider_id                           |str  |serviceProviderId                                  |
|disallow_repeated_digits                      |bool |disallowRepeatedDigits *Optional*                  |
|disallow_user_number                          |bool |disallowUserNumber *Optional*                      |
|disallow_reversed_user_number                 |bool |disallowReversedUserNumber *Optional*              |
|disallow_old_passcode                         |bool |disallowOldPasscode *Optional*                     |
|disallow_reversed_old_passcode                |bool |disallowReversedOldPasscode *Optional*             |
|min_code_length                               |int  |minCodeLength *Optional*                           |
|max_code_length                               |int  |maxCodeLength *Optional*                           |
|disable_login_after_max_failed_login_attempts |bool |disableLoginAfterMaxFailedLoginAttempts *Optional* |
|max_failed_login_attempts                     |int  |maxFailedLoginAttempts *Optional*                  |
|expire_password                               |bool |expirePassword *Optional*                          |
|passcode_expires_days                         |int  |passcodeExpiresDays *Optional*                     |
|send_login_disabled_notify_email              |bool |sendLoginDisabledNotifyEmail *Optional*            |
|login_disabled_notify_email_address           |str  |loginDisabledNotifyEmailAddress *Optional*         |
</div>


## `ServiceProviderVoiceMessagingGroupModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a service provider's or enterprise's voice messaging settings.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                                 |Type |Description                                              |
|-----------------------------------------------------|-----|---------------------------------------------------------|
|service_provider_id                                  |str  |serviceProviderId                                        |
|delivery_from_address                                |str  |deliveryFromAddress *Optional*                           |
|notification_from_address                            |str  |notificationFromAddress *Optional*                       |
|voice_portal_lockout_from_address                    |str  |voicePortalLockoutFromAddress *Optional*                 |
|use_system_default_delivery_from_address             |bool |useSystemDefaultDeliveryFromAddress *Optional*           |
|use_system_default_notification_from_address         |bool |useSystemDefaultNotificationFromAddress *Optional*       |
|use_system_default_voice_portal_lockout_from_address |bool |useSystemDefaultVoicePortalLockoutFromAddress *Optional* |
</div>


## `ServiceProviderVoiceMessagingGroupModifyVoicePortalRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to change the service provider's or enterprise's voice portal settings.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description                 |
|--------------------|----|----------------------------|
|service_provider_id |str |serviceProviderId           |
|voice_portal_scope  |str |voicePortalScope *Optional* |
</div>


## `ServiceProviderXsiPolicyProfileGetAssignedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of Xsi policy profile assigned.

The response is either a `ServiceProviderXsiPolicyProfileGetAssignedListResponse()` or
an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
|level               |str |level *Optional*  |
</div>


## `ServiceProviderXsiPolicyProfileModifyDefaultRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the default Xsi policy profile for a service provider.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                             |Type|Description                             |
|---------------------------------|----|----------------------------------------|
|service_provider_id              |str |serviceProviderId                       |
|group_default_xsi_policy_profile |str |groupDefaultXsiPolicyProfile *Optional* |
|user_default_xsi_policy_profile  |str |userDefaultXsiPolicyProfile *Optional*  |
</div>


## `ServiceProviderZoneCallingRestrictionsGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Gets the Service Provider/Enterprise level Zone Calling Restrictions Policies.

The response is `ServiceProviderZoneCallingRestrictionsGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|service_provider_id |str |serviceProviderId |
</div>


## `ServiceProviderZoneCallingRestrictionsModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the Service Provider/Enterprise level Zone Calling Restrictions Policies.

The response is `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                              |Type |Description                                              |
|--------------------------------------------------|-----|---------------------------------------------------------|
|service_provider_id                               |str  |serviceProviderId                                        |
|enable_zone_calling_restrictions                  |bool |enableZoneCallingRestrictions *Optional*                 |
|enable_origination_roaming_restrictions           |bool |enableOriginationRoamingRestrictions *Optional*          |
|enable_emergency_origination_roaming_restrictions |bool |enableEmergencyOriginationRoamingRestrictions *Optional* |
|enable_termination_roaming_restrictions           |bool |enableTerminationRoamingRestrictions *Optional*          |
</div>


## `SystemASRParametersGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of Application Server Registration system parameters.

The response is either `SystemASRParametersGetResponse()` or `ErrorResponse()`.

Replaced By: `SystemASRParametersGetRequest14sp5()`

</div>


## `SystemASRParametersGetRequest14sp5`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of Application Server Registration system parameters.

The response is either `SystemASRParametersGetResponse14sp5()` or `ErrorResponse()`.

</div>


## `SystemASRParametersGetRequest14sp7`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of Application Server Registration system parameters.

The response is either `SystemASRParametersGetResponse14sp7()` or `ErrorResponse()`.
Replaced by: `SystemASRParametersGetRequest23()` in AS data mode.

</div>


## `SystemASRParametersGetRequest23`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of Application Server Registration system parameters.

The response is either `SystemASRParametersGetResponse23()` or `ErrorResponse()`.

</div>


## `SystemASRParametersModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify Application Server Registration system parameters.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                               |Type|Description                                |
|-----------------------------------|----|-------------------------------------------|
|max_transmissions                  |int |maxTransmissions *Optional*                |
|retransmission_delay_milli_seconds |int |retransmissionDelayMilliSeconds *Optional* |
|listening_port                     |int |listeningPort *Optional*                   |
|source_address                     |str |sourceAddress *Optional*                   |
</div>


## `SystemASRParametersModifyRequest14sp7`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify Application Server Registration system parameters.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode:
enableCustomMessageControl customNumberOfUsersPerMessage
customMessageIntervalMilliseconds

**Attributes:**

|Name                                 |Type |Description                                  |
|-------------------------------------|-----|---------------------------------------------|
|max_transmissions                    |int  |maxTransmissions *Optional*                  |
|retransmission_delay_milli_seconds   |int  |retransmissionDelayMilliSeconds *Optional*   |
|listening_port                       |int  |listeningPort *Optional*                     |
|enable_custom_message_control        |bool |enableCustomMessageControl *Optional*        |
|custom_number_of_users_per_message   |int  |customNumberOfUsersPerMessage *Optional*     |
|custom_message_interval_milliseconds |int  |customMessageIntervalMilliseconds *Optional* |
</div>


## `SystemAccessDeviceCustomTagAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a static configuration tag for a system access device.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description         |
|------------|----|--------------------|
|device_name |str |deviceName          |
|tag_name    |str |tagName             |
|tag_value   |str |tagValue *Optional* |
</div>


## `SystemAccessDeviceCustomTagDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete static configuration tags for a system access device.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type      |Description|
|------------|----------|-----------|
|device_name |str       |deviceName |
|tag_name    |List[str] |tagName    |
</div>


## `SystemAccessDeviceCustomTagGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of custom configuration tags managed by the Device Management
System, on a per-device profile basis.

The response is either `SystemAccessDeviceCustomTagGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_name |str |deviceName |
</div>


## `SystemAccessDeviceCustomTagModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a static configuration tag for a system access device.

The following elements are only used in XS data mode and ignored in AS data mode:
tagValueToEncrypt

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                 |Type|Description                  |
|---------------------|----|-----------------------------|
|device_name          |str |deviceName                   |
|tag_name             |str |tagName                      |
|tag_value            |str |tagValue *Optional*          |
|tag_value_to_encrypt |str |tagValueToEncrypt *Optional* |
</div>


## `SystemAccessDeviceDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a specified system access device.

The following elements are only used in AS data mode and ignored in XS data mode:
deviceExternalId

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name               |Type|Description                 |
|-------------------|----|----------------------------|
|device_name        |str |deviceName *Optional*       |
|device_external_id |str |deviceExternalId *Optional* |
</div>


## `SystemAccessDeviceDeviceActivationGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the activation information for a device configured at System level.

Returns a `SystemAccessDeviceDeviceActivationGetResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_name |str |deviceName |
</div>


## `SystemAccessDeviceDeviceActivationModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Activates or deactivates a device configured at the System level.

It is only possible for this request to activate a device which is deactivated.
Trying to activate a device in the activating state will result in an error response
since only the DAS is allowed to execute this operation.  Returns a
`SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type |Description    |
|----------------|-----|---------------|
|device_name     |str  |deviceName     |
|activate_device |bool |activateDevice |
</div>


## `SystemAccessDeviceFileGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of device files managed by the Device Management System, on a
per-device profile basis.

The response is either `SystemAccessDeviceFileGetListResponse()` or `ErrorResponse()`.

Replaced By: `SystemAccessDeviceFileGetListRequest14sp8()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_name |str |deviceName |
</div>


## `SystemAccessDeviceFileGetListRequest14sp8`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of device files managed by the Device Management System, on a
per-device profile basis.

The response is either `SystemAccessDeviceFileGetListResponse14sp8()` or
`ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_name |str |deviceName |
</div>


## `SystemAccessDeviceFileGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a device profile file.

The response is either `SystemAccessDeviceFileGetResponse()` or `ErrorResponse()`.

Replaced By: `SystemAccessDeviceFileGetRequest14sp8()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_name |str |deviceName |
|file_type   |str |fileType   |
</div>


## `SystemAccessDeviceFileGetRequest14sp8`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a device profile file.

The response is either `SystemAccessDeviceFileGetResponse14sp8()` or
`ErrorResponse()`. Replaced by: `SystemAccessDeviceFileGetRequest16sp1()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_name |str |deviceName |
|file_format |str |fileFormat |
</div>


## `SystemAccessDeviceFileGetRequest16sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a device profile file.

The response is either `SystemAccessDeviceFileGetResponse16sp1()` or
`ErrorResponse()`. Replaced by: `SystemAccessDeviceFileGetRequest20()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_name |str |deviceName |
|file_format |str |fileFormat |
</div>


## `SystemAccessDeviceFileGetRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a device profile file.

The response is either `SystemAccessDeviceFileGetResponse20()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_name |str |deviceName |
|file_format |str |fileFormat |
</div>


## `SystemAccessDeviceGenerateActivationCodeRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests a new activation code for a device configured at the System level.

Returns a `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_name |str |deviceName |
</div>


## `SystemAccessDeviceGetAvailableCustomTagListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of all available custom tags managed by the Device Management System, on
a per-device profile basis.

The response is either `SystemAccessDeviceGetAvailableCustomTagListResponse()` or
`ErrorResponse()`. The following elements are used in AS mode and ignored in XS data
mode: tagSetName

**Attributes:**

|Name         |Type|Description           |
|-------------|----|----------------------|
|device_name  |str |deviceName            |
|tag_set_name |str |tagSetName *Optional* |
</div>


## `SystemAccessDeviceGetLinkedLeafDeviceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of linked leaf devices for the system level tree device passed in
the request.

A tree device is a device associated with a device type that has the option
supportLinks set to "Support Links from Devices". Many leaf devices can be linked to
it.  A leaf device is a device associated with a device type that has the option
supportLinks set to "Support Link to Device". It can be linked to only one tree
device.  The list includes devices created at the system, service provider, and group
levels.

The response is either `SystemAccessDeviceGetLinkedLeafDeviceListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_name |str |deviceName |
</div>


## `SystemAccessDeviceGetLinkedTreeDeviceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the tree device linked with the system level leaf device passed in the
request.

A tree device is a device associated with a device type that has the option
supportLinks set to "Support Links from Devices". Many leaf devices can be linked to
it.  A leaf device is a device associated with a device type that has the option
supportLinks set to "Support Link to Device". It can be linked to only one tree
device.

The response is either `SystemAccessDeviceGetLinkedTreeDeviceResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_name |str |deviceName |
</div>


## `SystemAccessDeviceGetNativeTagsWithLogicListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of all native tags with logic managed by the Device Management System, on
a per-device profile basis.

The response is either `SystemAccessDeviceGetNativeTagsWithLogicListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_name |str |deviceName |
</div>


## `SystemAccessDeviceGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the configuration of a specified system access device.

The response is either `SystemAccessDeviceGetResponse()` or `ErrorResponse()`.

Replaced By: `SystemAccessDeviceGetRequest14sp3()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_name |str |deviceName |
</div>


## `SystemAccessDeviceGetRequest14sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the configuration of a specified system access device.

The response is either `SystemAccessDeviceGetResponse14sp3()` or `ErrorResponse()`.

Replaced By: `SystemAccessDeviceGetRequest14sp6()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_name |str |deviceName |
</div>


## `SystemAccessDeviceGetRequest14sp6`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the configuration of a specified system access device.

The response is either `SystemAccessDeviceGetResponse14sp6()` or `ErrorResponse()`.
Replaced by: `SystemAccessDeviceGetRequest16()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_name |str |deviceName |
</div>


## `SystemAccessDeviceGetRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the configuration of a specified system access device.

The response is either `SystemAccessDeviceGetResponse16()` or `ErrorResponse()`.
Replaced by: `SystemAccessDeviceGetRequest19()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_name |str |deviceName |
</div>


## `SystemAccessDeviceGetRequest18sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the configuration of a specified system access device.

The response is either `SystemAccessDeviceGetResponse18sp1()` or `ErrorResponse()`.
Replaced by: `SystemAccessDeviceGetRequest22()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_name |str |deviceName |
</div>


## `SystemAccessDeviceGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the configuration of a specified system access device.

The response is either `SystemAccessDeviceGetResponse22()` or `ErrorResponse()`.
Replaced by: `SystemAccessDeviceGetRequest24()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_name |str |deviceName |
</div>


## `SystemAccessDeviceGetRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the configuration of a specified system access device.

The following elements are only used in AS data mode and ignored in XS data mode:
deviceExternalId

The response is either `SystemAccessDeviceGetResponse22V2()` or `ErrorResponse()`.

Replaced By: `SystemAccessDeviceGetRequest24()`

**Attributes:**

|Name               |Type|Description                 |
|-------------------|----|----------------------------|
|device_name        |str |deviceName *Optional*       |
|device_external_id |str |deviceExternalId *Optional* |
</div>


## `SystemAccessDeviceGetRequest22V3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the configuration of a specified system access device.

The following elements are only used in AS data mode and ignored in XS data mode:
deviceExternalId

The response is either `SystemAccessDeviceGetResponse22V3()` or `ErrorResponse()`.

Replaced By: `SystemAccessDeviceGetRequest24()`

**Attributes:**

|Name               |Type|Description                 |
|-------------------|----|----------------------------|
|device_name        |str |deviceName *Optional*       |
|device_external_id |str |deviceExternalId *Optional* |
</div>


## `SystemAccessDeviceGetRequest22V4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the configuration of a specified system access device.

The response is either `SystemAccessDeviceGetResponse22V4()` or `ErrorResponse()`. The
following elements are only used in AS data mode and ignored in XS data mode:
deviceExternalId Replaced by: `SystemAccessDeviceGetRequest24()`

**Attributes:**

|Name               |Type|Description                 |
|-------------------|----|----------------------------|
|device_name        |str |deviceName *Optional*       |
|device_external_id |str |deviceExternalId *Optional* |
</div>


## `SystemAccessDeviceGetRequest24`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the configuration of a specified system access device.

The following elements are only used in AS data mode and ignored in XS data mode:
deviceExternalId

The response is either `SystemAccessDeviceGetResponse24()` or `ErrorResponse()`.

**Attributes:**

|Name               |Type|Description                 |
|-------------------|----|----------------------------|
|device_name        |str |deviceName *Optional*       |
|device_external_id |str |deviceExternalId *Optional* |
</div>


## `SystemAccessDeviceModifyUserRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify attributes for line/ports assigned on the system device profile.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in XS data mode and ignored in AS data mode: privateIdentity

**Attributes:**

|Name                 |Type |Description                  |
|---------------------|-----|-----------------------------|
|device_name          |str  |deviceName                   |
|line_port            |str  |linePort                     |
|private_identity     |str  |privateIdentity *Optional*   |
|is_primary_line_port |bool |isPrimaryLinePort *Optional* |
</div>


## `SystemAccessDeviceMonitorAddDeviceTypeRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a device type to be monitored.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                 |Type |Description                  |
|---------------------|-----|-----------------------------|
|add_all_device_types |bool |addAllDeviceTypes *Optional* |
|device_type          |str  |deviceType *Optional*        |
</div>


## `SystemAccessDeviceMonitorDeleteDeviceTypeRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Remove a device type to be monitored.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                    |Type |Description                     |
|------------------------|-----|--------------------------------|
|delete_all_device_types |bool |deleteAllDeviceTypes *Optional* |
|device_type             |str  |deviceType *Optional*           |
</div>


## `SystemAccessDeviceMonitorGetDeviceTypeListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of monitored device types.

The response is either a `SystemAccessDeviceMonitorGetDeviceTypeListResponse()` or an
`ErrorResponse()`.

</div>


## `SystemAccessDeviceMonitorParametersGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of Access Device Monitor system parameters.

The response is either `SystemAccessDeviceMonitorParametersGetResponse()` or
`ErrorResponse()`.

</div>


## `SystemAccessDeviceMonitorParametersModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify Access Device Monitor system parameters.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                     |Type|Description                       |
|-------------------------|----|----------------------------------|
|polling_interval_minutes |int |pollingIntervalMinutes *Optional* |
</div>


## `SystemAccessDeviceResetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Reset a specific system SIP device that supports the reset operation.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_name |str |deviceName |
</div>


## `SystemAccessDeviceTagSetGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the custom configuration tag set defined at the access device.

The response is either `SystemAccessDeviceTagSetGetResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_name |str |deviceName |
</div>


## `SystemAccessDeviceTagSetModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a static configuration tag set.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type|Description           |
|-------------|----|----------------------|
|device_name  |str |deviceName            |
|tag_set_name |str |tagSetName *Optional* |
</div>


## `SystemAccessDeviceTypeGetEnhancedConfigurableListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of device types supporting enhanced configuration.

The response is either `SystemAccessDeviceTypeGetEnhancedConfigurableListResponse()`
or `ErrorResponse()`.

</div>


## `SystemAccessDeviceTypeGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of access device types.

The response is either `SystemAccessDeviceTypeGetListResponse()` or `ErrorResponse()`.

</div>


## `SystemAccountingAddChargingFunctionElementServerRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a ChargingFunctionElement Server to the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                    |Type |Description            |
|------------------------|-----|-----------------------|
|address                 |str  |address                |
|is_net_address_extended |bool |isNetAddressExtended   |
|type                    |str  |type                   |
|description             |str  |description *Optional* |
</div>


## `SystemAccountingAddRadiusServerRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a Radius Server to the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description            |
|------------|----|-----------------------|
|net_address |str |netAddress             |
|port        |int |port                   |
|description |str |description *Optional* |
</div>


## `SystemAccountingDeleteChargingFunctionElementServerRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a ChargingFunctionElementServer from the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|address |str |address    |
</div>


## `SystemAccountingDeleteRadiusServerRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a Radius Server from the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|net_address |str |netAddress |
|port        |int |port       |
</div>


## `SystemAccountingGetChargingFunctionElementServerListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a list of ChargingFunctionElementServers defined in the system.

The response is either a
`SystemAccountingGetChargingFunctionElementServerListResponse()` or an
`ErrorResponse()`.

</div>


## `SystemAccountingGetRadiusServerListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a list of Radius Servers defined in the system.

The response is either a `SystemAccountingGetRadiusServerListResponse()` or an
`ErrorResponse()`.

</div>


## `SystemAccountingInhibitedAttributeValuePairCodeAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add an Attribute Value Pair (AVP) combination to disable.

The AVP combination includes a diameter AVP and a vendor ID.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                      |Type|Description            |
|--------------------------|----|-----------------------|
|attribute_value_pair_code |int |attributeValuePairCode |
|vendor_id                 |int |vendorId               |
</div>


## `SystemAccountingInhibitedAttributeValuePairCodeDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Remove an Attribute Value Pair (AVP) combination from the list of disabled AVP codes.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                      |Type|Description            |
|--------------------------|----|-----------------------|
|attribute_value_pair_code |int |attributeValuePairCode |
|vendor_id                 |int |vendorId               |
</div>


## `SystemAccountingInhibitedAttributeValuePairCodeGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of Attribute Value Pair (AVP) combinations that are disabled.

The response is either a
`SystemAccountingInhibitedAttributeValuePairCodeGetListResponse()` or an
`ErrorResponse()`.

</div>


## `SystemAccountingModifyChargingFunctionElementServerRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a ChargingFunctionElementServer in the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description            |
|------------|----|-----------------------|
|address     |str |address                |
|type        |str |type *Optional*        |
|description |str |description *Optional* |
</div>


## `SystemAccountingModifyRadiusServerRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a Radius Server in the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description            |
|------------|----|-----------------------|
|net_address |str |netAddress             |
|port        |int |port                   |
|description |str |description *Optional* |
</div>


## `SystemAccountingReorderChargingFunctionElementServerRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Reorder the charging function element servers.

You can not add or delete addresses, only re-ordering the list is allowed.  The
ordered list of addresses can be obtained with the
`SystemAccountingGetChargingFunctionElementServerListRequest()` command.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                 |Type      |Description        |
|---------------------|----------|-------------------|
|ordered_address_list |List[str] |orderedAddressList |
</div>


## `SystemAdminAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a system or provisioning administrator.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name       |Type |Description          |
|-----------|-----|---------------------|
|user_id    |str  |userId               |
|first_name |str  |firstName *Optional* |
|last_name  |str  |lastName *Optional*  |
|password   |str  |password             |
|language   |str  |language *Optional*  |
|admin_type |str  |adminType            |
|read_only  |bool |readOnly             |
</div>


## `SystemAdminDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a system or provisioning administrator.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `SystemAdminGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of system administrators.

The response is either a `SystemAdminGetResponse()` or an `ErrorResponse()`.

</div>


## `SystemAdminGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a system or provisioning administrators profile.

The response is either a `SystemAdminGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `SystemAdminModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a system or provisioning administrator.

Since old password is not specified here, any password rule related to old password
does not apply.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name       |Type|Description          |
|-----------|----|---------------------|
|user_id    |str |userId               |
|first_name |str |firstName *Optional* |
|last_name  |str |lastName *Optional*  |
|password   |str |password *Optional*  |
|language   |str |language *Optional*  |
</div>


## `SystemAdviceOfChargeCostInformationSourceAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a cost information source.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|peer_identity |str |peerIdentity |
|priority      |int |priority     |
</div>


## `SystemAdviceOfChargeCostInformationSourceDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a cost information source.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|peer_identity |str |peerIdentity |
</div>


## `SystemAdviceOfChargeCostInformationSourceGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of cost information sources.

The response is either `SystemAdviceOfChargeCostInformationSourceGetListResponse()` or
`ErrorResponse()`.

</div>


## `SystemAdviceOfChargeCostInformationSourceModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a cost information source.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|peer_identity |str |peerIdentity |
|priority      |int |priority     |
</div>


## `SystemAdviceOfChargeGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of Advice of Charge system parameters.

The response is either `SystemAdviceOfChargeGetResponse()` or `ErrorResponse()`.
Replaced by: `SystemAdviceOfChargeGetRequest19sp1()`

</div>


## `SystemAdviceOfChargeGetRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of Advice of Charge system parameters.

The response is either `SystemAdviceOfChargeGetResponse19sp1()` or `ErrorResponse()`.

</div>


## `SystemAdviceOfChargeModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify Advice of Charge system parameters.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by:
`SystemAdviceOfChargeModifyRequest19sp1()`

**Attributes:**

|Name                               |Type|Description                                |
|-----------------------------------|----|-------------------------------------------|
|delay_between_notification_seconds |int |delayBetweenNotificationSeconds *Optional* |
|incoming_aoc_handling              |str |incomingAocHandling *Optional*             |
|cost_information_source            |str |costInformationSource *Optional*           |
</div>


## `SystemAdviceOfChargeModifyRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify Advice of Charge system parameters.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                               |Type |Description                                |
|-----------------------------------|-----|-------------------------------------------|
|delay_between_notification_seconds |int  |delayBetweenNotificationSeconds *Optional* |
|incoming_aoc_handling              |str  |incomingAocHandling *Optional*             |
|use_ocs_enquiry                    |bool |useOCSEnquiry *Optional*                   |
|ocs_enquiry_type                   |str  |OCSEnquiryType *Optional*                  |
</div>


## `SystemAliasAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a system-level Application Server alias to the system.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name              |Type|Description     |
|------------------|----|----------------|
|alias_net_address |str |aliasNetAddress |
</div>


## `SystemAliasDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a system-level Application Server alias from the system.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name              |Type|Description     |
|------------------|----|----------------|
|alias_net_address |str |aliasNetAddress |
</div>


## `SystemAliasGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of all system-level Application Server aliases.

The response is either `SystemAliasGetListResponse()` or `ErrorResponse()`.

</div>


## `SystemAnonymousCallRejectionGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get Anonymous Call Rejection system parameters.

The response is either a `SystemAnonymousCallRejectionGetResponse()` or an
`ErrorResponse()`.

</div>


## `SystemAnonymousCallRejectionModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a system Anonymous Call Rejection parameter.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                    |Type |Description                     |
|------------------------|-----|--------------------------------|
|pai_required            |bool |paiRequired *Optional*          |
|screen_only_local_calls |bool |screenOnlyLocalCalls *Optional* |
</div>


## `SystemApplicationControllerAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add an application controller, which is a server where remote application resides and
controls the Route Point.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name           |Type|Description  |
|---------------|----|-------------|
|name           |str |name         |
|subscriber_id  |str |subscriberId |
|channel_set_id |str |channelSetId |
</div>


## `SystemApplicationControllerDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete an application controller.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemApplicationControllerGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of application controllers that are configured for the system.

The response is either `SystemApplicationControllerGetListResponse()` or
`ErrorResponse()`.

</div>


## `SystemAuthenticationLockoutExportDataGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to export system wide authentication lockout data to a file.

All locked out device profiles, sip endpoints, and sip trunk groups are returned.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name      |Type|Description|
|----------|----|-----------|
|file_name |str |fileName   |
</div>


## `SystemAuthenticationLockoutSettingsGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the authentication lockout settings in the system.

The response is either a `SystemAuthenticationLockoutSettingsResponse()` or an
`ErrorResponse()`.

</div>


## `SystemAuthenticationLockoutSettingsModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the system level device password lockout settings The response is
either `SuccessResponse()` or `ErrorResponse()`.


**Attributes:**

|Name                         |Type |Description                          |
|-----------------------------|-----|-------------------------------------|
|counter_reset_interval_days  |int  |counterResetIntervalDays *Optional*  |
|counter_reset_hour           |int  |counterResetHour *Optional*          |
|counter_reset_minute         |int  |counterResetMinute *Optional*        |
|emergency_sip_bypass_allowed |bool |emergencySIPBypassAllowed *Optional* |
</div>


## `SystemAutomaticCallbackAddReleaseCauseListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Adds automatic callback release cause to the releaseCause attribute.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name          |Type      |Description             |
|--------------|----------|------------------------|
|release_cause |List[str] |releaseCause *Optional* |
</div>


## `SystemAutomaticCallbackDeleteReleaseCauseListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Deletes automatic callback release causes from the release cause attribute.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name          |Type      |Description             |
|--------------|----------|------------------------|
|release_cause |List[str] |releaseCause *Optional* |
</div>


## `SystemAutomaticCallbackGetReleaseCauseListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system's automatic callback attributes.

The response is either a `SystemAutomaticCallbackGetReleaseCauseListResponse()` or an
`ErrorResponse()`.

</div>


## `SystemAutomaticCallbackGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system's automatic callback attributes.

The response is either a `SystemAutomaticCallbackGetResponse()` or an
`ErrorResponse()`.

Replaced By: `SystemAutomaticCallbackGetRequest15()`

</div>


## `SystemAutomaticCallbackGetRequest15`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system's automatic callback attributes.

The response is either a `SystemAutomaticCallbackGetResponse15()` or an
`ErrorResponse()`.

Replaced By: `SystemAutomaticCallbackGetRequest15sp2()`

</div>


## `SystemAutomaticCallbackGetRequest15sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system's automatic callback attributes.

The response is either a `SystemAutomaticCallbackGetResponse15sp2()` or an
`ErrorResponse()`. Replaced by: `SystemAutomaticCallbackGetRequest17()`

</div>


## `SystemAutomaticCallbackGetRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system's automatic callback attributes.

The response is either a `SystemAutomaticCallbackGetResponse17()` or an
`ErrorResponse()`.

</div>


## `SystemAutomaticCallbackModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the system's automatic callback attributes.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

Replaced By: `SystemAutomaticCallbackModifyRequest15()`

**Attributes:**

|Name                                  |Type|Description                                  |
|--------------------------------------|----|---------------------------------------------|
|monitor_minutes                       |int |monitorMinutes *Optional*                    |
|wait_between_retry_originator_minutes |int |waitBetweenRetryOriginatorMinutes *Optional* |
|max_monitors_per_originator           |int |maxMonitorsPerOriginator *Optional*          |
|max_callback_rings                    |int |maxCallbackRings *Optional*                  |
|max_retry_originator_minutes          |int |maxRetryOriginatorMinutes *Optional*         |
</div>


## `SystemAutomaticCallbackModifyRequest15`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the system's automatic callback attributes.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                          |Type|Description                           |
|------------------------------|----|--------------------------------------|
|monitor_minutes               |int |monitorMinutes *Optional*             |
|max_monitors_per_originator   |int |maxMonitorsPerOriginator *Optional*   |
|max_callback_rings            |int |maxCallbackRings *Optional*           |
|max_monitors_per_terminator   |int |maxMonitorsPerTerminator *Optional*   |
|terminator_idle_guard_seconds |int |terminatorIdleGuardSeconds *Optional* |
|callback_method               |str |callbackMethod *Optional*             |
|polling_interval_seconds      |int |pollingIntervalSeconds *Optional*     |
|activation_digit              |int |activationDigit *Optional*            |
</div>


## `SystemAutomaticCollectCallGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get system Automatic Collect Call service settings.

The response is either `SystemAutomaticCollectCallGetResponse()` or `ErrorResponse()`.
Replaced by `SystemAutomaticCollectCallGetRequest()` in AS mode.

</div>


## `SystemAutomaticCollectCallGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get system Automatic Collect Call service settings.

The response is either `SystemAutomaticCollectCallGetResponse22()` or
`ErrorResponse()`.

</div>


## `SystemAutomaticCollectCallModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify system Automatic Collect Call service settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                          |Type |Description                           |
|------------------------------|-----|--------------------------------------|
|enable_automatic_collect_call |bool |enableAutomaticCollectCall *Optional* |
|enable_connect_tone           |bool |enableConnectTone *Optional*          |
|include_country_code_in_cic   |bool |includeCountryCodeInCic *Optional*    |
</div>


## `SystemAutomaticCollectCallPrefixDigitsGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the system automatic collect call prefix digits lists.

The response is either `SystemAutomaticCollectCallPrefixDigitsGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name         |Type|Description            |
|-------------|----|-----------------------|
|country_code |str |countryCode *Optional* |
</div>


## `SystemBCCTAddOCIInterfaceAddressRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add an OCI entry to the Broadworks Common Communication Transport (BCCT) protocol to
interface mapping table.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                  |Type|Description         |
|----------------------|----|--------------------|
|interface_net_address |str |interfaceNetAddress |
</div>


## `SystemBCCTDeleteOCIInterfaceAddressRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete an OCI entry in the Broadworks Common Communication Transport (BCCT) protocol
to interface mapping table.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                  |Type|Description         |
|----------------------|----|--------------------|
|interface_net_address |str |interfaceNetAddress |
</div>


## `SystemBCCTGetOCIInterfaceAddressListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the OCI entries from the Broadworks Common Communication Transport (BCCT) protocol
to interface mapping list.

The response is `SystemBCCTGetOCIInterfaceAddressListResponse()` or `ErrorResponse()`.

</div>


## `SystemBroadCloudGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the system interface attributes for Messaging Server/BroadCloud.

The response is either `SystemBroadCloudGetResponse()` or `ErrorResponse()`.

</div>


## `SystemBroadCloudModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system interface attributes for Messaging Server/BroadCloud.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type |Description                      |
|-----------------------|-----|---------------------------------|
|provisioning_url       |str  |provisioningUrl *Optional*       |
|provisioning_user_id   |str  |provisioningUserId *Optional*    |
|provisioning_password  |str  |provisioningPassword *Optional*  |
|enable_synchronization |bool |enableSynchronization *Optional* |
</div>


## `SystemBroadWorksAnywhereGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the Broadworks Anywhere system parameters.

The response is either a `SystemBroadWorksAnywhereGetResponse()` or an
`ErrorResponse()`.

</div>


## `SystemBroadWorksAnywhereModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the BroadWorks Anywhere system parameters.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                         |Type |Description                           |
|-----------------------------|-----|--------------------------------------|
|enable_transfer_notification |bool |enableTransferNotification *Optional* |
</div>


## `SystemBroadWorksMobileManagerGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the BroadWorks Mobile Manager service system settings.

The response is either `SystemBroadWorksMobileManagerGetResponse()` or
`ErrorResponse()`.

</div>


## `SystemBroadWorksMobileManagerModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the BroadWorks Mobile Manager service system settings.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                 |Type |Description                   |
|---------------------|-----|------------------------------|
|scf_api_net_address1 |str  |scfApiNetAddress1 *Optional*  |
|scf_api_net_address2 |str  |scfApiNetAddress2 *Optional*  |
|user_name            |str  |userName *Optional*           |
|password             |str  |password *Optional*           |
|email_from_address   |str  |emailFromAddress *Optional*   |
|scf_ims_only         |bool |scfIMSOnly *Optional*         |
|signaling_ip_address |str  |signalingIPAddress *Optional* |
|signaling_port       |int  |signalingPort *Optional*      |
</div>


## `SystemBroadWorksMobilityDeleteIMRNListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Removes a BroadWorks Mobility IMRN number from the system.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type      |Description|
|------------|----------|-----------|
|imrn_number |List[str] |imrnNumber |
</div>


## `SystemBroadWorksMobilityDeleteMobileNetworkIMRNListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Remove BroadWorks Mobility IMRN numbers from a Mobile Network.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description       |
|--------------------|----------|------------------|
|mobile_network_name |str       |mobileNetworkName |
|imrn_number         |List[str] |imrnNumber        |
</div>


## `SystemBroadWorksMobilityGeographicalPoolAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a geographical pool to the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type |Description            |
|-------------|-----|-----------------------|
|name         |str  |name                   |
|country_code |str  |countryCode            |
|is_default   |bool |isDefault              |
|description  |str  |description *Optional* |
</div>


## `SystemBroadWorksMobilityGeographicalPoolDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a geographical pool from the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemBroadWorksMobilityGeographicalPoolGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of geographical pools defined in the system.

If countryCode is set, return the IMRN pools associated with the country code.

The response is either `SystemBroadWorksMobilityGeographicalPoolGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name         |Type|Description            |
|-------------|----|-----------------------|
|country_code |str |countryCode *Optional* |
</div>


## `SystemBroadWorksMobilityGeographicalPoolIMRNDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Remove BroadWorks Mobility IMRN numbers from a geographical pool.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                   |Type      |Description          |
|-----------------------|----------|---------------------|
|geographical_pool_name |str       |geographicalPoolName |
|imrn_number            |List[str] |imrnNumber           |
</div>


## `SystemBroadWorksMobilityGeographicalPoolModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the settings of a geographical pool.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type |Description            |
|------------|-----|-----------------------|
|name        |str  |name                   |
|new_name    |str  |newName *Optional*     |
|is_default  |bool |isDefault *Optional*   |
|description |str  |description *Optional* |
</div>


## `SystemBroadWorksMobilityGeographicalPoolPrefixAddListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a list of geographical prefixes.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type      |Description          |
|-----------------------|----------|---------------------|
|geographical_pool_name |str       |geographicalPoolName |
|prefix                 |List[str] |prefix               |
</div>


## `SystemBroadWorksMobilityGeographicalPoolPrefixDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a list of geographical prefixes from a pool.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type      |Description          |
|-----------------------|----------|---------------------|
|geographical_pool_name |str       |geographicalPoolName |
|prefix                 |List[str] |prefix               |
</div>


## `SystemBroadWorksMobilityGeographicalPoolPrefixGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Gets a list of geographical prefixes belonging to a geographical pool.

The response is either
`SystemBroadWorksMobilityGeographicalPoolPrefixGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                   |Type|Description          |
|-----------------------|----|---------------------|
|geographical_pool_name |str |geographicalPoolName |
</div>


## `SystemBroadWorksMobilityGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the broadworks mobility system parameters.

The response is either a `SystemBroadWorksMobilityGetResponse()` or an
`ErrorResponse()`. Replaced by: `SystemBroadWorksMobilityGetRequest17sp4()`.

</div>


## `SystemBroadWorksMobilityGetRequest17sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the broadworks mobility system parameters.

The response is either a `SystemBroadWorksMobilityGetResponse17sp4()` or an
`ErrorResponse()`. Replaced by: `SystemBroadWorksMobilityGetRequest19sp1()`

</div>


## `SystemBroadWorksMobilityGetRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the broadworks mobility system parameters.

The response is either a `SystemBroadWorksMobilityGetResponse19sp1()` or an
`ErrorResponse()`. Replaced by `SystemBroadWorksMobilityGetRequest21()`

</div>


## `SystemBroadWorksMobilityGetRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the broadworks mobility system parameters.

The response is either a `SystemBroadWorksMobilityGetResponse21()` or an
`ErrorResponse()`. Replaced by: `SystemBroadWorksMobilityGetRequest22()` in AS data
mode

</div>


## `SystemBroadWorksMobilityGetRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the broadworks mobility system parameters.

The response is either a `SystemBroadWorksMobilityGetResponse21sp1()` or an
`ErrorResponse()`. Replaced by `SystemBroadWorksMobilityGetRequest22V2()`.

</div>


## `SystemBroadWorksMobilityGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the broadworks mobility system parameters.

The response is either a `SystemBroadWorksMobilityGetResponse22()` or an
`ErrorResponse()`. Replaced by `SystemBroadWorksMobilityGetRequest22V2()`.

</div>


## `SystemBroadWorksMobilityGetRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the broadworks mobility system parameters.

The response is either a `SystemBroadWorksMobilityGetResponse22V2()` or an
`ErrorResponse()`. Replaced by `SystemBroadWorksMobilityGetRequest22V3()`.

</div>


## `SystemBroadWorksMobilityGetRequest22V3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the broadworks mobility system parameters.

The response is either a `SystemBroadWorksMobilityGetResponse22V3()` or an
`ErrorResponse()`.

</div>


## `SystemBroadWorksMobilityMobileNetworkAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Mobile Network.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                |Type |Description                          |
|------------------------------------|-----|-------------------------------------|
|name                                |str  |name                                 |
|scf_signaling_net_address           |str  |scfSignalingNetAddress *Optional*    |
|scf_signaling_port                  |int  |scfSignalingPort *Optional*          |
|refresh_period_seconds              |int  |refreshPeriodSeconds                 |
|max_consecutive_failures            |int  |maxConsecutiveFailures               |
|max_response_wait_time_milliseconds |int  |maxResponseWaitTimeMilliseconds      |
|enable_announcement_suppression     |bool |enableAnnouncementSuppression        |
|service_access_code_list_name       |str  |serviceAccessCodeListName *Optional* |
</div>


## `SystemBroadWorksMobilityMobileNetworkDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Mobile Network.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemBroadWorksMobilityMobileNetworkGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of Mobile Networks.

The response is either `SystemBroadWorksMobilityMobileNetworkGetListResponse()` or
`ErrorResponse()`.

</div>


## `SystemBroadWorksMobilityMobileNetworkGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a Mobile Network.

The response is either `SystemBroadWorksMobilityMobileNetworkGetResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemBroadWorksMobilityMobileNetworkModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a Mobile Network.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                |Type |Description                                |
|------------------------------------|-----|-------------------------------------------|
|name                                |str  |name                                       |
|new_name                            |str  |newName *Optional*                         |
|scf_signaling_net_address           |str  |scfSignalingNetAddress *Optional*          |
|scf_signaling_port                  |int  |scfSignalingPort *Optional*                |
|refresh_period_seconds              |int  |refreshPeriodSeconds *Optional*            |
|max_consecutive_failures            |int  |maxConsecutiveFailures *Optional*          |
|max_response_wait_time_milliseconds |int  |maxResponseWaitTimeMilliseconds *Optional* |
|enable_announcement_suppression     |bool |enableAnnouncementSuppression *Optional*   |
|service_access_code_list_name       |str  |serviceAccessCodeListName *Optional*       |
</div>


## `SystemBroadWorksMobilityModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the BroadWorks Mobility system parameters.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`SystemBroadWorksMobilityModifyRequest17sp4()`.

**Attributes:**

|Name                         |Type |Description                          |
|-----------------------------|-----|-------------------------------------|
|enable_location_services     |bool |enableLocationServices *Optional*    |
|enable_msrn_lookup           |bool |enableMSRNLookup *Optional*          |
|enable_mobile_state_checking |bool |enableMobileStateChecking *Optional* |
|deny_call_originations       |bool |denyCallOriginations *Optional*      |
|deny_call_terminations       |bool |denyCallTerminations *Optional*      |
|imrn_timeout_milliseconds    |int  |imrnTimeoutMilliseconds *Optional*   |
|scf_signaling_ip_address     |str  |scfSignalingIPAddress *Optional*     |
|scf_signaling_port           |int  |scfSignalingPort *Optional*          |
</div>


## `SystemBroadWorksMobilityModifyRequest17sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the BroadWorks Mobility system parameters.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by
`SystemBroadWorksMobilityModifyRequest21()`.

**Attributes:**

|Name                                |Type |Description                                |
|------------------------------------|-----|-------------------------------------------|
|enable_location_services            |bool |enableLocationServices *Optional*          |
|enable_msrn_lookup                  |bool |enableMSRNLookup *Optional*                |
|enable_mobile_state_checking        |bool |enableMobileStateChecking *Optional*       |
|deny_call_originations              |bool |denyCallOriginations *Optional*            |
|deny_call_terminations              |bool |denyCallTerminations *Optional*            |
|imrn_timeout_milliseconds           |int  |imrnTimeoutMilliseconds *Optional*         |
|scf_signaling_net_address           |str  |scfSignalingNetAddress *Optional*          |
|scf_signaling_port                  |int  |scfSignalingPort *Optional*                |
|refresh_period_seconds              |int  |refreshPeriodSeconds *Optional*            |
|max_consecutive_failures            |int  |maxConsecutiveFailures *Optional*          |
|max_response_wait_time_milliseconds |int  |maxResponseWaitTimeMilliseconds *Optional* |
|enable_announcement_suppression     |bool |enableAnnouncementSuppression *Optional*   |
</div>


## `SystemBroadWorksMobilityModifyRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the BroadWorks Mobility system parameters.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                           |Type |Description                                          |
|-----------------------------------------------|-----|-----------------------------------------------------|
|enable_location_services                       |bool |enableLocationServices *Optional*                    |
|enable_msrn_lookup                             |bool |enableMSRNLookup *Optional*                          |
|enable_mobile_state_checking                   |bool |enableMobileStateChecking *Optional*                 |
|deny_call_originations                         |bool |denyCallOriginations *Optional*                      |
|deny_call_terminations                         |bool |denyCallTerminations *Optional*                      |
|imrn_timeout_milliseconds                      |int  |imrnTimeoutMilliseconds *Optional*                   |
|enable_internal_clid_delivery                  |bool |enableInternalCLIDDelivery *Optional*                |
|include_redirect_for_mobility_termination      |bool |includeRedirectForMobilityTermination *Optional*     |
|enable_internal_clid_delivery_access_locations |bool |enableInternalCLIDDeliveryAccessLocations *Optional* |
|enable_enhanced_unreachable_state_checking     |bool |enableEnhancedUnreachableStateChecking *Optional*    |
|enable_network_call_barring_status_check       |bool |enableNetworkCallBarringStatusCheck *Optional*       |
|network_translation_index                      |str  |networkTranslationIndex *Optional*                   |
</div>


## `SystemBroadWorksMobilityServiceAccessCodeAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a system service access code.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by
`SystemBroadWorksMobilityServiceAccessCodeAddRequest21()`.

**Attributes:**

|Name                |Type|Description            |
|--------------------|----|-----------------------|
|service_access_code |str |serviceAccessCode      |
|country_code        |str |countryCode            |
|description         |str |description *Optional* |
</div>


## `SystemBroadWorksMobilityServiceAccessCodeAddRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a service access code to a list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                          |Type|Description               |
|------------------------------|----|--------------------------|
|service_access_code_list_name |str |serviceAccessCodeListName |
|country_code                  |str |countryCode               |
|service_access_code           |str |serviceAccessCode         |
|description                   |str |description *Optional*    |
</div>


## `SystemBroadWorksMobilityServiceAccessCodeDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a system service access code.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by
`SystemBroadWorksMobilityServiceAccessCodeDeleteRequest21()`.

**Attributes:**

|Name                |Type|Description       |
|--------------------|----|------------------|
|country_code        |str |countryCode       |
|service_access_code |str |serviceAccessCode |
</div>


## `SystemBroadWorksMobilityServiceAccessCodeDeleteRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a service access code from a list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                          |Type|Description               |
|------------------------------|----|--------------------------|
|service_access_code_list_name |str |serviceAccessCodeListName |
|country_code                  |str |countryCode               |
|service_access_code           |str |serviceAccessCode         |
</div>


## `SystemBroadWorksMobilityServiceAccessCodeGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of system service access codes.

The response is either `SystemBroadWorksMobilityServiceAccessCodeGetListResponse()` or
`ErrorResponse()`. Replaced by
`SystemBroadWorksMobilityServiceAccessCodeGetListRequest21()`.

</div>


## `SystemBroadWorksMobilityServiceAccessCodeGetListRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of system service access codes.

The response is either `SystemBroadWorksMobilityServiceAccessCodeGetListResponse21()`
or `ErrorResponse()`.

**Attributes:**

|Name                          |Type|Description               |
|------------------------------|----|--------------------------|
|service_access_code_list_name |str |serviceAccessCodeListName |
</div>


## `SystemBroadWorksMobilityServiceAccessCodeListAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Service Access Code list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemBroadWorksMobilityServiceAccessCodeListDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Service Access Code list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemBroadWorksMobilityServiceAccessCodeListGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of Service Access Code lists.

The response is either
`SystemBroadWorksMobilityServiceAccessCodeListGetListResponse()` or `ErrorResponse()`.

</div>


## `SystemBroadWorksMobilityServiceAccessCodeListModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a Service Access Code list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name     |Type|Description        |
|---------|----|-------------------|
|name     |str |name               |
|new_name |str |newName *Optional* |
</div>


## `SystemBroadWorksMobilityServiceAccessCodeListUsageGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get all the Mobile Networks using a given Service Access Code list.

The response is either
`SystemBroadWorksMobilityServiceAccessCodeListUsageGetResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                          |Type|Description               |
|------------------------------|----|--------------------------|
|service_access_code_list_name |str |serviceAccessCodeListName |
</div>


## `SystemBroadWorksMobilityServiceAccessCodeModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a system service access code.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by
`SystemBroadWorksMobilityServiceAccessCodeModifyRequest21()`.

**Attributes:**

|Name                |Type|Description            |
|--------------------|----|-----------------------|
|country_code        |str |countryCode            |
|service_access_code |str |serviceAccessCode      |
|description         |str |description *Optional* |
</div>


## `SystemBroadWorksMobilityServiceAccessCodeModifyRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a service access code.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                          |Type|Description               |
|------------------------------|----|--------------------------|
|service_access_code_list_name |str |serviceAccessCodeListName |
|country_code                  |str |countryCode               |
|service_access_code           |str |serviceAccessCode         |
|description                   |str |description *Optional*    |
</div>


## `SystemBroadWorksReceptionistEnterpriseGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of BroadWorks Receptionist - Enterprise parameters.

The response is either `SystemBroadWorksReceptionistEnterpriseGetResponse()` or
`ErrorResponse()`.

</div>


## `SystemBroadWorksReceptionistEnterpriseModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify BroadWorks Receptionist - Enterprise settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description                  |
|--------------------|----|-----------------------------|
|max_monitored_users |int |maxMonitoredUsers *Optional* |
</div>


## `SystemBusyLampFieldGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with the Busy Lamp Field service.

The response is either a `SystemBusyLampFieldGetResponse()` or an `ErrorResponse()`.

</div>


## `SystemBusyLampFieldGetRequest18`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with the Busy Lamp Field service.

The response is either a `SystemBusyLampFieldGetResponse18()` or an `ErrorResponse()`.
Replaced by: `SystemBusyLampFieldGetRequest23()` in AS data mode.

</div>


## `SystemBusyLampFieldGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with the Busy Lamp Field service.

The response is either a `SystemBusyLampFieldGetResponse22()` or an `ErrorResponse()`.
Replaced by: `SystemBusyLampFieldGetRequest23V2()` in AS data mode.

</div>


## `SystemBusyLampFieldGetRequest23`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with the Busy Lamp Field service.

The response is either a `SystemBusyLampFieldGetResponse23()` or an `ErrorResponse()`.
Replaced by: `SystemBusyLampFieldGetRequest23V2()` in AS data mode.

</div>


## `SystemBusyLampFieldGetRequest23V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with the Busy Lamp Field service.

The response is either a `SystemBusyLampFieldGetResponse23V2()` or an
`ErrorResponse()`.

</div>


## `SystemBusyLampFieldModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with the Busy Lamp Field Service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode: forceUseOfTCP The following elements are only
used in AS data mode and ignored in Amplify and XS data mode: enableRedundancy
redundancyTaskDelayMilliseconds redundancyTaskIntervalMilliseconds
maxNumberOfSubscriptionsPerRedundancyTaskInterval The following elements are only used
in AS data mode and ignored in XS data mode: ignoreUnansweredTerminatingCalls

**Attributes:**

|Name                                                     |Type |Description                                                  |
|---------------------------------------------------------|-----|-------------------------------------------------------------|
|display_local_user_identity_last_name_first              |bool |displayLocalUserIdentityLastNameFirst *Optional*             |
|force_use_of_tcp                                         |bool |forceUseOfTCP *Optional*                                     |
|enable_redundancy                                        |bool |enableRedundancy *Optional*                                  |
|redundancy_task_delay_milliseconds                       |int  |redundancyTaskDelayMilliseconds *Optional*                   |
|redundancy_task_interval_milliseconds                    |int  |redundancyTaskIntervalMilliseconds *Optional*                |
|max_number_of_subscriptions_per_redundancy_task_interval |int  |maxNumberOfSubscriptionsPerRedundancyTaskInterval *Optional* |
|ignore_unanswered_terminating_calls                      |bool |ignoreUnansweredTerminatingCalls *Optional*                  |
</div>


## `SystemBwDiameterBaseDataGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of System Diameter base parameters.

The response is either `SystemBwDiameterBaseDataGetResponse()` or `ErrorResponse()`.

</div>


## `SystemBwDiameterBaseDataGetRequest17sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of System Diameter base parameters.

The response is either `SystemBwDiameterBaseDataGetResponse17sp3()` or
`ErrorResponse()`.

</div>


## `SystemBwDiameterBaseDataGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of System Diameter base parameters.

The response is either `SystemBwDiameterBaseDataGetResponse22()` or `ErrorResponse()`.

</div>


## `SystemBwDiameterBaseDataModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the System Diameter base parameters.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                      |Type |Description                                     |
|------------------------------------------|-----|------------------------------------------------|
|xs_realm                                  |str  |xsRealm *Optional*                              |
|xs_listening_port                         |int  |xsListeningPort *Optional*                      |
|xs_listening_port_enabled                 |bool |xsListeningPortEnabled *Optional*               |
|xs_listening_secure_port                  |int  |xsListeningSecurePort *Optional*                |
|xs_listening_secure_port_enabled          |bool |xsListeningSecurePortEnabled *Optional*         |
|ps_realm                                  |str  |psRealm *Optional*                              |
|ps_listening_port                         |int  |psListeningPort *Optional*                      |
|ps_listening_port_enabled                 |bool |psListeningPortEnabled *Optional*               |
|ps_listening_secure_port                  |int  |psListeningSecurePort *Optional*                |
|ps_listening_secure_port_enabled          |bool |psListeningSecurePortEnabled *Optional*         |
|ps_relay_through_xs                       |bool |psRelayThroughXs *Optional*                     |
|xs_relay_listening_port                   |int  |xsRelayListeningPort *Optional*                 |
|tc_timer_seconds                          |int  |tcTimerSeconds *Optional*                       |
|tw_timer_seconds                          |int  |twTimerSeconds *Optional*                       |
|request_timer_seconds                     |int  |requestTimerSeconds *Optional*                  |
|busy_peer_detection_outstanding_txn_count |int  |busyPeerDetectionOutstandingTxnCount *Optional* |
|busy_peer_restore_outstanding_txn_count   |int  |busyPeerRestoreOutstandingTxnCount *Optional*   |
|dynamic_entry_inactivity_timer_hours      |int  |dynamicEntryInactivityTimerHours *Optional*     |
|advertised_offline_billing_application    |str  |advertisedOfflineBillingApplication *Optional*  |
|advertised_online_billing_application     |str  |advertisedOnlineBillingApplication *Optional*   |
|default_port                              |int  |defaultPort *Optional*                          |
|default_secure_port                       |int  |defaultSecurePort *Optional*                    |
|peer_discovery_mode                       |str  |peerDiscoveryMode *Optional*                    |
</div>


## `SystemBwDiameterPeerAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a static entry in the Diameter Peer Table.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name       |Type |Description          |
|-----------|-----|---------------------|
|instance   |str  |instance             |
|identity   |str  |identity             |
|ip_address |str  |ipAddress *Optional* |
|port       |int  |port                 |
|enabled    |bool |enabled              |
</div>


## `SystemBwDiameterPeerAddRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a static entry in the Diameter Peer Table.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name       |Type |Description          |
|-----------|-----|---------------------|
|instance   |str  |instance             |
|identity   |str  |identity             |
|ip_address |str  |ipAddress *Optional* |
|port       |int  |port                 |
|enabled    |bool |enabled              |
|secure     |bool |secure               |
</div>


## `SystemBwDiameterPeerDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Remove a Diameter peer.

A peer cannot be removed if is referenced by a Realm Routing Table entry.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name     |Type|Description|
|---------|----|-----------|
|instance |str |instance   |
|identity |str |identity   |
</div>


## `SystemBwDiameterPeerGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of Diameter peers.

The response is either `SystemBwDiameterPeerGetListResponse22()` or `ErrorResponse()`

</div>


## `SystemBwDiameterPeerModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the attributes of an entry in the Diameter Peer Table.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name       |Type |Description          |
|-----------|-----|---------------------|
|instance   |str  |instance             |
|identity   |str  |identity             |
|ip_address |str  |ipAddress *Optional* |
|port       |int  |port *Optional*      |
|enabled    |bool |enabled *Optional*   |
|secure     |bool |secure *Optional*    |
</div>


## `SystemBwDiameterRoutingPeerAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Diameter routing peer.

The realm must refer to a Diameter routing realm whose action is relay.  The
destinationPeerIdentity must refer to an existing Diameter peer whose mode is active.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name           |Type|Description   |
|---------------|----|--------------|
|instance       |str |instance      |
|realm          |str |realm         |
|application_id |str |applicationId |
|identity       |str |identity      |
|priority       |int |priority      |
|weight         |int |weight        |
</div>


## `SystemBwDiameterRoutingPeerDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Remove a Diameter routing peer.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name           |Type|Description   |
|---------------|----|--------------|
|instance       |str |instance      |
|realm          |str |realm         |
|application_id |str |applicationId |
|identity       |str |identity      |
</div>


## `SystemBwDiameterRoutingPeerGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of Diameter routing peers associated with the specified realm.

The response is either `SystemBwDiameterRoutingPeerGetListResponse()` or
`ErrorResponse()`.

</div>


## `SystemBwDiameterRoutingPeerModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a Diameter routing peer.

The realm must refer to a Diameter routing realm whose action is relay.  The
destinationPeerIdentity must refer to an existing Diameter peer whose mode is active.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name           |Type|Description         |
|---------------|----|--------------------|
|instance       |str |instance            |
|realm          |str |realm               |
|application_id |str |applicationId       |
|identity       |str |identity            |
|priority       |int |priority *Optional* |
|weight         |int |weight *Optional*   |
</div>


## `SystemBwDiameterRoutingRealmAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a static entry in the Realm Routing Table.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name           |Type |Description   |
|---------------|-----|--------------|
|instance       |str  |instance      |
|realm          |str  |realm         |
|application_id |str  |applicationId |
|default        |bool |default       |
</div>


## `SystemBwDiameterRoutingRealmDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a static entry in the Realm Routing Table.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name           |Type|Description   |
|---------------|----|--------------|
|instance       |str |instance      |
|realm          |str |realm         |
|application_id |str |applicationId |
</div>


## `SystemBwDiameterRoutingRealmGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of Diameter routing realms.

The response is either `SystemBwDiameterRoutingRealmGetListResponse()` or
`ErrorResponse()`.

</div>


## `SystemBwDiameterRoutingRealmModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a static entry in the Realm Routing Table.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name           |Type |Description        |
|---------------|-----|-------------------|
|instance       |str  |instance           |
|realm          |str  |realm              |
|application_id |str  |applicationId      |
|default        |bool |default *Optional* |
</div>


## `SystemCLIDDeliveryPrefixAddListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add one or more prefixes to the list of prefixes to be matched.

Matched prefixes will result in CLID delivery for Korea.  Prefix 00X must be sent
using uppercase X.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name   |Type      |Description|
|-------|----------|-----------|
|prefix |List[str] |prefix     |
</div>


## `SystemCLIDDeliveryPrefixDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete one or more prefixes from the system.

Prefix 00X must be sent using uppercase X.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name   |Type      |Description|
|-------|----------|-----------|
|prefix |List[str] |prefix     |
</div>


## `SystemCLIDDeliveryPrefixGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of provisioned prefixes in the system.

The response is either a `SystemCLIDDeliveryPrefixGetListResponse()` or an
`ErrorResponse()`.

</div>


## `SystemCPEConfigAddFileServerRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a device CPE config file server.

The response is either `SuccessResponse()` or `ErrorResponse()`.

Replaced By: `SystemCPEConfigAddFileServerRequest14sp6()`

**Attributes:**

|Name                 |Type |Description                 |
|---------------------|-----|----------------------------|
|device_type          |str  |deviceType                  |
|ftp_host_net_address |str  |ftpHostNetAddress           |
|ftp_user_id          |str  |ftpUserId                   |
|ftp_user_password    |str  |ftpUserPassword             |
|cpe_file_directory   |str  |cpeFileDirectory *Optional* |
|passive_ftp          |bool |passiveFTP *Optional*       |
</div>


## `SystemCPEConfigAddFileServerRequest14sp6`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a device CPE config file server.

The following elements are only used in AS data mode:
extendedCaptureFileRepositoryName

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                  |Type|Description                                  |
|--------------------------------------|----|---------------------------------------------|
|device_type                           |str |deviceType                                   |
|file_repository_name                  |str |fileRepositoryName                           |
|cpe_file_directory                    |str |cpeFileDirectory *Optional*                  |
|extended_capture_file_repository_name |str |extendedCaptureFileRepositoryName *Optional* |
</div>


## `SystemCPEConfigDeleteFileServerRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a device CPE config file server.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemCPEConfigGetFileServerListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of device CPE config file servers.

The response is either `SystemCPEConfigGetFileServerListResponse()` or
`ErrorResponse()`.

Replaced By: `SystemCPEConfigGetFileServerListRequest14sp6()`

</div>


## `SystemCPEConfigGetFileServerListRequest14sp6`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of device CPE config file servers.

The response is either `SystemCPEConfigGetFileServerListResponse14sp6()` or
`ErrorResponse()`.

</div>


## `SystemCPEConfigModifyFileServerRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a device CPE config file server.

The response is either `SuccessResponse()` or `ErrorResponse()`.

Replaced By: `SystemCPEConfigModifyFileServerRequest14sp6()`

**Attributes:**

|Name                 |Type |Description                  |
|---------------------|-----|-----------------------------|
|device_type          |str  |deviceType                   |
|ftp_host_net_address |str  |ftpHostNetAddress *Optional* |
|ftp_user_id          |str  |ftpUserId *Optional*         |
|ftp_user_password    |str  |ftpUserPassword *Optional*   |
|cpe_file_directory   |str  |cpeFileDirectory *Optional*  |
|passive_ftp          |bool |passiveFTP *Optional*        |
</div>


## `SystemCPEConfigModifyFileServerRequest14sp6`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a device CPE config file server.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                  |Type|Description                                  |
|--------------------------------------|----|---------------------------------------------|
|device_type                           |str |deviceType                                   |
|file_repository_name                  |str |fileRepositoryName *Optional*                |
|cpe_file_directory                    |str |cpeFileDirectory *Optional*                  |
|extended_capture_file_repository_name |str |extendedCaptureFileRepositoryName *Optional* |
</div>


## `SystemCPEConfigParametersGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of CPE Config system parameters.

The response is either `SystemCPEConfigParametersGetResponse()` or `ErrorResponse()`.

Replaced By: `SystemCPEConfigParametersGetRequest14sp6()`

</div>


## `SystemCPEConfigParametersGetRequest14sp6`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of CPE Config system parameters.

The response is either `SystemCPEConfigParametersGetResponse14sp6()` or
`ErrorResponse()`. Replaced by: `SystemCPEConfigParametersGetRequest20()`

</div>


## `SystemCPEConfigParametersGetRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of CPE Config system parameters.

The response is either `SystemCPEConfigParametersGetResponse20()` or
`ErrorResponse()`. Replaced by: `SystemCPEConfigParametersGetRequest21()`

</div>


## `SystemCPEConfigParametersGetRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of CPE Config system parameters.

The response is either `SystemCPEConfigParametersGetResponse21()` or
`ErrorResponse()`.

</div>


## `SystemCPEConfigParametersModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify CPE Config system parameters.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by:
`SystemCPEConfigParametersModifyRequest20()`.

**Attributes:**

|Name                                    |Type                     |Description                                    |
|----------------------------------------|-------------------------|-----------------------------------------------|
|enable_ip_device_management             |bool                     |enableIPDeviceManagement *Optional*            |
|ftp_connect_timeout_seconds             |int                      |ftpConnectTimeoutSeconds *Optional*            |
|ftp_file_transfer_timeout_seconds       |int                      |ftpFileTransferTimeoutSeconds *Optional*       |
|pause_between_file_rebuild_milliseconds |int                      |pauseBetweenFileRebuildMilliseconds *Optional* |
|max_busy_time_minutes                   |int                      |maxBusyTimeMinutes *Optional*                  |
|device_access_app_server_cluster_name   |str                      |deviceAccessAppServerClusterName *Optional*    |
|file_rebuild_immediate                  |OCI.fileRebuildImmediate |fileRebuildImmediate *Optional*                |
|file_rebuild_daily                      |OCI.fileRebuildDaily     |fileRebuildDaily *Optional*                    |
|file_rebuild_hourly                     |OCI.fileRebuildHourly    |fileRebuildHourly *Optional*                   |
</div>


## `SystemCPEConfigParametersModifyRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify CPE Config system parameters.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by:
`SystemCPEConfigParametersModifyRequest21()`

**Attributes:**

|Name                                    |Type |Description                                    |
|----------------------------------------|-----|-----------------------------------------------|
|enable_ip_device_management             |bool |enableIPDeviceManagement *Optional*            |
|ftp_connect_timeout_seconds             |int  |ftpConnectTimeoutSeconds *Optional*            |
|ftp_file_transfer_timeout_seconds       |int  |ftpFileTransferTimeoutSeconds *Optional*       |
|pause_between_file_rebuild_milliseconds |int  |pauseBetweenFileRebuildMilliseconds *Optional* |
|max_busy_time_minutes                   |int  |maxBusyTimeMinutes *Optional*                  |
|device_access_app_server_cluster_name   |str  |deviceAccessAppServerClusterName *Optional*    |
</div>


## `SystemCPEConfigParametersModifyRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify CPE Config system parameters.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in the AS data mode and ignored in the XS data mode:
allowDeviceCredentialsRetrieval

**Attributes:**

|Name                                    |Type |Description                                    |
|----------------------------------------|-----|-----------------------------------------------|
|enable_ip_device_management             |bool |enableIPDeviceManagement *Optional*            |
|ftp_connect_timeout_seconds             |int  |ftpConnectTimeoutSeconds *Optional*            |
|ftp_file_transfer_timeout_seconds       |int  |ftpFileTransferTimeoutSeconds *Optional*       |
|pause_between_file_rebuild_milliseconds |int  |pauseBetweenFileRebuildMilliseconds *Optional* |
|device_access_app_server_cluster_name   |str  |deviceAccessAppServerClusterName *Optional*    |
|min_time_between_reset_milliseconds     |int  |minTimeBetweenResetMilliseconds *Optional*     |
|always_push_files_on_rebuild            |bool |alwaysPushFilesOnRebuild *Optional*            |
|max_file_operation_retry_attempts       |int  |maxFileOperationRetryAttempts *Optional*       |
|enable_auto_rebuild_config              |bool |enableAutoRebuildConfig *Optional*             |
|event_queue_size                        |int  |eventQueueSize *Optional*                      |
|allow_device_credentials_retrieval      |bool |allowDeviceCredentialsRetrieval *Optional*     |
</div>


## `SystemCPEConfigRebuildConfigFileRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Rebuild the system default config file for the specified device type.

If the device type is not specified, all files for all device types in the system are
rebuilt.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type |Description            |
|-------------|-----|-----------------------|
|device_type  |str  |deviceType *Optional*  |
|rebuild_type |str  |rebuildType *Optional* |
|force        |bool |force *Optional*       |
</div>


## `SystemCPEConfigRebuildDeviceConfigFileRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Rebuild the config file for a specified device.

The following elements are only used in AS data mode: force

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type |Description      |
|------------|-----|-----------------|
|device_name |str  |deviceName       |
|force       |bool |force *Optional* |
</div>


## `SystemCPEConfigReorderDeviceLinePortsRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Reorder the lines of a System device.

You can not add or delete line ports, only re-ordering the list is allowed.  The
ordered list of line ports can be obtained with the `SystemAccessDeviceGetRequest16()`
command.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type      |Description         |
|-----------------------|----------|--------------------|
|device_name            |str       |deviceName          |
|ordered_line_port_list |List[str] |orderedLinePortList |
</div>


## `SystemCPEConfigResetDeviceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Reset a specific system device.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_name |str |deviceName |
</div>


## `SystemCPEConfigResetDeviceTypeRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Reset all the devices of the specified device type in the system.

If the device type is not specified, all device in the system are reset.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description           |
|------------|----|----------------------|
|device_type |str |deviceType *Optional* |
</div>


## `SystemCPEConfigSetConfigFileRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to set a new system default configuration file for a device type.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
|config_file |str |configFile |
</div>


## `SystemCallCenterEnhancedReportingBrandingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the system branding information.

The response is either `SystemCallCenterEnhancedReportingBrandingGetResponse()` or
`ErrorResponse()`.

</div>


## `SystemCallCenterEnhancedReportingDataTemplateGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of data template and the corresponding information in the
system.

The response is either a
`SystemCallCenterEnhancedReportingDataTemplateGetListResponse()` or an
`ErrorResponse()`.

</div>


## `SystemCallCenterEnhancedReportingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the call center enhanced reporting system settings.

The response is either a `SystemCallCenterEnhancedReportingGetResponse()` or an
`ErrorResponse()`.

</div>


## `SystemCallCenterEnhancedReportingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system settings for call center enhanced reporting.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                       |Type |Description                         |
|---------------------------|-----|------------------------------------|
|archive_reports            |bool |archiveReports *Optional*           |
|report_application_url     |str  |reportApplicationURL *Optional*     |
|repository_application_url |str  |repositoryApplicationURL *Optional* |
</div>


## `SystemCallCenterEnhancedReportingReportTemplateDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a system level call center report template.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemCallCenterEnhancedReportingReportTemplateGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get system level call center report template list.

The response is either a
`SystemCallCenterEnhancedReportingReportTemplateGetListResponse()` or an
`ErrorResponse()`.

</div>


## `SystemCallCenterEnhancedReportingReportTemplateGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a system level call center report template.

The response is either a
`SystemCallCenterEnhancedReportingReportTemplateGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemCallCenterEnhancedReportingScheduledReportGetReportTemplateUsageListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the call center reporting scheduled report in the system that uses
a given system level report template.

The response is either a
`SystemCallCenterEnhancedReportingScheduledReportGetReportTemplateUsageListResponse()`
or an `ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemCallCenterEnhancedReportingScheduledTaskParametersGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the system settings for the call center enhanced reporting scheduling
tasks.

The response is either a
`SystemCallCenterEnhancedReportingScheduledTaskParametersGetResponse()` or an
`ErrorResponse()`. Replaced by:
`SystemCallCenterEnhancedReportingScheduledTaskParametersGetRequest22()`

</div>


## `SystemCallCenterEnhancedReportingScheduledTaskParametersGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the system settings for the call center enhanced reporting scheduling
tasks.

The response is either a
`SystemCallCenterEnhancedReportingScheduledTaskParametersGetResponse22()` or an
`ErrorResponse()`.

</div>


## `SystemCallCenterEnhancedReportingScheduledTaskParametersModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system settings for the call center enhanced reporting scheduling tasks.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode: callCenterEventMode, value “Legacy ECCR" is
returned in Amplify data mode

**Attributes:**

|Name                                          |Type|Description                                         |
|----------------------------------------------|----|----------------------------------------------------|
|scheduled_report_search_interval_minutes      |int |scheduledReportSearchIntervalMinutes *Optional*     |
|maximum_scheduled_reports_per_interval        |int |maximumScheduledReportsPerInterval *Optional*       |
|delete_scheduled_report_days_after_completion |int |deleteScheduledReportDaysAfterCompletion *Optional* |
|call_center_event_mode                        |str |callCenterEventMode *Optional*                      |
</div>


## `SystemCallCenterEventRecordingFileParametersGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of Call Center Event Recording File system parameters.

The response is either `SystemCallCenterEventRecordingFileParametersGetResponse()` or
`ErrorResponse()`.

</div>


## `SystemCallCenterEventRecordingFileParametersModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify Call Center Event Recording File system parameters.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                         |Type|Description                          |
|-----------------------------|----|-------------------------------------|
|file_retention_time_days     |int |fileRetentionTimeDays *Optional*     |
|file_rotation_period_minutes |str |fileRotationPeriodMinutes *Optional* |
|file_rotation_offset_minutes |int |fileRotationOffsetMinutes *Optional* |
|remote_url                   |str |remoteUrl *Optional*                 |
|remote_user_id               |str |remoteUserId *Optional*              |
|remote_password              |str |remotePassword *Optional*            |
</div>


## `SystemCallCenterGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Call Center.

The response is either a `SystemCallCenterGetResponse()` or an `ErrorResponse()`.

Replaced By: `SystemCallCenterGetRequest14sp9()`

</div>


## `SystemCallCenterGetRequest14sp9`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Call Center.

The response is either a `SystemCallCenterGetResponse14sp9()` or an `ErrorResponse()`.

Replaced By: `SystemCallCenterGetRequest16()`

</div>


## `SystemCallCenterGetRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Call Center.

The response is either a `SystemCallCenterGetResponse16()` or an `ErrorResponse()`.
Replaced by: `SystemCallCenterGetRequest17()`

</div>


## `SystemCallCenterGetRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Call Center.

The response is either a `SystemCallCenterGetResponse17()` or an `ErrorResponse()`.
Replaced by `SystemCallCenterGetRequest17sp4()`.

</div>


## `SystemCallCenterGetRequest17sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Call Center.

The response is either a `SystemCallCenterGetResponse17sp4()` or an `ErrorResponse()`.
Replaced by: `SystemCallCenterGetRequest19()`

</div>


## `SystemCallCenterGetRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Call Center.

The response is either a `SystemCallCenterGetResponse19()` or an `ErrorResponse()`.
Replaced by `SystemCallCenterGetRequest21()`.

</div>


## `SystemCallCenterGetRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Call Center.

The response is either a `SystemCallCenterGetResponse21()` or an `ErrorResponse()`.

</div>


## `SystemCallCenterModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with Call Center.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in Amplify data mode:
callHandlingSamplingPeriodMinutes callHandlingMinimumSamplingSize
thresholdCrossingNotificationEmailGuardTimerSeconds

**Attributes:**

|Name                                                        |Type |Description                                                     |
|------------------------------------------------------------|-----|----------------------------------------------------------------|
|default_from_address                                        |str  |defaultFromAddress *Optional*                                   |
|statistics_sampling_period_minutes                          |int  |statisticsSamplingPeriodMinutes *Optional*                      |
|default_enable_guard_timer                                  |bool |defaultEnableGuardTimer *Optional*                              |
|default_guard_timer_seconds                                 |int  |defaultGuardTimerSeconds *Optional*                             |
|force_agent_unavailable_on_dnd_activation                   |bool |forceAgentUnavailableOnDNDActivation *Optional*                 |
|force_agent_unavailable_on_personal_calls                   |bool |forceAgentUnavailableOnPersonalCalls *Optional*                 |
|force_agent_unavailable_on_bounced_call_limit               |bool |forceAgentUnavailableOnBouncedCallLimit *Optional*              |
|number_consecutive_bounced_calls_to_force_agent_unavailable |int  |numberConsecutiveBouncedCallsToForceAgentUnavailable *Optional* |
|force_agent_unavailable_on_not_reachable                    |bool |forceAgentUnavailableOnNotReachable *Optional*                  |
|default_play_ring_when_offer_call                           |bool |defaultPlayRingWhenOfferCall *Optional*                         |
|uniform_call_distribution_policy_scope                      |str  |uniformCallDistributionPolicyScope *Optional*                   |
|call_handling_sampling_period_minutes                       |int  |callHandlingSamplingPeriodMinutes *Optional*                    |
|call_handling_minimum_sampling_size                         |int  |callHandlingMinimumSamplingSize *Optional*                      |
|play_tone_to_agent_for_emergency_call                       |bool |playToneToAgentForEmergencyCall *Optional*                      |
|emergency_call_clid_prefix                                  |str  |emergencyCallCLIDPrefix *Optional*                              |
|threshold_crossing_notification_email_guard_timer_seconds   |int  |thresholdCrossingNotificationEmailGuardTimerSeconds *Optional*  |
|allow_agent_device_initiated_forward                        |bool |allowAgentDeviceInitiatedForward *Optional*                     |
</div>


## `SystemCallCenterReportingServerGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a list of Call Center Reporting Server.

The response is either `SystemCallCenterReportingServerGetListResponse()` or
`ErrorResponse()`.

</div>


## `SystemCallMeNowGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Call Me Now service.

The response is either a `SystemCallMeNowGetResponse()` or an `ErrorResponse()`.

</div>


## `SystemCallMeNowModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with Call me now service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type|Description                       |
|-------------------------|----|----------------------------------|
|passcode_length          |int |passcodeLength *Optional*         |
|passcode_timeout_seconds |int |passcodeTimeoutSeconds *Optional* |
</div>


## `SystemCallNotifyGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Call Notify.

The response is either a `SystemCallNotifyGetResponse()` or an `ErrorResponse()`.

</div>


## `SystemCallNotifyModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with Call Notify.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type |Description                    |
|-----------------------|-----|-------------------------------|
|default_from_address   |str  |defaultFromAddress *Optional*  |
|use_short_subject_line |bool |useShortSubjectLine *Optional* |
|use_dn_in_mail_body    |bool |useDnInMailBody *Optional*     |
</div>


## `SystemCallProcessingGetPolicyRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Call Processing Policy.

The response is either a `SystemCallProcessingGetPolicyResponse14()` or an
`ErrorResponse()`.

</div>


## `SystemCallProcessingGetPolicyRequest14sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Call Processing Policy.

The response is either a `SystemCallProcessingGetPolicyResponse14sp1()` or an
`ErrorResponse()`.

</div>


## `SystemCallProcessingGetPolicyRequest14sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Call Processing Policy.

The response is either a `SystemCallProcessingGetPolicyResponse14sp4()` or an
`ErrorResponse()`.

Replaced By : `SystemCallProcessingGetPolicyRequest15()`

</div>


## `SystemCallProcessingGetPolicyRequest14sp7`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Call Processing Policy.

The response is either a `SystemCallProcessingGetPolicyResponse14sp7()` or an
`ErrorResponse()`.

Replaced By: `SystemCallProcessingGetPolicyRequest16()`

</div>


## `SystemCallProcessingGetPolicyRequest15`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Call Processing Policy.

The response is either a `SystemCallProcessingGetPolicyResponse15()` or an
`ErrorResponse()`.

Replaced By: `SystemCallProcessingGetPolicyRequest15sp2()`

</div>


## `SystemCallProcessingGetPolicyRequest15sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Call Processing Policy.

The response is either a `SystemCallProcessingGetPolicyResponse15sp2()` or an
`ErrorResponse()`.

</div>


## `SystemCallProcessingGetPolicyRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Call Processing Policy.

The response is either a `SystemCallProcessingGetPolicyResponse16()` or an
`ErrorResponse()`.

</div>


## `SystemCallProcessingGetPolicyRequest16sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Call Processing Policy.

The response is either a `SystemCallProcessingGetPolicyResponse16sp2()` or an
`ErrorResponse()`.

</div>


## `SystemCallProcessingGetPolicyRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
The response is either a `SystemCallProcessingGetPolicyResponse17()` or an
`ErrorResponse()`.


</div>


## `SystemCallProcessingGetPolicyRequest17sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Call Processing Policy.

The response is either a `SystemCallProcessingGetPolicyResponse17sp3()` or an
`ErrorResponse()`. Replaced by: `SystemCallProcessingGetPolicyRequest17sp4()`

</div>


## `SystemCallProcessingGetPolicyRequest17sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
The response is either a `SystemCallProcessingGetPolicyResponse17sp4()` or an
`ErrorResponse()`.

Replaced By : `SystemCallProcessingGetPolicyRequest18sp1()`

</div>


## `SystemCallProcessingGetPolicyRequest18sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
The response is either a `SystemCallProcessingGetPolicyResponse18sp1()` or an
`ErrorResponse()`.

Replaced by: `SystemCallProcessingGetPolicyRequest19sp1()`

</div>


## `SystemCallProcessingGetPolicyRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
The response is either a `SystemCallProcessingGetPolicyResponse19sp1()` or an
`ErrorResponse()`.

Replaced by: `SystemCallProcessingGetPolicyRequest21sp1()`

</div>


## `SystemCallProcessingGetPolicyRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
The response is either a `SystemCallProcessingGetPolicyResponse21sp1()` or an
`ErrorResponse()`.

Replaced by: `SystemCallProcessingGetPolicyRequest1sp2()`.

</div>


## `SystemCallProcessingGetPolicyRequest21sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
The response is either a `SystemCallProcessingGetPolicyResponse21sp2()` or an
`ErrorResponse()`.

Replaced by: `SystemCallProcessingGetPolicyRequest22()` in AS data mode.

</div>


## `SystemCallProcessingGetPolicyRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
The response is either a `SystemCallProcessingGetPolicyResponse22()` or an
`ErrorResponse()`.

Replaced by: `SystemCallProcessingGetPolicyRequest22V2()` in AS data mode.

</div>


## `SystemCallProcessingGetPolicyRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
The response is either a `SystemCallProcessingGetPolicyResponse22V2()` or an
`ErrorResponse()`.

Replaced by: `SystemCallProcessingGetPolicyRequest23()` in AS data mode.

</div>


## `SystemCallProcessingGetPolicyRequest22V3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
The response is either a `SystemCallProcessingGetPolicyResponse22V3()` or an
`ErrorResponse()`.

Replaced by: `SystemCallProcessingGetPolicyResponse23V2()` in AS data mode.

</div>


## `SystemCallProcessingGetPolicyRequest23`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
The response is either a `SystemCallProcessingGetPolicyResponse23()` or an
`ErrorResponse()`.

Replaced by: `SystemCallProcessingGetPolicyRequest23V2()` in AS data mode.

</div>


## `SystemCallProcessingGetPolicyRequest23V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
The response is either a `SystemCallProcessingGetPolicyResponse22V3()` or an
`ErrorResponse()`.


</div>


## `SystemCallProcessingModifyPolicyRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with Call Processing Policy.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

Replaced By : `SystemCallProcessingModifyPolicyRequest15()`

**Attributes:**

|Name                                                                  |Type |Description                                                             |
|----------------------------------------------------------------------|-----|------------------------------------------------------------------------|
|use_max_simultaneous_calls                                            |bool |useMaxSimultaneousCalls *Optional*                                      |
|max_simultaneous_calls                                                |int  |maxSimultaneousCalls *Optional*                                         |
|use_max_simultaneous_video_calls                                      |bool |useMaxSimultaneousVideoCalls *Optional*                                 |
|max_simultaneous_video_calls                                          |int  |maxSimultaneousVideoCalls *Optional*                                    |
|use_max_call_time_for_answered_calls                                  |bool |useMaxCallTimeForAnsweredCalls *Optional*                               |
|max_call_time_for_answered_calls_minutes                              |int  |maxCallTimeForAnsweredCallsMinutes *Optional*                           |
|use_max_call_time_for_unanswered_calls                                |bool |useMaxCallTimeForUnansweredCalls *Optional*                             |
|max_call_time_for_unanswered_calls_minutes                            |int  |maxCallTimeForUnansweredCallsMinutes *Optional*                         |
|media_policy_selection                                                |str  |mediaPolicySelection *Optional*                                         |
|supported_media_set_name                                              |str  |supportedMediaSetName *Optional*                                        |
|network_usage_selection                                               |str  |networkUsageSelection *Optional*                                        |
|enforce_group_calling_line_identity_restriction                       |bool |enforceGroupCallingLineIdentityRestriction *Optional*                   |
|enforce_enterprise_calling_line_identity_restriction                  |bool |enforceEnterpriseCallingLineIdentityRestriction *Optional*              |
|allow_enterprise_group_call_typing_for_private_dialing_plan           |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan *Optional*          |
|allow_enterprise_group_call_typing_for_public_dialing_plan            |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan *Optional*           |
|override_clid_restriction_for_external_calls_via_private_dialing_plan |bool |overrideCLIDRestrictionForExternalCallsViaPrivateDialingPlan *Optional* |
|enable_enterprise_extension_dialing                                   |bool |enableEnterpriseExtensionDialing *Optional*                             |
|conference_uri                                                        |str  |conferenceURI *Optional*                                                |
|max_conference_parties                                                |int  |maxConferenceParties *Optional*                                         |
|use_max_concurrent_redirected_calls                                   |bool |useMaxConcurrentRedirectedCalls *Optional*                              |
|max_concurrent_redirected_calls                                       |int  |maxConcurrentRedirectedCalls *Optional*                                 |
|use_max_find_me_follow_me_depth                                       |bool |useMaxFindMeFollowMeDepth *Optional*                                    |
|max_find_me_follow_me_depth                                           |int  |maxFindMeFollowMeDepth *Optional*                                       |
|max_redirection_depth                                                 |int  |maxRedirectionDepth *Optional*                                          |
|use_max_concurrent_find_me_follow_me_invocations                      |bool |useMaxConcurrentFindMeFollowMeInvocations *Optional*                    |
|max_concurrent_find_me_follow_me_invocations                          |int  |maxConcurrentFindMeFollowMeInvocations *Optional*                       |
|clid_policy                                                           |str  |clidPolicy *Optional*                                                   |
|emergency_clid_policy                                                 |str  |emergencyClidPolicy *Optional*                                          |
|allow_alternate_numbers_for_redirecting_identity                      |bool |allowAlternateNumbersForRedirectingIdentity *Optional*                  |
</div>


## `SystemCallProcessingModifyPolicyRequest15`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with Call Processing Policy.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode: enableDialableCallerID
allowConfigurableCLIDForRedirectingIdentity enterpriseCallsCLIDPolicy
enterpriseGroupCallsCLIDPolicy serviceProviderGroupCallsCLIDPolicy The following
elements are only used in AS data mode and ignored in XS data mode:
maxConferenceParties enablePhoneListLookup useMaxConcurrentTerminatingAlertingRequests
maxConcurrentTerminatingAlertingRequests delayTimerToRemoveCancelledCallsInSeconds
includeRedirectionsInMaximumNumberOfConcurrentCalls
useUserPhoneNumberForGroupCallsWhenInternalClidUnavailable
useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable
allowMobileDNForRedirectingIdentity conferenceDisableClampTones useMaxCallsPerSecond
maxCallsPerSecond The following elements are only used in XS data mode and ignored in
AS data mode: routeOverrideDomain routeOverridePrefix

**Attributes:**

|Name                                                                      |Type |Description                                                                |
|--------------------------------------------------------------------------|-----|---------------------------------------------------------------------------|
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls *Optional*                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls *Optional*                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls *Optional*                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls *Optional*                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls *Optional*                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes *Optional*                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls *Optional*                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes *Optional*                            |
|media_policy_selection                                                    |str  |mediaPolicySelection *Optional*                                            |
|supported_media_set_name                                                  |str  |supportedMediaSetName *Optional*                                           |
|network_usage_selection                                                   |str  |networkUsageSelection *Optional*                                           |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction *Optional*                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction *Optional*                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan *Optional*             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan *Optional*              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory *Optional*                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory *Optional*                         |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing *Optional*                                |
|conference_uri                                                            |str  |conferenceURI *Optional*                                                   |
|max_conference_parties                                                    |int  |maxConferenceParties *Optional*                                            |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls *Optional*                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls *Optional*                                    |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth *Optional*                                       |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth *Optional*                                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth *Optional*                                             |
|use_max_concurrent_find_me_follow_me_invocations                          |bool |useMaxConcurrentFindMeFollowMeInvocations *Optional*                       |
|max_concurrent_find_me_follow_me_invocations                              |int  |maxConcurrentFindMeFollowMeInvocations *Optional*                          |
|clid_policy                                                               |str  |clidPolicy *Optional*                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy *Optional*                                             |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity *Optional*                     |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID *Optional*                                          |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls *Optional*                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity *Optional*                     |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy *Optional*                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy *Optional*                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy *Optional*                             |
|enable_phone_list_lookup                                                  |bool |enablePhoneListLookup *Optional*                                           |
|use_max_concurrent_terminating_alerting_requests                          |bool |useMaxConcurrentTerminatingAlertingRequests *Optional*                     |
|max_concurrent_terminating_alerting_requests                              |int  |maxConcurrentTerminatingAlertingRequests *Optional*                        |
|delay_timer_to_remove_cancelled_calls_in_seconds                          |int  |delayTimerToRemoveCancelledCallsInSeconds *Optional*                       |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls *Optional*             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable *Optional*      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable *Optional* |
|route_override_domain                                                     |str  |routeOverrideDomain *Optional*                                             |
|route_override_prefix                                                     |str  |routeOverridePrefix *Optional*                                             |
|allow_mobile_dn_for_redirecting_identity                                  |bool |allowMobileDNForRedirectingIdentity *Optional*                             |
|conference_disable_clamp_tones                                            |bool |conferenceDisableClampTones *Optional*                                     |
|use_max_calls_per_second                                                  |bool |useMaxCallsPerSecond *Optional*                                            |
|max_calls_per_second                                                      |int  |maxCallsPerSecond *Optional*                                               |
</div>


## `SystemCallProcessingPolicyProfileAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a call processing policy profile to system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by
`SystemCallProcessingPolicyProfileAddRequest20()`.

**Attributes:**

|Name                     |Type      |Description                       |
|-------------------------|----------|----------------------------------|
|name                     |str       |name                              |
|description              |str       |description *Optional*            |
|assigned_subscriber_type |List[str] |assignedSubscriberType *Optional* |
</div>


## `SystemCallProcessingPolicyProfileAddRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a call processing policy profile to system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type      |Description                       |
|-------------------------|----------|----------------------------------|
|name                     |str       |name                              |
|description              |str       |description *Optional*            |
|assigned_subscriber_type |List[str] |assignedSubscriberType *Optional* |
</div>


## `SystemCallProcessingPolicyProfileAddRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a call processing policy profile to system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type      |Description                       |
|-------------------------|----------|----------------------------------|
|name                     |str       |name                              |
|description              |str       |description *Optional*            |
|assigned_subscriber_type |List[str] |assignedSubscriberType *Optional* |
</div>


## `SystemCallProcessingPolicyProfileAutoAttendantProfileGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile Auto Attendant
subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileAutoAttendantProfileGetRequestResponse()` or an
`ErrorResponse()`. The response contains the call processing policy profile setting
for Auto Attendant.  Replaced by:
`SystemCallProcessingPolicyProfileAutoAttendantProfileGetRequest22()`

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileAutoAttendantProfileGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile Auto Attendant
subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileAutoAttendantProfileGetRequestResponse22()` or an
`ErrorResponse()`. The response contains the call processing policy profile setting
for Auto Attendant.  Replaced by:
`SystemCallProcessingPolicyProfileAutoAttendantProfileGetRequest22V2()` in AS data
mode.

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileAutoAttendantProfileGetRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile Auto Attendant
subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileAutoAttendantProfileGetRequestResponse22V2()` or an
`ErrorResponse()`. The response contains the call processing policy profile setting
for Auto Attendant.

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileAutoAttendantProfileModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call processing policy profile auto attendant subscriber type profile in
system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode:
useMaxCallsPerSecond maxCallsPerSecond

**Attributes:**

|Name                                                                      |Type |Description                                                                |
|--------------------------------------------------------------------------|-----|---------------------------------------------------------------------------|
|call_processing_policy_profile_name                                       |str  |callProcessingPolicyProfileName                                            |
|use_clid_policy                                                           |bool |useCLIDPolicy *Optional*                                                   |
|clid_policy                                                               |str  |clidPolicy *Optional*                                                      |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity *Optional*                     |
|use_group_name                                                            |bool |useGroupName *Optional*                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls *Optional*                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity *Optional*                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride *Optional*                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy *Optional*                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy *Optional*                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy *Optional*                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy *Optional*                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls *Optional*                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls *Optional*                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls *Optional*                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls *Optional*                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls *Optional*                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes *Optional*                              |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls *Optional*                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls *Optional*                                    |
|max_redirection_depth                                                     |int  |maxRedirectionDepth *Optional*                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy *Optional*                                     |
|network_usage_selection                                                   |str  |networkUsageSelection *Optional*                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing *Optional*                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction *Optional*                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction *Optional*                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan *Optional*             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan *Optional*              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory *Optional*                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory *Optional*                         |
|use_incoming_clid_policy                                                  |bool |useIncomingCLIDPolicy *Optional*                                           |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID *Optional*                                          |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls *Optional*             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable *Optional*      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable *Optional* |
|use_max_calls_per_second                                                  |bool |useMaxCallsPerSecond *Optional*                                            |
|max_calls_per_second                                                      |int  |maxCallsPerSecond *Optional*                                               |
</div>


## `SystemCallProcessingPolicyProfileBroadWorksAnywhereProfileGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile BroadWorks
Anywhere subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileBroadWorksAnywhereProfileGetRequestResponse()` or an
`ErrorResponse()`. Replaced by:
`SystemCallProcessingPolicyProfileBroadWorksAnywhereProfileGetRequest22()`

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileBroadWorksAnywhereProfileGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile BroadWorks
Anywhere subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileBroadWorksAnywhereProfileGetRequestResponse22()` or
an `ErrorResponse()`. Replaced by:
`SystemCallProcessingPolicyProfileBroadWorksAnywhereProfileGetRequest22()` in AS data
mode.

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileBroadWorksAnywhereProfileGetRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile BroadWorks
Anywhere subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileBroadWorksAnywhereProfileGetRequestResponse22V2()`
or an `ErrorResponse()`.

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileBroadWorksAnywhereProfileModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call processing policy profile broadworks anywhare subscriber type profile in
system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode:
useMaxCallsPerSecond maxCallsPerSecond

**Attributes:**

|Name                                                                      |Type |Description                                                                |
|--------------------------------------------------------------------------|-----|---------------------------------------------------------------------------|
|call_processing_policy_profile_name                                       |str  |callProcessingPolicyProfileName                                            |
|use_clid_policy                                                           |bool |useCLIDPolicy *Optional*                                                   |
|clid_policy                                                               |str  |clidPolicy *Optional*                                                      |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity *Optional*                     |
|use_group_name                                                            |bool |useGroupName *Optional*                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls *Optional*                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity *Optional*                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride *Optional*                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy *Optional*                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy *Optional*                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy *Optional*                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy *Optional*                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls *Optional*                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls *Optional*                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls *Optional*                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls *Optional*                                       |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls *Optional*                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls *Optional*                                    |
|max_redirection_depth                                                     |int  |maxRedirectionDepth *Optional*                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy *Optional*                                     |
|network_usage_selection                                                   |str  |networkUsageSelection *Optional*                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing *Optional*                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction *Optional*                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction *Optional*                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan *Optional*             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan *Optional*              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory *Optional*                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory *Optional*                         |
|use_incoming_clid_policy                                                  |bool |useIncomingCLIDPolicy *Optional*                                           |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID *Optional*                                          |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls *Optional*             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable *Optional*      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable *Optional* |
|use_max_calls_per_second                                                  |bool |useMaxCallsPerSecond *Optional*                                            |
|max_calls_per_second                                                      |int  |maxCallsPerSecond *Optional*                                               |
</div>


## `SystemCallProcessingPolicyProfileCallCenterProfileGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile Call Center
subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileCallCenterProfileGetRequestResponse()` or an
`ErrorResponse()`. Replaced by:
`SystemCallProcessingPolicyProfileCallCenterProfileGetRequest22()`

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileCallCenterProfileGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile Call Center
subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileCallCenterProfileGetRequestResponse22()` or an
`ErrorResponse()`. Replaced by:
`SystemCallProcessingPolicyProfileCallCenterProfileGetRequest22V2()` in AS data mode.

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileCallCenterProfileGetRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile Call Center
subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileCallCenterProfileGetRequestResponse22V2()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileCallCenterProfileModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call processing policy profile call center subscriber type profile in system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode:
useMaxCallsPerSecond maxCallsPerSecond

**Attributes:**

|Name                                                                      |Type |Description                                                                |
|--------------------------------------------------------------------------|-----|---------------------------------------------------------------------------|
|call_processing_policy_profile_name                                       |str  |callProcessingPolicyProfileName                                            |
|use_clid_policy                                                           |bool |useCLIDPolicy *Optional*                                                   |
|clid_policy                                                               |str  |clidPolicy *Optional*                                                      |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity *Optional*                     |
|use_group_name                                                            |bool |useGroupName *Optional*                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls *Optional*                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity *Optional*                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride *Optional*                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy *Optional*                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy *Optional*                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy *Optional*                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy *Optional*                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls *Optional*                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls *Optional*                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls *Optional*                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls *Optional*                                       |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls *Optional*                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls *Optional*                                    |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth *Optional*                                       |
|use_max_concurrent_find_me_follow_me_invocations                          |bool |useMaxConcurrentFindMeFollowMeInvocations *Optional*                       |
|max_concurrent_find_me_follow_me_invocations                              |int  |maxConcurrentFindMeFollowMeInvocations *Optional*                          |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth *Optional*                                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth *Optional*                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy *Optional*                                     |
|network_usage_selection                                                   |str  |networkUsageSelection *Optional*                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing *Optional*                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction *Optional*                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction *Optional*                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan *Optional*             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan *Optional*              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory *Optional*                   |
|use_incoming_clid_policy                                                  |bool |useIncomingCLIDPolicy *Optional*                                           |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID *Optional*                                          |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls *Optional*             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable *Optional*      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable *Optional* |
|use_max_calls_per_second                                                  |bool |useMaxCallsPerSecond *Optional*                                            |
|max_calls_per_second                                                      |int  |maxCallsPerSecond *Optional*                                               |
</div>


## `SystemCallProcessingPolicyProfileCollaborateProfileGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile Collaborate
subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileCollaborateProfileGetResponse()` or an
`ErrorResponse()`. Replaced by:
`SystemCallProcessingPolicyProfileCollaborateProfileGetRequest22()`

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileCollaborateProfileGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile Collaborate
subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileCollaborateProfileGetResponse22()` or an
`ErrorResponse()`. Replaced by:
`SystemCallProcessingPolicyProfileCollaborateProfileGetRequest22V2()` in AS data mode.

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileCollaborateProfileGetRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile Collaborate
subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileCollaborateProfileGetResponse22V2()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileCollaborateProfileModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get to modify the call processing policy profile collaborate subscriber
type profile.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode:
useMaxCallsPerSecond maxCallsPerSecond

**Attributes:**

|Name                                                                      |Type |Description                                                                |
|--------------------------------------------------------------------------|-----|---------------------------------------------------------------------------|
|call_processing_policy_profile_name                                       |str  |callProcessingPolicyProfileName                                            |
|use_clid_policy                                                           |bool |useCLIDPolicy *Optional*                                                   |
|clid_policy                                                               |str  |clidPolicy *Optional*                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy *Optional*                                             |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity *Optional*                     |
|use_group_name                                                            |bool |useGroupName *Optional*                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls *Optional*                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity *Optional*                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride *Optional*                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy *Optional*                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy *Optional*                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy *Optional*                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy *Optional*                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls *Optional*                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls *Optional*                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls *Optional*                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls *Optional*                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls *Optional*                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes *Optional*                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls *Optional*                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes *Optional*                            |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls *Optional*                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls *Optional*                                    |
|max_redirection_depth                                                     |int  |maxRedirectionDepth *Optional*                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy *Optional*                                     |
|network_usage_selection                                                   |str  |networkUsageSelection *Optional*                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing *Optional*                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction *Optional*                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction *Optional*                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan *Optional*             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan *Optional*              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory *Optional*                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory *Optional*                         |
|use_incoming_clid_policy                                                  |bool |useIncomingCLIDPolicy *Optional*                                           |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID *Optional*                                          |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls *Optional*             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable *Optional*      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable *Optional* |
|use_max_calls_per_second                                                  |bool |useMaxCallsPerSecond *Optional*                                            |
|max_calls_per_second                                                      |int  |maxCallsPerSecond *Optional*                                               |
</div>


## `SystemCallProcessingPolicyProfileDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a call processing policy profile from system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemCallProcessingPolicyProfileFindMeFollowMeProfileGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile Find-me/Follow-
me subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileFindMeFollowMeProfileGetResponse()` or an
`ErrorResponse()`. Replaced by:
`SystemCallProcessingPolicyProfileFindMeFollowMeProfileGetRequest22()`

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileFindMeFollowMeProfileGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile Find-me/Follow-
me subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileFindMeFollowMeProfileGetResponse22()` or an
`ErrorResponse()`. Replaced by:
`SystemCallProcessingPolicyProfileFindMeFollowMeProfileGetRequest22V2()` in AS data
mode.

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileFindMeFollowMeProfileGetRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile Find-me/Follow-
me subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileFindMeFollowMeProfileGetResponse22V2()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileFindMeFollowMeProfileModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call processing policy profile find-me/follow-me subscriber type profile in
system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode:
useMaxCallsPerSecond maxCallsPerSecond

**Attributes:**

|Name                                                                      |Type |Description                                                                |
|--------------------------------------------------------------------------|-----|---------------------------------------------------------------------------|
|call_processing_policy_profile_name                                       |str  |callProcessingPolicyProfileName                                            |
|use_clid_policy                                                           |bool |useCLIDPolicy *Optional*                                                   |
|clid_policy                                                               |str  |clidPolicy *Optional*                                                      |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity *Optional*                     |
|use_group_name                                                            |bool |useGroupName *Optional*                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls *Optional*                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity *Optional*                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride *Optional*                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy *Optional*                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy *Optional*                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy *Optional*                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy *Optional*                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls *Optional*                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls *Optional*                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls *Optional*                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls *Optional*                                       |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls *Optional*                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes *Optional*                            |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls *Optional*                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls *Optional*                                    |
|use_max_concurrent_find_me_follow_me_invocations                          |bool |useMaxConcurrentFindMeFollowMeInvocations *Optional*                       |
|max_concurrent_find_me_follow_me_invocations                              |int  |maxConcurrentFindMeFollowMeInvocations *Optional*                          |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth *Optional*                                       |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth *Optional*                                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth *Optional*                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy *Optional*                                     |
|network_usage_selection                                                   |str  |networkUsageSelection *Optional*                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing *Optional*                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction *Optional*                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction *Optional*                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan *Optional*             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan *Optional*              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory *Optional*                   |
|use_incoming_clid_policy                                                  |bool |useIncomingCLIDPolicy *Optional*                                           |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID *Optional*                                          |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls *Optional*             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable *Optional*      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable *Optional* |
|use_max_calls_per_second                                                  |bool |useMaxCallsPerSecond *Optional*                                            |
|max_calls_per_second                                                      |int  |maxCallsPerSecond *Optional*                                               |
</div>


## `SystemCallProcessingPolicyProfileFlexibleSeatingHostProfileGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile Flexible Seating
Host subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileFlexibleSeatingHostProfileGetResponse()` or an
`ErrorResponse()`. Replaced by:
`SystemCallProcessingPolicyProfileFlexibleSeatingHostProfileGetRequest22()`

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileFlexibleSeatingHostProfileGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile Flexible Seating
Host subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileFlexibleSeatingHostProfileGetResponse()` or an
`ErrorResponse()`. Replaced by:
`SystemCallProcessingPolicyProfileFlexibleSeatingHostProfileGetRequest22V2()`

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileFlexibleSeatingHostProfileGetRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile Flexible Seating
Host subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileFlexibleSeatingHostProfileGetResponse22V2()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileFlexibleSeatingHostProfileModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call processing policy profile flexible seating host subscriber type profile
in system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode:
useMaxCallsPerSecond maxCallsPerSecond

**Attributes:**

|Name                                                                      |Type |Description                                                                |
|--------------------------------------------------------------------------|-----|---------------------------------------------------------------------------|
|call_processing_policy_profile_name                                       |str  |callProcessingPolicyProfileName                                            |
|use_clid_policy                                                           |bool |useCLIDPolicy *Optional*                                                   |
|clid_policy                                                               |str  |clidPolicy *Optional*                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy *Optional*                                             |
|use_group_name                                                            |bool |useGroupName *Optional*                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls *Optional*                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity *Optional*                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride *Optional*                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy *Optional*                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy *Optional*                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy *Optional*                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy *Optional*                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls *Optional*                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls *Optional*                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls *Optional*                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls *Optional*                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls *Optional*                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes *Optional*                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls *Optional*                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes *Optional*                            |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy *Optional*                                     |
|network_usage_selection                                                   |str  |networkUsageSelection *Optional*                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing *Optional*                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction *Optional*                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction *Optional*                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan *Optional*             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan *Optional*              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory *Optional*                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory *Optional*                         |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls *Optional*             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable *Optional*      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable *Optional* |
|use_max_calls_per_second                                                  |bool |useMaxCallsPerSecond *Optional*                                            |
|max_calls_per_second                                                      |int  |maxCallsPerSecond *Optional*                                               |
</div>


## `SystemCallProcessingPolicyProfileGetAssignedNCOSListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a list of NCOSs that have a given CallP Policy Profile assigned.

The response is either a
`SystemCallProcessingPolicyProfileGetAssignedNCOSListResponse()` or `ErrorResponse()`.

**Attributes:**

|Name         |Type|Description |
|-------------|----|------------|
|profile_name |str |profileName |
</div>


## `SystemCallProcessingPolicyProfileGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of all Call Processing Policy Profiles.

The response is either a `SystemCallProcessingPolicyProfileGetListResponse()` or an
`ErrorResponse()`.

</div>


## `SystemCallProcessingPolicyProfileGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a call processing policy profile in system.

The response is either a `SystemCallProcessingPolicyProfileGetResponse()` or an
`ErrorResponse()`. Replaced by `SystemCallProcessingPolicyProfileGetRequest20()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemCallProcessingPolicyProfileGetRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a call processing policy profile in system.

The response is either a `SystemCallProcessingPolicyProfileGetResponse20()` or an
`ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemCallProcessingPolicyProfileGetRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a call processing policy profile in system.

The response is either a `SystemCallProcessingPolicyProfileGetResponse21()` or an
`ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemCallProcessingPolicyProfileGroupPagingProfileGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile Group Paging
subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileGroupPagingProfileGetResponse()` or an
`ErrorResponse()`. Replaced by:
`SystemCallProcessingPolicyProfileGroupPagingProfileGetRequest22()`

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileGroupPagingProfileGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile Group Paging
subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileGroupPagingProfileGetResponse22()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileGroupPagingProfileModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">


**Attributes:**

|Name                                                                      |Type |Description                                                                |
|--------------------------------------------------------------------------|-----|---------------------------------------------------------------------------|
|call_processing_policy_profile_name                                       |str  |callProcessingPolicyProfileName                                            |
|use_clid_policy                                                           |bool |useCLIDPolicy *Optional*                                                   |
|clid_policy                                                               |str  |clidPolicy *Optional*                                                      |
|use_group_name                                                            |bool |useGroupName *Optional*                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls *Optional*                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity *Optional*                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride *Optional*                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy *Optional*                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy *Optional*                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy *Optional*                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy *Optional*                                             |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls *Optional*                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes *Optional*                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls *Optional*                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes *Optional*                            |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls *Optional*                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls *Optional*                                    |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth *Optional*                                       |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth *Optional*                                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth *Optional*                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy *Optional*                                     |
|network_usage_selection                                                   |str  |networkUsageSelection *Optional*                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing *Optional*                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction *Optional*                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction *Optional*                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan *Optional*             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan *Optional*              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory *Optional*                   |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable *Optional*      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable *Optional* |
</div>


## `SystemCallProcessingPolicyProfileHuntGroupProfileGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile Hunt Group
subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileHuntGroupProfileGetResponse()` or an
`ErrorResponse()`. Replaced by:
`SystemCallProcessingPolicyProfileHuntGroupProfileGetRequest22()`

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileHuntGroupProfileGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile Hunt Group
subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileHuntGroupProfileGetResponse22()` or an
`ErrorResponse()`. Replaced by:
`SystemCallProcessingPolicyProfileHuntGroupProfileGetRequest22V2()`.

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileHuntGroupProfileGetRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile Hunt Group
subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileHuntGroupProfileGetResponse22V2()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileHuntGroupProfileModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call processing policy profile hunt group subscriber type profile in system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode:
useMaxCallsPerSecond maxCallsPerSecond

**Attributes:**

|Name                                                                      |Type |Description                                                                |
|--------------------------------------------------------------------------|-----|---------------------------------------------------------------------------|
|call_processing_policy_profile_name                                       |str  |callProcessingPolicyProfileName                                            |
|use_clid_policy                                                           |bool |useCLIDPolicy *Optional*                                                   |
|clid_policy                                                               |str  |clidPolicy *Optional*                                                      |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity *Optional*                     |
|use_group_name                                                            |bool |useGroupName *Optional*                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls *Optional*                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity *Optional*                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride *Optional*                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy *Optional*                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy *Optional*                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy *Optional*                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy *Optional*                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls *Optional*                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls *Optional*                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls *Optional*                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls *Optional*                                       |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls *Optional*                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes *Optional*                            |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls *Optional*                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls *Optional*                                    |
|use_max_concurrent_find_me_follow_me_invocations                          |bool |useMaxConcurrentFindMeFollowMeInvocations *Optional*                       |
|max_concurrent_find_me_follow_me_invocations                              |int  |maxConcurrentFindMeFollowMeInvocations *Optional*                          |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth *Optional*                                       |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth *Optional*                                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth *Optional*                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy *Optional*                                     |
|network_usage_selection                                                   |str  |networkUsageSelection *Optional*                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing *Optional*                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction *Optional*                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction *Optional*                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan *Optional*             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan *Optional*              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory *Optional*                   |
|use_incoming_clid_policy                                                  |bool |useIncomingCLIDPolicy *Optional*                                           |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID *Optional*                                          |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls *Optional*             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable *Optional*      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable *Optional* |
|use_max_calls_per_second                                                  |bool |useMaxCallsPerSecond *Optional*                                            |
|max_calls_per_second                                                      |int  |maxCallsPerSecond *Optional*                                               |
</div>


## `SystemCallProcessingPolicyProfileInstantGroupCallProfileGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile Instant Group
Call subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileInstantGroupCallProfileGetResponse22()` or an
`ErrorResponse()`. Replaced by:
`SystemCallProcessingPolicyProfileInstantGroupCallProfileGetRequest22()`

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileInstantGroupCallProfileGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile Instant Group
Call subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileInstantGroupCallProfileGetResponse22()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileInstantGroupCallProfileModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">


**Attributes:**

|Name                                                                      |Type |Description                                                                |
|--------------------------------------------------------------------------|-----|---------------------------------------------------------------------------|
|call_processing_policy_profile_name                                       |str  |callProcessingPolicyProfileName                                            |
|use_clid_policy                                                           |bool |useCLIDPolicy *Optional*                                                   |
|clid_policy                                                               |str  |clidPolicy *Optional*                                                      |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity *Optional*                     |
|use_group_name                                                            |bool |useGroupName *Optional*                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls *Optional*                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity *Optional*                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride *Optional*                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy *Optional*                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy *Optional*                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy *Optional*                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy *Optional*                                             |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls *Optional*                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes *Optional*                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls *Optional*                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes *Optional*                            |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls *Optional*                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls *Optional*                                    |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth *Optional*                                       |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth *Optional*                                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth *Optional*                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy *Optional*                                     |
|network_usage_selection                                                   |str  |networkUsageSelection *Optional*                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing *Optional*                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction *Optional*                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction *Optional*                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan *Optional*             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan *Optional*              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory *Optional*                   |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable *Optional*      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable *Optional* |
</div>


## `SystemCallProcessingPolicyProfileMeetMeConferencingProfileGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile Meet-Me
Conferencing subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileMeetMeConferencingProfileGetResponse()` or an
`ErrorResponse()`. Replaced by:
`SystemCallProcessingPolicyProfileMeetMeConferencingProfileGetRequest22()`

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileMeetMeConferencingProfileGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile Meet-Me
Conferencing subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileMeetMeConferencingProfileGetResponse22()` or an
`ErrorResponse()`. Replaced by:
`SystemCallProcessingPolicyProfileMeetMeConferencingProfileGetRequest22V2()`.

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileMeetMeConferencingProfileGetRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile Meet-Me
Conferencing subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileMeetMeConferencingProfileGetResponse22V2()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileMeetMeConferencingProfileModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call processing policy profile meet-me conferencing subscriber type profile
in system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode:
useMaxCallsPerSecond maxCallsPerSecond

**Attributes:**

|Name                                                                      |Type |Description                                                                |
|--------------------------------------------------------------------------|-----|---------------------------------------------------------------------------|
|call_processing_policy_profile_name                                       |str  |callProcessingPolicyProfileName                                            |
|use_clid_policy                                                           |bool |useCLIDPolicy *Optional*                                                   |
|clid_policy                                                               |str  |clidPolicy *Optional*                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy *Optional*                                             |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity *Optional*                     |
|use_group_name                                                            |bool |useGroupName *Optional*                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls *Optional*                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity *Optional*                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride *Optional*                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy *Optional*                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy *Optional*                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy *Optional*                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy *Optional*                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls *Optional*                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls *Optional*                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls *Optional*                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls *Optional*                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls *Optional*                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes *Optional*                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls *Optional*                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes *Optional*                            |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls *Optional*                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls *Optional*                                    |
|max_redirection_depth                                                     |int  |maxRedirectionDepth *Optional*                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy *Optional*                                     |
|network_usage_selection                                                   |str  |networkUsageSelection *Optional*                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing *Optional*                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction *Optional*                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction *Optional*                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan *Optional*             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan *Optional*              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory *Optional*                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory *Optional*                         |
|use_incoming_clid_policy                                                  |bool |useIncomingCLIDPolicy *Optional*                                           |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID *Optional*                                          |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls *Optional*             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable *Optional*      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable *Optional* |
|use_max_calls_per_second                                                  |bool |useMaxCallsPerSecond *Optional*                                            |
|max_calls_per_second                                                      |int  |maxCallsPerSecond *Optional*                                               |
</div>


## `SystemCallProcessingPolicyProfileRoutePointProfileGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile Route Point
subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileRoutePointProfileGetResponse()` or an
`ErrorResponse()`. Replaced by:
`SystemCallProcessingPolicyProfileRoutePointProfileGetRequest22()`

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileRoutePointProfileGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile Route Point
subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileRoutePointProfileGetResponse22()` or an
`ErrorResponse()`. Replaced by:
`SystemCallProcessingPolicyProfileRoutePointProfileGetRequest22V2()`

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileRoutePointProfileGetRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile Route Point
subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileRoutePointProfileGetResponse22V2()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileRoutePointProfileModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call processing policy profile route point subscriber type profile in system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode:
useMaxCallsPerSecond maxCallsPerSecond

**Attributes:**

|Name                                                                      |Type |Description                                                                |
|--------------------------------------------------------------------------|-----|---------------------------------------------------------------------------|
|call_processing_policy_profile_name                                       |str  |callProcessingPolicyProfileName                                            |
|use_clid_policy                                                           |bool |useCLIDPolicy *Optional*                                                   |
|clid_policy                                                               |str  |clidPolicy *Optional*                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy *Optional*                                             |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity *Optional*                     |
|use_group_name                                                            |bool |useGroupName *Optional*                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls *Optional*                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity *Optional*                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride *Optional*                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy *Optional*                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy *Optional*                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy *Optional*                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy *Optional*                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls *Optional*                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls *Optional*                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls *Optional*                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls *Optional*                                       |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls *Optional*                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls *Optional*                                    |
|use_max_concurrent_find_me_follow_me_invocations                          |bool |useMaxConcurrentFindMeFollowMeInvocations *Optional*                       |
|max_concurrent_find_me_follow_me_invocations                              |int  |maxConcurrentFindMeFollowMeInvocations *Optional*                          |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth *Optional*                                       |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth *Optional*                                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth *Optional*                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy *Optional*                                     |
|network_usage_selection                                                   |str  |networkUsageSelection *Optional*                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing *Optional*                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction *Optional*                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction *Optional*                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan *Optional*             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan *Optional*              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory *Optional*                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory *Optional*                         |
|use_incoming_clid_policy                                                  |bool |useIncomingCLIDPolicy *Optional*                                           |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID *Optional*                                          |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls *Optional*             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable *Optional*      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable *Optional* |
|use_max_calls_per_second                                                  |bool |useMaxCallsPerSecond *Optional*                                            |
|max_calls_per_second                                                      |int  |maxCallsPerSecond *Optional*                                               |
</div>


## `SystemCallProcessingPolicyProfileTrunkGroupPilotProfileGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile Trunk Group
Pilot user subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileTrunkGroupPilotProfileGetResponse()` or an
`ErrorResponse()`. Replaced by:
`SystemCallProcessingPolicyProfileTrunkGroupPilotProfileGetRequest22()`

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileTrunkGroupPilotProfileGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile Trunk Group
Pilot user subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileTrunkGroupPilotProfileGetResponse22()` or an
`ErrorResponse()`. Replaced by:
`SystemCallProcessingPolicyProfileTrunkGroupPilotProfileGetRequest22V2()` in AS data
mode.

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileTrunkGroupPilotProfileGetRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile Trunk Group
Pilot user subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileTrunkGroupPilotProfileGetResponse22V2()` or an
`ErrorResponse()`. Replaced by:
`SystemCallProcessingPolicyProfileTrunkGroupPilotProfileGetRequest22V3()` in AS data
mode.

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileTrunkGroupPilotProfileGetRequest22V3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile Trunk Group
Pilot user subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileTrunkGroupPilotProfileGetResponse22V3()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileTrunkGroupPilotProfileModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call processing policy profile trunk group pilot subscriber type profile in
system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode:
useMaxCallsPerSecond maxCallsPerSecond

**Attributes:**

|Name                                                                      |Type |Description                                                                |
|--------------------------------------------------------------------------|-----|---------------------------------------------------------------------------|
|call_processing_policy_profile_name                                       |str  |callProcessingPolicyProfileName                                            |
|use_clid_policy                                                           |bool |useCLIDPolicy *Optional*                                                   |
|clid_policy                                                               |str  |clidPolicy *Optional*                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy *Optional*                                             |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity *Optional*                     |
|use_group_name                                                            |bool |useGroupName *Optional*                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls *Optional*                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity *Optional*                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride *Optional*                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy *Optional*                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy *Optional*                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy *Optional*                             |
|use_media_policy                                                          |bool |useMediaPolicy *Optional*                                                  |
|media_policy_selection                                                    |str  |mediaPolicySelection *Optional*                                            |
|supported_media_set_name                                                  |str  |supportedMediaSetName *Optional*                                           |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy *Optional*                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls *Optional*                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls *Optional*                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls *Optional*                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls *Optional*                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls *Optional*                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes *Optional*                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls *Optional*                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes *Optional*                            |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls *Optional*                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls *Optional*                                    |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth *Optional*                                       |
|use_max_concurrent_find_me_follow_me_invocations                          |bool |useMaxConcurrentFindMeFollowMeInvocations *Optional*                       |
|max_concurrent_find_me_follow_me_invocations                              |int  |maxConcurrentFindMeFollowMeInvocations *Optional*                          |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth *Optional*                                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth *Optional*                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy *Optional*                                     |
|network_usage_selection                                                   |str  |networkUsageSelection *Optional*                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing *Optional*                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction *Optional*                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction *Optional*                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan *Optional*             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan *Optional*              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory *Optional*                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory *Optional*                         |
|use_incoming_clid_policy                                                  |bool |useIncomingCLIDPolicy *Optional*                                           |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID *Optional*                                          |
|use_max_concurrent_terminating_alerting_requests                          |bool |useMaxConcurrentTerminatingAlertingRequests *Optional*                     |
|max_concurrent_terminating_alerting_requests                              |int  |maxConcurrentTerminatingAlertingRequests *Optional*                        |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls *Optional*             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable *Optional*      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable *Optional* |
|allow_mobile_dn_for_redirecting_identity                                  |bool |allowMobileDNForRedirectingIdentity *Optional*                             |
|use_max_calls_per_second                                                  |bool |useMaxCallsPerSecond *Optional*                                            |
|max_calls_per_second                                                      |int  |maxCallsPerSecond *Optional*                                               |
</div>


## `SystemCallProcessingPolicyProfileUserProfileGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile user subscriber
type profile.

The response is either a `SystemCallProcessingPolicyProfileUserProfileGetResponse()`
or an `ErrorResponse()`. Replaced by:
`SystemCallProcessingPolicyProfileUserProfileGetRequest21sp1()` in AS data mode

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileUserProfileGetRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile user subscriber
type profile.

The response is either a
`SystemCallProcessingPolicyProfileUserProfileGetResponse21sp1()` or an
`ErrorResponse()`. Replaced by:
`SystemCallProcessingPolicyProfileUserProfileGetRequest22()` in AS data mode

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileUserProfileGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile user subscriber
type profile.

The response is either a `SystemCallProcessingPolicyProfileUserProfileGetResponse22()`
or an `ErrorResponse()`. Replaced by:
`SystemCallProcessingPolicyProfileUserProfileGetRequest22V2()` in AS data mode.

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileUserProfileGetRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile user subscriber
type profile.

The response is either a
`SystemCallProcessingPolicyProfileUserProfileGetResponse22V2()` or an
`ErrorResponse()`. Replaced by:
`SystemCallProcessingPolicyProfileUserProfileGetRequest22V2()` in AS data mode.

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileUserProfileGetRequest22V3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile user subscriber
type profile.

The response is either a
`SystemCallProcessingPolicyProfileUserProfileGetResponse22V3()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileUserProfileModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call processing policy profile user subscriber type profile in system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode:
useMaxCallsPerSecond maxCallsPerSecond

**Attributes:**

|Name                                                                      |Type |Description                                                                |
|--------------------------------------------------------------------------|-----|---------------------------------------------------------------------------|
|call_processing_policy_profile_name                                       |str  |callProcessingPolicyProfileName                                            |
|use_clid_policy                                                           |bool |useCLIDPolicy *Optional*                                                   |
|clid_policy                                                               |str  |clidPolicy *Optional*                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy *Optional*                                             |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity *Optional*                     |
|use_group_name                                                            |bool |useGroupName *Optional*                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls *Optional*                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity *Optional*                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride *Optional*                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy *Optional*                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy *Optional*                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy *Optional*                             |
|use_media_policy                                                          |bool |useMediaPolicy *Optional*                                                  |
|media_policy_selection                                                    |str  |mediaPolicySelection *Optional*                                            |
|supported_media_set_name                                                  |str  |supportedMediaSetName *Optional*                                           |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy *Optional*                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls *Optional*                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls *Optional*                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls *Optional*                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls *Optional*                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls *Optional*                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes *Optional*                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls *Optional*                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes *Optional*                            |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls *Optional*                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls *Optional*                                    |
|use_max_concurrent_find_me_follow_me_invocations                          |bool |useMaxConcurrentFindMeFollowMeInvocations *Optional*                       |
|max_concurrent_find_me_follow_me_invocations                              |int  |maxConcurrentFindMeFollowMeInvocations *Optional*                          |
|use_max_find_me_follow_me_depth                                           |bool |useMaxFindMeFollowMeDepth *Optional*                                       |
|max_find_me_follow_me_depth                                               |int  |maxFindMeFollowMeDepth *Optional*                                          |
|max_redirection_depth                                                     |int  |maxRedirectionDepth *Optional*                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy *Optional*                                     |
|network_usage_selection                                                   |str  |networkUsageSelection *Optional*                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing *Optional*                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction *Optional*                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction *Optional*                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan *Optional*             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan *Optional*              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory *Optional*                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory *Optional*                         |
|use_incoming_clid_policy                                                  |bool |useIncomingCLIDPolicy *Optional*                                           |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID *Optional*                                          |
|use_phone_list_lookup_policy                                              |bool |usePhoneListLookupPolicy *Optional*                                        |
|enable_phone_list_lookup                                                  |bool |enablePhoneListLookup *Optional*                                           |
|use_max_concurrent_terminating_alerting_requests                          |bool |useMaxConcurrentTerminatingAlertingRequests *Optional*                     |
|max_concurrent_terminating_alerting_requests                              |int  |maxConcurrentTerminatingAlertingRequests *Optional*                        |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls *Optional*             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable *Optional*      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable *Optional* |
|allow_mobile_dn_for_redirecting_identity                                  |bool |allowMobileDNForRedirectingIdentity *Optional*                             |
|use_max_calls_per_second                                                  |bool |useMaxCallsPerSecond *Optional*                                            |
|max_calls_per_second                                                      |int  |maxCallsPerSecond *Optional*                                               |
</div>


## `SystemCallProcessingPolicyProfileVoicePortalProfileGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile Voice Portal
subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileVoicePortalProfileGetResponse()` or an
`ErrorResponse()`. Replaced by:
`SystemCallProcessingPolicyProfileVoicePortalProfileGetRequest22()`

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileVoicePortalProfileGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile Voice Portal
subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileVoicePortalProfileGetResponse22()` or an
`ErrorResponse()`. Replaced by:
`SystemCallProcessingPolicyProfileVoicePortalProfileGetRequest22V2()`.

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileVoicePortalProfileGetRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile Voice Portal
subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileVoicePortalProfileGetResponse22V2()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileVoicePortalProfileModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call processing policy profile voice portal type profile in system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode:
useMaxCallsPerSecond maxCallsPerSecond

**Attributes:**

|Name                                                                      |Type |Description                                                                |
|--------------------------------------------------------------------------|-----|---------------------------------------------------------------------------|
|call_processing_policy_profile_name                                       |str  |callProcessingPolicyProfileName                                            |
|use_clid_policy                                                           |bool |useCLIDPolicy *Optional*                                                   |
|clid_policy                                                               |str  |clidPolicy *Optional*                                                      |
|use_group_name                                                            |bool |useGroupName *Optional*                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls *Optional*                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity *Optional*                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride *Optional*                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy *Optional*                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy *Optional*                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy *Optional*                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy *Optional*                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls *Optional*                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls *Optional*                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls *Optional*                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls *Optional*                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls *Optional*                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes *Optional*                              |
|max_redirection_depth                                                     |int  |maxRedirectionDepth *Optional*                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy *Optional*                                     |
|network_usage_selection                                                   |str  |networkUsageSelection *Optional*                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing *Optional*                                |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan *Optional*             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan *Optional*              |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls *Optional*             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable *Optional*      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable *Optional* |
|use_max_calls_per_second                                                  |bool |useMaxCallsPerSecond *Optional*                                            |
|max_calls_per_second                                                      |int  |maxCallsPerSecond *Optional*                                               |
</div>


## `SystemCallProcessingPolicyProfileVoiceXMLProfileGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile VoiceXML
subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileVoiceXMLProfileGetResponse()` or an
`ErrorResponse()`. Replaced by:
`SystemCallProcessingPolicyProfileVoiceXMLProfileGetRequest22()`

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileVoiceXMLProfileGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile VoiceXML
subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileVoiceXMLProfileGetResponse22()` or an
`ErrorResponse()`. Replaced by:
`SystemCallProcessingPolicyProfileVoiceXMLProfileGetRequest22V2()`

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileVoiceXMLProfileGetRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the configuration for a call processing policy profile VoiceXML
subscriber type profile.

The response is either a
`SystemCallProcessingPolicyProfileVoiceXMLProfileGetResponse22V2()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                |Type|Description                     |
|------------------------------------|----|--------------------------------|
|call_processing_policy_profile_name |str |callProcessingPolicyProfileName |
</div>


## `SystemCallProcessingPolicyProfileVoiceXMLProfileModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call processing policy profile voice XML type profile in system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode:
useMaxCallsPerSecond maxCallsPerSecond

**Attributes:**

|Name                                                                      |Type |Description                                                                |
|--------------------------------------------------------------------------|-----|---------------------------------------------------------------------------|
|call_processing_policy_profile_name                                       |str  |callProcessingPolicyProfileName                                            |
|use_clid_policy                                                           |bool |useCLIDPolicy *Optional*                                                   |
|clid_policy                                                               |str  |clidPolicy *Optional*                                                      |
|emergency_clid_policy                                                     |str  |emergencyClidPolicy *Optional*                                             |
|allow_alternate_numbers_for_redirecting_identity                          |bool |allowAlternateNumbersForRedirectingIdentity *Optional*                     |
|use_group_name                                                            |bool |useGroupName *Optional*                                                    |
|block_calling_name_for_external_calls                                     |bool |blockCallingNameForExternalCalls *Optional*                                |
|allow_configurable_clid_for_redirecting_identity                          |bool |allowConfigurableCLIDForRedirectingIdentity *Optional*                     |
|allow_department_clid_name_override                                       |bool |allowDepartmentCLIDNameOverride *Optional*                                 |
|enterprise_calls_clid_policy                                              |str  |enterpriseCallsCLIDPolicy *Optional*                                       |
|enterprise_group_calls_clid_policy                                        |str  |enterpriseGroupCallsCLIDPolicy *Optional*                                  |
|service_provider_group_calls_clid_policy                                  |str  |serviceProviderGroupCallsCLIDPolicy *Optional*                             |
|use_call_limits_policy                                                    |bool |useCallLimitsPolicy *Optional*                                             |
|use_max_simultaneous_calls                                                |bool |useMaxSimultaneousCalls *Optional*                                         |
|max_simultaneous_calls                                                    |int  |maxSimultaneousCalls *Optional*                                            |
|use_max_simultaneous_video_calls                                          |bool |useMaxSimultaneousVideoCalls *Optional*                                    |
|max_simultaneous_video_calls                                              |int  |maxSimultaneousVideoCalls *Optional*                                       |
|use_max_call_time_for_answered_calls                                      |bool |useMaxCallTimeForAnsweredCalls *Optional*                                  |
|max_call_time_for_answered_calls_minutes                                  |int  |maxCallTimeForAnsweredCallsMinutes *Optional*                              |
|use_max_call_time_for_unanswered_calls                                    |bool |useMaxCallTimeForUnansweredCalls *Optional*                                |
|max_call_time_for_unanswered_calls_minutes                                |int  |maxCallTimeForUnansweredCallsMinutes *Optional*                            |
|use_max_concurrent_redirected_calls                                       |bool |useMaxConcurrentRedirectedCalls *Optional*                                 |
|max_concurrent_redirected_calls                                           |int  |maxConcurrentRedirectedCalls *Optional*                                    |
|max_redirection_depth                                                     |int  |maxRedirectionDepth *Optional*                                             |
|use_translation_routing_policy                                            |bool |useTranslationRoutingPolicy *Optional*                                     |
|network_usage_selection                                                   |str  |networkUsageSelection *Optional*                                           |
|enable_enterprise_extension_dialing                                       |bool |enableEnterpriseExtensionDialing *Optional*                                |
|enforce_group_calling_line_identity_restriction                           |bool |enforceGroupCallingLineIdentityRestriction *Optional*                      |
|enforce_enterprise_calling_line_identity_restriction                      |bool |enforceEnterpriseCallingLineIdentityRestriction *Optional*                 |
|allow_enterprise_group_call_typing_for_private_dialing_plan               |bool |allowEnterpriseGroupCallTypingForPrivateDialingPlan *Optional*             |
|allow_enterprise_group_call_typing_for_public_dialing_plan                |bool |allowEnterpriseGroupCallTypingForPublicDialingPlan *Optional*              |
|override_clid_restriction_for_private_call_category                       |bool |overrideCLIDRestrictionForPrivateCallCategory *Optional*                   |
|use_enterprise_clid_for_private_call_category                             |bool |useEnterpriseCLIDForPrivateCallCategory *Optional*                         |
|use_incoming_clid_policy                                                  |bool |useIncomingCLIDPolicy *Optional*                                           |
|enable_dialable_caller_id                                                 |bool |enableDialableCallerID *Optional*                                          |
|include_redirections_in_maximum_number_of_concurrent_calls                |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls *Optional*             |
|use_user_phone_number_for_group_calls_when_internal_clid_unavailable      |bool |useUserPhoneNumberForGroupCallsWhenInternalCLIDUnavailable *Optional*      |
|use_user_phone_number_for_enterprise_calls_when_internal_clid_unavailable |bool |useUserPhoneNumberForEnterpriseCallsWhenInternalCLIDUnavailable *Optional* |
|use_max_calls_per_second                                                  |bool |useMaxCallsPerSecond *Optional*                                            |
|max_calls_per_second                                                      |int  |maxCallsPerSecond *Optional*                                               |
</div>


## `SystemCallRecordingAddPlatformRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Call Recording platform.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`SystemCallRecordingAddPlatformRequest19()`

**Attributes:**

|Name           |Type|Description            |
|---------------|----|-----------------------|
|name           |str |name                   |
|net_address    |str |netAddress             |
|port           |int |port                   |
|media_stream   |str |mediaStream            |
|transport_type |str |transportType          |
|description    |str |description *Optional* |
</div>


## `SystemCallRecordingAddPlatformRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Call Recording platform.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`SystemCallRecordingAddPlatformRequest20()`

**Attributes:**

|Name           |Type|Description            |
|---------------|----|-----------------------|
|name           |str |name                   |
|net_address    |str |netAddress             |
|port           |int |port                   |
|media_stream   |str |mediaStream            |
|transport_type |str |transportType          |
|description    |str |description *Optional* |
|schema_version |str |schemaVersion          |
</div>


## `SystemCallRecordingAddPlatformRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Call Recording platform.

The first system level call recording platform added is made the system default call
recording platform.  The first reseller level call recording platform added for a
reseller is made the reseller default call recording platform.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`SystemCallRecordingAddPlatformRequest22()`

**Attributes:**

|Name                    |Type |Description            |
|------------------------|-----|-----------------------|
|name                    |str  |name                   |
|net_address             |str  |netAddress             |
|port                    |int  |port *Optional*        |
|media_stream            |str  |mediaStream            |
|transport_type          |str  |transportType          |
|description             |str  |description *Optional* |
|schema_version          |str  |schemaVersion          |
|support_video_recording |bool |supportVideoRecording  |
|reseller_id             |str  |resellerId *Optional*  |
</div>


## `SystemCallRecordingAddPlatformRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Call Recording platform.

The first system level call recording platform added is made the system default call
recording platform.  The first reseller level call recording platform added for a
reseller is made the reseller default call recording platform.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                    |Type |Description            |
|------------------------|-----|-----------------------|
|name                    |str  |name                   |
|net_address             |str  |netAddress             |
|port                    |int  |port *Optional*        |
|media_stream            |str  |mediaStream            |
|transport_type          |str  |transportType          |
|description             |str  |description *Optional* |
|schema_version          |str  |schemaVersion          |
|support_video_recording |bool |supportVideoRecording  |
|reseller_id             |str  |resellerId *Optional*  |
|route                   |str  |route *Optional*       |
</div>


## `SystemCallRecordingDeletePlatformRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Call Recording platform.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemCallRecordingGetPlatformListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get list of Call Recording platforms.

The response is either `SystemCallRecordingGetPlatformListResponse()` or
`ErrorResponse()`. The possible values for "Support Video Rec" can be either true or
false.  Schema version values include: 1.0, 2.0, 3.0 Replaced by:
`SystemCallRecordingGetPlatformListRequest20sp1()` in AS data mode

</div>


## `SystemCallRecordingGetPlatformListRequest20sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get list of Call Recording platforms.

The response is either `SystemCallRecordingGetPlatformListResponse20sp1()` or
`ErrorResponse()`. The possible values for "Support Video Rec" can be either true or
false.  Schema version values include: 1.0, 2.0, 3.0 Replaced by
`SystemCallRecordingGetPlatformListRequest22()` in AS data mode.

</div>


## `SystemCallRecordingGetPlatformListRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of all system-level call recording platforms and all reseller level
call recording platforms.

If an excludeReseller is specified, returns all the system-level call recording
platforms only.  If a resellerId is specified, returns all the system-level call
recording platforms and the given reseller's call recording platforms.  If a reseller
administrator sends the request and resellerId is not specified, the administrator's
resellerId is used.

The response is either `SystemCallRecordingGetPlatformListResponse22()` or
`ErrorResponse()`. Replaced by: `SystemCallRecordingGetPlatformListRequest22V2()`

**Attributes:**

|Name             |Type |Description                |
|-----------------|-----|---------------------------|
|exclude_reseller |bool |excludeReseller *Optional* |
|reseller_id      |str  |resellerId *Optional*      |
</div>


## `SystemCallRecordingGetPlatformListRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of all system-level call recording platforms and all reseller level
call recording platforms.

If an excludeReseller is specified, returns all the system-level call recording
platforms only.  If a resellerId is specified, returns all the system-level call
recording platforms and the given reseller's call recording platforms.  If a reseller
administrator sends the request and resellerId is not specified, the administrator's
resellerId is used.

The response is either `SystemCallRecordingGetPlatformListResponse22V2()` or
`ErrorResponse()`.

**Attributes:**

|Name             |Type |Description                |
|-----------------|-----|---------------------------|
|exclude_reseller |bool |excludeReseller *Optional* |
|reseller_id      |str  |resellerId *Optional*      |
</div>


## `SystemCallRecordingGetPlatformUsageRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of groups currently associated to the specified Call Recording platform.

The response is either `SystemCallRecordingGetPlatformUsageResponse()` or
`ErrorResponse()`. Replaced by `SystemCallRecordingGetPlatformUsageRequest22()` in AS
data mode.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemCallRecordingGetPlatformUsageRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of groups currently associated to the specified Call Recording platform.

The response is either `SystemCallRecordingGetPlatformUsageResponse22()` or
`ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemCallRecordingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Call Recording.

The response is either a `SystemCallRecordingGetResponse()` or an `ErrorResponse()`.
Replaced by: `SystemCallRecordingGetRequest22()`

</div>


## `SystemCallRecordingGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Call Recording.

The response is either a `SystemCallRecordingGetResponse22()` or an `ErrorResponse()`.
Replaced by: `SystemCallRecordingGetRequest23()`

</div>


## `SystemCallRecordingGetRequest23`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Call Recording.

The response is either a `SystemCallRecordingGetResponse23()` or an `ErrorResponse()`.

</div>


## `SystemCallRecordingModifyPlatformRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the specified Call Recording platform.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`SystemCallRecordingModifyPlatformRequest22()`

**Attributes:**

|Name                    |Type |Description                      |
|------------------------|-----|---------------------------------|
|name                    |str  |name                             |
|net_address             |str  |netAddress *Optional*            |
|port                    |int  |port *Optional*                  |
|media_stream            |str  |mediaStream *Optional*           |
|become_system_default   |bool |becomeSystemDefault *Optional*   |
|become_reseller_default |str  |becomeResellerDefault *Optional* |
|transport_type          |str  |transportType *Optional*         |
|description             |str  |description *Optional*           |
|schema_version          |str  |schemaVersion *Optional*         |
|support_video_recording |bool |supportVideoRecording *Optional* |
</div>


## `SystemCallRecordingModifyPlatformRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the specified Call Recording platform.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                    |Type |Description                      |
|------------------------|-----|---------------------------------|
|name                    |str  |name                             |
|net_address             |str  |netAddress *Optional*            |
|port                    |int  |port *Optional*                  |
|media_stream            |str  |mediaStream *Optional*           |
|become_system_default   |bool |becomeSystemDefault *Optional*   |
|become_reseller_default |str  |becomeResellerDefault *Optional* |
|transport_type          |str  |transportType *Optional*         |
|description             |str  |description *Optional*           |
|schema_version          |str  |schemaVersion *Optional*         |
|support_video_recording |bool |supportVideoRecording *Optional* |
|route                   |str  |route *Optional*                 |
</div>


## `SystemCallRecordingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with Call Recording.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

Replaced By: `SystemCallRecordingModifyRequest22()`

**Attributes:**

|Name                                        |Type |Description                                       |
|--------------------------------------------|-----|--------------------------------------------------|
|continue_call_after_recording_failure       |bool |continueCallAfterRecordingFailure *Optional*      |
|refresh_period_seconds                      |int  |refreshPeriodSeconds *Optional*                   |
|max_consecutive_failures                    |int  |maxConsecutiveFailures *Optional*                 |
|max_response_wait_time_milliseconds         |int  |maxResponseWaitTimeMilliseconds *Optional*        |
|continue_call_after_video_recording_failure |bool |continueCallAfterVideoRecordingFailure *Optional* |
</div>


## `SystemCallRecordingModifyRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with Call Recording.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                                                              |Type |Description                                                                      |
|----------------------------------------------------------------------------------|-----|---------------------------------------------------------------------------------|
|continue_call_after_recording_failure                                             |bool |continueCallAfterRecordingFailure *Optional*                                     |
|max_response_wait_time_milliseconds                                               |int  |maxResponseWaitTimeMilliseconds *Optional*                                       |
|continue_call_after_video_recording_failure                                       |bool |continueCallAfterVideoRecordingFailure *Optional*                                |
|use_continue_call_after_recording_failure_for_on_demand_mode                      |bool |useContinueCallAfterRecordingFailureForOnDemandMode *Optional*                   |
|use_continue_call_after_recording_failure_for_on_demand_user_initiated_start_mode |bool |useContinueCallAfterRecordingFailureForOnDemandUserInitiatedStartMode *Optional* |
|restrict_call_recording_provisioning_access                                       |bool |restrictCallRecordingProvisioningAccess *Optional*                               |
</div>


## `SystemCallReturnGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Call Return.

The response is either a `SystemCallReturnGetResponse()` or an `ErrorResponse()`.

</div>


## `SystemCallReturnModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with Call Return.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                     |Type |Description                                    |
|-----------------------------------------|-----|-----------------------------------------------|
|two_level_activation                     |bool |twoLevelActivation *Optional*                  |
|provide_date                             |bool |provideDate *Optional*                         |
|last_unanswered_call_only                |bool |lastUnansweredCallOnly *Optional*              |
|confirmation_key                         |str  |confirmationKey *Optional*                     |
|allow_restricted_number                  |bool |allowRestrictedNumber *Optional*               |
|delete_number_after_answered_call_return |bool |deleteNumberAfterAnsweredCallReturn *Optional* |
</div>


## `SystemCallTypeAddMappingRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a system call type mapping.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name         |Type|Description |
|-------------|----|------------|
|country_code |str |countryCode |
|digit_map    |str |digitMap    |
|call_type    |str |callType    |
</div>


## `SystemCallTypeDeleteMappingRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a system call type mapping.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name         |Type|Description |
|-------------|----|------------|
|country_code |str |countryCode |
|digit_map    |str |digitMap    |
</div>


## `SystemCallTypeGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of system call types.

The response is either `SystemCallTypeGetListResponse()` or `ErrorResponse()`.

</div>


## `SystemCallTypeGetMappingListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of system call type mappings.

The response is either `SystemCallTypeGetMappingListResponse()` or `ErrorResponse()`.

**Attributes:**

|Name         |Type|Description            |
|-------------|----|-----------------------|
|country_code |str |countryCode *Optional* |
</div>


## `SystemCallWaitingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Call Waiting.

The response is either a `SystemCallWaitingGetResponse()` or an `ErrorResponse()`.

</div>


## `SystemCallWaitingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with Call Waiting.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                      |Type |Description                        |
|--------------------------|-----|-----------------------------------|
|play_distinctive_ringback |bool |playDistinctiveRingback *Optional* |
</div>


## `SystemCallingNameRetrievalGetRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system's calling name retrieval attributes.

The response is either a `SystemCallingNameRetrievalGetResponse14()` or an
`ErrorResponse()`.

</div>


## `SystemCallingNameRetrievalGetRequest16sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system's calling name retrieval attributes.

The response is either a `SystemCallingNameRetrievalGetResponse16sp1()` or an
`ErrorResponse()`. Replaced by: `SystemCallingNameRetrievalGetRequest17sp4()`

</div>


## `SystemCallingNameRetrievalGetRequest17sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system's calling name retrieval attributes.

The response is either a `SystemCallingNameRetrievalGetResponse17sp4()` or an
`ErrorResponse()`. Replaced by: `SystemCallingNameRetrievalGetRequest24()`

</div>


## `SystemCallingNameRetrievalGetRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system's calling name retrieval attributes.

The response is either a `SystemCallingNameRetrievalGetResponse20()` or an
`ErrorResponse()`. Replaced by: `SystemCallingNameRetrievalGetRequest24()`

</div>


## `SystemCallingNameRetrievalGetRequest24`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system's calling name retrieval attributes.

The response is either a `SystemCallingNameRetrievalGetResponse24()` or an
`ErrorResponse()`.

</div>


## `SystemCallingNameRetrievalModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the system's calling name retrieval attributes.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`SystemCallingNameRetrievalModifyRequest16sp1()`

**Attributes:**

|Name                      |Type|Description                        |
|--------------------------|----|-----------------------------------|
|query_timer_milli_seconds |int |queryTimerMilliSeconds *Optional*  |
|server_net_address        |str |serverNetAddress *Optional*        |
|server_port               |int |serverPort *Optional*              |
|server_transport_protocol |str |serverTransportProtocol *Optional* |
</div>


## `SystemCallingNameRetrievalModifyRequest16sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the system's calling name retrieval attributes.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`SystemCallingNameRetrievalModifyRequest20()`

**Attributes:**

|Name                                                |Type |Description                                             |
|----------------------------------------------------|-----|--------------------------------------------------------|
|trigger_cnam_queries_for_all_network_calls          |bool |triggerCNAMQueriesForAllNetworkCalls *Optional*         |
|trigger_cnam_queries_for_group_and_enterprise_calls |bool |triggerCNAMQueriesForGroupAndEnterpriseCalls *Optional* |
|query_protocol                                      |str  |queryProtocol *Optional*                                |
|query_timeout_milliseconds                          |int  |queryTimeoutMilliseconds *Optional*                     |
|sip_external_database_net_address                   |str  |sipExternalDatabaseNetAddress *Optional*                |
|sip_external_database_port                          |int  |sipExternalDatabasePort *Optional*                      |
|sip_external_database_transport                     |str  |sipExternalDatabaseTransport *Optional*                 |
|soap_external_database_net_address                  |str  |soapExternalDatabaseNetAddress *Optional*               |
|soap_supports_dnssrv                                |bool |soapSupportsDNSSRV *Optional*                           |
|calling_name_source                                 |str  |callingNameSource *Optional*                            |
</div>


## `SystemCallingNameRetrievalModifyRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the system's calling name retrieval attributes.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                                |Type |Description                                             |
|----------------------------------------------------|-----|--------------------------------------------------------|
|trigger_cnam_queries_for_all_network_calls          |bool |triggerCNAMQueriesForAllNetworkCalls *Optional*         |
|trigger_cnam_queries_for_group_and_enterprise_calls |bool |triggerCNAMQueriesForGroupAndEnterpriseCalls *Optional* |
|query_protocol                                      |str  |queryProtocol *Optional*                                |
|query_timeout_milliseconds                          |int  |queryTimeoutMilliseconds *Optional*                     |
|sip_external_database_net_address                   |str  |sipExternalDatabaseNetAddress *Optional*                |
|sip_external_database_port                          |int  |sipExternalDatabasePort *Optional*                      |
|sip_external_database_transport                     |str  |sipExternalDatabaseTransport *Optional*                 |
|soap_external_database_net_address                  |str  |soapExternalDatabaseNetAddress *Optional*               |
|calling_name_source                                 |str  |callingNameSource *Optional*                            |
|route_advance_timer                                 |int  |routeAdvanceTimer *Optional*                            |
|retry_failed_cnam_server_interval                   |int  |retryFailedCNAMServerInterval *Optional*                |
|ignore_restricted_presentation_indicator            |bool |ignoreRestrictedPresentationIndicator *Optional*        |
|supports_dnssrv                                     |bool |supportsDNSSRV *Optional*                               |
</div>


## `SystemCallingPartyCategoryAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Calling Party Category to system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name            |Type |Description              |
|----------------|-----|-------------------------|
|category        |str  |category                 |
|cpc_value       |str  |cpcValue *Optional*      |
|isup_oli_value  |int  |isupOliValue *Optional*  |
|gtd_oli_value   |str  |gtdOliValue *Optional*   |
|user_category   |bool |userCategory             |
|pay_phone       |bool |payPhone                 |
|operator        |bool |operator                 |
|default         |bool |default                  |
|collect_call    |bool |collectCall              |
|web_display_key |str  |webDisplayKey *Optional* |
</div>


## `SystemCallingPartyCategoryDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Calling Party Category from system.

The category cannot be deleted if it is the default or is in use by any users.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name     |Type|Description|
|---------|----|-----------|
|category |str |category   |
</div>


## `SystemCallingPartyCategoryGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of all Calling Party Category in system.

The response is either a `SystemCallingPartyCategoryGetListResponse()` or an
`ErrorResponse()`.

</div>


## `SystemCallingPartyCategoryGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get an existing Calling Party Category in system.

The response is either a `SystemCallingPartyCategoryGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name     |Type|Description|
|---------|----|-----------|
|category |str |category   |
</div>


## `SystemCallingPartyCategoryModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a Calling Party Category in system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name            |Type |Description              |
|----------------|-----|-------------------------|
|category        |str  |category                 |
|cpc_value       |str  |cpcValue *Optional*      |
|isup_oli_value  |int  |isupOliValue *Optional*  |
|gtd_oli_value   |str  |gtdOliValue *Optional*   |
|user_category   |bool |userCategory *Optional*  |
|pay_phone       |bool |payPhone *Optional*      |
|operator        |bool |operator *Optional*      |
|become_default  |bool |becomeDefault *Optional* |
|collect_call    |bool |collectCall *Optional*   |
|web_display_key |str  |webDisplayKey *Optional* |
</div>


## `SystemClassmarkAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Class Mark to system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description              |
|----------------|----|-------------------------|
|classmark       |str |classmark                |
|value           |str |value                    |
|web_display_key |str |webDisplayKey *Optional* |
</div>


## `SystemClassmarkDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Class Mark from system.

It cannot be deleted if it is in use by any users.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name      |Type|Description|
|----------|----|-----------|
|classmark |str |classmark  |
</div>


## `SystemClassmarkGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of all Class Mark in system.

The response is either a `SystemClassmarkGetListResponse()` or an `ErrorResponse()`.

</div>


## `SystemClassmarkModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a Class Mark in system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description              |
|----------------|----|-------------------------|
|classmark       |str |classmark                |
|value           |str |value *Optional*         |
|web_display_key |str |webDisplayKey *Optional* |
</div>


## `SystemClientIdentityAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a client identity entry to the list of client identities in the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description    |
|----------------|----|---------------|
|client_identity |str |clientIdentity |
</div>


## `SystemClientIdentityDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a client identity.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description    |
|----------------|----|---------------|
|client_identity |str |clientIdentity |
</div>


## `SystemClientIdentityGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a list of client identities.

The response is either a `SystemClientIdentityGetListResponse()` or an
`ErrorResponse()`.

</div>


## `SystemClientSessionParametersGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of Client Session (web and CLI) system parameters.

The response is either `SystemClientSessionParametersGetResponse()` or
`ErrorResponse()`.

</div>


## `SystemClientSessionParametersModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify Client Session (web and CLI) system parameters.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                       |Type |Description                         |
|---------------------------|-----|------------------------------------|
|enable_inactivity_timeout  |bool |enableInactivityTimeout *Optional*  |
|inactivity_timeout_minutes |int  |inactivityTimeoutMinutes *Optional* |
</div>


## `SystemCodecAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a codec to the ordered list of codecs supported by the system.

The ordered list of codecs is sent to MGCP devices when creating connections.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name  |Type|Description|
|------|----|-----------|
|codec |str |codec      |
</div>


## `SystemCodecDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a supported codec from the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name  |Type|Description|
|------|----|-----------|
|codec |str |codec      |
</div>


## `SystemCodecGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the ordered list of supported codecs in the system.

The ordered list of codecs is sent to MGCP devices when creating connections.

The response is either a `SystemCodecGetListResponse()` or an `ErrorResponse()`.

</div>


## `SystemCollaborateGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with collaborate services.

The response is either a `SystemCollaborateGetResponse()` or an `ErrorResponse()`.
Replaced by: `SystemCollaborateGetRequest20sp1()`

</div>


## `SystemCollaborateGetRequest20sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with collaborate services.

The response is either a `SystemCollaborateGetResponse20sp1()` or an
`ErrorResponse()`. Replaced by: SystemCollaborateGetRequest20sp1V2

</div>


## `SystemCommunicationBarringAlternateCallIndicatorAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Communication Barring Alternate Call Indicator.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                    |Type|Description                         |
|----------------------------------------|----|------------------------------------|
|alternate_call_indicator                |str |alternateCallIndicator              |
|network_server_alternate_call_indicator |str |networkServerAlternateCallIndicator |
</div>


## `SystemCommunicationBarringAlternateCallIndicatorDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Communication Barring Alternate Call Indicator.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type|Description            |
|-------------------------|----|-----------------------|
|alternate_call_indicator |str |alternateCallIndicator |
</div>


## `SystemCommunicationBarringAlternateCallIndicatorGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get all the Communication Barring Alternate Call Indicator defined in the system.

The response is either a
`SystemCommunicationBarringAlternateCallIndicatorGetListResponse()` or an
`ErrorResponse()`.

</div>


## `SystemCommunicationBarringAlternateCallIndicatorModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a Communication Barring Alternate Call Indicator.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                    |Type|Description                                    |
|----------------------------------------|----|-----------------------------------------------|
|alternate_call_indicator                |str |alternateCallIndicator                         |
|network_server_alternate_call_indicator |str |networkServerAlternateCallIndicator *Optional* |
</div>


## `SystemCommunicationBarringCallTypeAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Communication Barring Call Type.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type|Description           |
|-------------------------|----|----------------------|
|call_type                |str |callType              |
|network_server_call_type |str |networkServerCallType |
</div>


## `SystemCommunicationBarringCallTypeDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Communication Barring Call Type.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name      |Type|Description|
|----------|----|-----------|
|call_type |str |callType   |
</div>


## `SystemCommunicationBarringCallTypeGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get all the Communication Barring Call Types defined in the system.

The response is either a `SystemCommunicationBarringCallTypeGetListResponse()` or an
`ErrorResponse()`.

</div>


## `SystemCommunicationBarringCallTypeModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a Communication Barring Call Type.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type|Description                      |
|-------------------------|----|---------------------------------|
|call_type                |str |callType                         |
|network_server_call_type |str |networkServerCallType *Optional* |
</div>


## `SystemCommunicationBarringCriteriaAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a new Communication Barring Criteria.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`SystemCommunicationBarringCriteriaAddRequest17()`

**Attributes:**

|Name                           |Type      |Description                            |
|-------------------------------|----------|---------------------------------------|
|name                           |str       |name                                   |
|description                    |str       |description *Optional*                 |
|match_call_type                |List[str] |matchCallType *Optional*               |
|match_alternate_call_indicator |List[str] |matchAlternateCallIndicator *Optional* |
|match_virtual_on_net_call_type |List[str] |matchVirtualOnNetCallType *Optional*   |
|match_public_network           |bool      |matchPublicNetwork                     |
|match_private_network          |bool      |matchPrivateNetwork                    |
|match_local_category           |bool      |matchLocalCategory                     |
|match_national_category        |bool      |matchNationalCategory                  |
|match_interlata_category       |bool      |matchInterlataCategory                 |
|match_intralata_category       |bool      |matchIntralataCategory                 |
|match_international_category   |bool      |matchInternationalCategory             |
|match_private_category         |bool      |matchPrivateCategory                   |
|match_emergency_category       |bool      |matchEmergencyCategory                 |
|match_other_category           |bool      |matchOtherCategory                     |
|match_inter_network            |bool      |matchInterNetwork                      |
|match_inter_hosting_ne         |bool      |matchInterHostingNE                    |
|match_inter_as                 |bool      |matchInterAS                           |
|match_intra_as                 |bool      |matchIntraAS                           |
|match_charge_calls             |bool      |matchChargeCalls                       |
|match_no_charge_calls          |bool      |matchNoChargeCalls                     |
|match_group_calls              |bool      |matchGroupCalls                        |
|match_enterprise_calls         |bool      |matchEnterpriseCalls                   |
|match_network_calls            |bool      |matchNetworkCalls                      |
|match_network_url_calls        |bool      |matchNetworkURLCalls                   |
|match_repair_calls             |bool      |matchRepairCalls                       |
|match_emergency_calls          |bool      |matchEmergencyCalls                    |
|match_internal_calls           |bool      |matchInternalCalls                     |
|time_schedule                  |str       |timeSchedule *Optional*                |
|holiday_schedule               |str       |holidaySchedule *Optional*             |
</div>


## `SystemCommunicationBarringCriteriaAddRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a new Communication Barring Criteria.

The following elements are only used in AS data mode: matchNumberPortabilityStatus

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                            |Type      |Description                             |
|--------------------------------|----------|----------------------------------------|
|name                            |str       |name                                    |
|description                     |str       |description *Optional*                  |
|match_call_type                 |List[str] |matchCallType *Optional*                |
|match_alternate_call_indicator  |List[str] |matchAlternateCallIndicator *Optional*  |
|match_virtual_on_net_call_type  |List[str] |matchVirtualOnNetCallType *Optional*    |
|match_public_network            |bool      |matchPublicNetwork                      |
|match_private_network           |bool      |matchPrivateNetwork                     |
|match_local_category            |bool      |matchLocalCategory                      |
|match_national_category         |bool      |matchNationalCategory                   |
|match_interlata_category        |bool      |matchInterlataCategory                  |
|match_intralata_category        |bool      |matchIntralataCategory                  |
|match_international_category    |bool      |matchInternationalCategory              |
|match_private_category          |bool      |matchPrivateCategory                    |
|match_emergency_category        |bool      |matchEmergencyCategory                  |
|match_other_category            |bool      |matchOtherCategory                      |
|match_inter_network             |bool      |matchInterNetwork                       |
|match_inter_hosting_ne          |bool      |matchInterHostingNE                     |
|match_inter_as                  |bool      |matchInterAS                            |
|match_intra_as                  |bool      |matchIntraAS                            |
|match_charge_calls              |bool      |matchChargeCalls                        |
|match_no_charge_calls           |bool      |matchNoChargeCalls                      |
|match_group_calls               |bool      |matchGroupCalls                         |
|match_enterprise_calls          |bool      |matchEnterpriseCalls                    |
|match_network_calls             |bool      |matchNetworkCalls                       |
|match_network_url_calls         |bool      |matchNetworkURLCalls                    |
|match_repair_calls              |bool      |matchRepairCalls                        |
|match_emergency_calls           |bool      |matchEmergencyCalls                     |
|match_internal_calls            |bool      |matchInternalCalls                      |
|match_location                  |str       |matchLocation                           |
|match_roaming                   |str       |matchRoaming                            |
|time_schedule                   |str       |timeSchedule *Optional*                 |
|holiday_schedule                |str       |holidaySchedule *Optional*              |
|match_number_portability_status |List[str] |matchNumberPortabilityStatus *Optional* |
</div>


## `SystemCommunicationBarringCriteriaDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete an existing Communication Barring Criteria.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemCommunicationBarringCriteriaGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of all Communication Barring Criteria.

The response is either a `SystemCommunicationBarringCriteriaGetListResponse()` or an
`ErrorResponse()`.

</div>


## `SystemCommunicationBarringCriteriaGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get an existing Communication Barring Criteria.

The response is either a `SystemCommunicationBarringCriteriaGetResponse()` or an
`ErrorResponse()`. Replaced by: `SystemCommunicationBarringCriteriaGetRequest17()`

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemCommunicationBarringCriteriaGetRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get an existing Communication Barring Criteria.

The response is either a `SystemCommunicationBarringCriteriaGetResponse17()` or an
`ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemCommunicationBarringCriteriaGetRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get an existing Communication Barring Criteria.

The response is either a `SystemCommunicationBarringCriteriaGetResponse19sp1()` or an
`ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemCommunicationBarringDigitPatternCriteriaAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a new Communication Barring Digit Pattern Criteria.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type      |Description                  |
|--------------------|----------|-----------------------------|
|name                |str       |name                         |
|description         |str       |description *Optional*       |
|match_digit_pattern |List[str] |matchDigitPattern *Optional* |
</div>


## `SystemCommunicationBarringDigitPatternCriteriaDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete an existing Communication Barring Digit Pattern Criteria.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemCommunicationBarringDigitPatternCriteriaGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of all Digit Pattern Criteria defined at the system level.

The response is either a
`SystemCommunicationBarringDigitPatternCriteriaGetListResponse()` or an
`ErrorResponse()`.

</div>


## `SystemCommunicationBarringDigitPatternCriteriaGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get an existing Communication Barring Digit Pattern Criteria.

The response is either a `SystemCommunicationBarringDigitPatternCriteriaGetResponse()`
or an `ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemCommunicationBarringDigitPatternCriteriaModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an existing Communication Barring Digit Pattern Criteria.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                       |Type      |Description                        |
|---------------------------|----------|-----------------------------------|
|name                       |str       |name                               |
|new_name                   |str       |newName *Optional*                 |
|description                |str       |description *Optional*             |
|add_match_digit_pattern    |List[str] |addMatchDigitPattern *Optional*    |
|delete_match_digit_pattern |List[str] |deleteMatchDigitPattern *Optional* |
</div>


## `SystemCommunicationBarringGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Communication Barring.

The response is either a `SystemCommunicationBarringGetResponse()` or an
`ErrorResponse()`. Replaced by: `SystemCommunicationBarringGetRequest21sp1()` in AS
data mode.

</div>


## `SystemCommunicationBarringGetRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Communication Barring.

The response is either a `SystemCommunicationBarringGetResponse21sp1()` or an
`ErrorResponse()`.

</div>


## `SystemCommunicationBarringIncomingCriteriaAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a new Communication Barring Incoming Criteria.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`SystemCommunicationBarringIncomingCriteriaAddRequest22()`

**Attributes:**

|Name                            |Type      |Description                             |
|--------------------------------|----------|----------------------------------------|
|name                            |str       |name                                    |
|description                     |str       |description *Optional*                  |
|time_schedule                   |str       |timeSchedule *Optional*                 |
|holiday_schedule                |str       |holidaySchedule *Optional*              |
|match_number_portability_status |List[str] |matchNumberPortabilityStatus *Optional* |
</div>


## `SystemCommunicationBarringIncomingCriteriaAddRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a new Communication Barring Incoming Criteria.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                            |Type      |Description                             |
|--------------------------------|----------|----------------------------------------|
|name                            |str       |name                                    |
|description                     |str       |description *Optional*                  |
|time_schedule                   |str       |timeSchedule *Optional*                 |
|holiday_schedule                |str       |holidaySchedule *Optional*              |
|match_number_portability_status |List[str] |matchNumberPortabilityStatus *Optional* |
|call_tagged_as_spam             |bool      |callTaggedAsSpam                        |
</div>


## `SystemCommunicationBarringIncomingCriteriaDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete an existing Communication Barring Incoming Criteria.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemCommunicationBarringIncomingCriteriaGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of all Communication Barring Incoming Criteria.

The response is either a `SystemCommunicationBarringIncomingCriteriaGetListResponse()`
or an `ErrorResponse()`.

</div>


## `SystemCommunicationBarringIncomingCriteriaGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get an existing Communication Barring Incoming Criteria.

The response is either a `SystemCommunicationBarringIncomingCriteriaGetResponse()` or
an `ErrorResponse()`. Replaced by:
`SystemCommunicationBarringIncomingCriteriaGetRequest22()`

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemCommunicationBarringIncomingCriteriaGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get an existing Communication Barring Incoming Criteria.

The response is either a `SystemCommunicationBarringIncomingCriteriaGetResponse22()`
or an `ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemCommunicationBarringModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with Communication Barring.

The following elements are only used in AS data mode and ignored in XS data mode:
vmCallbackScreening

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                      |Type |Description                        |
|--------------------------|-----|-----------------------------------|
|direct_transfer_screening |bool |directTransferScreening *Optional* |
|vm_callback_screening     |bool |vmCallbackScreening *Optional*     |
</div>


## `SystemCommunicationBarringProfileDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete an existing Communication Barring Profile.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemCommunicationBarringProfileGetCriteriaUsageListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of Communication Barring Proifles that uses a specific Communication
Barring criteria.

The response is either a
`SystemCommunicationBarringProfileGetCriteriaUsageListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemCommunicationBarringProfileGetDigitPatternCriteriaUsageListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of Profiles that use a specific Digit Pattern Criteria.

The response is either a
`SystemCommunicationBarringProfileGetDigitPatternCriteriaUsageListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemCommunicationBarringProfileGetIncomingCriteriaUsageListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of Communication Barring Proifles that uses a specific Communication
Barring Incoming criteria.

The response is either a
`SystemCommunicationBarringProfileGetIncomingCriteriaUsageListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemCommunicationBarringProfileGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of all Communication Barring Profiles.

The response is either a `SystemCommunicationBarringProfileGetListResponse()` or an
`ErrorResponse()`.

</div>


## `SystemCommunicationBarringProfileGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get an existing Communication Barring Profile.

The response is either a `SystemCommunicationBarringProfileGetResponse()` or an
`ErrorResponse()`. Replaced by: `SystemCommunicationBarringProfileGetRequest16()`

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemCommunicationBarringProfileGetRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get an existing Communication Barring Profile.

The response is either a `SystemCommunicationBarringProfileGetResponse16()` or an
`ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemCommunicationBarringProfileGetRequest17sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get an existing Communication Barring Profile.

The response is either a `SystemCommunicationBarringProfileGetResponse17sp1()` or an
`ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemCommunicationBarringProfileGetRequest17sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get an existing Communication Barring Profile.

The response is either a `SystemCommunicationBarringProfileGetResponse17sp3()` or an
`ErrorResponse()`. Replaced by: `SystemCommunicationBarringProfileGetRequest19sp1()`
in AS data mode

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemCommunicationBarringProfileGetRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get an existing Communication Barring Profile.

The response is either a `SystemCommunicationBarringProfileGetResponse19sp1()` or an
`ErrorResponse()`. Replaced by: SystemCommunicationBarringProfileGetRequest19sp1V2 in
AS data mode

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemCommunicationBarringServiceProviderGetCriteriaUsageListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of Service Providers that use a specific Communication Barring Criteria.

The response is either a
`SystemCommunicationBarringServiceProviderGetCriteriaUsageListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemCommunicationBarringServiceProviderGetIncomingCriteriaUsageListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of Service Providers that use a specific Communication Barring Incoming
Criteria.

The response is either a
`SystemCommunicationBarringServiceProviderGetIncomingCriteriaUsageListResponse()` or
an `ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemCommunicationBarringUserControlGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Gets the Communication Barring system level settings.

The response is either `SystemCommunicationBarringUserControlGetResponse()` or
`ErrorResponse()`.

</div>


## `SystemCommunicationBarringUserControlModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the system's Communication Barring User-Control settings.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                          |Type |Description                          |
|------------------------------|-----|-------------------------------------|
|enable_lockout                |bool |enableLockout *Optional*             |
|max_number_of_failed_attempts |int  |maxNumberOfFailedAttempts *Optional* |
|lockout_minutes               |int  |lockoutMinutes *Optional*            |
</div>


## `SystemConfigurableFileSystemGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the File System parameters.

The response is either `SystemConfigurableFileSystemGetResponse()` or
`ErrorResponse()`. Replaced by: `SystemConfigurableFileSystemGetRequest23()`

</div>


## `SystemConfigurableFileSystemGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the File System parameters.

The response is either `SystemConfigurableFileSystemGetResponse22()` or
`ErrorResponse()`.

</div>


## `SystemConfigurableFileSystemGetRequest23`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the File System parameters.

change of behavior is that CLI System/MediaFileSystem/get will no longer show the
password

The response is either `SystemConfigurableFileSystemGetResponse23()` or
`ErrorResponse()`.

</div>


## `SystemConfigurableFileSystemGetRequest23V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the File System parameters.

The response is either `SystemConfigurableFileSystemGetResponse23V2()` or
`ErrorResponse()`.

</div>


## `SystemConfigurableFileSystemModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify File System parameters.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode: protocolFile-
secure

**Attributes:**

|Name             |Type               |Description               |
|-----------------|-------------------|--------------------------|
|media_directory  |str                |mediaDirectory *Optional* |
|protocol_file    |OCI.protocolFile   |protocolFile *Optional*   |
|protocol_web_dav |OCI.protocolWebDAV |protocolWebDAV *Optional* |
</div>


## `SystemConfigurableTreatmentAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a configurable treatment.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                         |Type |Description                          |
|-----------------------------|-----|-------------------------------------|
|treatment_id                 |str  |treatmentId                          |
|charge_indicator             |str  |chargeIndicator                      |
|description                  |str  |description *Optional*               |
|access_sip_status_code       |int  |accessSIPStatusCode *Optional*       |
|access_sip_status_message    |str  |accessSIPStatusMessage *Optional*    |
|network_sip_status_code      |int  |networkSIPStatusCode *Optional*      |
|network_sip_status_message   |str  |networkSIPStatusMessage *Optional*   |
|q850_cause_value             |int  |q850CauseValue *Optional*            |
|q850_text                    |str  |q850Text *Optional*                  |
|access_treatment_audio_file  |str  |accessTreatmentAudioFile *Optional*  |
|access_treatment_video_file  |str  |accessTreatmentVideoFile *Optional*  |
|network_treatment_audio_file |str  |networkTreatmentAudioFile *Optional* |
|network_treatment_video_file |str  |networkTreatmentVideoFile *Optional* |
|cdr_termination_cause        |str  |cdrTerminationCause *Optional*       |
|route_advance                |bool |routeAdvance *Optional*              |
|internal_release_cause       |str  |internalReleaseCause *Optional*      |
|access_send_reason_header    |bool |accessSendReasonHeader *Optional*    |
|network_send_reason_header   |bool |networkSendReasonHeader *Optional*   |
</div>


## `SystemConfigurableTreatmentDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a configurable treatment.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type|Description |
|-------------|----|------------|
|treatment_id |str |treatmentId |
</div>


## `SystemConfigurableTreatmentGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of configurable treatments.

The response is either a `SystemConfigurableTreatmentGetListResponse()` or an
`ErrorResponse()`.

</div>


## `SystemConfigurableTreatmentGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get all the attributes of a configurable treatment.

The response is either a `SystemConfigurableTreatmentGetResponse()` or an
`ErrorResponse()`.

Replaced By: `SystemConfigurableTreatmentGetRequest16()`

**Attributes:**

|Name         |Type|Description |
|-------------|----|------------|
|treatment_id |str |treatmentId |
</div>


## `SystemConfigurableTreatmentGetRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get all the attributes of a configurable treatment.

The response is either a `SystemConfigurableTreatmentGetResponse16()` or an
`ErrorResponse()`.

**Attributes:**

|Name         |Type|Description |
|-------------|----|------------|
|treatment_id |str |treatmentId |
</div>


## `SystemConfigurableTreatmentModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the fields for a configurable treatment.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                         |Type |Description                          |
|-----------------------------|-----|-------------------------------------|
|treatment_id                 |str  |treatmentId                          |
|charge_indicator             |str  |chargeIndicator *Optional*           |
|description                  |str  |description *Optional*               |
|access_sip_status_code       |int  |accessSIPStatusCode *Optional*       |
|access_sip_status_message    |str  |accessSIPStatusMessage *Optional*    |
|network_sip_status_code      |int  |networkSIPStatusCode *Optional*      |
|network_sip_status_message   |str  |networkSIPStatusMessage *Optional*   |
|q850_cause_value             |int  |q850CauseValue *Optional*            |
|q850_text                    |str  |q850Text *Optional*                  |
|access_treatment_audio_file  |str  |accessTreatmentAudioFile *Optional*  |
|access_treatment_video_file  |str  |accessTreatmentVideoFile *Optional*  |
|network_treatment_audio_file |str  |networkTreatmentAudioFile *Optional* |
|network_treatment_video_file |str  |networkTreatmentVideoFile *Optional* |
|cdr_termination_cause        |str  |cdrTerminationCause *Optional*       |
|route_advance                |bool |routeAdvance *Optional*              |
|internal_release_cause       |str  |internalReleaseCause *Optional*      |
|access_send_reason_header    |bool |accessSendReasonHeader *Optional*    |
|network_send_reason_header   |bool |networkSendReasonHeader *Optional*   |
</div>


## `SystemConnectedLineIdentificationPresentationGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with the COLP service.

The response is either a `SystemConnectedLineIdentificationPresentationGetResponse()`
or an `ErrorResponse()`.

</div>


## `SystemConnectedLineIdentificationPresentationModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with the COLP Service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                            |Type |Description                             |
|--------------------------------|-----|----------------------------------------|
|enforce_user_service_assignment |bool |enforceUserServiceAssignment *Optional* |
</div>


## `SystemCountryCodeAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a country code to the system.

If ringPeriodMilliseconds is not specified, a default of 6000 milliseconds is assumed.
If offHookWarningTimerSeconds is not specified, a default of 30 seconds is assumed.
If enableNationalPrefix is not specified, a default of false is assumed.  If
nationalPrefix is not specified, a default of null string is assumed.  If
disableNationalPrefixForOffNetCalls is not specified, a default of false is assumed.
The following elements are only used in AS data mode:
disableNationalPrefixForOffNetCalls.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                         |Type |Description                                        |
|---------------------------------------------|-----|---------------------------------------------------|
|country_code                                 |str  |countryCode                                        |
|country_name                                 |str  |countryName                                        |
|ring_period_milliseconds                     |int  |ringPeriodMilliseconds *Optional*                  |
|off_hook_warning_timer_seconds               |int  |offHookWarningTimerSeconds *Optional*              |
|enable_national_prefix                       |bool |enableNationalPrefix *Optional*                    |
|national_prefix                              |str  |nationalPrefix *Optional*                          |
|max_call_waiting_tones                       |int  |maxCallWaitingTones *Optional*                     |
|time_between_call_waiting_tones_milliseconds |int  |timeBetweenCallWaitingTonesMilliseconds *Optional* |
|disable_national_prefix_for_off_net_calls    |bool |disableNationalPrefixForOffNetCalls *Optional*     |
</div>


## `SystemCountryCodeDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a country code from the system.

A country code cannot be deleted if it is the default country code or if any carriers
or call type mappings are defined against it.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type|Description |
|-------------|----|------------|
|country_code |str |countryCode |
</div>


## `SystemCountryCodeGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request data for all country codes.

The response is either a `SystemCountryCodeGetListResponse()` or an `ErrorResponse()`.

</div>


## `SystemCountryCodeModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the attributes of a country code.

If becomeDefaultCountryCode is true, the country code in this request becomes the
default country code for the system.  The following elements are only used in AS data
mode: disableNationalPrefixForOffNetCalls

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                         |Type |Description                                        |
|---------------------------------------------|-----|---------------------------------------------------|
|country_code                                 |str  |countryCode                                        |
|ring_period_milliseconds                     |int  |ringPeriodMilliseconds *Optional*                  |
|off_hook_warning_timer_seconds               |int  |offHookWarningTimerSeconds *Optional*              |
|enable_national_prefix                       |bool |enableNationalPrefix *Optional*                    |
|national_prefix                              |str  |nationalPrefix *Optional*                          |
|become_default_country_code                  |bool |becomeDefaultCountryCode *Optional*                |
|max_call_waiting_tones                       |int  |maxCallWaitingTones *Optional*                     |
|time_between_call_waiting_tones_milliseconds |int  |timeBetweenCallWaitingTonesMilliseconds *Optional* |
|disable_national_prefix_for_off_net_calls    |bool |disableNationalPrefixForOffNetCalls *Optional*     |
</div>


## `SystemCrInterfaceGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Gets the system level attributes of the Cr Interface.

The response is either a `SystemCrInterfaceGetResponse()` or an `ErrorResponse()`.

</div>


## `SystemCrInterfaceGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Gets the system level attributes of the Cr Interface.

The response is either a `SystemCrInterfaceGetResponse()` or an `ErrorResponse()`.

</div>


## `SystemCrInterfaceModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with Cr Interface.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                               |Type |Description                                |
|-----------------------------------|-----|-------------------------------------------|
|cr_audit_enabled                   |bool |crAuditEnabled *Optional*                  |
|cr_audit_interval_milliseconds     |int  |crAuditIntervalMilliseconds *Optional*     |
|cr_audit_timeout_milliseconds      |int  |crAuditTimeoutMilliseconds *Optional*      |
|cr_connection_enabled              |bool |crConnectionEnabled *Optional*             |
|cr_connection_timeout_milliseconds |int  |crConnectionTimeoutMilliseconds *Optional* |
|cr_tcp_connection_timeout_seconds  |int  |crTcpConnectionTimeoutSeconds *Optional*   |
|cr_number_of_reconnection_attempts |int  |crNumberOfReconnectionAttempts *Optional*  |
</div>


## `SystemCustomerOriginatedTraceGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Customer Originated Trace.

The response is either a `SystemCustomerOriginatedTraceGetResponse()` or an
`ErrorResponse()`.

</div>


## `SystemCustomerOriginatedTraceModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with Customer Originated Trace.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type |Description                       |
|-------------------------|-----|----------------------------------|
|screen_malicious_callers |bool |screenMaliciousCallers *Optional* |
</div>


## `SystemDTMFTransmissionGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the system DTMF transmission configurations.

The response is either `SystemDTMFTransmissionGetResponse()` or `ErrorResponse()`.

</div>


## `SystemDTMFTransmissionModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the DTMF transmission settings.

The response is either `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type|Description                     |
|-----------------------|----|--------------------------------|
|transmission_method    |str |transmissionMethod *Optional*   |
|signaling_content_type |str |signalingContentType *Optional* |
</div>


## `SystemDeviceActivationPolicyGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the Device Activation policy of the system.

The response is either a `SystemDeviceActivationPolicyGetResponse()` or an
`ErrorResponse()`.

</div>


## `SystemDeviceActivationPolicyModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Device Activation policy of the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                  |Type |Description                                 |
|--------------------------------------|-----|--------------------------------------------|
|allow_activation_code_request_by_user |bool |allowActivationCodeRequestByUser *Optional* |
|send_activation_code_in_email         |bool |sendActivationCodeInEmail *Optional*        |
</div>


## `SystemDeviceFamilyAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a device family.

When the optional element resellerId is specified, the device family created is at
reseller level.  Device family name should be unique throughout the system including
all the reseller level device families.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in the XS data mode: resellerId

**Attributes:**

|Name               |Type      |Description                 |
|-------------------|----------|----------------------------|
|device_family_name |str       |deviceFamilyName            |
|reseller_id        |str       |resellerId *Optional*       |
|assign_device_type |List[str] |assignDeviceType *Optional* |
|assign_tag_set     |List[str] |assignTagSet *Optional*     |
</div>


## `SystemDeviceFamilyAssignDeviceTypeListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to assign a list of Device Types to a device family.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name               |Type      |Description      |
|-------------------|----------|-----------------|
|device_family_name |str       |deviceFamilyName |
|device_type_name   |List[str] |deviceTypeName   |
</div>


## `SystemDeviceFamilyAssignTagSetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to assign a list of Tag Sets to a device family.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name               |Type      |Description      |
|-------------------|----------|-----------------|
|device_family_name |str       |deviceFamilyName |
|tag_set_name       |List[str] |tagSetName       |
</div>


## `SystemDeviceFamilyDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a device family.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name               |Type      |Description      |
|-------------------|----------|-----------------|
|device_family_name |List[str] |deviceFamilyName |
</div>


## `SystemDeviceFamilyExportRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to export a device family.

The response is either a `SystemDeviceFamilyExportResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name               |Type|Description      |
|-------------------|----|-----------------|
|device_family_name |str |deviceFamilyName |
</div>


## `SystemDeviceFamilyGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the associated device types and tagsets for a given device family.

The response is either `SystemDeviceFamilyGetResponse()` or `ErrorResponse()`.

**Attributes:**

|Name               |Type|Description      |
|-------------------|----|-----------------|
|device_family_name |str |deviceFamilyName |
</div>


## `SystemDeviceFamilyImportDryRunRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to perform a dry run import of a Device Family Set Archive File (DFAF) as a
new Device Family.

The URL supports the HTTP and the FILE protocols.  When the optional element
resellerId is specified, the device type created is at reseller level.  When the
optional element deviceFamilyOverride is set to true, an existing device family with
the same name on the destination system will be overridden.  When the optional element
tagSetOverride is set to true, any existing tag set on the destination system will be
overridden.  When the optional element deviceTypeFileUpdate is set, on import, for any
existing device type associated with the device family, the files that are matched
based on the file format are updated with the ones from the DTAF. The file format and
the file category are the only attributes that can't be updated.

The response is either a `SystemDeviceFamilyImportDryRunResponse()` or an
`ErrorResponse()`. The following data elements are only used in AS data mode and
ignored in XS data mode: resellerId

**Attributes:**

|Name                    |Type |Description                     |
|------------------------|-----|--------------------------------|
|file                    |str  |file                            |
|reseller_id             |str  |resellerId *Optional*           |
|device_family_override  |bool |deviceFamilyOverride *Optional* |
|tag_set_override        |bool |tagSetOverride *Optional*       |
|device_type_file_update |bool |deviceTypeFileUpdate *Optional* |
</div>


## `SystemDeviceFamilyImportRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to import a Device Family Set Archive File (DFAF) as a new Device Family.

The URL supports the HTTP and the FILE protocols.  When the optional element
resellerId is specified, the device type created is at reseller level.  When the
optional element deviceFamilyOverride is set to true, an existing device family with
the same name on the destination system will be overridden.  When the optional element
tagSetOverride is set to true, any existing tag set on the destination system will be
overridden.  When the optional element deviceTypeFileUpdate is set, on import, for any
existing device type associated with the device family, the files that are matched
based on the file format are updated with the ones from the DTAF. The file format and
the file category are the only attributes that can't be updated.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
data elements are only used in AS data mode and ignored in XS data mode: resellerId

**Attributes:**

|Name                    |Type |Description                     |
|------------------------|-----|--------------------------------|
|file                    |str  |file                            |
|reseller_id             |str  |resellerId *Optional*           |
|device_family_override  |bool |deviceFamilyOverride *Optional* |
|tag_set_override        |bool |tagSetOverride *Optional*       |
|device_type_file_update |bool |deviceTypeFileUpdate *Optional* |
</div>


## `SystemDeviceFamilyUnassignDeviceTypeListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to unassign a list of Device Types to a device family.

Device family name should be unique through out the system including all the reseller
level device families.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in the XS data mode: resellerId

**Attributes:**

|Name               |Type      |Description      |
|-------------------|----------|-----------------|
|device_family_name |str       |deviceFamilyName |
|device_type_name   |List[str] |deviceTypeName   |
</div>


## `SystemDeviceFamilyUnassignTagSetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to unassign a list of Tag Sets to a device family.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name               |Type      |Description      |
|-------------------|----------|-----------------|
|device_family_name |str       |deviceFamilyName |
|tag_set_name       |List[str] |tagSetName       |
</div>


## `SystemDeviceManagementAutoRebuildConfigGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the list of OCI request prefixes including if they trigger DM automatic
rebuild event or not.

The response is either a `SystemDeviceManagementAutoRebuildConfigGetListResponse()` or
an `ErrorResponse()`.

</div>


## `SystemDeviceManagementGetAccessDeviceCountForDeviceTypeRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the number of access device of a particular device type or all device types if
deviceType is not specified.

If countOnlyResetSupportedDevice is true, count only access devices if the device type
supports reset.  By default unmanaged device types are not allowed and devices are
counted only if their device type supports Device Management.  An error is returned if
deviceType is specified but does not support device management.  When
allowUnmanagedDeviceType is true, unmanaged device type will be counted and a
successful response is returned.

The response is either
`SystemDeviceManagementGetAccessDeviceCountForDeviceTypeResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                              |Type |Description                              |
|----------------------------------|-----|-----------------------------------------|
|device_type                       |str  |deviceType *Optional*                    |
|count_only_reset_supported_device |bool |countOnlyResetSupportedDevice *Optional* |
|allow_unmanaged_device_type       |bool |allowUnmanagedDeviceType *Optional*      |
</div>


## `SystemDeviceManagementGetEventStatusSummaryCountRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a summary table of the number of events in state 'Pending', 'Queued
Internally', and 'Completed' in the system per action.

One row is returned per action.  Actions are as per the
DeviceManagementEventActionType (ex: Delete, Download, Rebuild, Reset, Upload). The
state 'Queued Internally' includes total for events with status equal to 'Queued' and
'In Progress' as per DeviceManagementEventStatus.

The response is either `SystemDeviceManagementGetEventStatusSummaryCountResponse()` or
`ErrorResponse()`.

</div>


## `SystemDeviceManagementInProgressAndPendingEventCancelRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Cancel pending and in progress events.

Either all events, multiple events, or a list of specified events can be canceled.
When specifying multiple events, an event must meet all specified criteria to be
canceled.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type                     |Description                     |
|-----------------------|-------------------------|--------------------------------|
|cancel_all_events      |OCI.cancelAllEvents      |cancelAllEvents *Optional*      |
|cancel_multiple_events |OCI.cancelMultipleEvents |cancelMultipleEvents *Optional* |
|event_id               |List[int]                |eventId *Optional*              |
</div>


## `SystemDeviceManagementSwitchDeviceTypeDeviceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Switch the device type for a specified device.

To switch a system level device profile, serviceProviderId and groupId should not be
present.  To switch a service provider level device profile, only serviceProviderId
should be specified.  To switch a group level device profile, serviceProviderId and
groupId should specified.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description                  |
|--------------------|----|-----------------------------|
|service_provider_id |str |serviceProviderId *Optional* |
|svc_provider_id     |str |svcProviderId *Optional*     |
|group_id            |str |groupId *Optional*           |
|device_name         |str |deviceName                   |
|to_device_type      |str |toDeviceType                 |
</div>


## `SystemDeviceManagementSwitchDeviceTypeRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Switch the device type for all devices at the specified scope for a device type.

To switch all the device type's device profiles for the system, neither the
serviceProviderId and groupId should be present.  To switch all the device type's
device profiles for a service provider, only serviceProviderId should be specified.
To switch all the device type's device profiles for a group, serviceProviderId and
groupId should specified.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description                  |
|--------------------|----|-----------------------------|
|service_provider_id |str |serviceProviderId *Optional* |
|svc_provider_id     |str |svcProviderId *Optional*     |
|group_id            |str |groupId *Optional*           |
|from_device_type    |str |fromDeviceType               |
|to_device_type      |str |toDeviceType                 |
</div>


## `SystemDeviceManagementTagAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a static configuration tag.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`SystemDeviceManagementTagAddRequest21sp2()`

**Attributes:**

|Name                   |Type |Description                    |
|-----------------------|-----|-------------------------------|
|system_default_tag_set |bool |systemDefaultTagSet *Optional* |
|tag_set_name           |str  |tagSetName *Optional*          |
|tag_name               |str  |tagName                        |
|tag_value              |str  |tagValue *Optional*            |
</div>


## `SystemDeviceManagementTagAddRequest21sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a static configuration tag.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`SystemDeviceManagementTagAddRequest22()`

**Attributes:**

|Name                   |Type |Description                    |
|-----------------------|-----|-------------------------------|
|system_default_tag_set |bool |systemDefaultTagSet *Optional* |
|tag_set_name           |str  |tagSetName *Optional*          |
|tag_name               |str  |tagName                        |
|is_tag_value_encrypted |bool |isTagValueEncrypted            |
|tag_value              |str  |tagValue *Optional*            |
|tag_value_to_encrypt   |str  |tagValueToEncrypt *Optional*   |
</div>


## `SystemDeviceManagementTagAddRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a static configuration tag.

The following elements are only used in XS data mode and ignored in AS data mode:
isTagValueEncrypted tagValueToEncrypt

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type |Description                    |
|-------------------------|-----|-------------------------------|
|system_default_tag_set   |bool |systemDefaultTagSet *Optional* |
|tag_set_name             |str  |tagSetName *Optional*          |
|tag_name                 |str  |tagName                        |
|is_tag_value_encrypted   |bool |isTagValueEncrypted            |
|tag_value                |str  |tagValue *Optional*            |
|tag_value_to_encrypt     |str  |tagValueToEncrypt *Optional*   |
|is_tag_value_overridable |bool |isTagValueOverridable          |
</div>


## `SystemDeviceManagementTagDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete static configuration tags.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type      |Description                    |
|-----------------------|----------|-------------------------------|
|system_default_tag_set |bool      |systemDefaultTagSet *Optional* |
|tag_set_name           |str       |tagSetName *Optional*          |
|tag_name               |List[str] |tagName                        |
</div>


## `SystemDeviceManagementTagGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of custom configuration tags managed by the Device Management
System.

The response is either `SystemDeviceManagementTagGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                   |Type |Description                    |
|-----------------------|-----|-------------------------------|
|system_default_tag_set |bool |systemDefaultTagSet *Optional* |
|tag_set_name           |str  |tagSetName *Optional*          |
</div>


## `SystemDeviceManagementTagModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a static configuration tag.

The following elements are only used in XS data mode and ignored in AS data mode:
tagValueToEncrypt

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type |Description                      |
|-------------------------|-----|---------------------------------|
|system_default_tag_set   |bool |systemDefaultTagSet *Optional*   |
|tag_set_name             |str  |tagSetName *Optional*            |
|tag_name                 |str  |tagName                          |
|tag_value                |str  |tagValue *Optional*              |
|tag_value_to_encrypt     |str  |tagValueToEncrypt *Optional*     |
|is_tag_value_overridable |bool |isTagValueOverridable *Optional* |
</div>


## `SystemDeviceManagementTagSetAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a static configuration tag set.

When the optional element resellerId is specified, the tag set created is at reseller
level.  Tag set name should be unique through out the system including all the
reseller level tag sets.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in the XS data mode: resellerId

**Attributes:**

|Name         |Type|Description           |
|-------------|----|----------------------|
|tag_set_name |str |tagSetName            |
|reseller_id  |str |resellerId *Optional* |
</div>


## `SystemDeviceManagementTagSetCountryAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a country to a region within a static configuration tag set for per-
region tags override.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type|Description |
|-------------|----|------------|
|tag_set_name |str |tagSetName  |
|region_name  |str |regionName  |
|country_name |str |countryName |
</div>


## `SystemDeviceManagementTagSetCountryDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a list of countries from a region within a static configuration tag
set for per-region tags override.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type      |Description |
|-------------|----------|------------|
|tag_set_name |str       |tagSetName  |
|region_name  |str       |regionName  |
|country_name |List[str] |countryName |
</div>


## `SystemDeviceManagementTagSetCountryGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of countries within the region of a static configuration tag
set for per-region tags override.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type|Description|
|-------------|----|-----------|
|tag_set_name |str |tagSetName |
|region_name  |str |regionName |
</div>


## `SystemDeviceManagementTagSetDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a static configuration tag set.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type|Description|
|-------------|----|-----------|
|tag_set_name |str |tagSetName |
</div>


## `SystemDeviceManagementTagSetExportRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to export a custom tag set.

Tag set name should be unique through out the system including all the reseller level
tag sets.

The response is either a `SystemDeviceManagementTagSetExportResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name         |Type|Description|
|-------------|----|-----------|
|tag_set_name |str |tagSetName |
</div>


## `SystemDeviceManagementTagSetGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of custom configuration tag sets managed by the Device
Management System.

The response is either `SystemDeviceManagementTagSetGetListResponse()` or
`ErrorResponse()`. Replaced by `SystemDeviceManagementTagSetGetListRequest22()` in AS
data mode.

</div>


## `SystemDeviceManagementTagSetGetListRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of custom configuration tag sets managed by the Device
Management System.

If excludeReseller is set, only system level tag sets are returned.  If resellerId is
specified, all system level tag sets and the tag sets in the reseller are returned.
If reseller administrator sends the request, resellerId is not specified, the
administrator's resellerId is used.  If neither excludeReseller nor resellerId is
specified, all system level and reseller level tag sets are returned.

The response is either `SystemDeviceManagementTagSetGetListResponse22()` or
`ErrorResponse()`.

**Attributes:**

|Name             |Type |Description                |
|-----------------|-----|---------------------------|
|exclude_reseller |bool |excludeReseller *Optional* |
|reseller_id      |str  |resellerId *Optional*      |
</div>


## `SystemDeviceManagementTagSetModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a static configuration tag set.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name             |Type|Description              |
|-----------------|----|-------------------------|
|tag_set_name     |str |tagSetName               |
|new_tag_set_name |str |newTagSetName *Optional* |
</div>


## `SystemDeviceManagementTagSetRegionAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a region within a static configuration tag set for per-region tags
override.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type|Description|
|-------------|----|-----------|
|tag_set_name |str |tagSetName |
|region_name  |str |regionName |
</div>


## `SystemDeviceManagementTagSetRegionDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a region within a static configuration tag set for per-region tags
override.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type      |Description|
|-------------|----------|-----------|
|tag_set_name |str       |tagSetName |
|region_name  |List[str] |regionName |
</div>


## `SystemDeviceManagementTagSetRegionGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of regions within a static configuration tag set for per-
region tags override.

The response is either a `SystemDeviceManagementTagSetRegionGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name         |Type|Description|
|-------------|----|-----------|
|tag_set_name |str |tagSetName |
</div>


## `SystemDeviceManagementTagSetRegionModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the name of a region within a static configuration tag set for per-
region tags override.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description              |
|----------------|----|-------------------------|
|tag_set_name    |str |tagSetName               |
|region_name     |str |regionName               |
|new_region_name |str |newRegionName *Optional* |
</div>


## `SystemDeviceManagementTagSetRegionTagDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a tag override to a region of a static configuration tag set.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type      |Description|
|-------------|----------|-----------|
|tag_set_name |str       |tagSetName |
|region_name  |str       |regionName |
|tag_name     |List[str] |tagName    |
</div>


## `SystemDeviceManagementTagSetRegionTagGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of tag overrides for a region within a static configuration
tag set for per-region tags override.

The response is either a `SystemDeviceManagementTagSetRegionTagGetListResponse()` or
an `ErrorResponse()`.

**Attributes:**

|Name         |Type|Description|
|-------------|----|-----------|
|tag_set_name |str |tagSetName |
|region_name  |str |regionName |
</div>


## `SystemDeviceManagementTagSetRegionTagModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the value of a tag override within a region of a static
configuration tag set.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type|Description         |
|-------------|----|--------------------|
|tag_set_name |str |tagSetName          |
|region_name  |str |regionName          |
|tag_name     |str |tagName             |
|tag_value    |str |tagValue *Optional* |
</div>


## `SystemDeviceProfileAuthenticationLockoutClearAllRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to clear all device password authentication lockouts in the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

</div>


## `SystemDeviceProfileAuthenticationPasswordRulesGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the system level device profile authentication password rule settings.

The response is either a `SystemDeviceProfileAuthenticationPasswordRulesGetResponse()`
or an `ErrorResponse()`.

</div>


## `SystemDeviceProfileAuthenticationPasswordRulesModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the system level device profile authentication password rule
settings.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                       |Type |Description                                       |
|-------------------------------------------|-----|--------------------------------------------------|
|disallow_authentication_name               |bool |disallowAuthenticationName *Optional*             |
|disallow_old_password                      |bool |disallowOldPassword *Optional*                    |
|disallow_reversed_old_password             |bool |disallowReversedOldPassword *Optional*            |
|restrict_min_digits                        |bool |restrictMinDigits *Optional*                      |
|min_digits                                 |int  |minDigits *Optional*                              |
|restrict_min_upper_case_letters            |bool |restrictMinUpperCaseLetters *Optional*            |
|min_upper_case_letters                     |int  |minUpperCaseLetters *Optional*                    |
|restrict_min_lower_case_letters            |bool |restrictMinLowerCaseLetters *Optional*            |
|min_lower_case_letters                     |int  |minLowerCaseLetters *Optional*                    |
|restrict_min_non_alphanumeric_characters   |bool |restrictMinNonAlphanumericCharacters *Optional*   |
|min_non_alphanumeric_characters            |int  |minNonAlphanumericCharacters *Optional*           |
|min_length                                 |int  |minLength *Optional*                              |
|send_permanent_lockout_notification        |bool |sendPermanentLockoutNotification *Optional*       |
|permanent_lockout_notify_email_address     |str  |permanentLockoutNotifyEmailAddress *Optional*     |
|device_profile_authentication_lockout_type |str  |deviceProfileAuthenticationLockoutType *Optional* |
|device_profile_temporary_lockout_threshold |int  |deviceProfileTemporaryLockoutThreshold *Optional* |
|device_profile_wait_algorithm              |str  |deviceProfileWaitAlgorithm *Optional*             |
|device_profile_lockout_fixed_minutes       |str  |deviceProfileLockoutFixedMinutes *Optional*       |
|device_profile_permanent_lockout_threshold |int  |deviceProfilePermanentLockoutThreshold *Optional* |
</div>


## `SystemDeviceTypeExportRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to export an existing Device Type to a Device Type Archive File (DTAF).

The response is either a `SystemDeviceTypeExportResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemDeviceTypeGetAvailableListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests a list of non-obsolete Identity/device profile types defined in the system.

It is possible to get either all conference device types or all non-conferernce types.
This command is similar to the `SystemSIPDeviceTypeGetListRequest()` and
`SystemMGCPDeviceTypeGetListRequest()` but gets both SIP and MGCP types.

The response is either `SystemDeviceTypeGetlAvailableListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                     |Type |Description           |
|-------------------------|-----|----------------------|
|allow_conference         |bool |allowConference       |
|allow_music_on_hold      |bool |allowMusicOnHold      |
|only_conference          |bool |onlyConference        |
|only_video_capable       |bool |onlyVideoCapable      |
|only_optional_ip_address |bool |onlyOptionalIpAddress |
</div>


## `SystemDeviceTypeGetAvailableListRequest14sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests a list of non-obsolete Identity/device profile types defined in the system.

It is possible to get either all conference device types or all non-conferernce types.
This command is similar to the `SystemSIPDeviceTypeGetListRequest()` and
`SystemMGCPDeviceTypeGetListRequest()` but gets both SIP and MGCP types.

The response is either `SystemDeviceTypeGetlAvailableListResponse14sp1()` or
`ErrorResponse()`.

Replaced By: `SystemDeviceTypeGetAvailableListRequest14sp3()`

**Attributes:**

|Name                     |Type |Description           |
|-------------------------|-----|----------------------|
|allow_conference         |bool |allowConference       |
|allow_music_on_hold      |bool |allowMusicOnHold      |
|only_conference          |bool |onlyConference        |
|only_video_capable       |bool |onlyVideoCapable      |
|only_optional_ip_address |bool |onlyOptionalIpAddress |
</div>


## `SystemDeviceTypeGetAvailableListRequest14sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests a list of non-obsolete Identity/device profile types defined in the system.

It is possible to get either all conference device types or all non-conferernce types.
This command is similar to the `SystemSIPDeviceTypeGetListRequest()` and
`SystemMGCPDeviceTypeGetListRequest()` but gets both SIP and MGCP types.

The response is either `SystemDeviceTypeGetlAvailableListResponse14sp1()` or
`ErrorResponse()`. Replaced by: `SystemDeviceTypeGetAvailableListRequest19()`.

**Attributes:**

|Name                     |Type |Description           |
|-------------------------|-----|----------------------|
|allow_conference         |bool |allowConference       |
|allow_music_on_hold      |bool |allowMusicOnHold      |
|only_conference          |bool |onlyConference        |
|only_video_capable       |bool |onlyVideoCapable      |
|only_optional_ip_address |bool |onlyOptionalIpAddress |
</div>


## `SystemDeviceTypeGetAvailableListRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests a list of non-obsolete Identity/device profile types defined in the system.

It is possible to get either all conference device types or all non-conferernce types.
This command is similar to the `SystemSIPDeviceTypeGetListRequest()` and
`SystemMGCPDeviceTypeGetListRequest()` but gets both SIP and MGCP types.

The response is either `SystemDeviceTypeGetlAvailableListResponse19()` or
`ErrorResponse()`. Replaced by `SystemDeviceTypeGetAvailableListRequest22()` in AS
data mode.

**Attributes:**

|Name                     |Type |Description           |
|-------------------------|-----|----------------------|
|allow_conference         |bool |allowConference       |
|allow_music_on_hold      |bool |allowMusicOnHold      |
|only_conference          |bool |onlyConference        |
|only_video_capable       |bool |onlyVideoCapable      |
|only_optional_ip_address |bool |onlyOptionalIpAddress |
</div>


## `SystemDeviceTypeGetAvailableListRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests a list of non-obsolete Identity/device profile types defined in the system
and resellers.

It is possible to get either all conference device types or all non-conference types.
This command is similar to the `SystemSIPDeviceTypeGetListRequest()` and
`SystemMGCPDeviceTypeGetListRequest()` but gets both SIP and MGCP types.  If
excludeReseller is specified, only system level available device types are returned.
If resellerId is specified, all the system level available device types and the device
types in the given reseller are returned.  If reseller administrator sends the
request, resellerId is not specified, the administrator's resellerId is used.  If
neither excludeReseller nor resellerId is specified, all the system level and reseller
level available device types are returned.  If excludeLeafDeviceTypes is specified,
leaf device types are excluded in the response returned.  Leaf device types are device
types that have the option supportLinks set to "Support Link to Device". The following
elements are only used in AS data mode and ignored in the XS data mode: resellerId
excludeLeafDeviceTypes

The response is either `SystemDeviceTypeGetlAvailableListResponse22()` or
`ErrorResponse()`.

**Attributes:**

|Name                      |Type |Description                       |
|--------------------------|-----|----------------------------------|
|allow_conference          |bool |allowConference                   |
|allow_music_on_hold       |bool |allowMusicOnHold                  |
|only_conference           |bool |onlyConference                    |
|only_video_capable        |bool |onlyVideoCapable                  |
|only_optional_ip_address  |bool |onlyOptionalIpAddress             |
|exclude_reseller          |bool |excludeReseller *Optional*        |
|reseller_id               |str  |resellerId *Optional*             |
|exclude_leaf_device_types |bool |excludeLeafDeviceTypes *Optional* |
</div>


## `SystemDeviceTypeGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the information about the specified device type without regard to whether the
type is SIP or MGCP.

The response is either `SystemDeviceTypeGetResponse()` or `ErrorResponse()`.

Replaced By: `SystemDeviceTypeGetRequest14sp3()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemDeviceTypeGetRequest14sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the information about the specified device type without regard to whether the
type is SIP or MGCP.

The response is either `SystemDeviceTypeGetResponse14sp3()` or `ErrorResponse()`.

Replaced By: `SystemDeviceTypeGetRequest14sp6()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemDeviceTypeGetRequest14sp6`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the information about the specified device type without regard to whether the
type is SIP or MGCP.

The response is either `SystemDeviceTypeGetResponse14sp6()` or `ErrorResponse()`.
Replaced by: `SystemDeviceTypeGetRequest16()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemDeviceTypeGetRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the information about the specified device type without regard to whether the
type is SIP or MGCP.

The response is either `SystemDeviceTypeGetResponse16()` or `ErrorResponse()`.
Replaced by: `SystemDeviceTypeGetRequest16sp1()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemDeviceTypeGetRequest16sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Replaced By `SystemDeviceTypeGetRequest18()`.

Requests the information about the specified device type without regard to whether the
type is SIP or MGCP.

The response is either `SystemDeviceTypeGetResponse16sp1()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemDeviceTypeGetRequest18`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the information about the specified device type without regard to whether the
type is SIP or MGCP.

The response is either `SystemDeviceTypeGetResponse18()` or `ErrorResponse()`. Note:
The elements deviceTypeConfigurationOption applies to SIP device types only.
Therefore, only present in the response when the device type is SIP. Replaced by:
`SystemSIPDeviceTypeGetRequest19()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemDeviceTypeGetRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the information about the specified device type without regard to whether the
type is SIP or MGCP.

The response is either `SystemDeviceTypeGetResponse19()` or `ErrorResponse()`. Note:
The elements deviceTypeConfigurationOption and staticLineOrdering apply to SIP device
types only.  Therefore, only present in the response when the device type is SIP.
Replaced by: `SystemSIPDeviceTypeGetRequest21sp1()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemDeviceTypeGetRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the information about the specified device type without regard to whether the
type is SIP or MGCP.

The response is either `SystemDeviceTypeGetResponse21sp1()` or `ErrorResponse()`.
Note: The elements deviceTypeConfigurationOption and staticLineOrdering apply to SIP
device types only.  Therefore, only present in the response when the device type is
SIP.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemDeviceTypeGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the information about the specified device type without regard to whether the
type is SIP or MGCP.

The response is either `SystemDeviceTypeGetResponse22()` or `ErrorResponse()`. Note:
The elements deviceTypeConfigurationOption and staticLineOrdering apply to SIP device
types only.  Therefore, only present in the response when the device type is SIP.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemDeviceTypeGetRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the information about the specified device type without regard to whether the
type is SIP or MGCP.

The response is either `SystemDeviceTypeGetResponse22V2()` or `ErrorResponse()`. Note:
The elements deviceTypeConfigurationOption and staticLineOrdering apply to SIP device
types only.  Therefore, only present in the response when the device type is SIP.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemDeviceTypeGetRequest22V3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the information about the specified device type without regard to whether the
type is SIP or MGCP.

The response is either `SystemDeviceTypeGetResponse22V3()` or `ErrorResponse()`. Note:
The elements deviceTypeConfigurationOption and staticLineOrdering apply to SIP device
types only.  Therefore, only present in the response when the device type is SIP.
Replaced by: `SystemDeviceTypeGetRequest22V4()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemDeviceTypeGetRequest22V4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the information about the specified device type without regard to whether the
type is SIP or MGCP.

The response is either `SystemDeviceTypeGetResponse22V4()` or `ErrorResponse()`. Note:
The elements deviceTypeConfigurationOption and staticLineOrdering apply to SIP device
types only.  Therefore, only present in the response when the device type is SIP.
Replaced by: `SystemDeviceTypeGetRequest22V5()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemDeviceTypeGetRequest22V5`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the information about the specified device type without regard to whether the
type is SIP or MGCP.

The response is either `SystemDeviceTypeGetResponse22V5()` or `ErrorResponse()`. Note:
The elements deviceTypeConfigurationOption and staticLineOrdering apply to SIP device
types only.  Therefore, only present in the response when the device type is SIP.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemDialPlanPolicyAddAccessCodeRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a system-level Dial Plan Access Code and its all attribues.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                              |Type |Description                                 |
|--------------------------------------------------|-----|--------------------------------------------|
|access_code                                       |str  |accessCode                                  |
|include_code_for_network_translations_and_routing |bool |includeCodeForNetworkTranslationsAndRouting |
|include_code_for_screening_services               |bool |includeCodeForScreeningServices             |
|enable_secondary_dial_tone                        |bool |enableSecondaryDialTone                     |
|description                                       |str  |description *Optional*                      |
</div>


## `SystemDialPlanPolicyDeleteAccessCodeRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a system-level Dial Plan Access Code and its all attribues.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|access_code |str |accessCode |
</div>


## `SystemDialPlanPolicyGetAccessCodeListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level Access Codes data associated with Dial Plan Policy.

The response is either a `SystemDialPlanPolicyGetAccessCodeListResponse()` or an
`ErrorResponse()`.

</div>


## `SystemDialPlanPolicyGetAccessCodeRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request access code data associated with system level Dial Plan Policy access codes.

The response is either a `SystemDialPlanPolicyGetAccessCodeResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|access_code |str |accessCode |
</div>


## `SystemDialPlanPolicyGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Dial Plan Policy.

The response is either a `SystemDialPlanPolicyGetResponse()` or an `ErrorResponse()`.
Replaced by: `SystemDialPlanPolicyGetRequest17()`

</div>


## `SystemDialPlanPolicyGetRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Dial Plan Policy.

The response is either a `SystemDialPlanPolicyGetResponse17()` or an
`ErrorResponse()`. Replaced by: `SystemDialPlanPolicyGetRequest22()` in AS data mode.

</div>


## `SystemDialPlanPolicyGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Dial Plan Policy.

The response is either a `SystemDialPlanPolicyGetResponse22()` or an
`ErrorResponse()`. Replaced by: `SystemDialPlanPolicyGetRequest22V2()` in AS data
mode.

</div>


## `SystemDialPlanPolicyGetRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Dial Plan Policy.

The response is either a `SystemDialPlanPolicyGetResponse22V2()` or an
`ErrorResponse()`.

</div>


## `SystemDialPlanPolicyModifyAccessCodeRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a system-level Dial Plan Access Code and its attribues.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                              |Type |Description                                            |
|--------------------------------------------------|-----|-------------------------------------------------------|
|access_code                                       |str  |accessCode                                             |
|include_code_for_network_translations_and_routing |bool |includeCodeForNetworkTranslationsAndRouting *Optional* |
|include_code_for_screening_services               |bool |includeCodeForScreeningServices *Optional*             |
|enable_secondary_dial_tone                        |bool |enableSecondaryDialTone *Optional*                     |
|description                                       |str  |description *Optional*                                 |
</div>


## `SystemDialPlanPolicyModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with Dial Plan Policy.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode:
overrideResolvedDeviceDigitMap deviceDigitMap permissiveOACDialing
performInternalTranslationsWithOAC

**Attributes:**

|Name                                            |Type |Description                                          |
|------------------------------------------------|-----|-----------------------------------------------------|
|requires_access_code_for_public_calls           |bool |requiresAccessCodeForPublicCalls *Optional*          |
|allow_e164_public_calls                         |bool |allowE164PublicCalls *Optional*                      |
|prefer_e164_number_format_for_callback_services |bool |preferE164NumberFormatForCallbackServices *Optional* |
|public_digit_map                                |str  |publicDigitMap *Optional*                            |
|private_digit_map                               |str  |privateDigitMap *Optional*                           |
|override_resolved_device_digit_map              |bool |overrideResolvedDeviceDigitMap *Optional*            |
|device_digit_map                                |str  |deviceDigitMap *Optional*                            |
|perform_internal_translations_with_oac          |bool |performInternalTranslationsWithOAC *Optional*        |
|permissive_oac_dialing                          |bool |permissiveOACDialing *Optional*                      |
</div>


## `SystemDialableCallerIDCriteriaAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a new Dialable Caller ID Criteria.

Criteria are added at the bottom of the list with the lowest priority.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                           |Type      |Description                            |
|-------------------------------|----------|---------------------------------------|
|name                           |str       |name                                   |
|description                    |str       |description *Optional*                 |
|prefix_digits                  |str       |prefixDigits *Optional*                |
|match_call_type                |List[str] |matchCallType *Optional*               |
|match_alternate_call_indicator |List[str] |matchAlternateCallIndicator *Optional* |
|match_local_category           |bool      |matchLocalCategory                     |
|match_national_category        |bool      |matchNationalCategory                  |
|match_interlata_category       |bool      |matchInterlataCategory                 |
|match_intralata_category       |bool      |matchIntralataCategory                 |
|match_international_category   |bool      |matchInternationalCategory             |
|match_private_category         |bool      |matchPrivateCategory                   |
|match_emergency_category       |bool      |matchEmergencyCategory                 |
|match_other_category           |bool      |matchOtherCategory                     |
</div>


## `SystemDialableCallerIDCriteriaDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Dialable Caller ID Criteria.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemDialableCallerIDCriteriaGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get an existing Dialable Caller ID Criteria.

The response is either a `SystemDialableCallerIDCriteriaGetRequest()` or an
`ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemDialableCallerIDGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the system level Dialable Caller ID criteria list.

The response is either a `SystemDialableCallerIDGetResponse()` or an
`ErrorResponse()`.

</div>


## `SystemDigitCollectionGetRequest13mp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system's digit collection attributes.

The response is either a `SystemDigitCollectionGetResponse13mp4()` or an
`ErrorResponse()`.

</div>


## `SystemDigitCollectionModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the system's digit collection attributes.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name              |Type|Description                |
|------------------|----|---------------------------|
|access_code       |str |accessCode *Optional*      |
|public_digit_map  |str |publicDigitMap *Optional*  |
|private_digit_map |str |privateDigitMap *Optional* |
</div>


## `SystemDnGetUtilizationListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a list of DN utilizations by service providers.

If resellerId is specified, the DNs assigned to the enterprises/service providers
within the reseller are returned.  If reseller administrator sends the request and
resellerId is not specified, the administrator's resellerId is used.

The response is either `SystemDnUtilizationGetListResponse()` or `ErrorResponse()`.
The following data elements are only used in AS data mode: resellerId

**Attributes:**

|Name        |Type|Description           |
|------------|----|----------------------|
|reseller_id |str |resellerId *Optional* |
</div>


## `SystemDnGetUtilizationRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the utilization of a single DN.

The response is either `SystemDnGetUtilizationResponse()` or `ErrorResponse()`.

Replaced By: `SystemDnGetUtilizationRequest14sp3()`

**Attributes:**

|Name         |Type|Description |
|-------------|----|------------|
|phone_number |str |phoneNumber |
</div>


## `SystemDnGetUtilizationRequest14sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the utilization of a single DN.

The response is either `SystemDnGetUtilizationResponse14sp3()` or `ErrorResponse()`.

**Attributes:**

|Name         |Type|Description |
|-------------|----|------------|
|phone_number |str |phoneNumber |
</div>


## `SystemDomainAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a system or reseller domain to the system.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description           |
|------------|----|----------------------|
|domain      |str |domain                |
|reseller_id |str |resellerId *Optional* |
</div>


## `SystemDomainDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a system domain from the system.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name   |Type|Description|
|-------|----|-----------|
|domain |str |domain     |
</div>


## `SystemDomainGetAssignedServiceProviderListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a list of service providers that have a given domain assigned.

If resellerId is specified, only the service providers within the reseller should be
returned.  If reseller administrator sends the request and resellerId is not
specified, the administrator's resellerId is used.

The response is either `SystemDomainGetAssignedServiceProviderListResponse()` or
`ErrorResponse()`. The following elements are only used in AS data mode: resellerId

**Attributes:**

|Name        |Type|Description           |
|------------|----|----------------------|
|domain      |str |domain                |
|reseller_id |str |resellerId *Optional* |
</div>


## `SystemDomainGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of all system-level domain names.

The response is either `SystemDomainGetListResponse()` or `ErrorResponse()`. Replaced
by `SystemDomainGetListRequest22()` in AS data mode.

</div>


## `SystemDomainGetListRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of all matching system-level domains and all matching reseller level
domains.

If excludeReseller is specified, returns all matching system-level domain names only.
If resellerId is specified, returns all matching system-level domain names and the
given reseller's domains.  If reseller administrator sends the request and resellerId
is not specified, the administrator's resellerId is used.

The response is either `SystemDomainGetListResponse22()` or `ErrorResponse()`. The
following elements are only used in AS data mode: includeReseller resellerId Replaced
by `SystemDomainGetListRequest22V2()` in AS data mode.

**Attributes:**

|Name             |Type |Description                |
|-----------------|-----|---------------------------|
|exclude_reseller |bool |excludeReseller *Optional* |
|reseller_id      |str  |resellerId *Optional*      |
</div>


## `SystemDomainParametersGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of system Domain parameters.

The response is either `SystemDomainParametersGetResponse()` or `ErrorResponse()`.

</div>


## `SystemDomainParametersModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify system Domain parameters.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode: useAliasForDomain
The following elements are only used in AS and XS data mode and ignored in Amplify
data mode: defaultDomain

**Attributes:**

|Name                 |Type |Description                  |
|---------------------|-----|-----------------------------|
|use_alias_for_domain |bool |useAliasForDomain *Optional* |
|default_domain       |str  |defaultDomain *Optional*     |
</div>


## `SystemEmergencyCallDDoSProtectionGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the system Emergency Call DDos Protection configurations.

The response is either `SystemEmergencyCallDDoSProtectionGetResponse()` or
`ErrorResponse()`.

</div>


## `SystemEmergencyCallDDoSProtectionModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Emergency Call DDos Protection settings.

The response is either `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                    |Type |Description                      |
|------------------------|-----|---------------------------------|
|enabled                 |bool |enabled *Optional*               |
|sample_interval_seconds |int  |sampleIntervalSeconds *Optional* |
|protection_rate         |int  |protectionRate *Optional*        |
|protection_action       |str  |protectionAction *Optional*      |
</div>


## `SystemEmergencyCallNotificationGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Emergency Call Notification.

The response is either a `SystemEmergencyCallNotificationGetResponse()` or an
`ErrorResponse()`.

</div>


## `SystemEmergencyCallNotificationModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with Emergency Call Notification.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                 |Type|Description                   |
|---------------------|----|------------------------------|
|default_from_address |str |defaultFromAddress *Optional* |
</div>


## `SystemEmergencyZonesGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Emergency Zones.

The response is either a `SystemEmergencyZonesGetResponse()` or an `ErrorResponse()`.

</div>


## `SystemEmergencyZonesModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with Emergency Zones.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                 |Type|Description                   |
|---------------------|----|------------------------------|
|default_from_address |str |defaultFromAddress *Optional* |
</div>


## `SystemEnhancedCallLogsActiveSchemaInstanceGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level database schema instances defined for Enhanced Call Logs.

For each instance, the number of actual users (users that have the Enhanced Call Logs
service, are assigned to that schema instance and have recorded call logs on the NDS)
are given.

The response is either a `SystemEnhancedCallLogsActiveSchemaInstanceGetListResponse()`
or an `ErrorResponse()`.

</div>


## `SystemEnhancedCallLogsGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Enhanced Call Logs.

The response is either a `SystemEnhancedCallLogsGetResponse()` or an
`ErrorResponse()`.

</div>


## `SystemEnhancedCallLogsGetRequest17sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Enhanced Call Logs.

The response is either a `SystemEnhancedCallLogsGetResponse17sp4()` or an
`ErrorResponse()`. Replaced by:`SystemEnhancedCallLogsGetRequest20sp1()` in AS data
mode

</div>


## `SystemEnhancedCallLogsGetRequest20sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Enhanced Call Logs.

The response is either a `SystemEnhancedCallLogsGetResponse20sp1()` or an
`ErrorResponse()`. Replaced by:`SystemEnhancedCallLogsGetRequest22()` in AS data mode

</div>


## `SystemEnhancedCallLogsGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Enhanced Call Logs.

Replaced by: `SystemEnhancedCallLogsGetRequest24()`. Response to
`SystemDeviceTypeGetRequest16sp1()`.

</div>


## `SystemEnhancedCallLogsGetRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Enhanced Call Logs.

The response is either a `SystemEnhancedCallLogsGetResponse22V2()` or an
`ErrorResponse()`.

</div>


## `SystemEnhancedCallLogsModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with Enhanced Call Logs.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode: isSendEnabled server1NetAddress
server1SendPort server1RetrievePort server2NetAddress server2SendPort
server2RetrievePort sharedSecret retransmissionDelayMilliSeconds maxTransmissions
soapTimeoutSeconds useDBS eclQueryApplicationURL eclQueryDataRepositoryURL

**Attributes:**

|Name                               |Type |Description                                |
|-----------------------------------|-----|-------------------------------------------|
|is_send_enabled                    |bool |isSendEnabled *Optional*                   |
|server1_net_address                |str  |server1NetAddress *Optional*               |
|server1_send_port                  |int  |server1SendPort *Optional*                 |
|server1_retrieve_port              |int  |server1RetrievePort *Optional*             |
|server2_net_address                |str  |server2NetAddress *Optional*               |
|server2_send_port                  |int  |server2SendPort *Optional*                 |
|server2_retrieve_port              |int  |server2RetrievePort *Optional*             |
|shared_secret                      |str  |sharedSecret *Optional*                    |
|retransmission_delay_milli_seconds |int  |retransmissionDelayMilliSeconds *Optional* |
|max_transmissions                  |int  |maxTransmissions *Optional*                |
|soap_timeout_seconds               |int  |soapTimeoutSeconds *Optional*              |
|use_dbs                            |bool |useDBS *Optional*                          |
|max_non_paged_response_size        |int  |maxNonPagedResponseSize *Optional*         |
|ecl_query_application_url          |str  |eclQueryApplicationURL *Optional*          |
|ecl_query_data_repository_url      |str  |eclQueryDataRepositoryURL *Optional*       |
</div>


## `SystemEnhancedCallLogsModifyRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with Enhanced Call Logs.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                          |Type|Description                          |
|------------------------------|----|-------------------------------------|
|max_non_paged_response_size   |int |maxNonPagedResponseSize *Optional*   |
|ecl_query_application_url     |str |eclQueryApplicationURL *Optional*    |
|ecl_query_data_repository_url |str |eclQueryDataRepositoryURL *Optional* |
|default_schema                |str |defaultSchema *Optional*             |
</div>


## `SystemEnhancedCallLogsSchemaInstanceGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level database schema instances defined for Enhanced Call Logs.

For each instance, the number of actual users (users that have the Enhanced Call Logs
service and are assigned to that schema instance) and the number of potential users
are given (users part of a group or service provider using that schema instance).

The response is either a `SystemEnhancedCallLogsSchemaInstanceGetListResponse()` or an
`ErrorResponse()`.

</div>


## `SystemEnterpriseTrunkGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with the Enterprise Trunk service.

The response is either `SystemEnterpriseTrunkGetResponse()` or `ErrorResponse()`.

</div>


## `SystemEnterpriseTrunkModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with the Enterprise Trunk Service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                     |Type |Description                                    |
|-----------------------------------------|-----|-----------------------------------------------|
|enable_holdover_of_highwater_call_counts |bool |enableHoldoverOfHighwaterCallCounts *Optional* |
|holdover_period                          |str  |holdoverPeriod *Optional*                      |
|time_zone_offset_minutes                 |str  |timeZoneOffsetMinutes *Optional*               |
</div>


## `SystemExecutiveGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the Executive system parameters.

The response is either `SystemExecutiveGetResponse()` or `ErrorResponse()`.

</div>


## `SystemExecutiveModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the Executive system parameters.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                   |Type |Description                                 |
|---------------------------------------|-----|--------------------------------------------|
|treat_virtual_on_net_calls_as_internal |bool |treatVirtualOnNetCallsAsInternal *Optional* |
</div>


## `SystemExpensiveCallNotificationGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the expensive call notification service parameters.

The response is either a `SystemExpensiveCallNotificationGetResponse()` or an
`ErrorResponse()`.

</div>


## `SystemExpensiveCallNotificationModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the expensive call notification service parameters.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                 |Type |Description                                 |
|-------------------------------------|-----|--------------------------------------------|
|enable_post_announcement_delay_timer |bool |enablePostAnnouncementDelayTimer *Optional* |
|post_announcement_delay_seconds      |int  |postAnnouncementDelaySeconds *Optional*     |
</div>


## `SystemExpensiveCallTypeAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add an alternate call indicator to the list of expensive alternate call indicators.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                     |Type|Description                   |
|-------------------------|----|------------------------------|
|alternate_call_indicator |str |alternateCallIndicator        |
|treatment_audio_file     |str |treatmentAudioFile *Optional* |
</div>


## `SystemExpensiveCallTypeDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete an alternate call indicator from the list of expensive alternate call
indicators.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type|Description            |
|-------------------------|----|-----------------------|
|alternate_call_indicator |str |alternateCallIndicator |
</div>


## `SystemExpensiveCallTypeGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of expensive alternate call indicators in the system.

The response is either a `SystemExpensiveCallTypeGetListResponse()` or an
`ErrorResponse()`. Replaced by: `SystemExpensiveCallTypeGetListRequest16sp1()`

</div>


## `SystemExpensiveCallTypeGetListRequest16sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of expensive alternate call indicators in the system.

The response is either a `SystemExpensiveCallTypeGetListResponse16sp1()` or an
`ErrorResponse()`.

</div>


## `SystemExpensiveCallTypeModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an existing call indicator in the list of expensive alternate call indicators.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                     |Type|Description                   |
|-------------------------|----|------------------------------|
|alternate_call_indicator |str |alternateCallIndicator        |
|treatment_audio_file     |str |treatmentAudioFile *Optional* |
</div>


## `SystemExportAddressingDataRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to export Application Server addressing data, such as DNs, extensions, alias
and user ids to a file so they can be uploaded to a Network Server.

In XS data mode, response is sent without waiting for completion.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name      |Type|Description|
|----------|----|-----------|
|file_name |str |fileName   |
</div>


## `SystemExportBroadCloudDataRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to export all users that have BroadCloud services, such as user profile
information and BroadCloud services related information for that user to a file so
they can be uploaded to a Messaging Server/BroadCloud.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name      |Type|Description|
|----------|----|-----------|
|file_name |str |fileName   |
</div>


## `SystemExportSubscriberRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request subscribers be exported to files on the AS filesystem.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. ***** Warning
*****: This activity should only be done during non-busy hours on the secondary
provisioning server because this may cause large amounts of data to be dumped to disk
and it may take some time to execute.

</div>


## `SystemExtensionLengthGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system's extension range.

The response is either a `SystemExtensionLengthGetResponse()` or an `ErrorResponse()`.

</div>


## `SystemExtensionLengthModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the group's extension length range.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                 |Type|Description                   |
|---------------------|----|------------------------------|
|min_extension_length |int |minExtensionLength *Optional* |
|max_extension_length |int |maxExtensionLength *Optional* |
</div>


## `SystemExternalAuthenticationAddACLEntryRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add an entry to the external authentication access control list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description            |
|------------|----|-----------------------|
|net_address |str |netAddress             |
|description |str |description *Optional* |
</div>


## `SystemExternalAuthenticationAddACLEntryRequest14sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add an entry to the external authentication access control list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description            |
|------------|----|-----------------------|
|net_address |str |netAddress             |
|description |str |description *Optional* |
</div>


## `SystemExternalAuthenticationDeleteACLEntryRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete an entry from the external authentication access control list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|net_address |str |netAddress |
</div>


## `SystemExternalAuthenticationDeleteACLEntryRequest14sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete an entry from the external authentication access control list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|net_address |str |netAddress |
</div>


## `SystemExternalAuthenticationGetACLListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the external authentication access control list.

The response is either `SystemExternalAuthenticationGetACLListResponse()` or
`ErrorResponse()`.

</div>


## `SystemExternalAuthenticationModifyACLEntryRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an entry from the external authentication access control list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description            |
|------------|----|-----------------------|
|net_address |str |netAddress             |
|description |str |description *Optional* |
</div>


## `SystemExternalAuthenticationModifyACLEntryRequest14sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an entry from the external authentication access control list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description            |
|------------|----|-----------------------|
|net_address |str |netAddress             |
|description |str |description *Optional* |
</div>


## `SystemExternalEmergencyRoutingParametersGetRequest13mp13`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of External Emergency Routing system parameters.

The response is either `SystemExternalEmergencyRoutingParametersGetResponse13mp13()`
or `ErrorResponse()`.

</div>


## `SystemExternalEmergencyRoutingParametersModifyRequest13mp13`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify Call External Emergency Routing system parameters.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                       |Type |Description                         |
|---------------------------|-----|------------------------------------|
|service_uri                |str  |serviceURI *Optional*               |
|default_emergency_number   |str  |defaultEmergencyNumber *Optional*   |
|is_active                  |bool |isActive *Optional*                 |
|supports_dnssrv            |bool |supportsDNSSRV *Optional*           |
|connection_timeout_seconds |int  |connectionTimeoutSeconds *Optional* |
</div>


## `SystemFaxMessagingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Fax Messaging.

The response is either a `SystemFaxMessagingGetResponse()` or an `ErrorResponse()`.

</div>


## `SystemFaxMessagingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with Fax Messaging.

The following elements are only used in AS data mode and ignored in XS data mode:
statusDurationHours statusAuditIntervalHours

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                              |Type|Description                              |
|----------------------------------|----|-----------------------------------------|
|status_duration_hours             |int |statusDurationHours *Optional*           |
|status_audit_interval_hours       |int |statusAuditIntervalHours *Optional*      |
|maximum_concurrent_faxes_per_user |int |maximumConcurrentFaxesPerUser *Optional* |
</div>


## `SystemFeatureAccessCodeGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get list of default Feature Access Codes defined on system level.

The response is either `SystemFeatureAccessCodeGetListResponse()` or
`ErrorResponse()`. Replaced by: `SystemFeatureAccessCodeGetListRequest21()` in AS data
mode

</div>


## `SystemFeatureAccessCodeGetListRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get list of default Feature Access Codes defined on system level.

The response is either `SystemFeatureAccessCodeGetListResponse20()` or
`ErrorResponse()`. In release 20 the "Call Recording" FAC name is changed to "Call
Recording - Start". Replaced by: `SystemFeatureAccessCodeGetListRequest21()`

</div>


## `SystemFeatureAccessCodeGetListRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get list of default Feature Access Codes defined on system level.

The response is either `SystemFeatureAccessCodeGetListResponse20()` or
`ErrorResponse()`. In release 20 the "Call Recording" FAC name is changed to "Call
Recording - Start".

</div>


## `SystemFileGetContentRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the contents of a file.

This transaction is only allowed to get content for files under
/var/broadworks/userfiles/AuditLogs/ or /var/broadworks/IpDeviceConfig/.

The response is either a `SystemFileGetContentResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name      |Type|Description|
|----------|----|-----------|
|file_name |str |fileName   |
</div>


## `SystemFileRepositoryDeviceDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a file repository.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemFileRepositoryDeviceGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the list of file repositories in the system.

The response is either a `SystemFileRepositoryDeviceGetListResponse()` or an
`ErrorResponse()`.

</div>


## `SystemFileRepositoryDeviceGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the file repository information.

The response is either `SystemFileRepositoryDeviceGetResponse()` or `ErrorResponse()`.
Replaced by: `SystemFileRepositoryDeviceGetRequest16()`

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemFileRepositoryDeviceGetRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the file repository information.

The response is either `SystemFileRepositoryDeviceGetResponse16()` or
`ErrorResponse()`. Replaced by: `SystemFileRepositoryDeviceGetRequest20()`

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemFileRepositoryDeviceGetRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the file repository information.

The response is either `SystemFileRepositoryDeviceGetResponse20()` or
`ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemFileRepositoryDeviceGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the file repository information.

The response is either `SystemFileRepositoryDeviceGetResponse22()` or
`ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemFileRepositoryDeviceModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a file repository.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                    |Type |Description                      |
|------------------------|-----|---------------------------------|
|name                    |str  |name                             |
|root_directory          |str  |rootDirectory *Optional*         |
|secure                  |bool |secure *Optional*                |
|net_address             |str  |netAddress *Optional*            |
|ftp_passive             |bool |ftpPassive *Optional*            |
|protocol                |str  |protocol *Optional*              |
|port                    |int  |port *Optional*                  |
|ftp_remote_verification |bool |ftpRemoteVerification *Optional* |
</div>


## `SystemFileRepositoryDeviceModifyRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a file repository.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                    |Type |Description                      |
|------------------------|-----|---------------------------------|
|name                    |str  |name                             |
|root_directory          |str  |rootDirectory *Optional*         |
|secure                  |bool |secure *Optional*                |
|net_address             |str  |netAddress *Optional*            |
|ftp_passive             |bool |ftpPassive *Optional*            |
|protocol                |str  |protocol *Optional*              |
|port                    |int  |port *Optional*                  |
|ftp_remote_verification |bool |ftpRemoteVerification *Optional* |
</div>


## `SystemFileRepositoryDeviceUserAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a new file repository user.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                 |Type |Description        |
|---------------------|-----|-------------------|
|file_repository_name |str  |fileRepositoryName |
|user_name            |str  |userName           |
|password             |str  |password           |
|allow_put            |bool |allowPut           |
|allow_delete         |bool |allowDelete        |
|allow_get            |bool |allowGet           |
</div>


## `SystemFileRepositoryDeviceUserDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a file repository user.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                 |Type|Description        |
|---------------------|----|-------------------|
|file_repository_name |str |fileRepositoryName |
|user_name            |str |userName           |
</div>


## `SystemFileRepositoryDeviceUserGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the list of users for a file repository in the system.

The response is either a `SystemFileRepositoryDeviceUserGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                 |Type|Description        |
|---------------------|----|-------------------|
|file_repository_name |str |fileRepositoryName |
</div>


## `SystemFileRepositoryDeviceUserGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a user of a file repository in the system.

The response is either a `SystemFileRepositoryDeviceUserGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                 |Type|Description        |
|---------------------|----|-------------------|
|file_repository_name |str |fileRepositoryName |
|user_name            |str |userName           |
</div>


## `SystemFileRepositoryDeviceUserModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a file repository user.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                 |Type |Description            |
|---------------------|-----|-----------------------|
|file_repository_name |str  |fileRepositoryName     |
|user_name            |str  |userName               |
|password             |str  |password *Optional*    |
|allow_put            |bool |allowPut *Optional*    |
|allow_delete         |bool |allowDelete *Optional* |
|allow_get            |bool |allowGet *Optional*    |
</div>


## `SystemGETSAvpCodeMapAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a GETS AVP Code map at the system level.

It maps a Diameter AVP Code with a vendor ID for.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name      |Type|Description|
|----------|----|-----------|
|avp_code  |int |avpCode    |
|vendor_id |int |vendorId   |
</div>


## `SystemGETSAvpCodeMapDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a system GETS AVP Code map.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name      |Type|Description|
|----------|----|-----------|
|avp_code  |int |avpCode    |
|vendor_id |int |vendorId   |
</div>


## `SystemGETSAvpCodeMapGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of GETS AVP Code Maps at the system level.

The response is either `SystemGETSAvpCodeMapGetListResponse()` or `ErrorResponse()`.

</div>


## `SystemGETSGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the GETS system settings.

The response is either `SystemGETSGetResponse()` or `ErrorResponse()`.

</div>


## `SystemGETSModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify GETS system settings.

The following elements are only used in AS data mode and ignored in the Amplify data
mode: callIdentifierMode

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                             |Type |Description                              |
|---------------------------------|-----|-----------------------------------------|
|enabled                          |bool |enabled *Optional*                       |
|enable_require_resource_priority |bool |enableRequireResourcePriority *Optional* |
|send_access_resource_priority    |bool |sendAccessResourcePriority *Optional*    |
|call_identifier_mode             |str  |callIdentifierMode *Optional*            |
|default_priority_avp             |int  |defaultPriorityAVP *Optional*            |
|signaling_dscp                   |int  |signalingDSCP *Optional*                 |
|default_r_value                  |str  |defaultRValue *Optional*                 |
|bypass_ro_release                |bool |bypassRoRelease *Optional*               |
</div>


## `SystemGETSNumberAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a GETS reserved Number.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description            |
|------------|----|-----------------------|
|number      |str |number                 |
|type        |str |type                   |
|description |str |description *Optional* |
</div>


## `SystemGETSNumberDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a GETS reserved Number.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name   |Type|Description|
|-------|----|-----------|
|number |str |number     |
</div>


## `SystemGETSNumberGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of GETS reserved Numbers.

The response is either `SystemGETSNumberGetListResponse()` or `ErrorResponse()`.

</div>


## `SystemGETSNumberModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a GETS reserved Number.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description            |
|------------|----|-----------------------|
|number      |str |number                 |
|type        |str |type *Optional*        |
|description |str |description *Optional* |
</div>


## `SystemGETSReservedFeatureAccessCodeAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a GETS reserved FAC.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description            |
|------------|----|-----------------------|
|code        |str |code                   |
|description |str |description *Optional* |
</div>


## `SystemGETSReservedFeatureAccessCodeDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a GETS reserved FAC.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|code |str |code       |
</div>


## `SystemGETSReservedFeatureAccessCodeGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of GETS reserved FAC.

The response is either `SystemGETSReservedFeatureAccessCodeGetListResponse()` or
`ErrorResponse()`.

</div>


## `SystemGETSReservedFeatureAccessCodeModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a GETS reserved FAC.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description            |
|------------|----|-----------------------|
|code        |str |code                   |
|new_code    |str |newCode *Optional*     |
|description |str |description *Optional* |
</div>


## `SystemGETSResourcePriorityAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a GETS Resource Priority.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name           |Type|Description   |
|---------------|----|--------------|
|priority_value |str |priorityValue |
|priority_level |int |priorityLevel |
|priority_class |str |priorityClass |
</div>


## `SystemGETSResourcePriorityDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a GETS Resource Priority.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name           |Type|Description   |
|---------------|----|--------------|
|priority_value |str |priorityValue |
</div>


## `SystemGETSResourcePriorityGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of GETS Resource Priorities.

The response is either `SystemGETSResourcePriorityGetListResponse()` or
`ErrorResponse()`.

</div>


## `SystemGETSResourcePriorityModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a GETS reserved Resource Priority.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name               |Type|Description                 |
|-------------------|----|----------------------------|
|priority_value     |str |priorityValue               |
|new_priority_value |str |newPriorityValue *Optional* |
|priority_level     |int |priorityLevel *Optional*    |
|priority_class     |str |priorityClass *Optional*    |
</div>


## `SystemGETSSessionPriorityMapAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a GETS Session Priority map.

It maps a priority level with a session priority AVP value.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name             |Type|Description     |
|-----------------|----|----------------|
|priority_level   |int |priorityLevel   |
|session_priority |int |sessionPriority |
</div>


## `SystemGETSSessionPriorityMapDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a GETS Session Priority map.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name           |Type|Description   |
|---------------|----|--------------|
|priority_level |int |priorityLevel |
</div>


## `SystemGETSSessionPriorityMapGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of GETS Session Priority maps.

The response is either `SystemGETSSessionPriorityMapGetListResponse()` or
`ErrorResponse()`.

</div>


## `SystemGETSSessionPriorityMapModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a GETS Session Priority Map.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name             |Type|Description                |
|-----------------|----|---------------------------|
|priority_level   |int |priorityLevel              |
|session_priority |int |sessionPriority *Optional* |
</div>


## `SystemGeographicRedundancyPeerSipConnectionMonitoringGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of Peer SIP Connection system parameters The response is a
`SystemGeographicRedundancyPeerSipConnectionMonitoringGetResponse()`.


</div>


## `SystemGeographicRedundancyPeerSipConnectionMonitoringModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the list of Peer SIP Connection Monitoring system parameters The response is
either a `SuccessResponse()` or an `ErrorResponse()`.


**Attributes:**

|Name               |Type |Description                  |
|-------------------|-----|-----------------------------|
|enabled            |bool |enabled *Optional*           |
|heartbeat_interval |int  |heartbeatInterval *Optional* |
|heartbeat_timeout  |int  |heartbeatTimeout *Optional*  |
</div>


## `SystemGeographicRedundancyProxyGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of Geographic Redundancy Proxy system parameters The response
is a `SystemGeographicRedundancyProxyGetResponse()`.


</div>


## `SystemGeographicRedundancyProxyModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the list of Geographic Redundancy Proxysystem parameters The response is either
a `SuccessResponse()` or an `ErrorResponse()`.


**Attributes:**

|Name    |Type |Description        |
|--------|-----|-------------------|
|enabled |bool |enabled *Optional* |
</div>


## `SystemGeographicRedundancyUnreachableFromPrimaryGetUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of users that are unreachable from the primary application server.

The response is a
`SystemGeographicRedundancyUnreachableFromPrimaryGetUserListResponse()` or an
`ErrorResponse()`. Replaced by:
`SystemGeographicRedundancyUnreachableFromPrimaryGetUserListRequest22()` in AS data
mode

</div>


## `SystemGeographicRedundancyUnreachableFromPrimaryGetUserListRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of users that are unreachable from the primary application server.

The response is a
`SystemGeographicRedundancyUnreachableFromPrimaryGetUserListResponse22()` or an
`ErrorResponse()`.

**Attributes:**

|Name                 |Type|Description                  |
|---------------------|----|-----------------------------|
|user_list_size_limit |int |userListSizeLimit *Optional* |
</div>


## `SystemGetAvailableLeafDeviceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of available leaf devices that can be linked to a tree device for
the entire system.

A leaf device is a device associated with a device type that has the option
supportLinks set to "Support Link to Device". It can be linked to only one tree
device.  The list returned includes devices created at the system, service provider,
and group levels.

The response is either `SystemGetAvailableLeafDeviceListResponse()` or
`ErrorResponse()`.

</div>


## `SystemGetAvailableTreeDeviceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of available tree devices to link to for the entire system.

Requests the list of available tree devices to which a leaf device can be linked for
the entire system.  A tree device is a device associated with a device type that has
the option supportLinks set to "Support Links from Devices". Many leaf devices can be
linked to it.  The list returned includes devices created at the system, service
provider, and group levels.

The response is either `SystemGetAvailableTreeDeviceListResponse()` or
`ErrorResponse()`.

</div>


## `SystemGroupNightForwardingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the Group Night Forwarding system parameters.

The response is either `SystemGroupNightForwardingGetResponse()` or `ErrorResponse()`.

</div>


## `SystemGroupNightForwardingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the Group Night Forwarding system parameters.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                        |Type |Description                                       |
|--------------------------------------------|-----|--------------------------------------------------|
|night_forward_group_calls_within_enterprise |bool |nightForwardGroupCallsWithinEnterprise *Optional* |
</div>


## `SystemHPBXAlternateCarrierSelectionAddCarrierRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a new alternate carrier for CbC and Preselection.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name   |Type|Description|
|-------|----|-----------|
|name   |str |name       |
|prefix |str |prefix     |
|domain |str |domain     |
|type   |str |type       |
</div>


## `SystemHPBXAlternateCarrierSelectionDeleteCarrierRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete an alternate carrier for CbC and Preselection.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemHPBXAlternateCarrierSelectionGetCarrierListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the list of alternate carriers available for CbC and Preselection.

The response is either a `SystemHPBXAlternateCarrierSelectionGetCarrierListResponse()`
or an `ErrorResponse()`.

</div>


## `SystemHPBXAlternateCarrierSelectionModifyCarrierRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an alternate carrier for CbC and Preselection.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name     |Type|Description        |
|---------|----|-------------------|
|name     |str |name               |
|new_name |str |newName *Optional* |
|prefix   |str |prefix *Optional*  |
|domain   |str |domain *Optional*  |
|type     |str |type *Optional*    |
</div>


## `SystemHPBXMobileTerminationGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the hPBX mobile termination related configuration parameters.

The response is either a `SystemHPBXMobileTerminationGetResponse()` or an
`ErrorResponse()`.

</div>


## `SystemHPBXMobileTerminationModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the hPBX mobile termination related configuration parameters.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name           |Type|Description              |
|---------------|----|-------------------------|
|routing_prefix |str |routingPrefix *Optional* |
</div>


## `SystemHolidayScheduleDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a system holiday schedule.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                  |Type|Description         |
|----------------------|----|--------------------|
|holiday_schedule_name |str |holidayScheduleName |
</div>


## `SystemHolidayScheduleGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a list of all system holiday schedules.

The response is either a `SystemHolidayScheduleGetListResponse()` or an
`ErrorResponse()`.

</div>


## `SystemHolidayScheduleGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a system holiday schedule.

The response is either a `SystemHolidayScheduleGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                  |Type|Description         |
|----------------------|----|--------------------|
|holiday_schedule_name |str |holidayScheduleName |
</div>


## `SystemHomeNetworkAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Home Network.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|msc_address |str |mscAddress |
</div>


## `SystemHomeNetworkDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Home Network.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|msc_address |str |mscAddress |
</div>


## `SystemHuntGroupGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Hunt Group.

The response is either a `SystemHuntGroupGetResponse()` or an `ErrorResponse()`.
Replaced by: `SystemHuntGroupGetRequest17()`

</div>


## `SystemHuntGroupGetRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Hunt Group.

The response is either a `SystemHuntGroupGetResponse()` or an `ErrorResponse()`.
Replaced by: `SystemHuntGroupGetRequest21()` in AS data mode

</div>


## `SystemHuntGroupGetRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Hunt Group.

The response is either a `SystemHuntGroupGetResponse21()` or an `ErrorResponse()`.

</div>


## `SystemHuntGroupModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with Hunt Group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`SystemHuntGroupModifyRequest21()` in AS data mode

**Attributes:**

|Name                                   |Type |Description                                   |
|---------------------------------------|-----|----------------------------------------------|
|anonymous_instead_of_private_clid      |bool |anonymousInsteadOfPrivateCLID *Optional*      |
|remove_hunt_group_name_from_clid       |bool |removeHuntGroupNameFromCLID *Optional*        |
|uniform_call_distribution_policy_scope |str  |uniformCallDistributionPolicyScope *Optional* |
</div>


## `SystemHuntGroupModifyRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with Hunt Group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                   |Type |Description                                   |
|---------------------------------------|-----|----------------------------------------------|
|remove_hunt_group_name_from_clid       |bool |removeHuntGroupNameFromCLID *Optional*        |
|uniform_call_distribution_policy_scope |str  |uniformCallDistributionPolicyScope *Optional* |
|allow_agent_device_initiated_forward   |bool |allowAgentDeviceInitiatedForward *Optional*   |
</div>


## `SystemInCallServiceActivationGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system's DTMF based in-call service activation trigger attributes.

The response is either a `SystemInCallServiceActivationGetResponse()` or an
`ErrorResponse()`. Replaced by: `SystemInCallServiceActivationGetRequest17()`

</div>


## `SystemInCallServiceActivationGetRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system's DTMF based in-call service activation trigger attributes.

The response is either a `SystemInCallServiceActivationGetResponse17()` or an
`ErrorResponse()`.

</div>


## `SystemInCallServiceActivationModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the system's DTMF based in-call service activation trigger attributes.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`SystemInCallServiceActivationModifyRequest17()`

**Attributes:**

|Name                      |Type|Description                        |
|--------------------------|----|-----------------------------------|
|default_activation_digits |str |defaultActivationDigits *Optional* |
</div>


## `SystemInCallServiceActivationModifyRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the system's DTMF based in-call service activation trigger attributes.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                    |Type|Description                                    |
|----------------------------------------|----|-----------------------------------------------|
|default_flash_activation_digits         |str |defaultFlashActivationDigits *Optional*        |
|default_call_transfer_activation_digits |str |defaultCallTransferActivationDigits *Optional* |
</div>


## `SystemIntegratedIMPGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the system Integrated IMP service attributes.

The response is either `SystemIntegratedIMPGetResponse()` or `ErrorResponse()`.
Replaced by `SystemIntegratedIMPGetRequest19()`.

</div>


## `SystemIntegratedIMPGetRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the system Integrated IMP service attributes.

The response is either `SystemIntegratedIMPGetResponse19()` or `ErrorResponse()`.
Replaced by: `SystemIntegratedIMPGetRequest21()` in AS data mode

</div>


## `SystemIntegratedIMPGetRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the system Integrated IMP service attributes.

The response is either `SystemIntegratedIMPGetResponse19()` or `ErrorResponse()`.

</div>


## `SystemIntegratedIMPModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system Integrated IMP service attributes.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode: boshURL allowImpPasswordRetrieval

**Attributes:**

|Name                                |Type |Description                              |
|------------------------------------|-----|-----------------------------------------|
|service_domain                      |str  |serviceDomain *Optional*                 |
|service_port                        |int  |servicePort *Optional*                   |
|add_service_provider_in_imp_user_id |bool |addServiceProviderInIMPUserId *Optional* |
|bosh_url                            |str  |boshURL *Optional*                       |
|allow_imp_password_retrieval        |bool |allowImpPasswordRetrieval *Optional*     |
</div>


## `SystemInterceptUserDeleteDnListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete an Intercept User number(s) from the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name          |Type      |Description  |
|--------------|----------|-------------|
|phone_numbers |List[str] |phoneNumbers |
</div>


## `SystemInterceptUserGetDnListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a list of Intercept User dns defined in the system.

The response is either a `SystemInterceptUserGetDnListResponse()` or an
`ErrorResponse()`.

</div>


## `SystemInterceptUserGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the system-level intercept user service settings.

The response is either a `SystemInterceptUserGetResponse()` or an `ErrorResponse()`.

</div>


## `SystemInterceptUserModifyDnRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a Intercept User number's description in the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type|Description            |
|-------------|----|-----------------------|
|phone_number |str |phoneNumber            |
|description  |str |description *Optional* |
</div>


## `SystemInterceptUserModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system-level intercept user service settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                           |Type |Description                            |
|-------------------------------|-----|---------------------------------------|
|emergency_and_repair_intercept |bool |emergencyAndRepairIntercept *Optional* |
</div>


## `SystemInventoryReportGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Inventory Report.

The response is either a `SystemInventoryReportGetResponse()` or an `ErrorResponse()`.

</div>


## `SystemInventoryReportModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with Inventory Report.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                 |Type|Description                   |
|---------------------|----|------------------------------|
|default_from_address |str |defaultFromAddress *Optional* |
</div>


## `SystemLanguageAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a language to the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`SystemLanguageAddRequest22()`.

**Attributes:**

|Name     |Type|Description|
|---------|----|-----------|
|language |str |language   |
|locale   |str |locale     |
|encoding |str |encoding   |
</div>


## `SystemLanguageAddRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a language to the system.

The command will fail in Amplify data mode if the locale element is greater than 5
characters in length.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name     |Type|Description|
|---------|----|-----------|
|language |str |language   |
|locale   |str |locale     |
|encoding |str |encoding   |
</div>


## `SystemLanguageDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a language from the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name     |Type|Description|
|---------|----|-----------|
|language |str |language   |
</div>


## `SystemLanguageGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the defined languages in the system.

The response is either a `SystemLanguageGetListResponse()` or an `ErrorResponse()`.

</div>


## `SystemLanguageModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a language properties in the system.

If the becomeDefaultLanguage element is present, the language in this request becomes
the default language for the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`SystemLanguageModifyRequest22()`.

**Attributes:**

|Name                    |Type |Description                      |
|------------------------|-----|---------------------------------|
|language                |str  |language                         |
|become_default_language |bool |becomeDefaultLanguage *Optional* |
|locale                  |str  |locale *Optional*                |
|encoding                |str  |encoding *Optional*              |
</div>


## `SystemLanguageModifyRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a language properties in the system.

If the becomeDefaultLanguage element is present, the language in this request becomes
the default language for the system.  The command will fail in Amplify data mode if
the locale element is greater than 5 characters in length.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                    |Type |Description                      |
|------------------------|-----|---------------------------------|
|language                |str  |language                         |
|become_default_language |bool |becomeDefaultLanguage *Optional* |
|locale                  |str  |locale *Optional*                |
|encoding                |str  |encoding *Optional*              |
</div>


## `SystemLegacyAutomaticCallbackGetLineTypeListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system's legacy automatic callback line type settings.

The response is either a `SystemLegacyAutomaticCallbackGetTypeLineListResponse()` or
an `ErrorResponse()`.

</div>


## `SystemLegacyAutomaticCallbackGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system's legacy automatic callback attributes.

The response is either a `SystemLegacyAutomaticCallbackGetResponse()` or an
`ErrorResponse()`.

</div>


## `SystemLegacyAutomaticCallbackModifyLineTypeRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the system's legacy automatic callback line type attributes.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description              |
|----------------|----|-------------------------|
|line_type       |str |lineType                 |
|match_action    |str |matchAction *Optional*   |
|no_match_action |str |noMatchAction *Optional* |
</div>


## `SystemLegacyAutomaticCallbackModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the system's legacy automatic callback attributes.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                        |Type|Description                         |
|----------------------------|----|------------------------------------|
|max_monitors_per_originator |int |maxMonitorsPerOriginator *Optional* |
|max_monitors_per_terminator |int |maxMonitorsPerTerminator *Optional* |
|t2_minutes                  |int |t2Minutes *Optional*                |
|t4_seconds                  |int |t4Seconds *Optional*                |
|t5_seconds                  |int |t5Seconds *Optional*                |
|t6_minutes                  |int |t6Minutes *Optional*                |
|t7_minutes                  |int |t7Minutes *Optional*                |
|t8_seconds                  |int |t8Seconds *Optional*                |
|t_ring_seconds              |int |tRingSeconds *Optional*             |
|t10_o_minutes               |int |t10OMinutes *Optional*              |
|t10_t_minutes               |int |t10TMinutes *Optional*              |
</div>


## `SystemLicensingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get all the licensing information.

The response is either `SystemLicensingGetResponse()` or `ErrorResponse()`.

Replaced By: `SystemLicensingGetRequest14sp3()`

</div>


## `SystemLicensingGetRequest14sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get all the licensing information.

The response is either `SystemLicensingGetResponse14sp3()` or `ErrorResponse()`.

</div>


## `SystemLicensingGetRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get all the licensing information.

The response is either `SystemLicensingGetResponse21sp1()` or `ErrorResponse()`.

</div>


## `SystemLicensingGetSystemLicenseListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of system licenses in the system.

The response is either a `SystemLicensingGetSystemLicenseListResponse()` or an
`ErrorResponse()`. Replaced by: `SystemLicensingGetSystemLicenseListRequest21()` in AS
data mode

</div>


## `SystemLicensingGetSystemLicenseListRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of system licenses in the system.

The response is either a `SystemLicensingGetSystemLicenseListResponse21()` or an
`ErrorResponse()`. Replaced by: `SystemLicensingGetSystemLicenseListRequest21sp1()`.

</div>


## `SystemLicensingGetSystemLicenseListRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of system licenses in the system.

The response is either a `SystemLicensingGetSystemLicenseListResponse21()` or an
`ErrorResponse()`. Replaced by: SystemLicensingGetSystemLicenseListRequest21p1.

</div>


## `SystemLicensingGetSystemLicenseListRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of system licenses in the system.

The response is either a `SystemLicensingGetSystemLicenseListResponse21sp1()` or an
`ErrorResponse()`. Replaced by: `SystemLicensingGetSystemLicenseListRequest22()`.

</div>


## `SystemLicensingGetSystemLicenseListRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of system licenses in the system.

The response is either a `SystemLicensingGetSystemLicenseListResponse22()` or an
`ErrorResponse()`. Replaced by: `SystemLicensingGetSystemLicenseListRequest22V2()`.

</div>


## `SystemLicensingGetSystemLicenseListRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of system licenses in the system.

The response is either a `SystemLicensingGetSystemLicenseListResponse22V2()` or an
`ErrorResponse()`.

</div>


## `SystemLicensingReloadRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Load a new license file.

The response is either `SuccessResponse()` or `ErrorResponse()`.

</div>


## `SystemLocationBasedCallingRestrictionsGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Gets system level the Location Based Calling Restrictions attributes.

The response is either a `SystemLocationBasedCallingRestrictionsGetResponse()` or an
`ErrorResponse()`. Replaced by:
`SystemLocationBasedCallingRestrictionsGetRequest17sp3()`

</div>


## `SystemLocationBasedCallingRestrictionsGetRequest17sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Gets system level the Location Based Calling Restrictions attributes.

The response is either a `SystemLocationBasedCallingRestrictionsGetResponse17sp3()` or
an `ErrorResponse()`.

</div>


## `SystemLocationBasedCallingRestrictionsModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the system level Location Based Calling Restriction attributes.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                            |Type |Description                             |
|--------------------------------|-----|----------------------------------------|
|physical_location_indicator     |str  |physicalLocationIndicator *Optional*    |
|enforce_msc_validation          |bool |enforceMscValidation *Optional*         |
|enable_office_zone_announcement |bool |enableOfficeZoneAnnouncement *Optional* |
|enhance_office_zone             |bool |enhanceOfficeZone *Optional*            |
</div>


## `SystemMGCPDeviceTypeGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of mgcp device types in the system.

See Also: `SystemDeviceTypeGetAvailableListRequest14sp3()`.

The response is either `SystemMGCPDeviceTypeGetListResponse()` or `ErrorResponse()`.

</div>


## `SystemMGCPDeviceTypeGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a mgcp device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemMGCPDeviceTypeGetResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemMGCPDeviceTypeModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a mgcp device type.

In release 14, this is limited to changing the obsolete flag.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type |Description           |
|------------|-----|----------------------|
|device_type |str  |deviceType            |
|is_obsolete |bool |isObsolete *Optional* |
</div>


## `SystemMailParametersGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of Mail system parameters.

The response is either `SystemMailParametersGetResponse()` or `ErrorResponse()`.

</div>


## `SystemMailParametersGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of Mail system parameters.

The response is either `SystemMailParametersGetResponse22()` or `ErrorResponse()`.

</div>


## `SystemMailParametersModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify Mail system parameters.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                  |Type |Description                                 |
|--------------------------------------|-----|--------------------------------------------|
|primary_server_net_address            |str  |primaryServerNetAddress *Optional*          |
|secondary_server_net_address          |str  |secondaryServerNetAddress *Optional*        |
|default_from_address                  |str  |defaultFromAddress *Optional*               |
|default_subject                       |str  |defaultSubject *Optional*                   |
|support_dnssrv_for_mail_server_access |bool |supportDNSSRVForMailServerAccess *Optional* |
|secure_mode                           |str  |secureMode *Optional*                       |
|port                                  |int  |port *Optional*                             |
</div>


## `SystemMaliciousCallTraceGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get Malicious Call Trace system parameters and the list of users that use the
Malicious Call Trace feature.

The response is either a `SystemMaliciousCallTraceGetResponse()` or an
`ErrorResponse()`.

</div>


## `SystemMaliciousCallTraceGetUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the list of users that use the Malicious Call Trace feature.

The response is either a `SystemMaliciousCallTraceGetUserListResponse()` or an
`ErrorResponse()`.

Replaced By: `SystemMaliciousCallTraceGetRequest()`

</div>


## `SystemMaliciousCallTraceModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a Malicious Call Trace system parameter.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                          |Type |Description                           |
|------------------------------|-----|--------------------------------------|
|play_mct_warning_announcement |bool |playMCTWarningAnnouncement *Optional* |
</div>


## `SystemMediaAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a Media to the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                       |Type|Description               |
|---------------------------|----|--------------------------|
|media_name                 |str |mediaName                 |
|codec_name                 |str |codecName                 |
|media_type                 |str |mediaType                 |
|bandwidth_enforcement_type |str |bandwidthEnforcementType  |
|media_bandwidth            |int |mediaBandwidth *Optional* |
</div>


## `SystemMediaAddRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a Media to the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                       |Type|Description               |
|---------------------------|----|--------------------------|
|media_name                 |str |mediaName                 |
|codec_name                 |str |codecName                 |
|media_type                 |str |mediaType                 |
|bandwidth_enforcement_type |str |bandwidthEnforcementType  |
|media_bandwidth            |int |mediaBandwidth *Optional* |
</div>


## `SystemMediaDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a Media from the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name       |Type|Description|
|-----------|----|-----------|
|media_name |str |mediaName  |
</div>


## `SystemMediaGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a list of media in the system.

The response is either a `SystemMediaGetListResponse()` or an `ErrorResponse()`.

</div>


## `SystemMediaGroupAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a media group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemMediaGroupCodecAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a media to a media group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type|Description |
|-------------|----|------------|
|name         |str |name        |
|codec_name   |str |codecName   |
|codec_weight |int |codecWeight |
</div>


## `SystemMediaGroupCodecDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete media from a media group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name       |Type|Description|
|-----------|----|-----------|
|name       |str |name       |
|codec_name |str |codecName  |
</div>


## `SystemMediaGroupCodecGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of media under a media group.

The response is either `SystemMediaGroupCodecGetListResponse()` or `ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemMediaGroupCodecModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a media associated with a media group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type|Description            |
|-------------|----|-----------------------|
|name         |str |name                   |
|codec_name   |str |codecName              |
|codec_weight |int |codecWeight *Optional* |
</div>


## `SystemMediaGroupDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a media group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemMediaGroupGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of media groups.

The response is either `SystemMediaGroupGetListResponse()` or `ErrorResponse()`.

</div>


## `SystemMediaGroupModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a media group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name     |Type|Description        |
|---------|----|-------------------|
|name     |str |name               |
|new_name |str |newName *Optional* |
</div>


## `SystemMediaGroupUsageListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of SAC groups associated with a media group.

The response is either `SystemMediaGroupUsageResponse()` or `ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemMediaModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a media.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                       |Type|Description                         |
|---------------------------|----|------------------------------------|
|media_name                 |str |mediaName                           |
|codec_name                 |str |codecName *Optional*                |
|bandwidth_enforcement_type |str |bandwidthEnforcementType *Optional* |
|media_bandwidth            |int |mediaBandwidth *Optional*           |
</div>


## `SystemMediaServerAddRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a Media Server to the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name               |Type|Description            |
|-------------------|----|-----------------------|
|net_address        |str |netAddress             |
|port               |int |port *Optional*        |
|transport_protocol |str |transportProtocol      |
|description        |str |description *Optional* |
</div>


## `SystemMediaServerDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a Media Server from the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|net_address |str |netAddress |
</div>


## `SystemMediaServerGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a list of Media Servers defined in the system.

The response is either a `SystemMediaServerGetListResponse()` or an `ErrorResponse()`.

</div>


## `SystemMediaServerModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a Media Server in the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name               |Type|Description                  |
|-------------------|----|-----------------------------|
|net_address        |str |netAddress                   |
|port               |int |port *Optional*              |
|transport_protocol |str |transportProtocol *Optional* |
|description        |str |description *Optional*       |
</div>


## `SystemMediaServerParametersGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of Media Server system parameters.

The response is either `SystemMediaServerParametersGetResponse()` or
`ErrorResponse()`.

</div>


## `SystemMediaServerParametersModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify Media Server system parameters.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                            |Type |Description                                           |
|------------------------------------------------|-----|------------------------------------------------------|
|media_server_response_timer_milliseconds        |int  |mediaServerResponseTimerMilliseconds *Optional*       |
|media_server_selection_route_timer_milliseconds |int  |mediaServerSelectionRouteTimerMilliseconds *Optional* |
|use_static_media_server_device                  |bool |useStaticMediaServerDevice *Optional*                 |
</div>


## `SystemMediaSetAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a Media Set.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name       |Type      |Description|
|-----------|----------|-----------|
|set_name   |str       |setName    |
|media_name |List[str] |mediaName  |
</div>


## `SystemMediaSetDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a Media Set.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name     |Type|Description|
|---------|----|-----------|
|set_name |str |setName    |
</div>


## `SystemMediaSetGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of Media Sets in the system.

The response is either a `SystemMediaSetGetListResponse()` or an `ErrorResponse()`.

</div>


## `SystemMediaSetGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a Media Set.

The response is either a `SystemMediaSetGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name     |Type|Description|
|---------|----|-----------|
|set_name |str |setName    |
</div>


## `SystemMeetMeConferencingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Meet-Me Conferencing functions.

The response is either a `SystemMeetMeConferencingGetResponse()` or an
`ErrorResponse()`. Replaced by: `SystemMeetMeConferencingGetRequest17sp3()`

</div>


## `SystemMeetMeConferencingGetRequest17sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Meet-Me Conferencing functions.

The response is either a `SystemMeetMeConferencingGetResponse17sp3()` or an
`ErrorResponse()`. Replaced by: `SystemMeetMeConferencingGetRequest18()`

</div>


## `SystemMeetMeConferencingGetRequest18`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Meet-Me Conferencing functions.

The response is either a `SystemMeetMeConferencingGetResponse18()` or an
`ErrorResponse()`. Replaced by `SystemMeetMeConferencingGetRequest19()`

</div>


## `SystemMeetMeConferencingGetRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Meet-Me Conferencing functions.

The response is either a `SystemMeetMeConferencingGetResponse19()` or an
`ErrorResponse()`.

</div>


## `SystemMigratedUsersGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of migrated users.

The response is either `SystemMigratedUsersGetListResponse()` or `ErrorResponse()`.
Replaced by: `SystemMigratedUsersGetListRequest22()` in AS data mode

</div>


## `SystemMigratedUsersGetListRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of migrated users.

If the optional parameter userListSizeLimit is set, then the list returned in the
response will contain entries up to value of userListSizeLimit.

The response is either `SystemMigratedUsersGetListResponse22()` or `ErrorResponse()`.

**Attributes:**

|Name                 |Type|Description                  |
|---------------------|----|-----------------------------|
|user_list_size_limit |int |userListSizeLimit *Optional* |
</div>


## `SystemMultimediaPolicyGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Multimedia Policy.

The response is either a `SystemMultimediaPolicyGetResponse()` or an
`ErrorResponse()`.

</div>


## `SystemMultimediaPolicyModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with Multimedia Policy.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                 |Type |Description                                |
|-------------------------------------|-----|-------------------------------------------|
|restrict_non_audio_video_media_types |bool |restrictNonAudioVideoMediaTypes *Optional* |
</div>


## `SystemMusicOnHoldGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Music On Hold.

The response is either a `SystemMusicOnHoldGetResponse()` or an `ErrorResponse()`.

</div>


## `SystemMusicOnHoldModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with Music On Hold.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name               |Type|Description                  |
|-------------------|----|-----------------------------|
|delay_milliseconds |int |delayMilliseconds *Optional* |
</div>


## `SystemNetworkClassOfServiceDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Network Class of Service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemNetworkClassOfServiceGetAssignedServiceProviderListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a list of service providers that have a given Network Class of Service
assigned.

The response is either a
`SystemNetworkClassOfServiceGetAssignedServiceProviderListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemNetworkClassOfServiceGetAssignedSystemVoicePortalListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a list of system voice portals that have a given Network Class of Service
assigned.

The response is either a
`SystemNetworkClassOfServiceGetAssignedSystemVoicePortalListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemNetworkClassOfServiceGetCommunicationBarringProfileUsageListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of Network Classes of Service that contain a specific Communication
Barring Profile.

The response is either a
`SystemNetworkClassOfServiceGetCommunicationBarringProfileUsageListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemNetworkClassOfServiceGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of all Network Classes of Service.

The response is either a `SystemNetworkClassOfServiceGetListResponse()` or an
`ErrorResponse()`.

</div>


## `SystemNetworkClassOfServiceGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get an existing Network Class of Service.

The response is either a `SystemNetworkClassOfServiceGetResponse()` or an
`ErrorResponse()`. Replaced by: `SystemNetworkClassOfServiceGetRequest17()`

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemNetworkClassOfServiceGetRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get an existing Network Class of Service.

The response is either a `SystemNetworkClassOfServiceGetResponse17()` or an
`ErrorResponse()`. Replaced by: `SystemNetworkClassOfServiceGetRequest19sp1()` in AS
data mode

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemNetworkClassOfServiceGetRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get an existing Network Class of Service.

The response is either a `SystemNetworkClassOfServiceGetResponse19sp1()` or an
`ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemNetworkDeviceMonitorParametersGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of Network Device Polling system parameters.

The response is either `SystemNetworkDeviceMonitorParametersGetResponse()` or
`ErrorResponse()`.

</div>


## `SystemNetworkDeviceMonitorParametersModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify Network Device Polling system parameters.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                            |Type|Description                             |
|--------------------------------|----|----------------------------------------|
|polling_interval_minutes        |int |pollingIntervalMinutes *Optional*       |
|failed_polling_interval_minutes |int |failedPollingIntervalMinutes *Optional* |
</div>


## `SystemNetworkProgressionGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with network progression.

The response is either a `SystemNetworkProgressionGetResponse()` or an
`ErrorResponse()`.

</div>


## `SystemNetworkProgressionModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with network progression.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type |Description                  |
|--------------------|-----|-----------------------------|
|is_active           |bool |isActive *Optional*          |
|wait_period_seconds |int  |waitPeriodSeconds *Optional* |
</div>


## `SystemNetworkRoutingServerAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a routing Network Server to the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name               |Type |Description            |
|-------------------|-----|-----------------------|
|net_address        |str  |netAddress             |
|port               |int  |port *Optional*        |
|transport_protocol |str  |transportProtocol      |
|poll               |bool |poll                   |
|description        |str  |description *Optional* |
</div>


## `SystemNetworkRoutingServerDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a routing Network Server from the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|net_address |str |netAddress |
</div>


## `SystemNetworkRoutingServerGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a list of routing Network Servers defined in the system.

The response is either a `SystemNetworkRoutingServerGetListResponse()` or an
`ErrorResponse()`.

</div>


## `SystemNetworkRoutingServerModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a routing Network Server in the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name               |Type |Description                  |
|-------------------|-----|-----------------------------|
|net_address        |str  |netAddress                   |
|port               |int  |port *Optional*              |
|transport_protocol |str  |transportProtocol *Optional* |
|poll               |bool |poll *Optional*              |
|description        |str  |description *Optional*       |
</div>


## `SystemNetworkServerSyncParametersGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of Network Server Sync system parameters.

The response is either `SystemNetworkServerSyncParametersGetResponse()` or
`ErrorResponse()`.

</div>


## `SystemNetworkServerSyncParametersGetRequest14sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of Network Server Sync system parameters.

The response is either `SystemNetworkServerSyncParametersGetResponse14sp2()` or
`ErrorResponse()`.

Replaced By: `SystemNetworkServerSyncParametersGetRequest16()`

</div>


## `SystemNetworkServerSyncParametersGetRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of Network Server Sync system parameters.

The response is either `SystemNetworkServerSyncParametersGetResponse16()` or
`ErrorResponse()`.

Replaced By: `SystemNetworkServerSyncParametersGetRequest17sp4()`

</div>


## `SystemNetworkServerSyncParametersGetRequest17sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of Network Server Sync system parameters.

The response is either `SystemNetworkServerSyncParametersGetResponse17sp4()` or
`ErrorResponse()`. Replaced by: `SystemNetworkServerSyncParametersGetRequest24()`

</div>


## `SystemNetworkServerSyncParametersGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of Network Server Sync system parameters.

The response is either `SystemNetworkServerSyncParametersGetResponse22()` or
`ErrorResponse()`. Replaced by: `SystemNetworkServerSyncParametersGetRequest24V2()` in
AS data mode.

</div>


## `SystemNetworkServerSyncParametersGetRequest24`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of Network Server Sync system parameters.

The response is either `SystemNetworkServerSyncParametersGetResponse24()` or
`ErrorResponse()`. Replaced by: `SystemNetworkServerSyncParametersGetRequest24V2()` in
AS data mode.

</div>


## `SystemNetworkServerSyncParametersGetRequest24V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of Network Server Sync system parameters.

The response is either `SystemNetworkServerSyncParametersGetResponse24V2()` or
`ErrorResponse()`.

</div>


## `SystemNetworkServerSyncParametersModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify Network Server Sync system parameters.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in AS data mode: syncTrunkGroups syncConnectionTimeoutSeconds

**Attributes:**

|Name                            |Type |Description                             |
|--------------------------------|-----|----------------------------------------|
|enable_sync                     |bool |enableSync *Optional*                   |
|sync_line_ports                 |bool |syncLinePorts *Optional*                |
|sync_device_management_info     |bool |syncDeviceManagementInfo *Optional*     |
|sync_trunk_groups               |bool |syncTrunkGroups *Optional*              |
|sync_connection_timeout_seconds |int  |syncConnectionTimeoutSeconds *Optional* |
|sync_enterprise_numbers         |bool |syncEnterpriseNumbers *Optional*        |
</div>


## `SystemNetworkSynchingServerAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a Network Server to the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by
`SystemNetworkSynchingServerAddRequest22V2()`

**Attributes:**

|Name        |Type|Description            |
|------------|----|-----------------------|
|net_address |str |netAddress             |
|port        |int |port *Optional*        |
|description |str |description *Optional* |
</div>


## `SystemNetworkSynchingServerAddRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a Network Server to the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by
`SystemNetworkSynchingServerAddRequest22V2()`

**Attributes:**

|Name        |Type|Description            |
|------------|----|-----------------------|
|net_address |str |netAddress             |
|port        |int |port                   |
|description |str |description *Optional* |
|order       |int |order                  |
</div>


## `SystemNetworkSynchingServerAddRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a Network Server to the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in XS data mode and ignored in AS data mode: order

**Attributes:**

|Name        |Type |Description            |
|------------|-----|-----------------------|
|net_address |str  |netAddress             |
|port        |int  |port                   |
|description |str  |description *Optional* |
|order       |int  |order *Optional*       |
|secure      |bool |secure                 |
</div>


## `SystemNetworkSynchingServerDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a Network Server from the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|net_address |str |netAddress |
</div>


## `SystemNetworkSynchingServerGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a list of Network Servers defined in the system.

The response is either a `SystemNetworkSynchingServerGetListResponse()` or an
`ErrorResponse()`.

</div>


## `SystemNetworkSynchingServerModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a Network Server in the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode: becomePreferred
The following elements are only used in XS data mode and ignored in AS data mode:
order Replaced by `SystemNetworkSynchingServerModifyRequest22()`

**Attributes:**

|Name             |Type |Description                |
|-----------------|-----|---------------------------|
|net_address      |str  |netAddress                 |
|port             |int  |port *Optional*            |
|description      |str  |description *Optional*     |
|become_preferred |bool |becomePreferred *Optional* |
|order            |int  |order *Optional*           |
</div>


## `SystemNetworkSynchingServerModifyRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a Network Server in the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode: becomePreferred
The following elements are only used in XS data mode and ignored in AS data mode:
order

**Attributes:**

|Name             |Type |Description                |
|-----------------|-----|---------------------------|
|net_address      |str  |netAddress                 |
|port             |int  |port *Optional*            |
|description      |str  |description *Optional*     |
|become_preferred |bool |becomePreferred *Optional* |
|order            |int  |order *Optional*           |
|secure           |bool |secure *Optional*          |
</div>


## `SystemNumberActivationGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the Number Activation state.

The response is either `SystemNumberActivationGetResponse()` or `ErrorResponse()`.

</div>


## `SystemNumberActivationGetRequest18sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the Number Activation state.

The response is either `SystemNumberActivationGetResponse18sp1()` or
`ErrorResponse()`. Replaced by: `SystemNumberActivationGetRequest21()`

</div>


## `SystemNumberActivationGetRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the number activation state and enterprise trunk number range
activation status.

The response is either `SystemNumberActivationGetResponse21()` or `ErrorResponse()`.

</div>


## `SystemNumberActivationModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify system number activation setting.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                  |Type |Description                    |
|----------------------|-----|-------------------------------|
|use_number_activation |bool |useNumberActivation *Optional* |
</div>


## `SystemNumberActivationModifyRequest18sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify system number activation and enterprise trunk number range
activation setting.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following element
values are only applicable in AS data mode: enableEnterpriseTrunkNumberRangeActivation
numberActivationMode = Group And User Activation Enabled will raise an error in XS
data mode.

**Attributes:**

|Name                                            |Type |Description                                           |
|------------------------------------------------|-----|------------------------------------------------------|
|number_activation_mode                          |str  |numberActivationMode *Optional*                       |
|enable_enterprise_trunk_number_range_activation |bool |enableEnterpriseTrunkNumberRangeActivation *Optional* |
</div>


## `SystemNumberFormattingParametersGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the system number formatting parameters.

The response is either `SystemNumberFormattingParametersGetResponse()` or
`ErrorResponse()`.

</div>


## `SystemNumberFormattingParametersModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the system number formatting parameters.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                             |Type |Description                             |
|---------------------------------|-----|----------------------------------------|
|apply_formatting_to_e164_numbers |bool |applyFormattingToE164Numbers *Optional* |
</div>


## `SystemNumberPortabilityQueryDigitPatternAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a System Number Portability Query Status Digit Pattern mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|digit_pattern |str |digitPattern |
|status        |str |status       |
</div>


## `SystemNumberPortabilityQueryDigitPatternDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a list of System Number Portability Status Digit Pattern mappings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name          |Type      |Description  |
|--------------|----------|-------------|
|digit_pattern |List[str] |digitPattern |
</div>


## `SystemNumberPortabilityQueryDigitPatternGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a System Number Portability Status Digit Pattern mapping.

The response is either a `SystemNumberPortabilityQueryDigitPatternGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|digit_pattern |str |digitPattern |
</div>


## `SystemNumberPortabilityQueryDigitPatternModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a System Number Portability Status Digit Pattern mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name              |Type|Description                |
|------------------|----|---------------------------|
|digit_pattern     |str |digitPattern               |
|new_digit_pattern |str |newDigitPattern *Optional* |
|status            |str |status *Optional*          |
</div>


## `SystemNumberPortabilityQueryGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get system Number Portability Query Parameters.

The response is either `SystemNumberPortabilityQueryGetResponse()` or
`ErrorResponse()`.

</div>


## `SystemNumberPortabilityQueryModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify system Number Portability Query Parameters.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                                |Type |Description                                               |
|----------------------------------------------------|-----|----------------------------------------------------------|
|continue_call_as_dialed_on_timeout_or_error         |bool |continueCallAsDialedOnTimeoutOrError *Optional*           |
|number_portability_name_lookup_timeout_milliseconds |int  |numberPortabilityNameLookupTimeoutMilliseconds *Optional* |
</div>


## `SystemNumberPortabilityQueryStatusAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a system number portability status information.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description                  |
|--------------------|----|-----------------------------|
|status              |str |status                       |
|treatment_file_name |str |treatmentFileName *Optional* |
</div>


## `SystemNumberPortabilityQueryStatusDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a list of system number portability query statuses.

The number of status entries is limited to 100.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name   |Type      |Description|
|-------|----------|-----------|
|status |List[str] |status     |
</div>


## `SystemNumberPortabilityQueryStatusGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list system Number Portability Query Statuses.

The response is either `SystemNumberPortabilityQueryStatusGetListResponse()` or
`ErrorResponse()`.

</div>


## `SystemNumberPortabilityQueryStatusGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get information for a system Number Portability Query Status.

The response is either `SystemNumberPortabilityQueryStatusGetResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name   |Type|Description|
|-------|----|-----------|
|status |str |status     |
</div>


## `SystemNumberPortabilityQueryStatusModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system number portability status information.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description                  |
|--------------------|----|-----------------------------|
|status_name         |str |statusName                   |
|new_status_name     |str |newStatusName *Optional*     |
|treatment_file_name |str |treatmentFileName *Optional* |
</div>


## `SystemOCIAddACLEntryRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add an entry to the OCI access control list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description            |
|------------|----|-----------------------|
|net_address |str |netAddress             |
|description |str |description *Optional* |
</div>


## `SystemOCICallControlAddACLEntryRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add an entry to the OCI call control access control list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description            |
|------------|----|-----------------------|
|net_address |str |netAddress             |
|description |str |description *Optional* |
</div>


## `SystemOCICallControlApplicationAddACLEntryRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add an entry to the OCI call control application access control list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name           |Type|Description            |
|---------------|----|-----------------------|
|application_id |str |applicationId          |
|net_address    |str |netAddress             |
|description    |str |description *Optional* |
</div>


## `SystemOCICallControlApplicationAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add an application to the OCI call control application list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name               |Type |Description            |
|-------------------|-----|-----------------------|
|application_id     |str  |applicationId          |
|enable_system_wide |bool |enableSystemWide       |
|description        |str  |description *Optional* |
</div>


## `SystemOCICallControlApplicationAddRequest14sp9`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add an application to the OCI call control application list.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by:
`SystemOCICallControlApplicationAddRequest17()`

**Attributes:**

|Name                         |Type |Description                |
|-----------------------------|-----|---------------------------|
|application_id               |str  |applicationId              |
|enable_system_wide           |bool |enableSystemWide           |
|notification_timeout_seconds |int  |notificationTimeoutSeconds |
|description                  |str  |description *Optional*     |
</div>


## `SystemOCICallControlApplicationAddRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add an application to the OCI call control application list.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by:
`SystemOCICallControlApplicationAddRequest22()`

**Attributes:**

|Name                         |Type |Description                |
|-----------------------------|-----|---------------------------|
|application_id               |str  |applicationId              |
|enable_system_wide           |bool |enableSystemWide           |
|notification_timeout_seconds |int  |notificationTimeoutSeconds |
|description                  |str  |description *Optional*     |
|max_event_channels_per_set   |int  |maxEventChannelsPerSet     |
</div>


## `SystemOCICallControlApplicationAddRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add an application to the OCI call control application list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                          |Type |Description                              |
|----------------------------------------------|-----|-----------------------------------------|
|application_id                                |str  |applicationId                            |
|enable_system_wide                            |bool |enableSystemWide                         |
|notification_timeout_seconds                  |int  |notificationTimeoutSeconds               |
|description                                   |str  |description *Optional*                   |
|max_event_channels_per_set                    |int  |maxEventChannelsPerSet                   |
|unresponsive_channel_set_grace_period_seconds |int  |unresponsiveChannelSetGracePeriodSeconds |
</div>


## `SystemOCICallControlApplicationDeleteACLEntryRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete an entry from the OCI call control application access control list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name           |Type|Description   |
|---------------|----|--------------|
|application_id |str |applicationId |
|net_address    |str |netAddress    |
</div>


## `SystemOCICallControlApplicationDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete an entry from the OCI call control application list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name           |Type|Description   |
|---------------|----|--------------|
|application_id |str |applicationId |
</div>


## `SystemOCICallControlApplicationGetACLListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the OCI call control access control list.

The response is either `SystemOCICallControlApplicationGetACLListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name           |Type|Description   |
|---------------|----|--------------|
|application_id |str |applicationId |
</div>


## `SystemOCICallControlApplicationGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the OCI call control application list.

The response is either `SystemOCICallControlApplicationGetListResponse()` or
`ErrorResponse()`.

</div>


## `SystemOCICallControlApplicationModifyACLEntryRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an entry from the call control access control list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name           |Type|Description            |
|---------------|----|-----------------------|
|application_id |str |applicationId          |
|net_address    |str |netAddress             |
|description    |str |description *Optional* |
</div>


## `SystemOCICallControlApplicationModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an application from the OCI call control application list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                          |Type |Description                                         |
|----------------------------------------------|-----|----------------------------------------------------|
|application_id                                |str  |applicationId                                       |
|enable_system_wide                            |bool |enableSystemWide *Optional*                         |
|notification_timeout_seconds                  |int  |notificationTimeoutSeconds *Optional*               |
|description                                   |str  |description *Optional*                              |
|max_event_channels_per_set                    |int  |maxEventChannelsPerSet *Optional*                   |
|unresponsive_channel_set_grace_period_seconds |int  |unresponsiveChannelSetGracePeriodSeconds *Optional* |
</div>


## `SystemOCICallControlDeleteACLEntryRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete an entry from the OCI call control access control list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|net_address |str |netAddress |
</div>


## `SystemOCICallControlGetACLListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the OCI call control access control list.

The response is either `SystemOCICallControlGetACLListResponse()` or
`ErrorResponse()`.

</div>


## `SystemOCICallControlModifyACLEntryRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an entry from the call control access control list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description            |
|------------|----|-----------------------|
|net_address |str |netAddress             |
|description |str |description *Optional* |
</div>


## `SystemOCIDeleteACLEntryRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete an entry from the OCI access control list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|net_address |str |netAddress |
</div>


## `SystemOCIGetACLListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the OCI access control list.

The response is either `SystemOCIGetACLListResponse()` or `ErrorResponse()`.

</div>


## `SystemOCIModifyACLEntryRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an entry in the OCI access control list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description            |
|------------|----|-----------------------|
|net_address |str |netAddress             |
|description |str |description *Optional* |
</div>


## `SystemOCIReportingAddACLEntryRequest13mp9`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add an entry to the OCI Reporting Access Control List.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name              |Type |Description            |
|------------------|-----|-----------------------|
|net_address       |str  |netAddress             |
|description       |str  |description *Optional* |
|restrict_messages |bool |restrictMessages       |
</div>


## `SystemOCIReportingAddMessageNameListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a list of reported messages for a host in the OCI Reporting Access Control List.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type      |Description           |
|-------------------------|----------|----------------------|
|net_address              |str       |netAddress            |
|message_name_starts_with |List[str] |messageNameStartsWith |
</div>


## `SystemOCIReportingDeleteACLEntryRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete an entry from the OCI Reporting Access Control List.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|net_address |str |netAddress |
</div>


## `SystemOCIReportingDeleteMessageNameListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a list of reported messages from a host in the OCI Reporting Access Control
List.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type      |Description                      |
|-------------------------|----------|---------------------------------|
|net_address              |str       |netAddress                       |
|delete_all_message_names |bool      |deleteAllMessageNames *Optional* |
|message_name_starts_with |List[str] |messageNameStartsWith *Optional* |
</div>


## `SystemOCIReportingGetACLListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the OCI Reporting Access Control List.

The response is either a `SystemOCIReportingACLListGetResponse()` or an
`ErrorResponse()`.

</div>


## `SystemOCIReportingGetMessageNameListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of restricted messages from a host in the OCI Reporting Access Control
List.

The response is either a `SystemOCIReportingGetMessageNameListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|net_address |str |netAddress |
</div>


## `SystemOCIReportingModifyACLEntryRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the description on an entry in the OCI Reporting Access Control List.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name              |Type |Description                 |
|------------------|-----|----------------------------|
|net_address       |str  |netAddress                  |
|description       |str  |description *Optional*      |
|restrict_messages |bool |restrictMessages *Optional* |
</div>


## `SystemOCIReportingParametersGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of OCIReporting system parameters.

The response is either `SystemOCIReportingParametersGetResponse()` or
`ErrorResponse()`.

</div>


## `SystemOCIReportingParametersGetRequest14sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of OCIReporting system parameters.

The response is either `SystemOCIReportingParametersGetResponse14sp1()` or
`ErrorResponse()`.

</div>


## `SystemOCIReportingParametersGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of OCIReporting system parameters.

The response is either `SystemOCIReportingParametersGetResponse22()` or
`ErrorResponse()`.

</div>


## `SystemOCIReportingParametersModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify OCI Reporting system parameters.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                             |Type |Description                              |
|---------------------------------|-----|-----------------------------------------|
|server_port                      |int  |serverPort *Optional*                    |
|enable_connection_ping           |bool |enableConnectionPing *Optional*          |
|connection_ping_interval_seconds |int  |connectionPingIntervalSeconds *Optional* |
|alter_passwords                  |bool |alterPasswords *Optional*                |
|enable_public_identity_reporting |bool |enablePublicIdentityReporting *Optional* |
|secure                           |bool |secure *Optional*                        |
</div>


## `SystemOfficeZoneAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a new Office Zone.

The zoneList is an ordered list with the first member being of the highest priority.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name              |Type      |Description            |
|------------------|----------|-----------------------|
|office_zone_name  |str       |officeZoneName         |
|description       |str       |description *Optional* |
|zone_name         |List[str] |zoneName               |
|primary_zone_name |str       |primaryZoneName        |
</div>


## `SystemOfficeZoneDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete an Office Zone.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name             |Type|Description    |
|-----------------|----|---------------|
|office_zone_name |str |officeZoneName |
</div>


## `SystemOfficeZoneGetAssignedServiceProviderListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a list of service providers that have a given Office Zone assigned.

The response is either a `SystemOfficeZoneGetAssignedServiceProviderListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name             |Type|Description    |
|-----------------|----|---------------|
|office_zone_name |str |officeZoneName |
</div>


## `SystemOfficeZoneGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of all Office Zones.

The response is either a `SystemOfficeZoneGetListResponse()` or an `ErrorResponse()`.

</div>


## `SystemOfficeZoneGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get an existing Office Zone.

The response is either a `SystemOfficeZoneGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name             |Type|Description    |
|-----------------|----|---------------|
|office_zone_name |str |officeZoneName |
</div>


## `SystemOfficeZoneGetZoneUsageListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of Office Zones that contain a specific Zone.

The response is either a `SystemOfficeZoneGetZoneUsageListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name      |Type|Description|
|----------|----|-----------|
|zone_name |str |zoneName   |
</div>


## `SystemOutboundProxyCacheParametersGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of Outbound Proxy Cache system parameters.

The response is either `SystemOutboundProxyCacheParametersGetResponse()` or
`ErrorResponse()`. Note that an error is returned if CloudPBX is not licensed.

</div>


## `SystemOutboundProxyCacheParametersModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify Outbound Proxy Cache system parameters.

The response is either `SuccessResponse()` or `ErrorResponse()`. Note that an error is
returned if CloudPBX is not licensed.

**Attributes:**

|Name                         |Type|Description                          |
|-----------------------------|----|-------------------------------------|
|eviction_timeout_minutes     |int |evictionTimeoutMinutes *Optional*    |
|refresh_timeout_minutes      |int |refreshTimeoutMinutes *Optional*     |
|audit_interval_minutes       |int |auditIntervalMinutes *Optional*      |
|maximum_cache_size           |int |maximumCacheSize *Optional*          |
|dns_type_default_value       |str |dnsTypeDefaultValue *Optional*       |
|use_dns_srv_default_value    |str |useDnsSrvDefaultValue *Optional*     |
|srv_prefix_default_value     |str |srvPrefixDefaultValue *Optional*     |
|outbound_proxy_default_value |str |outboundProxyDefaultValue *Optional* |
|transport_type_default_value |str |transportTypeDefaultValue *Optional* |
|secure_rtp_default_value     |str |secureRtpDefaultValue *Optional*     |
</div>


## `SystemOutboundProxyCacheStaleRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to stale the Outbound Proxy Cache.

The response is either `SuccessResponse()` or `ErrorResponse()`. Note that an error is
returned if CloudPBX is not licensed.

**Attributes:**

|Name                |Type|Description                  |
|--------------------|----|-----------------------------|
|reseller_id         |str |resellerId *Optional*        |
|service_provider_id |str |serviceProviderId *Optional* |
</div>


## `SystemOutgoingCallingPlanCallTypeAddMappingRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a system outgoing calling plan call type mapping.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name         |Type|Description |
|-------------|----|------------|
|country_code |str |countryCode |
|digit_map    |str |digitMap    |
|call_type    |str |callType    |
</div>


## `SystemOutgoingCallingPlanCallTypeDeleteMappingRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a system outgoing calling plan call type mapping.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name         |Type|Description |
|-------------|----|------------|
|country_code |str |countryCode |
|digit_map    |str |digitMap    |
</div>


## `SystemOutgoingCallingPlanCallTypeGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of call types of outgoing calling plan Response is
`SystemOutgoingCallingPlanCallTypeGetListRequest()` or `ErrorResponse()`.


</div>


## `SystemOutgoingCallingPlanCallTypeGetMappingListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of system outgoing calling plan call type mappings.

The response is either `SystemOutgoingCallingPlanCallTypeGetMappingListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name         |Type|Description            |
|-------------|----|-----------------------|
|country_code |str |countryCode *Optional* |
</div>


## `SystemOutgoingCallingPlanGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Outgoing Calling Plan.

The response is either a `SystemOutgoingCallingPlanGetResponse()` or an
`ErrorResponse()`.

</div>


## `SystemOutgoingCallingPlanGetRequest17sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Outgoing Calling Plan.

The response is either a `SystemOutgoingCallingPlanGetResponse17sp3()` or an
`ErrorResponse()`.

</div>


## `SystemOutgoingCallingPlanModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with Outgoing Calling Plan.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                             |Type |Description                             |
|---------------------------------|-----|----------------------------------------|
|direct_transfer_screening        |bool |directTransferScreening *Optional*      |
|enable_enhanced_toll_call_typing |bool |enableEnhancedTollCallTyping *Optional* |
</div>


## `SystemPasswordRulesGetRequest13mp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the system's password rules setting applicable to System administrator,
Provisioning Administrator, and/or Service Provider Administrator, Group
Administrator, Department Administrator, user.

The response is either `SystemPasswordRulesGetResponse13mp2()` or `ErrorResponse()`.

Replaced By : `SystemPasswordRulesGetRequest16()`

</div>


## `SystemPasswordRulesGetRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the system's password rules setting applicable to System administrator,
Provisioning Administrator, and/or Service Provider Administrator, Group
Administrator, Department Administrator, user.

The response is either `SystemPasswordRulesGetResponse16()` or `ErrorResponse()`.
Replaced by: `SystemPasswordRulesGetRequest22()` in AS data mode.

</div>


## `SystemPasswordRulesGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the system's password rules setting applicable to System administrator,
Provisioning Administrator, and/or Service Provider Administrator, Group
Administrator, Department Administrator, user.

The response is either `SystemPasswordRulesGetResponse22()` or `ErrorResponse()`.
Replaced by: `SystemPasswordRulesGetRequest23()` in AS data mode.

</div>


## `SystemPasswordRulesGetRequest23`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the system's password rules setting applicable to System administrator,
Provisioning Administrator, and/or Service Provider Administrator, Group
Administrator, Department Administrator, user.

The response is either `SystemPasswordRulesGetResponse23()` or `ErrorResponse()`.

</div>


## `SystemPasswordRulesModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the system providers password rule setting applicable to System
Adminstrator, Provisioning Administrator, and/or Service Provider Administrator, Group
Administrator, Department Administrator, User.

The response is either `SuccessResponse()` or `ErrorResponse()`.

Replaced By: `SystemPasswordRulesModifyRequest14sp3()`

**Attributes:**

|Name                                        |Type |Description                                       |
|--------------------------------------------|-----|--------------------------------------------------|
|rules_apply_to                              |str  |rulesApplyTo *Optional*                           |
|allow_web_add_external_authentication_users |bool |allowWebAddExternalAuthenticationUsers *Optional* |
|disallow_user_id                            |bool |disallowUserId *Optional*                         |
|disallow_old_password                       |bool |disallowOldPassword *Optional*                    |
|disallow_reversed_old_password              |bool |disallowReversedOldPassword *Optional*            |
|restrict_min_digits                         |bool |restrictMinDigits *Optional*                      |
|min_digits                                  |int  |minDigits *Optional*                              |
|restrict_min_upper_case_letters             |bool |restrictMinUpperCaseLetters *Optional*            |
|min_upper_case_letters                      |int  |minUpperCaseLetters *Optional*                    |
|restrict_min_lower_case_letters             |bool |restrictMinLowerCaseLetters *Optional*            |
|min_lower_case_letters                      |int  |minLowerCaseLetters *Optional*                    |
|restrict_min_non_alphanumeric_characters    |bool |restrictMinNonAlphanumericCharacters *Optional*   |
|min_non_alphanumeric_characters             |int  |minNonAlphanumericCharacters *Optional*           |
|min_length                                  |int  |minLength *Optional*                              |
|max_failed_login_attempts                   |int  |maxFailedLoginAttempts *Optional*                 |
|password_expires_days                       |int  |passwordExpiresDays *Optional*                    |
|send_login_disabled_notify_email            |bool |sendLoginDisabledNotifyEmail *Optional*           |
|login_disabled_notify_email_address         |str  |loginDisabledNotifyEmailAddress *Optional*        |
|disallow_rules_modification                 |bool |disallowRulesModification *Optional*              |
</div>


## `SystemPasswordRulesModifyRequest14sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the system providers password rule setting applicable to System
Adminstrator, Provisioning Administrator, and/or Service Provider Administrator, Group
Administrator, Department Administrator, User.

The following elements are only used in AS data mode and ignored in XS data mode:
forcePasswordChangeAfterReset

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                        |Type |Description                                       |
|--------------------------------------------|-----|--------------------------------------------------|
|rules_apply_to                              |str  |rulesApplyTo *Optional*                           |
|allow_web_add_external_authentication_users |bool |allowWebAddExternalAuthenticationUsers *Optional* |
|disallow_user_id                            |bool |disallowUserId *Optional*                         |
|disallow_old_password                       |bool |disallowOldPassword *Optional*                    |
|disallow_reversed_old_password              |bool |disallowReversedOldPassword *Optional*            |
|restrict_min_digits                         |bool |restrictMinDigits *Optional*                      |
|min_digits                                  |int  |minDigits *Optional*                              |
|restrict_min_upper_case_letters             |bool |restrictMinUpperCaseLetters *Optional*            |
|min_upper_case_letters                      |int  |minUpperCaseLetters *Optional*                    |
|restrict_min_lower_case_letters             |bool |restrictMinLowerCaseLetters *Optional*            |
|min_lower_case_letters                      |int  |minLowerCaseLetters *Optional*                    |
|restrict_min_non_alphanumeric_characters    |bool |restrictMinNonAlphanumericCharacters *Optional*   |
|min_non_alphanumeric_characters             |int  |minNonAlphanumericCharacters *Optional*           |
|min_length                                  |int  |minLength *Optional*                              |
|max_failed_login_attempts                   |int  |maxFailedLoginAttempts *Optional*                 |
|password_expires_days                       |int  |passwordExpiresDays *Optional*                    |
|send_login_disabled_notify_email            |bool |sendLoginDisabledNotifyEmail *Optional*           |
|login_disabled_notify_email_address         |str  |loginDisabledNotifyEmailAddress *Optional*        |
|disallow_previous_passwords                 |bool |disallowPreviousPasswords *Optional*              |
|number_of_previous_passwords                |int  |numberOfPreviousPasswords *Optional*              |
|force_password_change_after_reset           |bool |forcePasswordChangeAfterReset *Optional*          |
|enforce_external_auth_for_route_point       |bool |enforceExternalAuthForRoutePoint *Optional*       |
</div>


## `SystemPasswordSecurityParametersGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the password security parameters for the system.

The response is either a `SystemPasswordSecurityParametersGetResponse()` or an
`ErrorResponse()`.

</div>


## `SystemPasswordSecurityParametersModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the password security settings for the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                              |Type |Description                              |
|----------------------------------|-----|-----------------------------------------|
|use_existing_hashing              |bool |useExistingHashing *Optional*            |
|enforce_password_change_on_expiry |bool |enforcePasswordChangeOnExpiry *Optional* |
</div>


## `SystemPerformanceMeasurementGenerateReportRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Generate a performance measurements report.

The response is either `SuccessResponse()` or `ErrorResponse()`.

</div>


## `SystemPerformanceMeasurementReportingAddFileServerRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a performance measurements reporting ftp server.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                 |Type |Description           |
|---------------------|-----|----------------------|
|ftp_host_net_address |str  |ftpHostNetAddress     |
|ftp_user_id          |str  |ftpUserId             |
|ftp_user_password    |str  |ftpUserPassword       |
|passive_ftp          |bool |passiveFTP *Optional* |
</div>


## `SystemPerformanceMeasurementReportingAddFileServerRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a performance measurements reporting ftp server.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name              |Type |Description           |
|------------------|-----|----------------------|
|repository_url    |str  |repositoryUrl         |
|ftp_user_id       |str  |ftpUserId             |
|ftp_user_password |str  |ftpUserPassword       |
|passive_ftp       |bool |passiveFTP *Optional* |
</div>


## `SystemPerformanceMeasurementReportingDeleteFileServerRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a performance measurements reporting ftp server.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                 |Type|Description       |
|---------------------|----|------------------|
|ftp_host_net_address |str |ftpHostNetAddress |
</div>


## `SystemPerformanceMeasurementReportingDeleteFileServerRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a performance measurements reporting ftp server.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name           |Type|Description   |
|---------------|----|--------------|
|repository_url |str |repositoryUrl |
</div>


## `SystemPerformanceMeasurementReportingGetFileServerListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list performance measurements reporting ftp servers.

The response is either
`SystemPerformanceMeasurementReportingGetFileServerListResponse()` or
`ErrorResponse()`.

</div>


## `SystemPerformanceMeasurementReportingGetFileServerListRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list performance measurements reporting ftp servers.

The response is either
`SystemPerformanceMeasurementReportingGetFileServerListResponse22()` or
`ErrorResponse()`.

</div>


## `SystemPerformanceMeasurementReportingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the performance measurements reporting settings.

The response is either `SystemPerformanceMeasurementReportingGetResponse()` or
`ErrorResponse()`. Replaced by: `SystemPerformanceMeasurementReportingGetRequest22()`

</div>


## `SystemPerformanceMeasurementReportingGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the performance measurements reporting settings.

The response is either `SystemPerformanceMeasurementReportingGetResponse22()` or
`ErrorResponse()`. Replaced by: `SystemPerformanceMeasurementReportingGetRequest24()`

</div>


## `SystemPerformanceMeasurementReportingGetRequest24`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the performance measurements reporting settings.

The response is either `SystemPerformanceMeasurementReportingGetResponse24()` or
`ErrorResponse()`.

</div>


## `SystemPerformanceMeasurementReportingModifyFileServerRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a performance measurements reporting ftp server.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                 |Type |Description           |
|---------------------|-----|----------------------|
|ftp_host_net_address |str  |ftpHostNetAddress     |
|passive_ftp          |bool |passiveFTP *Optional* |
</div>


## `SystemPerformanceMeasurementReportingModifyFileServerRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a performance measurements reporting ftp server.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name           |Type |Description           |
|---------------|-----|----------------------|
|repository_url |str  |repositoryUrl         |
|passive_ftp    |bool |passiveFTP *Optional* |
</div>


## `SystemPerformanceMeasurementReportingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the performance measurements reporting settings.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                 |Type |Description                                 |
|-------------------------------------|-----|--------------------------------------------|
|is_active                            |bool |isActive *Optional*                         |
|reporting_interval                   |int  |reportingInterval *Optional*                |
|reset_measurements_after_each_report |bool |resetMeasurementsAfterEachReport *Optional* |
|report_enterprise                    |bool |reportEnterprise *Optional*                 |
|report_service_provider              |bool |reportServiceProvider *Optional*            |
|report_device                        |bool |reportDevice *Optional*                     |
|report_table                         |bool |reportTable *Optional*                      |
|report_encoding                      |str  |reportEncoding *Optional*                   |
</div>


## `SystemPersonalAssistantGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get system Personal Assistant Parameters.

The response is either `SystemPersonalAssistantGetResponse()` or `ErrorResponse()`.

</div>


## `SystemPersonalAssistantModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify system Personal Assistant Parameters.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                            |Type|Description                            |
|--------------------------------|----|---------------------------------------|
|transfer_to_attendant_key       |str |transferToAttendantKey *Optional*      |
|transfer_to_voice_messaging_key |str |transferToVoiceMessagingKey *Optional* |
</div>


## `SystemPhysicalLocationGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of Physical Location system parameters.

The response is either `SystemPhysicalLocationGetResponse()` or `ErrorResponse()`.

</div>


## `SystemPhysicalLocationModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify Physical Location system parameters.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                         |Type |Description                          |
|-----------------------------|-----|-------------------------------------|
|always_allow_emergency_calls |bool |alwaysAllowEmergencyCalls *Optional* |
</div>


## `SystemPolicyGetDefaultRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the system's default policy settings.

The response is either `SystemPolicyGetDefaultResponse14()` or `ErrorResponse()`.

</div>


## `SystemPolicyGetDefaultRequest14sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the system's default policy settings.

The response is either `SystemPolicyGetDefaultResponse14sp1()` or `ErrorResponse()`.

Replaced By: `SystemPolicyGetDefaultRequest14sp4()`

</div>


## `SystemPolicyGetDefaultRequest14sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the system's default policy settings.

The response is either `SystemPolicyGetDefaultResponse14sp4()` or `ErrorResponse()`.

</div>


## `SystemPolicyGetDefaultRequest16sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the system's default policy settings.

The response is either `SystemPolicyGetDefaultResponse16sp1()` or `ErrorResponse()`.

</div>


## `SystemPolicyGetDefaultRequest16sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the system's default policy settings.

The response is either `SystemPolicyGetDefaultResponse16sp2()` or `ErrorResponse()`.

</div>


## `SystemPolicyGetDefaultRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the system's default policy settings.

The response is either `SystemPolicyGetDefaultResponse17()` or `ErrorResponse()`.

</div>


## `SystemPolicyGetDefaultRequest17sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the system's default policy settings.

The response is either `SystemPolicyGetDefaultResponse17sp1()` or `ErrorResponse()`.

</div>


## `SystemPolicyGetDefaultRequest17sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the system's default policy settings.

The response is either `SystemPolicyGetDefaultResponse17sp3()` or `ErrorResponse()`.

</div>


## `SystemPolicyGetDefaultRequest18`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the system's default policy settings.

The response is either `SystemPolicyGetDefaultResponse18()` or `ErrorResponse()`.
Replaced by: `SystemPolicyGetDefaultRequest20()` in AS data mode

</div>


## `SystemPolicyGetDefaultRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the system's default policy settings.

The response is either `SystemPolicyGetDefaultResponse19sp1()` or `ErrorResponse()`.
Replaced by: `SystemPolicyGetDefaultRequest20()` in AS mode

</div>


## `SystemPolicyGetDefaultRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the system's default policy settings.

The response is either `SystemPolicyGetDefaultResponse20()` or `ErrorResponse()`.
Replaced by: `SystemPolicyGetDefaultRequest22()` in AS mode

</div>


## `SystemPolicyGetDefaultRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the system's default policy settings.

The response is either `SystemPolicyGetDefaultResponse22()` or `ErrorResponse()`.

</div>


## `SystemPolicyModifyDefaultRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the system's default policy settings.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in AS data mode: GroupAdminDialableCallerIDAccess
ServiceProviderAdminDialableCallerIDAccess
GroupAdminCommunicationBarringUserProfileAccess (This element is only used for groups
in an Enterprise) GroupAdminVerifyTranslationAndRoutingAccess
ServiceProviderVerifyTranslationAndRoutingAccess
groupUserAutoAttendantNameDialingAccess The following elements are only used in XS
data mode: serviceProviderAdminCommunicationBarringAccess Replaced by:
`SystemPolicyModifyDefaultRequest22()` in AS mode

**Attributes:**

|Name                                                         |Type|Description                                                      |
|-------------------------------------------------------------|----|-----------------------------------------------------------------|
|group_calling_plan_access                                    |str |groupCallingPlanAccess *Optional*                                |
|group_extension_access                                       |str |groupExtensionAccess *Optional*                                  |
|group_ldap_integration_access                                |str |groupLDAPIntegrationAccess *Optional*                            |
|group_voice_messaging_access                                 |str |groupVoiceMessagingAccess *Optional*                             |
|group_department_admin_user_access                           |str |groupDepartmentAdminUserAccess *Optional*                        |
|group_department_admin_trunk_group_access                    |str |groupDepartmentAdminTrunkGroupAccess *Optional*                  |
|group_department_admin_phone_number_extension_access         |str |groupDepartmentAdminPhoneNumberExtensionAccess *Optional*        |
|group_department_admin_calling_line_id_number_access         |str |groupDepartmentAdminCallingLineIdNumberAccess *Optional*         |
|group_user_authentication_access                             |str |groupUserAuthenticationAccess *Optional*                         |
|group_user_group_directory_access                            |str |groupUserGroupDirectoryAccess *Optional*                         |
|group_user_profile_access                                    |str |groupUserProfileAccess *Optional*                                |
|group_user_enhanced_call_logs_access                         |str |groupUserEnhancedCallLogsAccess *Optional*                       |
|group_user_auto_attendant_name_dialing_access                |str |groupUserAutoAttendantNameDialingAccess *Optional*               |
|group_admin_profile_access                                   |str |groupAdminProfileAccess *Optional*                               |
|group_admin_user_access                                      |str |groupAdminUserAccess *Optional*                                  |
|group_admin_admin_access                                     |str |groupAdminAdminAccess *Optional*                                 |
|group_admin_department_access                                |str |groupAdminDepartmentAccess *Optional*                            |
|group_admin_access_device_access                             |str |groupAdminAccessDeviceAccess *Optional*                          |
|group_admin_enhanced_service_instance_access                 |str |groupAdminEnhancedServiceInstanceAccess *Optional*               |
|group_admin_feature_access_code_access                       |str |groupAdminFeatureAccessCodeAccess *Optional*                     |
|group_admin_phone_number_extension_access                    |str |groupAdminPhoneNumberExtensionAccess *Optional*                  |
|group_admin_calling_line_id_number_access                    |str |groupAdminCallingLineIdNumberAccess *Optional*                   |
|group_admin_service_access                                   |str |groupAdminServiceAccess *Optional*                               |
|group_admin_trunk_group_access                               |str |groupAdminTrunkGroupAccess *Optional*                            |
|group_admin_verify_translation_and_routing_access            |str |groupAdminVerifyTranslationAndRoutingAccess *Optional*           |
|group_admin_session_admission_control_access                 |str |groupAdminSessionAdmissionControlAccess *Optional*               |
|group_admin_dialable_caller_id_access                        |str |groupAdminDialableCallerIDAccess *Optional*                      |
|group_admin_office_zone_access                               |str |groupAdminOfficeZoneAccess *Optional*                            |
|group_admin_number_activation_access                         |str |groupAdminNumberActivationAccess *Optional*                      |
|group_admin_communication_barring_user_profile_access        |str |groupAdminCommunicationBarringUserProfileAccess *Optional*       |
|service_provider_admin_profile_access                        |str |serviceProviderAdminProfileAccess *Optional*                     |
|service_provider_admin_group_access                          |str |serviceProviderAdminGroupAccess *Optional*                       |
|service_provider_admin_user_access                           |str |serviceProviderAdminUserAccess *Optional*                        |
|service_provider_admin_admin_access                          |str |serviceProviderAdminAdminAccess *Optional*                       |
|service_provider_admin_department_access                     |str |ServiceProviderAdminDepartmentAccess *Optional*                  |
|service_provider_admin_access_device_access                  |str |serviceProviderAdminAccessDeviceAccess *Optional*                |
|service_provider_admin_phone_number_extension_access         |str |serviceProviderAdminPhoneNumberExtensionAccess *Optional*        |
|service_provider_admin_calling_line_id_number_access         |str |serviceProviderAdminCallingLineIdNumberAccess *Optional*         |
|service_provider_admin_service_access                        |str |serviceProviderAdminServiceAccess *Optional*                     |
|service_provider_admin_service_pack_access                   |str |serviceProviderAdminServicePackAccess *Optional*                 |
|service_provider_admin_session_admission_control_access      |str |serviceProviderAdminSessionAdmissionControlAccess *Optional*     |
|service_provider_admin_verify_translation_and_routing_access |str |serviceProviderAdminVerifyTranslationAndRoutingAccess *Optional* |
|service_provider_admin_web_branding_access                   |str |serviceProviderAdminWebBrandingAccess *Optional*                 |
|service_provider_admin_office_zone_access                    |str |serviceProviderAdminOfficeZoneAccess *Optional*                  |
|service_provider_admin_communication_barring_access          |str |serviceProviderAdminCommunicationBarringAccess *Optional*        |
|enterprise_admin_network_policy_access                       |str |enterpriseAdminNetworkPolicyAccess *Optional*                    |
|service_provider_admin_dialable_caller_id_access             |str |serviceProviderAdminDialableCallerIDAccess *Optional*            |
|enterprise_admin_number_activation_access                    |str |enterpriseAdminNumberActivationAccess *Optional*                 |
</div>


## `SystemPolicyModifyDefaultRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the system's default policy settings.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in AS data mode: GroupAdminDialableCallerIDAccess
ServiceProviderAdminDialableCallerIDAccess
GroupAdminCommunicationBarringUserProfileAccess (This element is only used for groups
in an Enterprise) GroupAdminVerifyTranslationAndRoutingAccess
ServiceProviderVerifyTranslationAndRoutingAccess
groupUserAutoAttendantNameDialingAccess The following elements are only used in XS
data mode: serviceProviderAdminCommunicationBarringAccess

**Attributes:**

|Name                                                         |Type|Description                                                      |
|-------------------------------------------------------------|----|-----------------------------------------------------------------|
|group_calling_plan_access                                    |str |groupCallingPlanAccess *Optional*                                |
|group_extension_access                                       |str |groupExtensionAccess *Optional*                                  |
|group_voice_messaging_access                                 |str |groupVoiceMessagingAccess *Optional*                             |
|group_department_admin_user_access                           |str |groupDepartmentAdminUserAccess *Optional*                        |
|group_department_admin_trunk_group_access                    |str |groupDepartmentAdminTrunkGroupAccess *Optional*                  |
|group_department_admin_phone_number_extension_access         |str |groupDepartmentAdminPhoneNumberExtensionAccess *Optional*        |
|group_department_admin_calling_line_id_number_access         |str |groupDepartmentAdminCallingLineIdNumberAccess *Optional*         |
|group_user_authentication_access                             |str |groupUserAuthenticationAccess *Optional*                         |
|group_user_group_directory_access                            |str |groupUserGroupDirectoryAccess *Optional*                         |
|group_user_profile_access                                    |str |groupUserProfileAccess *Optional*                                |
|group_user_enhanced_call_logs_access                         |str |groupUserEnhancedCallLogsAccess *Optional*                       |
|group_user_auto_attendant_name_dialing_access                |str |groupUserAutoAttendantNameDialingAccess *Optional*               |
|group_admin_profile_access                                   |str |groupAdminProfileAccess *Optional*                               |
|group_admin_user_access                                      |str |groupAdminUserAccess *Optional*                                  |
|group_admin_admin_access                                     |str |groupAdminAdminAccess *Optional*                                 |
|group_admin_department_access                                |str |groupAdminDepartmentAccess *Optional*                            |
|group_admin_access_device_access                             |str |groupAdminAccessDeviceAccess *Optional*                          |
|group_admin_enhanced_service_instance_access                 |str |groupAdminEnhancedServiceInstanceAccess *Optional*               |
|group_admin_feature_access_code_access                       |str |groupAdminFeatureAccessCodeAccess *Optional*                     |
|group_admin_phone_number_extension_access                    |str |groupAdminPhoneNumberExtensionAccess *Optional*                  |
|group_admin_calling_line_id_number_access                    |str |groupAdminCallingLineIdNumberAccess *Optional*                   |
|group_admin_service_access                                   |str |groupAdminServiceAccess *Optional*                               |
|group_admin_trunk_group_access                               |str |groupAdminTrunkGroupAccess *Optional*                            |
|group_admin_verify_translation_and_routing_access            |str |groupAdminVerifyTranslationAndRoutingAccess *Optional*           |
|group_admin_session_admission_control_access                 |str |groupAdminSessionAdmissionControlAccess *Optional*               |
|group_admin_dialable_caller_id_access                        |str |groupAdminDialableCallerIDAccess *Optional*                      |
|group_admin_office_zone_access                               |str |groupAdminOfficeZoneAccess *Optional*                            |
|group_admin_number_activation_access                         |str |groupAdminNumberActivationAccess *Optional*                      |
|group_admin_communication_barring_user_profile_access        |str |groupAdminCommunicationBarringUserProfileAccess *Optional*       |
|service_provider_admin_profile_access                        |str |serviceProviderAdminProfileAccess *Optional*                     |
|service_provider_admin_group_access                          |str |serviceProviderAdminGroupAccess *Optional*                       |
|service_provider_admin_user_access                           |str |serviceProviderAdminUserAccess *Optional*                        |
|service_provider_admin_admin_access                          |str |serviceProviderAdminAdminAccess *Optional*                       |
|service_provider_admin_department_access                     |str |ServiceProviderAdminDepartmentAccess *Optional*                  |
|service_provider_admin_access_device_access                  |str |serviceProviderAdminAccessDeviceAccess *Optional*                |
|service_provider_admin_phone_number_extension_access         |str |serviceProviderAdminPhoneNumberExtensionAccess *Optional*        |
|service_provider_admin_calling_line_id_number_access         |str |serviceProviderAdminCallingLineIdNumberAccess *Optional*         |
|service_provider_admin_service_access                        |str |serviceProviderAdminServiceAccess *Optional*                     |
|service_provider_admin_service_pack_access                   |str |serviceProviderAdminServicePackAccess *Optional*                 |
|service_provider_admin_session_admission_control_access      |str |serviceProviderAdminSessionAdmissionControlAccess *Optional*     |
|service_provider_admin_verify_translation_and_routing_access |str |serviceProviderAdminVerifyTranslationAndRoutingAccess *Optional* |
|service_provider_admin_web_branding_access                   |str |serviceProviderAdminWebBrandingAccess *Optional*                 |
|service_provider_admin_office_zone_access                    |str |serviceProviderAdminOfficeZoneAccess *Optional*                  |
|service_provider_admin_communication_barring_access          |str |serviceProviderAdminCommunicationBarringAccess *Optional*        |
|enterprise_admin_network_policy_access                       |str |enterpriseAdminNetworkPolicyAccess *Optional*                    |
|service_provider_admin_dialable_caller_id_access             |str |serviceProviderAdminDialableCallerIDAccess *Optional*            |
|enterprise_admin_number_activation_access                    |str |enterpriseAdminNumberActivationAccess *Optional*                 |
</div>


## `SystemPortalPasscodeRulesGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the system passcode rules setting.

The response is either `SystemPortalPasscodeRulesGetResponse()` or `ErrorResponse()`.
Replaced by: `SystemPortalPasscodeRulesGetRequest19()`

</div>


## `SystemPortalPasscodeRulesGetRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the system passcode rules setting.

The response is either `SystemPortalPasscodeRulesGetResponse19()` or
`ErrorResponse()`.

</div>


## `SystemPortalPasscodeRulesModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the system passcode rules setting.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in AS data mode: numberOfRepeatedDigits
disallowRepeatedPatterns disallowContiguousSequences numberOfAscendingDigits
numberOfDescendingDigits numberOfPreviousPasscodes

**Attributes:**

|Name                                          |Type |Description                                        |
|----------------------------------------------|-----|---------------------------------------------------|
|disallow_repeated_digits                      |bool |disallowRepeatedDigits *Optional*                  |
|number_of_repeated_digits                     |int  |numberOfRepeatedDigits *Optional*                  |
|disallow_repeated_patterns                    |bool |disallowRepeatedPatterns *Optional*                |
|disallow_contiguous_sequences                 |bool |disallowContiguousSequences *Optional*             |
|number_of_ascending_digits                    |int  |numberOfAscendingDigits *Optional*                 |
|number_of_descending_digits                   |int  |numberOfDescendingDigits *Optional*                |
|disallow_user_number                          |bool |disallowUserNumber *Optional*                      |
|disallow_reversed_user_number                 |bool |disallowReversedUserNumber *Optional*              |
|disallow_old_passcode                         |bool |disallowOldPasscode *Optional*                     |
|number_of_previous_passcodes                  |int  |numberOfPreviousPasscodes *Optional*               |
|disallow_reversed_old_passcode                |bool |disallowReversedOldPasscode *Optional*             |
|min_code_length                               |int  |minCodeLength *Optional*                           |
|max_code_length                               |int  |maxCodeLength *Optional*                           |
|disable_login_after_max_failed_login_attempts |bool |disableLoginAfterMaxFailedLoginAttempts *Optional* |
|max_failed_login_attempts                     |int  |maxFailedLoginAttempts *Optional*                  |
|expire_password                               |bool |expirePassword *Optional*                          |
|passcode_expires_days                         |int  |passcodeExpiresDays *Optional*                     |
|send_login_disabled_notify_email              |bool |sendLoginDisabledNotifyEmail *Optional*            |
|login_disabled_notify_email_address           |str  |loginDisabledNotifyEmailAddress *Optional*         |
|default_password                              |str  |defaultPassword *Optional*                         |
</div>


## `SystemPreferredCarrierAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a carrier to the system.

More than one carrier may be assigned to each country code.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name             |Type |Description     |
|-----------------|-----|----------------|
|carrier          |str  |carrier         |
|cic              |str  |cic             |
|country_code     |str  |countryCode     |
|is_intra_lata    |bool |isIntraLata     |
|is_inter_lata    |bool |isInterLata     |
|is_international |bool |isInternational |
</div>


## `SystemPreferredCarrierDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a carrier from the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. An
`ErrorResponse()` is returned if the carrier is in use, or if the carrier didn't exist
prior to deletion..

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|carrier |str |carrier    |
</div>


## `SystemPreferredCarrierGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests a table of all the carriers defined in the system.

The response is either a `SystemPreferredCarrierGetListResponse()` or an
`ErrorResponse()`.

</div>


## `SystemPreferredCarrierGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the attributes of carrier.

The response is either a `SystemPreferreredCarrierGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|carrier |str |carrier    |
</div>


## `SystemPreferredCarrierModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the attributes of a carrier.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. An
`ErrorResponse()` is returned if countryCode modification is attempted while the
carrier is assigned to a service provider.  An `ErrorResponse()` is returned if an
attempt to set isIntraLata to false is made while the carrier is used as an intra-LATA
carrier.  An `ErrorResponse()` is returned if an attempt to set isInternational to
false is made while the carrier is used as an international carrier.

**Attributes:**

|Name             |Type |Description                |
|-----------------|-----|---------------------------|
|carrier          |str  |carrier                    |
|cic              |str  |cic *Optional*             |
|country_code     |str  |countryCode *Optional*     |
|is_intra_lata    |bool |isIntraLata *Optional*     |
|is_inter_lata    |bool |isInterLata *Optional*     |
|is_international |bool |isInternational *Optional* |
</div>


## `SystemProvisioningValidationGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the system's provisioning validation attributes.

The response is either a `SystemProvisioningValidationGetResponse()` or and
`ErrorResponse()`.

</div>


## `SystemProvisioningValidationGetRequest14sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the system's provisioning validation attributes.

The response is either a `SystemProvisioningValidationGetResponse14sp2()` or
`ErrorResponse()`.

</div>


## `SystemProvisioningValidationGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the system's provisioning validation attributes.

The response is either a `SystemProvisioningValidationGetResponse22()` or
`ErrorResponse()`.

</div>


## `SystemProvisioningValidationModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the system's provisioning validation attributes.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode:
denyMobilityNumberAsRedirectionDestination
denyEnterpriseNumberAsNetworkLocationDestination

**Attributes:**

|Name                                                   |Type |Description                                                 |
|-------------------------------------------------------|-----|------------------------------------------------------------|
|is_active                                              |bool |isActive *Optional*                                         |
|is_network_server_query_active                         |bool |isNetworkServerQueryActive *Optional*                       |
|timeout_seconds                                        |int  |timeoutSeconds *Optional*                                   |
|deny_mobility_number_as_redirection_destination        |bool |denyMobilityNumberAsRedirectionDestination *Optional*       |
|deny_enterprise_number_as_network_location_destination |bool |denyEnterpriseNumberAsNetworkLocationDestination *Optional* |
</div>


## `SystemPushNotificationAllowedApplicationAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add an application to the list of allowed push notification applications.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name           |Type|Description            |
|---------------|----|-----------------------|
|application_id |str |applicationId          |
|description    |str |description *Optional* |
</div>


## `SystemPushNotificationAllowedApplicationDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to remove an application from the list of allowed push notification
applications.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name           |Type|Description   |
|---------------|----|--------------|
|application_id |str |applicationId |
</div>


## `SystemPushNotificationAllowedApplicationGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of allowed push notification applications.

The response is either `SystemPushNotificationAllowedApplicationGetListResponse()` or
`ErrorResponse()`.

</div>


## `SystemPushNotificationAllowedApplicationModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify an application in the list of allowed push notification
applications.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name           |Type|Description            |
|---------------|----|-----------------------|
|application_id |str |applicationId          |
|description    |str |description *Optional* |
</div>


## `SystemPushNotificationParametersGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of push notification system parameters.

The response is either `SystemPushNotificationParametersGetResponse()` or
`ErrorResponse()`.

</div>


## `SystemPushNotificationParametersModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify push notification system parameters.

The following elements are only used in AS data mode and ignored in the Amplify data
mode: subscriptionEventsPerSecond

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                             |Type |Description                              |
|---------------------------------|-----|-----------------------------------------|
|enforce_allowed_application_list |bool |enforceAllowedApplicationList *Optional* |
|maximum_registrations_per_user   |int  |maximumRegistrationsPerUser *Optional*   |
|maximum_registration_age_days    |int  |maximumRegistrationAgeDays *Optional*    |
|new_call_timeout                 |int  |newCallTimeout *Optional*                |
|subscription_events_per_second   |int  |subscriptionEventsPerSecond *Optional*   |
</div>


## `SystemRedundancyParametersGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Replaced By `SystemRedundancyParametersGetRequest16sp2()` Request to get the list of
Redundancy system parameters.

The response is either `SystemRedundancyParametersGetResponse()` or `ErrorResponse()`.

</div>


## `SystemRedundancyParametersGetRequest16sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of Redundancy system parameters.

The response is either `SystemRedundancyParametersGetResponse16sp2()` or
`ErrorResponse()`.

</div>


## `SystemRedundancyParametersModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify Redundancy system parameters.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                   |Type |Description                                  |
|---------------------------------------|-----|---------------------------------------------|
|roll_back_timer_minutes                |int  |rollBackTimerMinutes *Optional*              |
|send_sip_option_message_upon_migration |bool |sendSipOptionMessageUponMigration *Optional* |
</div>


## `SystemResourcePriorityGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the system Resource Priority service attributes.

The response is either `SystemResourcePriorityGetResponse()` or `ErrorResponse()`.

</div>


## `SystemResourcePriorityModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system Resource Priority service attributes.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                              |Type |Description                              |
|----------------------------------|-----|-----------------------------------------|
|send_resource_priority_to_network |bool |sendResourcePriorityToNetwork *Optional* |
|resource_priority                 |str  |resourcePriority *Optional*              |
</div>


## `SystemRoamingNetworkAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Roaming Network.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                      |Type|Description                        |
|--------------------------|----|-----------------------------------|
|msc_address               |str |mscAddress                         |
|network_translation_index |str |networkTranslationIndex *Optional* |
</div>


## `SystemRoamingNetworkDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Roaming Network.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|msc_address |str |mscAddress |
</div>


## `SystemRoamingNetworkModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a Roaming Network.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                      |Type|Description                        |
|--------------------------|----|-----------------------------------|
|msc_address               |str |mscAddress                         |
|network_translation_index |str |networkTranslationIndex *Optional* |
</div>


## `SystemRouteListEnterpriseTrunkNumberPrefixGetSummaryListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a summary table of all enterprise trunk prefixes in the system.

If resellerId is specified, only the prefixes assigned to the enterprise/service
provider within the given reseller are returned.  If reseller administrator sends the
request and resellerId is not specified, the administrator's resellerId is used.

The response is either
`SystemRouteListEnterpriseTrunkNumberPrefixGetSummaryListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name        |Type|Description           |
|------------|----|----------------------|
|reseller_id |str |resellerId *Optional* |
</div>


## `SystemRouteListEnterpriseTrunkNumberRangeGetSummaryListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a summary table of all enterprise trunk number ranges in the system.

If resellerId is specified, the number ranges assigned to the enterprises/service
providers within the reseller are returned.  If reseller administrator sends the
request and resellerId is not specified, the administrator's resellerId is used.

The response is either
`SystemRouteListEnterpriseTrunkNumberRangeGetSummaryListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name        |Type|Description           |
|------------|----|----------------------|
|reseller_id |str |resellerId *Optional* |
</div>


## `SystemRoutePointExternalSystemAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add an Route Point External System, which is a cluster of Application Controllers.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description            |
|------------|----|-----------------------|
|name        |str |name                   |
|description |str |description *Optional* |
</div>


## `SystemRoutePointExternalSystemApplicationControllerAddListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add an application controller to Route Point External System.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type      |Description                      |
|-----------------------|----------|---------------------------------|
|name                   |str       |name                             |
|application_controller |List[str] |applicationController *Optional* |
</div>


## `SystemRoutePointExternalSystemApplicationControllerDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete an application controller for Route Point External System.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type      |Description                      |
|-----------------------|----------|---------------------------------|
|name                   |str       |name                             |
|application_controller |List[str] |applicationController *Optional* |
</div>


## `SystemRoutePointExternalSystemApplicationControllerGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of Application Controllers assigned to the Route Point External Systems
specified.

The response is either
`SystemRoutePointExternalSystemApplicationControllerGetResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description    |
|----------------|----|---------------|
|external_system |str |externalSystem |
</div>


## `SystemRoutePointExternalSystemDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete an Route Point External System.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name |Type|Description|
|-----|----|-----------|
|name |str |name       |
</div>


## `SystemRoutePointExternalSystemGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of Route Point External Systems that are configured for the system.

The response is either `SystemRoutePointExternalSystemGetListResponse()` or
`ErrorResponse()`.

</div>


## `SystemRoutePointExternalSystemGetRoutePointListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of Route Points that are using the specified Route Point External System.

The response is either a `SystemRoutePointExternalSystemGetRoutePointListResponse()`
or an `ErrorResponse()`.

**Attributes:**

|Name                        |Type|Description              |
|----------------------------|----|-------------------------|
|route_point_external_system |str |routePointExternalSystem |
</div>


## `SystemRoutePointExternalSystemModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an Route Point External System.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description            |
|------------|----|-----------------------|
|name        |str |name                   |
|new_name    |str |newName *Optional*     |
|description |str |description *Optional* |
</div>


## `SystemRoutingAddRouteDeviceRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a routing device to a route.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name               |Type|Description            |
|-------------------|----|-----------------------|
|route_name         |str |routeName              |
|net_address        |str |netAddress             |
|port               |int |port *Optional*        |
|transport_protocol |str |transportProtocol      |
|description        |str |description *Optional* |
</div>


## `SystemRoutingAddRouteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a route to the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name       |Type|Description|
|-----------|----|-----------|
|route_name |str |routeName  |
</div>


## `SystemRoutingAddTranslationRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a digit routing table entry to the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name       |Type|Description|
|-----------|----|-----------|
|digits     |str |digits     |
|route_name |str |routeName  |
</div>


## `SystemRoutingDeleteRouteDeviceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a routing device from a route.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description     |
|------------|----|----------------|
|route_name  |str |routeName       |
|net_address |str |netAddress      |
|port        |int |port *Optional* |
</div>


## `SystemRoutingDeleteRouteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a route from the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name       |Type|Description|
|-----------|----|-----------|
|route_name |str |routeName  |
</div>


## `SystemRoutingDeleteTranslationRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a digit routing table entry from the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name   |Type|Description|
|-------|----|-----------|
|digits |str |digits     |
</div>


## `SystemRoutingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system's general routing attributes.

The response is either a `SystemRoutingGetResponse()` or an `ErrorResponse()`.

</div>


## `SystemRoutingGetRouteDeviceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a list of devices for a route.

The response is either a `SystemRoutingGetRouteDeviceListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name       |Type|Description|
|-----------|----|-----------|
|route_name |str |routeName  |
</div>


## `SystemRoutingGetRouteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a list of routes in the system.

The response is either a `SystemRoutingGetRouteListResponse()` or an
`ErrorResponse()`.

</div>


## `SystemRoutingGetTranslationListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the system digit routing table.

The response is either a `SystemRoutingGetTranslationListResponse()` or an
`ErrorResponse()`.

</div>


## `SystemRoutingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the system's general routing attributes.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                  |Type |Description                                  |
|--------------------------------------|-----|---------------------------------------------|
|is_route_round_robin                  |bool |isRouteRoundRobin *Optional*                 |
|route_timer_seconds                   |int  |routeTimerSeconds *Optional*                 |
|dns_resolved_address_selection_policy |str  |dnsResolvedAddressSelectionPolicy *Optional* |
|stateful_expiration_minutes           |int  |statefulExpirationMinutes *Optional*         |
|max_addresses_per_hostname            |int  |maxAddressesPerHostname *Optional*           |
|max_addresses_during_setup            |int  |maxAddressesDuringSetup *Optional*           |
</div>


## `SystemRoutingModifyRouteDeviceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a routing device.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name               |Type|Description                  |
|-------------------|----|-----------------------------|
|route_name         |str |routeName                    |
|net_address        |str |netAddress                   |
|port               |int |port *Optional*              |
|transport_protocol |str |transportProtocol *Optional* |
|description        |str |description *Optional*       |
</div>


## `SystemRoutingModifyTranslationRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a digit routing table entry in the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name       |Type|Description          |
|-----------|----|---------------------|
|digits     |str |digits               |
|route_name |str |routeName *Optional* |
</div>


## `SystemRoutingProfileGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of system routing profiles.

If resellerId is specified, the routing profiles assigned to the given reseller are
returned.  If reseller administrator sends the request, resellerId is not specified,
the administrator’s resellerId is used.  If system or provisioning administrator sends
the request, resellerId is not specified, all system routing profiles are returned.

The response is either a `SystemRoutingProfileGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name        |Type|Description           |
|------------|----|----------------------|
|reseller_id |str |resellerId *Optional* |
</div>


## `SystemRoutingProfileParametersGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of Routing Profile related system parameters.

The response is either `SystemRoutingProfileParametersGetResponse()` or
`ErrorResponse()`.

</div>


## `SystemRoutingProfileParametersModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify Routing Profile system parameters.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                      |Type |Description             |
|--------------------------|-----|------------------------|
|enable_permissive_routing |bool |enablePermissiveRouting |
</div>


## `SystemRuntimeDataPublicationGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the system call admission control parameters.

The response is either a `SystemRuntimeDataPublicationGetResponse()` or an
`ErrorResponse()`.

</div>


## `SystemRuntimeDataPublicationModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system call admission control parameters.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode:
enableRuntimeDataSync, runtimeIntervalInMilliSeconds

**Attributes:**

|Name                                        |Type |Description                                      |
|--------------------------------------------|-----|-------------------------------------------------|
|enable_runtime_data_sync                    |bool |enableRuntimeDataSync *Optional*                 |
|runtime_data_sync_interval_in_milli_seconds |int  |runtimeDataSyncIntervalInMilliSeconds *Optional* |
</div>


## `SystemSIPAddACLEntryRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add an entry to the SIP access control list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name               |Type|Description            |
|-------------------|----|-----------------------|
|net_address        |str |netAddress             |
|transport_protocol |str |transportProtocol      |
|description        |str |description *Optional* |
</div>


## `SystemSIPAddACLEntryRequest14sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add an entry to the SIP access control list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name               |Type|Description            |
|-------------------|----|-----------------------|
|net_address        |str |netAddress             |
|transport_protocol |str |transportProtocol      |
|description        |str |description *Optional* |
</div>


## `SystemSIPAddContentTypeRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a content type for the SIP interface.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name         |Type|Description |
|-------------|----|------------|
|content_type |str |contentType |
|interface    |str |interface   |
</div>


## `SystemSIPAuthenticationLockoutClearAllRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to clear all sip authentication lockouts (both endpoint and trunk group) in
the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

</div>


## `SystemSIPAuthenticationPasswordRulesGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the system level SIP authentication password rule settings.

The response is either a `SystemSIPAuthenticationPasswordRulesGetResponse()` or an
`ErrorResponse()`.

</div>


## `SystemSIPAuthenticationPasswordRulesModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the system level SIP authentication password rule settings The
response is either `SuccessResponse()` or `ErrorResponse()`.


**Attributes:**

|Name                                     |Type |Description                                     |
|-----------------------------------------|-----|------------------------------------------------|
|disallow_authentication_name             |bool |disallowAuthenticationName *Optional*           |
|disallow_old_password                    |bool |disallowOldPassword *Optional*                  |
|disallow_reversed_old_password           |bool |disallowReversedOldPassword *Optional*          |
|restrict_min_digits                      |bool |restrictMinDigits *Optional*                    |
|min_digits                               |int  |minDigits *Optional*                            |
|restrict_min_upper_case_letters          |bool |restrictMinUpperCaseLetters *Optional*          |
|min_upper_case_letters                   |int  |minUpperCaseLetters *Optional*                  |
|restrict_min_lower_case_letters          |bool |restrictMinLowerCaseLetters *Optional*          |
|min_lower_case_letters                   |int  |minLowerCaseLetters *Optional*                  |
|restrict_min_non_alphanumeric_characters |bool |restrictMinNonAlphanumericCharacters *Optional* |
|min_non_alphanumeric_characters          |int  |minNonAlphanumericCharacters *Optional*         |
|min_length                               |int  |minLength *Optional*                            |
|send_permanent_lockout_notification      |bool |sendPermanentLockoutNotification *Optional*     |
|permanent_lockout_notify_email_address   |str  |permanentLockoutNotifyEmailAddress *Optional*   |
|endpoint_authentication_lockout_type     |str  |endpointAuthenticationLockoutType *Optional*    |
|endpoint_temporary_lockout_threshold     |int  |endpointTemporaryLockoutThreshold *Optional*    |
|endpoint_wait_algorithm                  |str  |endpointWaitAlgorithm *Optional*                |
|endpoint_lockout_fixed_minutes           |str  |endpointLockoutFixedMinutes *Optional*          |
|endpoint_permanent_lockout_threshold     |int  |endpointPermanentLockoutThreshold *Optional*    |
|trunk_group_authentication_lockout_type  |str  |trunkGroupAuthenticationLockoutType *Optional*  |
|trunk_group_temporary_lockout_threshold  |int  |trunkGroupTemporaryLockoutThreshold *Optional*  |
|trunk_group_wait_algorithm               |str  |trunkGroupWaitAlgorithm *Optional*              |
|trunk_group_lockout_fixed_minutes        |str  |trunkGroupLockoutFixedMinutes *Optional*        |
|trunk_group_permanent_lockout_threshold  |int  |trunkGroupPermanentLockoutThreshold *Optional*  |
</div>


## `SystemSIPDeleteACLEntryRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete an entry from the SIP access control list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|net_address |str |netAddress |
</div>


## `SystemSIPDeleteACLEntryRequest14sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete an entry from the SIP access control list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|net_address |str |netAddress |
</div>


## `SystemSIPDeleteContentTypeRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a content type for the SIP interface.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name         |Type|Description |
|-------------|----|------------|
|content_type |str |contentType |
</div>


## `SystemSIPDeviceFileApplyExtendedCaptureToAllDeviceProfilesRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to apply an extended file capture value to all the profile instances
associated to a sip device type file.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                   |Type |Description                       |
|---------------------------------------|-----|----------------------------------|
|device_type                            |str  |deviceType                        |
|file_format                            |str  |fileFormat                        |
|extended_capture_on_upload_from_device |bool |extendedCaptureOnUploadFromDevice |
</div>


## `SystemSIPDeviceTypeDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeFileDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a sip device type file.

The response is either `SuccessResponse()` or `ErrorResponse()`.

Replaced By: `SystemSIPDeviceTypeFileDeleteRequest14sp8()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
|file_type   |str |fileType   |
</div>


## `SystemSIPDeviceTypeFileDeleteRequest14sp8`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a sip device type file.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
|file_format |str |fileFormat |
</div>


## `SystemSIPDeviceTypeFileGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of device files managed by the Device Management System, on a
per-device type basis.

The response is either `SystemSIPDeviceTypeFileGetListResponse()` or
`ErrorResponse()`.

Replaced By: `SystemSIPDeviceTypeFileGetListRequest14sp8()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeFileGetListRequest14sp8`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of device files managed by the Device Management System, on a
per-device type basis.

The response is either `SystemSIPDeviceTypeFileGetListResponse14sp8()` or
`ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeFileGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type file.

The response is either `SystemSIPDeviceTypeFileGetResponse()` or `ErrorResponse()`.

Replaced By: `SystemSIPDeviceTypeFileGetRequest14sp8()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
|file_type   |str |fileType   |
</div>


## `SystemSIPDeviceTypeFileGetRequest14sp8`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type file.

The response is either `SystemSIPDeviceTypeFileGetResponse14sp8()` or
`ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
|file_format |str |fileFormat |
</div>


## `SystemSIPDeviceTypeFileGetRequest16sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Replaced By `SystemSIPDeviceTypeFileGetRequest18()`.

Request to get a sip device type file.

The response is either `SystemSIPDeviceTypeFileGetResponse16sp1()` or
`ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
|file_format |str |fileFormat |
</div>


## `SystemSIPDeviceTypeFileGetRequest18`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type file.

The response is either `SystemSIPDeviceTypeFileGetResponse18()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
|file_format |str |fileFormat |
</div>


## `SystemSIPDeviceTypeFileGetRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type file.

The response is either `SystemSIPDeviceTypeFileGetResponse19()` or `ErrorResponse()`.
Replaced by: `SystemSIPDeviceTypeFileGetRequest20()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
|file_format |str |fileFormat |
</div>


## `SystemSIPDeviceTypeFileGetRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type file.

The response is either `SystemSIPDeviceTypeFileGetResponse20()` or `ErrorResponse()`.
Replaced by: SystemSIPDeviceTypeFileGetRequest20Sp1

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
|file_format |str |fileFormat |
</div>


## `SystemSIPDeviceTypeFileGetRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type file.

The response is either `SystemSIPDeviceTypeFileGetResponse21sp1()` or
`ErrorResponse()`. Replaced by: `SystemSIPDeviceTypeFileGetRequest22()` in AS data
mode.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
|file_format |str |fileFormat |
</div>


## `SystemSIPDeviceTypeFileGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type file.

The response is either `SystemSIPDeviceTypeFileGetResponse22()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
|file_format |str |fileFormat |
</div>


## `SystemSIPDeviceTypeGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest14sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse14sp1()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest14sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse14sp2()` or `ErrorResponse()`.

Replaced By: `SystemSIPDeviceTypeGetRequest14sp3()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest14sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse14sp3()` or `ErrorResponse()`.
Replaced by: `SystemSIPDeviceTypeGetRequest14sp6()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest14sp6`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse14sp6()` or `ErrorResponse()`.

Replaced By : `SystemSIPDeviceTypeGetRequest15()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest15`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse15()` or `ErrorResponse()`.

Replaced By : `SystemSIPDeviceTypeGetRequest16()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse16()` or `ErrorResponse()`.
Replaced by: `SystemSIPDeviceTypeGetRequest16sp1()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest16sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse16sp1()` or `ErrorResponse()`.
Replaced by: `SystemSIPDeviceTypeGetRequest17()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse17()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest17sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Replaced By `SystemSIPDeviceTypeGetRequest18()`.

Request to get a sip device type.  See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse17sp4()` or `ErrorResponse()`.
Replaced by: `SystemSIPDeviceTypeGetRequest18()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest18`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse18()` or `ErrorResponse()`.
Replaced by: `SystemSIPDeviceTypeGetRequest19()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest18sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse18sp1()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse19()` or `ErrorResponse()`.
Replaced by: `SystemSIPDeviceTypeGetRequest19sp1()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse19sp1()` or `ErrorResponse()`.
Replaced by: `SystemSIPDeviceTypeGetRequest20()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse20()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest20sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse20()` or `ErrorResponse()`.
Replaced by: SystemSIPDeviceTypeGetRequest21sp1V2.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse21()` or `ErrorResponse()`.
Replaced by: SystemSIPDeviceTypeGetRequest21Sp1

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse21sp1()` or `ErrorResponse()`.
Replaced by: SystemSIPDeviceTypeGetRequest21sp1V2

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse22()` or `ErrorResponse()`.
Deprecated by: `SystemSIPDeviceTypeGetRequest22V2()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest22V10`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse22V10()` or `ErrorResponse()`.

Replaced By: `SystemSIPDeviceTypeGetRequest23V6()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest22V11`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse22V11()` or `ErrorResponse()`.
Replaced by `SystemSIPDeviceTypeGetRequest23V7()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest22V12`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse22V12()` or `ErrorResponse()`.
Replaced by `SystemSIPDeviceTypeGetRequest23V8()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest22V13`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse22V13()` or `ErrorResponse()`.
Replaced by: `SystemSIPDeviceTypeGetRequest23V9()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse22V2()` or `ErrorResponse()`.
Deprecated by `SystemSIPDeviceTypeGetRequest22V3()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest22V3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse22V3()` or `ErrorResponse()`.
Deprecated by `SystemSIPDeviceTypeGetRequest22V4()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest22V4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse22V4()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest22V5`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse22V5()` or `ErrorResponse()`.
Replaced by: `SystemDeviceTypeGetRequest22V13()` in XS data mode.  Replaced by:
`SystemDeviceTypeGetRequest22V6()` in AS data mode.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest22V6`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse22V6()` or `ErrorResponse()`.

Replaced By: `SystemSIPDeviceTypeGetRequest23V2()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest22V7`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse22V7()` or `ErrorResponse()`.

Replaced By: `SystemSIPDeviceTypeGetRequest23V2()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest22V8`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse22V8()` or `ErrorResponse()`.

Replaced By: `SystemSIPDeviceTypeGetRequest23V4()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest22V9`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse22V8()` or `ErrorResponse()`.

Replaced By: `SystemSIPDeviceTypeGetRequest23V4()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest23`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse23()` or `ErrorResponse()`.

Replaced By: `SystemSIPDeviceTypeGetRequest23V2()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest23V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse23V2()` or `ErrorResponse()`.
Replaced by: `SystemSIPDeviceTypeGetRequest23V3()` in AS data mode.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest23V3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse23V3()` or `ErrorResponse()`.

Replaced By: `SystemSIPDeviceTypeGetRequest23V4()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest23V4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse23V4()` or `ErrorResponse()`.
Replaced by: `SystemSIPDeviceTypeGetRequest23V5()` in AS data mode.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest23V5`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse23V5()` or `ErrorResponse()`.
Replaced by `SystemSIPDeviceTypeGetRequest23V6()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest23V6`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse23V6()` or `ErrorResponse()`.
Replaced by `SystemSIPDeviceTypeGetRequest23V7()`

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest23V7`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse23V7()` or `ErrorResponse()`.
Replaced by SystemSIPDeviceTypeGetResquest23V8

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest23V8`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse23V8()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeGetRequest23V9`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a sip device type.

See Also: `SystemDeviceTypeGetRequest()`

The response is either `SystemSIPDeviceTypeGetResponse23V9()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeLanguageMappingGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of device language names mapped to BroadWorks language names,
per-device type.

The response is either `SystemSIPDeviceTypeLanguageMappingGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeServiceGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of BroadWorks services that can be integrated to a device type
and the level of integration for this device type.

The response is either `SystemSIPDeviceTypeServiceGetResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_type |str |deviceType |
</div>


## `SystemSIPDeviceTypeServiceModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to set the level of integration that a device type has in relation to
BroadWorks services.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                            |Type |Description                             |
|--------------------------------|-----|----------------------------------------|
|device_type                     |str  |deviceType                              |
|supports_polycom_phone_services |bool |supportsPolycomPhoneServices *Optional* |
</div>


## `SystemSIPDiversionReasonGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of SIP Diversion Cause values.

The response is either a `SystemSIPDiversionReasonGetResponse()` or `ErrorResponse()`.

</div>


## `SystemSIPDiversionReasonModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the SIP cause value for a given diversion reason.

The response is either a `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name             |Type|Description     |
|-----------------|----|----------------|
|diversion_reason |str |diversionReason |
|cause_value      |str |causeValue      |
</div>


## `SystemSIPGetACLListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the SIP access control list.

The response is either `SystemSIPGetACLListResponse()` or `ErrorResponse()`.

</div>


## `SystemSIPGetContentTypeListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the content type list for the SIP interface.

The response is either `SystemSIPGetContentTypeListResponse()` or `ErrorResponse()`.

</div>


## `SystemSIPModifyACLEntryRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an entry from the SIP access control list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name               |Type|Description                  |
|-------------------|----|-----------------------------|
|net_address        |str |netAddress                   |
|transport_protocol |str |transportProtocol *Optional* |
|description        |str |description *Optional*       |
</div>


## `SystemSIPModifyACLEntryRequest14sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an entry from the SIP access control list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name               |Type|Description                  |
|-------------------|----|-----------------------------|
|net_address        |str |netAddress                   |
|transport_protocol |str |transportProtocol *Optional* |
|description        |str |description *Optional*       |
</div>


## `SystemSIPModifyContentTypeRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an content type for the SIP interface.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name         |Type|Description          |
|-------------|----|---------------------|
|content_type |str |contentType          |
|interface    |str |interface *Optional* |
</div>


## `SystemSMDIAddACLEntryRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add an entry to the SMDI access control list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description            |
|------------|----|-----------------------|
|net_address |str |netAddress             |
|description |str |description *Optional* |
</div>


## `SystemSMDIAddACLEntryRequest14sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add an entry to the SMDI access control list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description            |
|------------|----|-----------------------|
|net_address |str |netAddress             |
|description |str |description *Optional* |
</div>


## `SystemSMDIDeleteACLEntryRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete an entry from the SMDI access control list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|net_address |str |netAddress |
</div>


## `SystemSMDIDeleteACLEntryRequest14sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete an entry from the SMDI access control list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|net_address |str |netAddress |
</div>


## `SystemSMDIGetACLListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the SMDI access control list.

The response is either `SystemSMDIGetACLListResponse()` or `ErrorResponse()`.

</div>


## `SystemSMDIMessageDeskAddServerRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a SMDI Server to the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description            |
|------------|----|-----------------------|
|device_name |str |deviceName             |
|net_address |str |netAddress             |
|port        |int |port                   |
|description |str |description *Optional* |
</div>


## `SystemSMDIMessageDeskAddServerRouteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a SMDI Server route to the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name              |Type      |Description      |
|------------------|----------|-----------------|
|route_destination |str       |routeDestination |
|device_name       |List[str] |deviceName       |
</div>


## `SystemSMDIMessageDeskDeleteServerRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a SMDI Server from the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_name |str |deviceName |
</div>


## `SystemSMDIMessageDeskDeleteServerRouteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a SMDI Server route from the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name              |Type|Description      |
|------------------|----|-----------------|
|route_destination |str |routeDestination |
</div>


## `SystemSMDIMessageDeskGetServerListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a list of SMDI Servers defined in the system.

The response is either a `SystemSMDIMessageDeskGetServerListResponse()` or an
`ErrorResponse()`.

</div>


## `SystemSMDIMessageDeskGetServerRouteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a list of SMDI Servers routes in the system.

The response is either a `SystemSMDIMessageDeskGetServerRouteListResponse()` or an
`ErrorResponse()`.

</div>


## `SystemSMDIMessageDeskModifyServerRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a SMDI Server in the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description            |
|------------|----|-----------------------|
|device_name |str |deviceName             |
|net_address |str |netAddress *Optional*  |
|port        |int |port *Optional*        |
|description |str |description *Optional* |
</div>


## `SystemSMDIMessageDeskModifyServerRouteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Replace the list of devices associated with a SMDI server route destination.

There must be at least one device in the list.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name              |Type               |Description               |
|------------------|-------------------|--------------------------|
|route_destination |str                |routeDestination          |
|device_name_list  |OCI.deviceNameList |deviceNameList *Optional* |
</div>


## `SystemSMDIModifyACLEntryRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an entry from the SMDI access control list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description            |
|------------|----|-----------------------|
|net_address |str |netAddress             |
|description |str |description *Optional* |
</div>


## `SystemSMDIModifyACLEntryRequest14sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an entry from the SMDI access control list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description            |
|------------|----|-----------------------|
|net_address |str |netAddress             |
|description |str |description *Optional* |
</div>


## `SystemSMDIParametersGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of SMDI system parameters.

The response is either `SystemSMDIParametersGetResponse()` or `ErrorResponse()`.

</div>


## `SystemSMDIParametersModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify SMDI system parameters.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type |Description               |
|----------------|-----|--------------------------|
|enable_smdi     |bool |enableSMDI *Optional*     |
|listening_port  |int  |listeningPort *Optional*  |
|max_connections |int  |maxConnections *Optional* |
</div>


## `SystemSMPPGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with SMPP external interface.

The response is either a `SystemSMPPGetResponse()` or an `ErrorResponse()`.

Replaced By: `SystemSMPPGetRequest14sp5()`

</div>


## `SystemSMPPGetRequest14sp5`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with SMPP external interface.

The response is either a `SystemSMPPGetResponse14sp5()` or an `ErrorResponse()`.
Replaced by: `SystemSMPPGetRequest21()` in AS data mode

</div>


## `SystemSMPPGetRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with SMPP external interface.

The response is either a `SystemSMPPGetResponse21()` or an `ErrorResponse()`.

</div>


## `SystemSMPPGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with SMPP external interface.

The response is either a `SystemSMPPGetResponse21()` or an `ErrorResponse()`.

</div>


## `SystemSMPPModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the system level data associated with the SMPP external interface.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                              |Type |Description                              |
|----------------------------------|-----|-----------------------------------------|
|primary_smpp_server_net_address   |str  |primarySMPPServerNetAddress *Optional*   |
|primary_smpp_port                 |int  |primarySMPPPort *Optional*               |
|secondary_smpp_server_net_address |str  |secondarySMPPServerNetAddress *Optional* |
|secondary_smpp_port               |int  |secondarySMPPPort *Optional*             |
|system_id                         |str  |systemId *Optional*                      |
|password                          |str  |password *Optional*                      |
|version                           |str  |version *Optional*                       |
|system_type                       |str  |systemType *Optional*                    |
|enable_mwi_customized_message     |bool |enableMWICustomizedMessage *Optional*    |
|support_message_payload           |bool |supportMessagePayload *Optional*         |
|max_short_message_length          |int  |maxShortMessageLength *Optional*         |
|use_gsm_mwi_ucs2_encoding         |bool |useGsmMwiUcs2Encoding *Optional*         |
|include_only_new_message_count    |bool |includeOnlyNewMessageCount *Optional*    |
</div>


## `SystemScheduleAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a system schedule.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|schedule_name |str |scheduleName |
|schedule_type |str |scheduleType |
</div>


## `SystemScheduleGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of a system schedules.

The list can be filtered by schedule type.

The response is either a `SystemScheduleGetListResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name          |Type|Description             |
|--------------|----|------------------------|
|schedule_type |str |scheduleType *Optional* |
</div>


## `SystemSecurityClassificationDeleteClassificationRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a System Security Classification The response is either a `SuccessResponse()`
or an `ErrorResponse()`.


**Attributes:**

|Name                         |Type|Description                |
|-----------------------------|----|---------------------------|
|security_classification_name |str |securityClassificationName |
</div>


## `SystemSecurityClassificationGetClassificationRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a system Security Classification.

The response is either `SystemSecurityClassificationGetClassificationResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                         |Type|Description                |
|-----------------------------|----|---------------------------|
|security_classification_name |str |securityClassificationName |
</div>


## `SystemSecurityClassificationGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a system Security Classifications parameters.

The response is either `SystemSecurityClassificationGetResponse()` or
`ErrorResponse()`.

</div>


## `SystemSecurityClassificationGetRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get system Security Classifications parameters.

The response is either `SystemSecurityClassificationGetResponse21()` or
`ErrorResponse()`.

</div>


## `SystemSecurityClassificationModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify security classification parameters.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. NOTE: The
security classifications must be specified in order of priority.  The command fails if
all the security classifications defined for the system are not provided.

**Attributes:**

|Name                                                 |Type      |Description                                                |
|-----------------------------------------------------|----------|-----------------------------------------------------------|
|meet_me_annc_threshold                               |int       |meetMeAnncThreshold *Optional*                             |
|play_trunk_user_security_classification_announcement |bool      |playTrunkUserSecurityClassificationAnnouncement *Optional* |
|security_classification_name                         |List[str] |securityClassificationName *Optional*                      |
</div>


## `SystemSelectiveServicesGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Selective Services.

The response is either a `SystemSelectiveServicesGetResponse()` or an
`ErrorResponse()`.

</div>


## `SystemSelectiveServicesGetRequest18sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Selective Services.

The response is either a `SystemSelectiveServicesGetResponse18sp1()` or an
`ErrorResponse()`.

</div>


## `SystemSelectiveServicesGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Selective Services.

The response is either a `SystemSelectiveServicesGetResponse22()` or an
`ErrorResponse()`.

</div>


## `SystemSelectiveServicesModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with `SystemSelectiveServicesRequest()`.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                      |Type |Description                                    |
|------------------------------------------|-----|-----------------------------------------------|
|schedule_combination                      |str  |scheduleCombination *Optional*                 |
|screen_private_number                     |bool |screenPrivateNumber *Optional*                 |
|empty_holiday_schedule_is_out_of_schedule |bool |emptyHolidayScheduleIsOutOfSchedule *Optional* |
</div>


## `SystemServerAddressesGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of Server Addresses.

The response is either `SystemServerAddressesGetResponse()` or `ErrorResponse()`. See
also: `PrimaryInfoGetRequest()` `PublicClusterGetFullyQualifiedDomainNameRequest()`

</div>


## `SystemServerAddressesModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify Server Addresses.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                              |Type|Description                                             |
|--------------------------------------------------|----|--------------------------------------------------------|
|web_server_cluster_public_fqdn                    |str |webServerClusterPublicFQDN *Optional*                   |
|application_server_cluster_primary_public_fqdn    |str |applicationServerClusterPrimaryPublicFQDN *Optional*    |
|application_server_cluster_secondary_public_fqdn  |str |applicationServerClusterSecondaryPublicFQDN *Optional*  |
|application_server_cluster_primary_private_fqdn   |str |applicationServerClusterPrimaryPrivateFQDN *Optional*   |
|application_server_cluster_secondary_private_fqdn |str |applicationServerClusterSecondaryPrivateFQDN *Optional* |
</div>


## `SystemServiceActivationAccessCodeGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the Service Activation Access Code system parameters.

The response is either a `SystemServiceActivationAccessCodeGetResponse()` or an
`ErrorResponse()`.

</div>


## `SystemServiceActivationAccessCodeModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify Service Activation Access Code system parameters.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                      |Type |Description                      |
|--------------------------|-----|---------------------------------|
|is_active                 |bool |isActive *Optional*              |
|terminating_access_code   |str  |terminatingAccessCode *Optional* |
|redirecting_access_code   |str  |redirectingAccessCode *Optional* |
|click_to_dial_access_code |str  |clickToDialAccessCode *Optional* |
</div>


## `SystemServiceAttributeDefaultGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the default attributes for a service that are used when assigning the
feature.

The response is either a `SystemServiceAttributeDefaultGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name         |Type|Description |
|-------------|----|------------|
|service_name |str |serviceName |
</div>


## `SystemServiceCodeAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a service code for the purpose of providing free format routable
strings for dialing The response is either `SuccessResponse()` or `ErrorResponse()`.


**Attributes:**

|Name         |Type|Description |
|-------------|----|------------|
|service_code |str |serviceCode |
|description  |str |description |
</div>


## `SystemServiceCodeDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a service code for the purpose of providing free format routable
strings for dialing The response is either `SuccessResponse()` or `ErrorResponse()`.


**Attributes:**

|Name         |Type|Description |
|-------------|----|------------|
|service_code |str |serviceCode |
</div>


## `SystemServiceCodeModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify service code.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name         |Type|Description            |
|-------------|----|-----------------------|
|service_code |str |serviceCode            |
|description  |str |description *Optional* |
</div>


## `SystemServicePackMigrationGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get system level Service Pack Migration parameters.

The response is either a `SystemServicePackMigrationGetResponse()` or an
`ErrorResponse()`.

</div>


## `SystemServicePackMigrationModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify system level settings for Service Pack Migration.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                             |Type|Description                              |
|---------------------------------|----|-----------------------------------------|
|max_simultaneous_migration_tasks |int |maxSimultaneousMigrationTasks *Optional* |
</div>


## `SystemServicePhoneNumberLookupRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Lookup if the given number is defined in the specified service in the system.

The response is `SystemServicePhoneNumberLookupResponse()`.

**Attributes:**

|Name         |Type|Description |
|-------------|----|------------|
|service_type |str |serviceType |
|phone_number |str |phoneNumber |
</div>


## `SystemSessionAdmissionControlGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the session admission control settings for the system.

The response is either a `SystemSessionAdmissionControlGetResponse()` or an
`ErrorResponse()`. Replaced by: `SystemSessionAdmissionControlGetRequest21sp1()`.

</div>


## `SystemSessionAdmissionControlGetRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the session admission control settings for the system.

The response is either a `SystemSessionAdmissionControlGetResponse21sp1()` or an
`ErrorResponse()`. Replaced by: `SystemSessionAdmissionControlGetRequest22()`.

</div>


## `SystemSessionAdmissionControlGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the session admission control settings for the system.

The response is either a `SystemSessionAdmissionControlGetResponse22()` or an
`ErrorResponse()`. Replaced by: `SystemSessionAdmissionControlGetRequest22V2()`.

</div>


## `SystemSessionAdmissionControlGetRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the session admission control settings for the system.

The response is either a `SystemSessionAdmissionControlGetResponse22V2()` or an
`ErrorResponse()`.

</div>


## `SystemSessionAdmissionControlModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the session admission control settings for the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                           |Type |Description                                        |
|-----------------------------------------------|-----|---------------------------------------------------|
|count_long_connections_to_media_server         |bool |countLongConnectionsToMediaServer *Optional*       |
|sac_handling_for_mo_h                          |str  |sacHandlingForMoH *Optional*                       |
|block_vm_deposit_due_to_sac_limits             |bool |blockVMDepositDueToSACLimits *Optional*            |
|sac_codec_selection_policy                     |str  |sacCodecSelectionPolicy *Optional*                 |
|count_call_to_mobile_number_for_sac_subscriber |bool |countCallToMobileNumberForSACSubscriber *Optional* |
|count_bw_anywhere_for_sac_subscriber           |bool |countBWAnywhereForSACSubscriber *Optional*         |
|count_ro_for_sac_subscriber                    |bool |countROForSACSubscriber *Optional*                 |
|exclude_bw_mobility_for_sac_subscriber         |bool |excludeBWMobilityForSACSubscriber *Optional*       |
|enable_holdover_of_highwater_session_counts    |bool |enableHoldoverOfHighwaterSessionCounts *Optional*  |
|holdover_period_minutes                        |str  |holdoverPeriodMinutes *Optional*                   |
|time_zone_offset_minutes                       |str  |timeZoneOffsetMinutes *Optional*                   |
</div>


## `SystemSessionAuditGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with session audit.

The response is either a `SystemSessionAuditGetResponse()` or an `ErrorResponse()`.

Replaced By: `SystemSessionAuditGetRequest14sp3()`

</div>


## `SystemSessionAuditGetRequest14sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with session audit.

The response is either a `SystemSessionAuditGetResponse14sp3()` or an
`ErrorResponse()`.

</div>


## `SystemSessionAuditGetRequest17sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with session audit.

The response is either a `SystemSessionAuditGetResponse17sp3()` or an
`ErrorResponse()`. Replaced by: `SystemSessionAuditGetRequest23()` in AS data mode.

</div>


## `SystemSessionAuditGetRequest23`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with session audit.

The response is either a `SystemSessionAuditGetResponse23()` or an `ErrorResponse()`.

</div>


## `SystemSessionAuditModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with session sudit.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

Replaced By: `SystemSessionAuditModifyRequest14sp3()`

**Attributes:**

|Name                   |Type |Description                     |
|-----------------------|-----|--------------------------------|
|is_active              |bool |isActive *Optional*             |
|interval_seconds       |int  |intervalSeconds *Optional*      |
|timeout_period_seconds |int  |timeoutPeriodSeconds *Optional* |
</div>


## `SystemSessionAuditModifyRequest14sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with session audit.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode:
alwaysAllowRefreshForMS msAuditIntervalSeconds

**Attributes:**

|Name                                    |Type |Description                                   |
|----------------------------------------|-----|----------------------------------------------|
|is_audit_active                         |bool |isAuditActive *Optional*                      |
|audit_interval_seconds                  |int  |auditIntervalSeconds *Optional*               |
|audit_timeout_seconds                   |int  |auditTimeoutSeconds *Optional*                |
|release_call_on_audit_failure           |bool |releaseCallOnAuditFailure *Optional*          |
|is_sip_refresh_allowed_on_audit         |bool |isSIPRefreshAllowedOnAudit *Optional*         |
|allow_update_for_sip_refresh            |bool |allowUpdateForSIPRefresh *Optional*           |
|is_sip_session_timer_active             |bool |isSIPSessionTimerActive *Optional*            |
|sip_session_expires_minimum_seconds     |int  |sipSessionExpiresMinimumSeconds *Optional*    |
|enforce_sip_session_expires_maximum     |bool |enforceSIPSessionExpiresMaximum *Optional*    |
|sip_session_expires_maximum_seconds     |int  |sipSessionExpiresMaximumSeconds *Optional*    |
|sip_session_expires_timer_seconds       |int  |sipSessionExpiresTimerSeconds *Optional*      |
|always_use_session_timer_when_supported |bool |alwaysUseSessionTimerWhenSupported *Optional* |
|preferred_session_timer_refresher       |str  |preferredSessionTimerRefresher *Optional*     |
|enable_emergency_call_alarm_timer       |bool |enableEmergencyCallAlarmTimer *Optional*      |
|emergency_call_alarm_minutes            |int  |emergencyCallAlarmMinutes *Optional*          |
|enable_emergency_call_cleanup_timer     |bool |enableEmergencyCallCleanupTimer *Optional*    |
|emergency_call_cleanup_minutes          |int  |emergencyCallCleanupMinutes *Optional*        |
|always_allow_refresh_for_ms             |bool |alwaysAllowRefreshForMS *Optional*            |
|ms_audit_interval_seconds               |int  |msAuditIntervalSeconds *Optional*             |
</div>


## `SystemShInterfaceParametersGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Retrieves the Sh Interface system parameters.

The response is either a `SystemShInterfaceParametersGetResponse()` or an
`ErrorResponse()`. Replaced by: `SystemShInterfaceParametersGetRequest17()`

</div>


## `SystemShInterfaceParametersGetRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Retrieves the Sh Interface system parameters.

The response is either a `SystemShInterfaceParametersGetResponse()` or an
`ErrorResponse()`.

</div>


## `SystemShInterfaceParametersModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the Sh Interface system parameters.

This request must be submitted on both nodes in the redundant Application Server
cluster in order for the changes to take effect on each node without requiring a
restart.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`SystemShInterfaceParametersModifyRequest17()`

**Attributes:**

|Name                                  |Type|Description                                  |
|--------------------------------------|----|---------------------------------------------|
|hss_realm                             |str |hssRealm *Optional*                          |
|request_timeout_seconds               |int |requestTimeoutSeconds *Optional*             |
|public_identity_refresh_delay_seconds |int |publicIdentityRefreshDelaySeconds *Optional* |
</div>


## `SystemShInterfaceParametersModifyRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the Sh Interface system parameters.

This request must be submitted on both nodes in the redundant Application Server
cluster in order for the changes to take effect on each node without requiring a
restart.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                  |Type|Description                                  |
|--------------------------------------|----|---------------------------------------------|
|hss_realm                             |str |hssRealm *Optional*                          |
|public_identity_refresh_delay_seconds |int |publicIdentityRefreshDelaySeconds *Optional* |
</div>


## `SystemShInterfaceRefreshTaskGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Retrieves the status of the system refresh task on the local Application Server node.

The response is either a `SystemShInterfaceRefreshTaskGetResponse()` or an
`ErrorResponse()`.

</div>


## `SystemShInterfaceRefreshTaskStartRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Dispatches the system refresh task on the local Application Server node.

At most one instance of the system refresh task may run on an Application Server node
at a given point in time.  If the system refresh task is already running when this
request is made, an `ErrorResponse()` is returned.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

</div>


## `SystemShInterfaceRefreshTaskTerminateRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Terminates the system refresh task in progress on the local Application Server node.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

</div>


## `SystemSoftwareVersionGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the software version of the Application Server.

The response is either `SystemSoftwareVersionGetResponse()` or `ErrorResponse()`.

</div>


## `SystemSpeedDial100GetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the speed dial 100 system-wide default setting.

The response is either a `SystemSpeedDial100GetResponse()` or an `ErrorResponse()`.
Replaced by: `SystemSpeedDial100GetRequest17sp1()`

</div>


## `SystemSpeedDial100GetRequest17sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the speed dial 100 system-wide default setting.

The response is either a `SystemSpeedDial100GetResponse17sp1()` or an
`ErrorResponse()`.

</div>


## `SystemSpeedDial100ModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the speed dial 100 system-wide default prefix setting.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name   |Type|Description       |
|-------|----|------------------|
|prefix |str |prefix *Optional* |
</div>


## `SystemStateOrProvinceGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of state and province names.

The response is either `SystemStateOrProvinceGetListResponse()` or `ErrorResponse()`.

</div>


## `SystemStirShakenGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get system Stir Shaken service settings.

The response is either `SystemStirShakenGetResponse()` or `ErrorResponse()`.

</div>


## `SystemStirShakenModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify system Stir Shaken service settings.


**Attributes:**

|Name                                                   |Type |Description                                                 |
|-------------------------------------------------------|-----|------------------------------------------------------------|
|signing_policy                                         |str  |signingPolicy *Optional*                                    |
|tagging_policy                                         |str  |taggingPolicy *Optional*                                    |
|sign_emergency_calls                                   |bool |signEmergencyCalls *Optional*                               |
|tag_emergency_calls                                    |bool |tagEmergencyCalls *Optional*                                |
|signing_service_url                                    |str  |signingServiceURL *Optional*                                |
|tag_from_or_pai                                        |str  |tagFromOrPAI *Optional*                                     |
|verstat_tag                                            |str  |verstatTag *Optional*                                       |
|use_os_value_for_orig_id                               |bool |useOSValueForOrigId *Optional*                              |
|orig_uuid                                              |str  |origUUID *Optional*                                         |
|attestation_level                                      |str  |attestationLevel *Optional*                                 |
|enable_verification                                    |bool |enableVerification *Optional*                               |
|verification_service_url                               |str  |verificationServiceURL *Optional*                           |
|verification_error_handling                            |str  |verificationErrorHandling *Optional*                        |
|proxy_verstat_to_cnam_subscribe                        |bool |proxyVerstatToCNAMSubscribe *Optional*                      |
|use_unknown_headers_from_cnam_notify                   |bool |useUnknownHeadersFromCNAMNotify *Optional*                  |
|use_ts24229_headers                                    |bool |useTS24229Headers *Optional*                                |
|enable_signing_for_unscreened_trunk_group_originations |bool |enableSigningForUnscreenedTrunkGroupOriginations *Optional* |
|enable_tagging_for_unscreened_trunk_group_originations |bool |enableTaggingForUnscreenedTrunkGroupOriginations *Optional* |
|unscreened_trunk_group_origination_attestation_level   |str  |unscreenedTrunkGroupOriginationAttestationLevel *Optional*  |
|verify_gets_calls                                      |bool |verifyGETSCalls *Optional*                                  |
</div>


## `SystemSubscriberGetCallProcessingParametersRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the system call processing configuration for all subscribers The response is
either a `SystemSubscriberGetCallProcessingParametersResponse()` or an
`ErrorResponse()`.

Replaced By: `SystemSubscriberGetCallProcessingParametersRequest14sp3()`

</div>


## `SystemSubscriberGetCallProcessingParametersRequest14sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the system call processing configuration for all subscribers The response is
either a `SystemSubscriberGetCallProcessingParametersResponse14sp3()` or an
`ErrorResponse()`.


</div>


## `SystemSubscriberGetCallProcessingParametersRequest14sp7`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the system call processing configuration for all subscribers The response is
either a `SystemSubscriberGetCallProcessingParametersResponse14sp7()` or an
`ErrorResponse()`.

Replaced By : `SystemSubscriberGetCallProcessingParametersRequest15sp2()`

</div>


## `SystemSubscriberGetCallProcessingParametersRequest15`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the system call processing configuration for all subscribers The response is
either a `SystemSubscriberGetCallProcessingParametersResponse15()` or an
`ErrorResponse()`.

Replaced By: `SystemSubscriberGetCallProcessingParametersRequest15sp2()`

</div>


## `SystemSubscriberGetCallProcessingParametersRequest15sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the system call processing configuration for all subscribers The response is
either a `SystemSubscriberGetCallProcessingParametersResponse15sp2()` or an
`ErrorResponse()`.

Replaced by: `SystemSubscriberGetCallProcessingParametersRequest17()`

</div>


## `SystemSubscriberGetCallProcessingParametersRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the system call processing configuration for all subscribers The response is
either a `SystemSubscriberGetCallProcessingParametersResponse17()` or an
`ErrorResponse()`.


</div>


## `SystemSubscriberGetCallProcessingParametersRequest17sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the system call processing configuration for all subscribers The response is
either a `SystemSubscriberGetCallProcessingParametersResponse17sp3()` or an
`ErrorResponse()`.


</div>


## `SystemSubscriberGetCallProcessingParametersRequest17sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the system call processing configuration for all subscribers The response is
either a `SystemSubscriberGetCallProcessingParametersResponse17sp4()` or an
`ErrorResponse()`.

Replaced by `SystemSubscriberGetCallProcessingParametersRequest18sp1()`.

</div>


## `SystemSubscriberGetCallProcessingParametersRequest18sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the system call processing configuration for all subscribers The response is
either a `SystemSubscriberGetCallProcessingParametersResponse18sp1()` or an
`ErrorResponse()`.


</div>


## `SystemSubscriberGetLoginParametersRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the system login configuration for all subscribers.

The response is either a `SystemSubscriberGetLoginParametersResponse()` or an
`ErrorResponse()`.

</div>


## `SystemSubscriberGetProvisioningParametersRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the system provisioning configuration for all subscribers The response is either a
`SystemSubscriberGetProvisioningParametersResponse()` or an `ErrorResponse()`.

Replaced by: `SystemSubscriberGetProvisioningParametersRequest24()`

</div>


## `SystemSubscriberGetProvisioningParametersRequest24`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the system provisioning configuration for all subscribers The response is either a
`SystemSubscriberGetProvisioningParametersResponse24()` or an `ErrorResponse()`.


</div>


## `SystemSubscriberModifyCallProcessingParametersRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system call processing configuration for all subscribers.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in the XS data mode:
userCallingLineIdSelection isExtendedCallingLineIdActive isRingTimeOutActive
ringTimeoutSeconds allowEmergencyRemoteOfficeOriginations

Replaced By: `SystemSubscriberModifyCallProcessingParametersRequest14sp7()`

**Attributes:**

|Name                                       |Type |Description                                       |
|-------------------------------------------|-----|--------------------------------------------------|
|user_calling_line_id_selection             |str  |userCallingLineIdSelection *Optional*             |
|is_extended_calling_line_id_active         |bool |isExtendedCallingLineIdActive *Optional*          |
|is_ring_time_out_active                    |bool |isRingTimeOutActive *Optional*                    |
|ring_timeout_seconds                       |int  |ringTimeoutSeconds *Optional*                     |
|allow_emergency_remote_office_originations |bool |allowEmergencyRemoteOfficeOriginations *Optional* |
|max_no_answer_number_of_rings              |int  |maxNoAnswerNumberOfRings *Optional*               |
</div>


## `SystemSubscriberModifyCallProcessingParametersRequest14sp7`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system call processing configuration for all subscribers.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in XS data mode and ignored in the AS data mode:
minNoAnswerNumberOfRings The following elements are only used in AS data mode and
ignored in the XS data mode: isExtendedCallingLineIdActive isRingTimeOutActive
ringTimeoutSeconds allowEmergencyRemoteOfficeOriginations incomingCallToUserAliasMode
bypassTerminationLoopDetection honorCLIDBlockingForEmergencyCalls
useUnicodeIdentityName

**Attributes:**

|Name                                       |Type |Description                                       |
|-------------------------------------------|-----|--------------------------------------------------|
|is_extended_calling_line_id_active         |bool |isExtendedCallingLineIdActive *Optional*          |
|is_ring_time_out_active                    |bool |isRingTimeOutActive *Optional*                    |
|ring_timeout_seconds                       |int  |ringTimeoutSeconds *Optional*                     |
|allow_emergency_remote_office_originations |bool |allowEmergencyRemoteOfficeOriginations *Optional* |
|max_no_answer_number_of_rings              |int  |maxNoAnswerNumberOfRings *Optional*               |
|min_no_answer_number_of_rings              |int  |minNoAnswerNumberOfRings *Optional*               |
|incoming_call_to_user_alias_mode           |str  |incomingCallToUserAliasMode *Optional*            |
|bypass_termination_loop_detection          |bool |bypassTerminationLoopDetection *Optional*         |
|honor_clid_blocking_for_emergency_calls    |bool |honorCLIDBlockingForEmergencyCalls *Optional*     |
|use_unicode_identity_name                  |bool |useUnicodeIdentityName *Optional*                 |
</div>


## `SystemSubscriberModifyLoginParametersRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system login configuration for all subscribers The response is either a
`SuccessResponse()` or an `ErrorResponse()`.


**Attributes:**

|Name                      |Type|Description                       |
|--------------------------|----|----------------------------------|
|max_failed_login_attempts |int |maxFailedLoginAttempts *Optional* |
|min_login_id_length       |int |minLoginIdLength *Optional*       |
</div>


## `SystemSubscriberModifyProvisioningParametersRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system provisioning configuration for all subscribers.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                            |Type |Description                              |
|--------------------------------|-----|-----------------------------------------|
|configurable_clid_normalization |bool |configurableCLIDNormalization *Optional* |
|include_default_domain          |bool |includeDefaultDomain *Optional*          |
</div>


## `SystemSystemServiceCallProcessingPoliciesGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the data associated with Call Processing Policy for system service instances.

The response is either `SystemSystemServiceCallProcessingPoliciesGetResponse()` or
`ErrorResponse()`.

</div>


## `SystemSystemServiceCallProcessingPoliciesModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the data associated with Call Processing Policy for system service instances.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                     |Type |Description                                   |
|-----------------------------------------|-----|----------------------------------------------|
|use_max_simultaneous_calls               |bool |useMaxSimultaneousCalls *Optional*            |
|max_simultaneous_calls                   |int  |maxSimultaneousCalls *Optional*               |
|use_max_simultaneous_video_calls         |bool |useMaxSimultaneousVideoCalls *Optional*       |
|max_simultaneous_video_calls             |int  |maxSimultaneousVideoCalls *Optional*          |
|use_max_concurrent_redirected_calls      |bool |useMaxConcurrentRedirectedCalls *Optional*    |
|max_concurrent_redirected_calls          |int  |maxConcurrentRedirectedCalls *Optional*       |
|use_max_call_time_for_answered_calls     |bool |useMaxCallTimeForAnsweredCalls *Optional*     |
|max_call_time_for_answered_calls_minutes |int  |maxCallTimeForAnsweredCallsMinutes *Optional* |
</div>


## `SystemSystemServiceDnGetAvailableListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a list of system service DNs not yet in use.

The response is either `SystemSystemServiceDnGetAvailableListResponse()` or
`ErrorResponse()`.

</div>


## `SystemSystemServiceDnGetSummaryListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a summary table of all System Service DNs.

The response is either `SystemSystemServiceDnGetSummaryListResponse()` or
`ErrorResponse()`.

</div>


## `SystemSystemServiceDnGetUsageListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a list of System Service DN utilization.

The response is either `SystemSystemServiceDnGetUsageListResponse()` or
`ErrorResponse()`.

</div>


## `SystemSystemVoicePortalDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a system voice portal instance.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                   |Type|Description         |
|-----------------------|----|--------------------|
|system_voice_portal_id |str |systemVoicePortalId |
</div>


## `SystemSystemVoicePortalGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of the system voice portals.

The response is either SystemSystemVoicePortalGetListResponce or `ErrorResponse()`.

</div>


## `SystemSystemVoicePortalGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a system voice portal instance.

The response is either `SystemSystemVoicePortalGetResponse()` or `ErrorResponse()`.
Replaced by: `SystemSystemVoicePortalGetRequest21sp1()`.

**Attributes:**

|Name                   |Type|Description         |
|-----------------------|----|--------------------|
|system_voice_portal_id |str |systemVoicePortalId |
</div>


## `SystemSystemVoicePortalGetRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a system voice portal instance.

The response is either `SystemSystemVoicePortalGetResponse21sp1()` or
`ErrorResponse()`. Replaced by: `SystemSystemVoicePortalGetRequest23()`.

**Attributes:**

|Name                   |Type|Description         |
|-----------------------|----|--------------------|
|system_voice_portal_id |str |systemVoicePortalId |
</div>


## `SystemSystemVoicePortalGetRequest23`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a system voice portal instance.

The response is either `SystemSystemVoicePortalGetResponse23()` or `ErrorResponse()`.

**Attributes:**

|Name                   |Type|Description         |
|-----------------------|----|--------------------|
|system_voice_portal_id |str |systemVoicePortalId |
</div>


## `SystemTemplateOnlyDeviceFileGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of template files used to support a VDM device defined at
system level.

The response is either `SystemTemplateOnlyDeviceFileGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_name |str |deviceName |
</div>


## `SystemThirdPartyEmergencyCallingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the third-party emergency call service settings for the system.

The response is either a `SystemThirdPartyEmergencyCallingGetResponse()` or an
`ErrorResponse()`. Replaced by: `SystemThirdPartyEmergencyCallingGetRequest24()`

</div>


## `SystemThirdPartyEmergencyCallingGetRequest24`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the third-party emergency call service settings for the system.

The response is either a `SystemThirdPartyEmergencyCallingGetResponse24()` or an
`ErrorResponse()`.

</div>


## `SystemThirdPartyEmergencyCallingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the third-party emergency call service settings for the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                        |Type|Description                         |
|----------------------------|----|------------------------------------|
|primary_held_server_url     |str |primaryHELDServerURL *Optional*     |
|secondary_held_server_url   |str |secondaryHELDServerURL *Optional*   |
|emergency_route_net_address |str |emergencyRouteNetAddress *Optional* |
|emergency_route_port        |int |emergencyRoutePort *Optional*       |
|emergency_route_transport   |str |emergencyRouteTransport *Optional*  |
</div>


## `SystemThirdPartyIMPGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the system Third-Party IMP service attributes.

The response is either `SystemThirdPartyIMPGetResponse()` or `ErrorResponse()`.
Replaced by `SystemThirdPartyIMPGetRequest19()`.

</div>


## `SystemThirdPartyIMPGetRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the system Third-Party IMP service attributes.

The response is either `SystemThirdPartyIMPGetResponse19()` or `ErrorResponse()`.

</div>


## `SystemThirdPartyIMPModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system Third-Party IMP service attributes.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description                  |
|--------------------|----|-----------------------------|
|service_net_address |str |serviceNetAddress *Optional* |
|service_port        |int |servicePort *Optional*       |
|bosh_url            |str |boshURL *Optional*           |
</div>


## `SystemThirdPartyVoiceMailSupportAddDnRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a ThirdPartyVoiceMailSupport User DN to the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type|Description            |
|-------------|----|-----------------------|
|phone_number |str |phoneNumber            |
|description  |str |description *Optional* |
</div>


## `SystemThirdPartyVoiceMailSupportDeleteDnRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a ThirdPartyVoiceMailSupport User DN from the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type|Description |
|-------------|----|------------|
|phone_number |str |phoneNumber |
</div>


## `SystemThirdPartyVoiceMailSupportGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Third-party Voice Mail Support.

The response is either a `SystemThirdPartyVoiceMailSupportGetResponse()` or an
`ErrorResponse()`. Replaced by: `SystemThirdPartyVoiceMailSupportGetRequest17sp4()`

</div>


## `SystemThirdPartyVoiceMailSupportGetRequest17sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Third-party Voice Mail Support.

The response is either a `SystemThirdPartyVoiceMailSupportGetResponse17sp4()` or an
`ErrorResponse()`.

</div>


## `SystemThirdPartyVoiceMailSupportModifyDnRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a ThirdPartyVoiceMailSupport User DN and description in the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type|Description            |
|-------------|----|-----------------------|
|phone_number |str |phoneNumber            |
|description  |str |description *Optional* |
</div>


## `SystemThirdPartyVoiceMailSupportModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with Third-party Voice Mail Support.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode: stripDiversionOnVMDestinationRetrieval

**Attributes:**

|Name                                        |Type |Description                                       |
|--------------------------------------------|-----|--------------------------------------------------|
|override_alt_caller_id_for_vm_retrieval     |bool |overrideAltCallerIdForVMRetrieval *Optional*      |
|strip_diversion_on_vm_destination_retrieval |bool |stripDiversionOnVMDestinationRetrieval *Optional* |
</div>


## `SystemTimeScheduleDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a system time schedule.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name               |Type|Description      |
|-------------------|----|-----------------|
|time_schedule_name |str |timeScheduleName |
</div>


## `SystemTimeScheduleGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a list of all system time schedules.

The response is either a `SystemTimeScheduleGetListResponse()` or an
`ErrorResponse()`.

</div>


## `SystemTimeScheduleGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a system time schedule.

The response is either a `SystemTimeScheduleGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name               |Type|Description      |
|-------------------|----|-----------------|
|time_schedule_name |str |timeScheduleName |
</div>


## `SystemTimeZoneGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of time zone names.

The response is either `SystemTimeZoneGetListResponse()` or `ErrorResponse()`.
Replaced by: `SystemTimeZoneGetListRequest20()` in AS data mode

</div>


## `SystemTimeZoneGetListRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the configured time zone of the server processing the request and the list of
time zone names.

The response is either `SystemTimeZoneGetListResponse20()` or `ErrorResponse()`.

</div>


## `SystemTreatmentMappingAccessSIPStatusAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add an Access SIP Status Code Mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|sip_status_code |int |sipStatusCode |
|treatment_id    |str |treatmentId   |
</div>


## `SystemTreatmentMappingAccessSIPStatusDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete an Access SIP Status Code mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|sip_status_code |int |sipStatusCode |
</div>


## `SystemTreatmentMappingAccessSIPStatusGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests a table of all the existing Access Side SIP Status Code Mappings in the
system.

The response is either an `SystemTreatmentMappingAccessSIPStatusGetListResponse()` or
an `ErrorResponse()`.

</div>


## `SystemTreatmentMappingAccessSIPStatusModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the fields for an Access SIP Status Code mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description            |
|----------------|----|-----------------------|
|sip_status_code |int |sipStatusCode          |
|treatment_id    |str |treatmentId *Optional* |
</div>


## `SystemTreatmentMappingCallBlockingServiceAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Call Blocking Service mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`SystemTreatmentMappingCallBlockingServiceAddRequest22()` in AS data mode

**Attributes:**

|Name                  |Type|Description         |
|----------------------|----|--------------------|
|call_blocking_service |str |callBlockingService |
|treatment_id          |str |treatmentId         |
</div>


## `SystemTreatmentMappingCallBlockingServiceAddRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Call Blocking Service mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`SystemTreatmentMappingCallBlockingServiceAddRequest22V2()` in AS data mode

**Attributes:**

|Name                  |Type|Description         |
|----------------------|----|--------------------|
|call_blocking_service |str |callBlockingService |
|treatment_id          |str |treatmentId         |
</div>


## `SystemTreatmentMappingCallBlockingServiceAddRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Call Blocking Service mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`SystemTreatmentMappingCallBlockingServiceAddRequest23()` in AS data mode

**Attributes:**

|Name                  |Type|Description         |
|----------------------|----|--------------------|
|call_blocking_service |str |callBlockingService |
|treatment_id          |str |treatmentId         |
</div>


## `SystemTreatmentMappingCallBlockingServiceAddRequest22V3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Call Blocking Service mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                  |Type|Description         |
|----------------------|----|--------------------|
|call_blocking_service |str |callBlockingService |
|treatment_id          |str |treatmentId         |
</div>


## `SystemTreatmentMappingCallBlockingServiceAddRequest23`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Call Blocking Service mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`SystemTreatmentMappingCallBlockingServiceAddRequest23V2()` in AS data mode.

**Attributes:**

|Name                  |Type|Description         |
|----------------------|----|--------------------|
|call_blocking_service |str |callBlockingService |
|treatment_id          |str |treatmentId         |
</div>


## `SystemTreatmentMappingCallBlockingServiceAddRequest23V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Call Blocking Service mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                  |Type|Description         |
|----------------------|----|--------------------|
|call_blocking_service |str |callBlockingService |
|treatment_id          |str |treatmentId         |
</div>


## `SystemTreatmentMappingCallBlockingServiceAddRequest23V3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Call Blocking Service mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                  |Type|Description         |
|----------------------|----|--------------------|
|call_blocking_service |str |callBlockingService |
|treatment_id          |str |treatmentId         |
</div>


## `SystemTreatmentMappingCallBlockingServiceDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Call Blocking Service mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`SystemTreatmentMappingCallBlockingServiceDeleteRequest22()` in AS data mode

**Attributes:**

|Name                  |Type|Description         |
|----------------------|----|--------------------|
|call_blocking_service |str |callBlockingService |
</div>


## `SystemTreatmentMappingCallBlockingServiceDeleteRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Call Blocking Service mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`SystemTreatmentMappingCallBlockingServiceDeleteRequest22V2()` in AS data mode

**Attributes:**

|Name                  |Type|Description         |
|----------------------|----|--------------------|
|call_blocking_service |str |callBlockingService |
</div>


## `SystemTreatmentMappingCallBlockingServiceDeleteRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Call Blocking Service mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`SystemTreatmentMappingCallBlockingServiceDeleteRequest23()` in AS data mode

**Attributes:**

|Name                  |Type|Description         |
|----------------------|----|--------------------|
|call_blocking_service |str |callBlockingService |
</div>


## `SystemTreatmentMappingCallBlockingServiceDeleteRequest22V3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Call Blocking Service mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                  |Type|Description         |
|----------------------|----|--------------------|
|call_blocking_service |str |callBlockingService |
</div>


## `SystemTreatmentMappingCallBlockingServiceDeleteRequest23`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Call Blocking Service mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`SystemTreatmentMappingCallBlockingServiceDeleteRequest23V2()` in AS data mode.

**Attributes:**

|Name                  |Type|Description         |
|----------------------|----|--------------------|
|call_blocking_service |str |callBlockingService |
</div>


## `SystemTreatmentMappingCallBlockingServiceDeleteRequest23V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Call Blocking Service mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                  |Type|Description         |
|----------------------|----|--------------------|
|call_blocking_service |str |callBlockingService |
</div>


## `SystemTreatmentMappingCallBlockingServiceDeleteRequest23V3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Call Blocking Service mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                  |Type|Description         |
|----------------------|----|--------------------|
|call_blocking_service |str |callBlockingService |
</div>


## `SystemTreatmentMappingCallBlockingServiceGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests a table of all the existing Call Blocking Service Mappings in the system.

The response is either a `SystemTreatmentMappingCallBlockingServicesGetListResponse()`
or an `ErrorResponse()`. Replaced by:
`SystemTreatmentMappingCallBlockingServiceGetListRequest19sp1()` in AS data mode

</div>


## `SystemTreatmentMappingCallBlockingServiceGetListRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests a table of all the existing Call Blocking Service Mappings in the system.

The response is either a
`SystemTreatmentMappingCallBlockingServicesGetListResponse19sp1()` or an
`ErrorResponse()`. Replaced by:
`SystemTreatmentMappingCallBlockingServiceGetListRequest22()`

</div>


## `SystemTreatmentMappingCallBlockingServiceGetListRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests a table of all the existing Call Blocking Service Mappings in the system.

The response is either a
`SystemTreatmentMappingCallBlockingServicesGetListResponse22()` or an
`ErrorResponse()`. Replaced by:
`SystemTreatmentMappingCallBlockingServiceGetListRequest23()`

</div>


## `SystemTreatmentMappingCallBlockingServiceGetListRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests a table of all the existing Call Blocking Service Mappings in the system.

The response is either a
`SystemTreatmentMappingCallBlockingServicesGetListResponse22V2()` or an
`ErrorResponse()`.

</div>


## `SystemTreatmentMappingCallBlockingServiceGetListRequest23`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests a table of all the existing Call Blocking Service Mappings in the system.

The response is either a
`SystemTreatmentMappingCallBlockingServicesGetListResponse23()` or an
`ErrorResponse()`. Replaced by:
`SystemTreatmentMappingCallBlockingServiceGetListRequest23V2()` in AS data mode.

</div>


## `SystemTreatmentMappingCallBlockingServiceGetListRequest23V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests a table of all the existing Call Blocking Service Mappings in the system.

The response is either a
`SystemTreatmentMappingCallBlockingServicesGetListResponse23V2()` or an
`ErrorResponse()`.

</div>


## `SystemTreatmentMappingCallBlockingServiceGetListRequest23V3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests a table of all the existing Call Blocking Service Mappings in the system.

The response is either a
`SystemTreatmentMappingCallBlockingServicesGetListResponse23V3()` or an
`ErrorResponse()`.

</div>


## `SystemTreatmentMappingCallBlockingServiceModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the fields for a Call Blocking Service mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`SystemTreatmentMappingCallBlockingServiceModifyRequest22()` in AS data mode

**Attributes:**

|Name                  |Type|Description            |
|----------------------|----|-----------------------|
|call_blocking_service |str |callBlockingService    |
|treatment_id          |str |treatmentId *Optional* |
</div>


## `SystemTreatmentMappingCallBlockingServiceModifyRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the fields for a Call Blocking Service mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`SystemTreatmentMappingCallBlockingServiceModifyRequest22V2()` in AS data mode

**Attributes:**

|Name                  |Type|Description            |
|----------------------|----|-----------------------|
|call_blocking_service |str |callBlockingService    |
|treatment_id          |str |treatmentId *Optional* |
</div>


## `SystemTreatmentMappingCallBlockingServiceModifyRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the fields for a Call Blocking Service mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`SystemTreatmentMappingCallBlockingServiceModifyRequest23()` in AS data mode

**Attributes:**

|Name                  |Type|Description            |
|----------------------|----|-----------------------|
|call_blocking_service |str |callBlockingService    |
|treatment_id          |str |treatmentId *Optional* |
</div>


## `SystemTreatmentMappingCallBlockingServiceModifyRequest22V3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the fields for a Call Blocking Service mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                  |Type|Description            |
|----------------------|----|-----------------------|
|call_blocking_service |str |callBlockingService    |
|treatment_id          |str |treatmentId *Optional* |
</div>


## `SystemTreatmentMappingCallBlockingServiceModifyRequest23`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the fields for a Call Blocking Service mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`SystemTreatmentMappingCallBlockingServiceModifyRequest23V2()` in AS data mode.

**Attributes:**

|Name                  |Type|Description            |
|----------------------|----|-----------------------|
|call_blocking_service |str |callBlockingService    |
|treatment_id          |str |treatmentId *Optional* |
</div>


## `SystemTreatmentMappingCallBlockingServiceModifyRequest23V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the fields for a Call Blocking Service mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                  |Type|Description            |
|----------------------|----|-----------------------|
|call_blocking_service |str |callBlockingService    |
|treatment_id          |str |treatmentId *Optional* |
</div>


## `SystemTreatmentMappingCallBlockingServiceModifyRequest23V3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the fields for a Call Blocking Service mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                  |Type|Description            |
|----------------------|----|-----------------------|
|call_blocking_service |str |callBlockingService    |
|treatment_id          |str |treatmentId *Optional* |
</div>


## `SystemTreatmentMappingInternalReleaseCauseAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add an Internal Release Cause mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type|Description          |
|-----------------------|----|---------------------|
|internal_release_cause |str |internalReleaseCause |
|treatment_id           |str |treatmentId          |
</div>


## `SystemTreatmentMappingInternalReleaseCauseDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete an Internal Release Cause mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type|Description          |
|-----------------------|----|---------------------|
|internal_release_cause |str |internalReleaseCause |
</div>


## `SystemTreatmentMappingInternalReleaseCauseGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests a table of all the Internal Release Cause mappings in the system.

The response is either a `SystemTreatmentMappingInternalReleaseCauseGetListResponse()`
or an `ErrorResponse()`.

</div>


## `SystemTreatmentMappingInternalReleaseCauseModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the fields for an Internal Release Cause mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type|Description            |
|-----------------------|----|-----------------------|
|internal_release_cause |str |internalReleaseCause   |
|treatment_id           |str |treatmentId *Optional* |
</div>


## `SystemTreatmentMappingNetworkSIPStatusAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Network SIP Status Code mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|sip_status_code |int |sipStatusCode |
|treatment_id    |str |treatmentId   |
</div>


## `SystemTreatmentMappingNetworkSIPStatusDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Network SIP Status Code mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|sip_status_code |int |sipStatusCode |
</div>


## `SystemTreatmentMappingNetworkSIPStatusGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests a table of all the existing Network SIP Status Code Mappings in the system.

The response is either an
`SystemTreatmentMappingNetworkSIPStatusCodeGetListResponse()` or an `ErrorResponse()`.

</div>


## `SystemTreatmentMappingNetworkSIPStatusModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the fields for a Network SIP Status Code mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description            |
|----------------|----|-----------------------|
|sip_status_code |int |sipStatusCode          |
|treatment_id    |str |treatmentId *Optional* |
</div>


## `SystemTreatmentMappingNetworkServerTreatmentAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Network Server Treatment mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type|Description |
|-------------|----|------------|
|ns_treatment |str |nsTreatment |
|treatment_id |str |treatmentId |
</div>


## `SystemTreatmentMappingNetworkServerTreatmentDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a NS Treatment mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type|Description |
|-------------|----|------------|
|ns_treatment |str |nsTreatment |
</div>


## `SystemTreatmentMappingNetworkServerTreatmentGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests a table of all the existing NS Treatment Mappings in the system.

The response is either a
`SystemTreatmentMappingNetworkServerTreatmentGetListResponse()` or an
`ErrorResponse()`.

</div>


## `SystemTreatmentMappingNetworkServerTreatmentModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the fields for a Network Server Treatment mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type|Description            |
|-------------|----|-----------------------|
|ns_treatment |str |nsTreatment            |
|treatment_id |str |treatmentId *Optional* |
</div>


## `SystemTreatmentMappingQ850CauseAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Q850 Cause Value mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name             |Type|Description    |
|-----------------|----|---------------|
|q850_cause_value |int |q850CauseValue |
|treatment_id     |str |treatmentId    |
</div>


## `SystemTreatmentMappingQ850CauseDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Q850 Cause Value mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name             |Type|Description    |
|-----------------|----|---------------|
|q850_cause_value |int |q850CauseValue |
</div>


## `SystemTreatmentMappingQ850CauseGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests a table of all the existing Q850 Cause Value Mappings in the system.

The response is either a `SystemTreatmentMappingQ850CauseGetListResponse()` or an
`ErrorResponse()`.

</div>


## `SystemTreatmentMappingQ850CauseModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the fields for a Q850CauseValue mapping.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name             |Type|Description            |
|-----------------|----|-----------------------|
|q850_cause_value |int |q850CauseValue         |
|treatment_id     |str |treatmentId *Optional* |
</div>


## `SystemTrunkGroupGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with the Trunk Group service.

The response is either `SystemTrunkGroupGetResponse()` or `ErrorResponse()`. Replaced
by: `SystemTrunkGroupGetRequest19sp1()`.

</div>


## `SystemTrunkGroupGetRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with the Trunk Group service.

The response is either `SystemTrunkGroupGetResponse19sp1()` or `ErrorResponse()`.
Replaced by: `SystemTrunkGroupGetRequest21()`

</div>


## `SystemTrunkGroupGetRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with the Trunk Group service.

The response is either `SystemTrunkGroupGetResponse21()` or `ErrorResponse()`.
Replaced by: `SystemTrunkGroupGetRequest22()`

</div>


## `SystemTrunkGroupGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with the Trunk Group service.

The response is either `SystemTrunkGroupGetResponse22()` or `ErrorResponse()`.
Replaced by: `SystemTrunkGroupGetRequest23()`

</div>


## `SystemTrunkGroupGetRequest23`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with the Trunk Group service.

The response is either `SystemTrunkGroupGetResponse23()` or `ErrorResponse()`.
Replaced by: `SystemTrunkGroupGetRequest24()`

</div>


## `SystemTrunkGroupGetRequest24`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with the Trunk Group service.

The response is either `SystemTrunkGroupGetResponse24()` or `ErrorResponse()`.

</div>


## `SystemTrunkGroupModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with the Trunk Group Service.

Following attributes are only used in IMS mode.  The values are saved if specified not
in IMS mode: implicitRegistrationSetSupportPolicy
sipIdentityForPilotAndProxyTrunkModesPolicy useMostRecentEntryOnDeflection

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                                       |Type |Description                                                   |
|-----------------------------------------------------------|-----|--------------------------------------------------------------|
|enforce_clid_service_assignment_for_pilot_user             |bool |enforceCLIDServiceAssignmentForPilotUser *Optional*           |
|terminate_unreachable_trigger_detection_on_receipt_of18x   |bool |terminateUnreachableTriggerDetectionOnReceiptOf18x *Optional* |
|pilot_user_calling_line_asserted_identity_policy           |str  |pilotUserCallingLineAssertedIdentityPolicy *Optional*         |
|enforce_out_of_dialog_pbx_redirection_policies             |bool |enforceOutOfDialogPBXRedirectionPolicies *Optional*           |
|unscreened_redirection_handling                            |str  |unscreenedRedirectionHandling *Optional*                      |
|enable_holdover_of_highwater_call_counts                   |bool |enableHoldoverOfHighwaterCallCounts *Optional*                |
|holdover_period                                            |int  |holdoverPeriod *Optional*                                     |
|time_zone_offset_minutes                                   |int  |timeZoneOffsetMinutes *Optional*                              |
|clid_source_for_screened_calls_policy                      |str  |clidSourceForScreenedCallsPolicy *Optional*                   |
|user_lookup_policy                                         |str  |userLookupPolicy *Optional*                                   |
|out_of_dialog_pbx_redirection_clid_mapping                 |str  |outOfDialogPBXRedirectionCLIDMapping *Optional*               |
|enforce_out_of_dialog_pbx_redirection_trunk_group_capacity |bool |enforceOutOfDialogPBXRedirectionTrunkGroupCapacity *Optional* |
|implicit_registration_set_support_policy                   |str  |implicitRegistrationSetSupportPolicy *Optional*               |
|sip_identity_for_pilot_and_proxy_trunk_modes_policy        |str  |sipIdentityForPilotAndProxyTrunkModesPolicy *Optional*        |
|support_connected_identity_policy                          |str  |supportConnectedIdentityPolicy *Optional*                     |
|use_unmapped_sessions_for_trunk_users                      |bool |useUnmappedSessionsForTrunkUsers *Optional*                   |
|allow_pai_lookup_for_out_of_dialog_pbx_redirection         |bool |allowPAILookupForOutOfDialogPBXRedirection *Optional*         |
|out_of_dialog_pbx_redirection_originator_lookup_policy     |str  |outOfDialogPBXRedirectionOriginatorLookupPolicy *Optional*    |
|allow_trunk_identity_for_all_originations                  |bool |allowTrunkIdentityForAllOriginations *Optional*               |
|use_most_recent_entry_on_deflection                        |bool |useMostRecentEntryOnDeflection *Optional*                     |
</div>


## `SystemTrunkGroupOptionsMessageResponseStatusCodeAddListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a list of system level successful SIP OPTIONS message respoonse status codes.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type      |Description|
|------------|----------|-----------|
|status_code |List[str] |statusCode |
</div>


## `SystemTrunkGroupOptionsMessageResponseStatusCodeDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a list of system level successful SIP OPTIONS message respoonse status codes.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type      |Description|
|------------|----------|-----------|
|status_code |List[str] |statusCode |
</div>


## `SystemTrunkGroupOptionsMessageResponseStatusCodeGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of system level successful SIP OPTIONS message respoonse status codes.

The response is either
`SystemTrunkGroupOptionsMessageResponseStatusCodeGetListResponse()` or
`ErrorResponse()`.

</div>


## `SystemTrunkGroupUserCreationTaskGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of user creation tasks in the system.

The response is either `SystemTrunkGroupUserCreationTaskGetListResponse()` or
`ErrorResponse()`.

</div>


## `SystemTrunkGroupUserCreationTaskGetListRequest14sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of user creation tasks in the system.

The response is either `SystemTrunkGroupUserCreationTaskGetListResponse14sp4()` or
`ErrorResponse()`.

</div>


## `SystemTwoStageDialingAddDnRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add Two Stage Dialing number to the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type|Description            |
|-------------|----|-----------------------|
|phone_number |str |phoneNumber            |
|description  |str |description *Optional* |
</div>


## `SystemTwoStageDialingDeleteDnRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a Two Stage Dialing number from the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type|Description |
|-------------|----|------------|
|phone_number |str |phoneNumber |
</div>


## `SystemTwoStageDialingModifyDnRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a Two Stage Dialing number's description in the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type|Description            |
|-------------|----|-----------------------|
|phone_number |str |phoneNumber            |
|description  |str |description *Optional* |
</div>


## `SystemVideoServerAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a video server to the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name               |Type|Description            |
|-------------------|----|-----------------------|
|net_address        |str |netAddress             |
|port               |int |port *Optional*        |
|transport_protocol |str |transportProtocol      |
|description        |str |description *Optional* |
</div>


## `SystemVideoServerDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a video server from the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|net_address |str |netAddress |
</div>


## `SystemVideoServerGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a list of video servers defined in the system.

The response is either a `SystemVideoServerGetListResponse()` or an `ErrorResponse()`.

</div>


## `SystemVideoServerModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a video server in the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name               |Type|Description                  |
|-------------------|----|-----------------------------|
|net_address        |str |netAddress                   |
|port               |int |port *Optional*              |
|transport_protocol |str |transportProtocol *Optional* |
|description        |str |description *Optional*       |
</div>


## `SystemVideoServerParametersGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of video server system parameters.

The response is either `SystemVideoServerParametersGetResponse()` or
`ErrorResponse()`.

</div>


## `SystemVideoServerParametersModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify video server system parameters.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                            |Type |Description                                           |
|------------------------------------------------|-----|------------------------------------------------------|
|video_server_response_timer_milliseconds        |int  |videoServerResponseTimerMilliseconds *Optional*       |
|video_server_selection_route_timer_milliseconds |int  |videoServerSelectionRouteTimerMilliseconds *Optional* |
|use_static_video_server_device                  |bool |useStaticVideoServerDevice *Optional*                 |
</div>


## `SystemVirtualOnNetCallTypeAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Virtual On-Net Call Type.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                               |Type|Description                  |
|-----------------------------------|----|-----------------------------|
|virtual_on_net_call_type_name      |str |virtualOnNetCallTypeName     |
|virtual_on_net_call_type_cdr_value |str |virtualOnNetCallTypeCdrValue |
</div>


## `SystemVirtualOnNetCallTypeDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Virtual On-Net Call Type.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                          |Type|Description              |
|------------------------------|----|-------------------------|
|virtual_on_net_call_type_name |str |virtualOnNetCallTypeName |
</div>


## `SystemVirtualOnNetCallTypeGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list Virtual On-Net Call Types in the system.

The response is either a `SystemVirtualOnNetCallTypeGetListResponse()` or an
`ErrorResponse()`.

</div>


## `SystemVirtualOnNetCallTypeModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a Virtual On-Net Call Type.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                               |Type|Description                             |
|-----------------------------------|----|----------------------------------------|
|virtual_on_net_call_type_name      |str |virtualOnNetCallTypeName                |
|virtual_on_net_call_type_cdr_value |str |virtualOnNetCallTypeCdrValue *Optional* |
</div>


## `SystemVisualDeviceManagementGetDeviceInfoRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the information for a specified device supporting visual device management.

The response is either a `SystemVisualDeviceManagementGetDeviceInfoResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|device_name |str |deviceName |
</div>


## `SystemVoiceMessageSummaryUpdateGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests system voice mail message summary update parameter settings.

The response is either `SystemVoiceMessageSummaryUpdateGetResponse()` or
`ErrorResponse()`.

</div>


## `SystemVoiceMessageSummaryUpdateModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with Voice Messaging.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                      |Type |Description                                    |
|------------------------------------------|-----|-----------------------------------------------|
|send_saved_and_urgent_mwi_on_notification |bool |sendSavedAndUrgentMWIOnNotification *Optional* |
|send_message_summary_update_on_register   |bool |sendMessageSummaryUpdateOnRegister *Optional*  |
|min_time_between_mwi_on_register          |int  |minTimeBetweenMWIOnRegister *Optional*         |
</div>


## `SystemVoiceMessagingGroupGetPasscodeRulesRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the system voice portal passcode rules setting.

The response is either `SystemVoiceMessagingGroupGetPasscodeRulesResponse14()` or
`ErrorResponse()`.

Replaced By: `SystemPortalPasscodeRulesGetRequest()`

</div>


## `SystemVoiceMessagingGroupGetRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Voice Messaging.

The response is either a `SystemVoiceMessagingGroupGetResponse14()` or an
`ErrorResponse()`. Replaced by: `SystemVoiceMessagingGroupGetRequest16()`

</div>


## `SystemVoiceMessagingGroupGetRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Voice Messaging.

The response is either a `SystemVoiceMessagingGroupGetResponse16()` or an
`ErrorResponse()`. Replaced by: `SystemVoiceMessagingGroupGetRequest16sp2()`

</div>


## `SystemVoiceMessagingGroupGetRequest16sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Voice Messaging.

The response is either a `SystemVoiceMessagingGroupGetResponse16sp2()` or an
`ErrorResponse()`. Replaced by: `SystemVoiceMessagingGroupGetRequest20()` in AS data
mode

</div>


## `SystemVoiceMessagingGroupGetRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Voice Messaging.

The response is either a `SystemVoiceMessagingGroupGetResponse20()` or an
`ErrorResponse()`. Replaced by: `SystemVoiceMessagingGroupGetRequest21()`

</div>


## `SystemVoiceMessagingGroupGetRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Voice Messaging.

The response is either a `SystemVoiceMessagingGroupGetResponse21()` or an
`ErrorResponse()`. Replaced by: `SystemVoiceMessagingGroupGetRequest22()` in AS data
mode

</div>


## `SystemVoiceMessagingGroupGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Response to `SystemVoiceMessagingGroupGetRequest22()`.

Replaced by: `SystemVoiceMessagingGroupGetRequest22V2()`.

</div>


## `SystemVoiceMessagingGroupGetRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the system level data associated with Voice Messaging.

The response is either a `SystemVoiceMessagingGroupGetResponse22V2()` or an
`ErrorResponse()`.

</div>


## `SystemVoiceMessagingGroupGetVoicePortalMenusRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the system voice portal Menus setting.

The response is either `SystemVoiceMessagingGroupGetVoicePortalMenusResponse14()` or
`ErrorResponse()`.

**Attributes:**

|Name                  |Type |Description        |
|----------------------|-----|-------------------|
|get_default_menu_keys |bool |getDefaultMenuKeys |
</div>


## `SystemVoiceMessagingGroupGetVoicePortalMenusRequest18`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the system voice portal Menus setting.

The response is either `SystemVoiceMessagingGroupGetVoicePortalMenusResponse18()` or
`ErrorResponse()`. Replaced by
`SystemVoiceMessagingGroupGetVoicePortalMenusRequest19()`

**Attributes:**

|Name                  |Type |Description        |
|----------------------|-----|-------------------|
|get_default_menu_keys |bool |getDefaultMenuKeys |
</div>


## `SystemVoiceMessagingGroupGetVoicePortalMenusRequest18sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the system voice portal Menus setting.

The response is either `SystemVoiceMessagingGroupGetVoicePortalMenusResponse18sp1()`
or `ErrorResponse()`. Replaced by
`SystemVoiceMessagingGroupGetVoicePortalMenusRequest19sp1()`

**Attributes:**

|Name                  |Type |Description        |
|----------------------|-----|-------------------|
|get_default_menu_keys |bool |getDefaultMenuKeys |
</div>


## `SystemVoiceMessagingGroupGetVoicePortalMenusRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the system voice portal Menus setting.

The response is either `SystemVoiceMessagingGroupGetVoicePortalMenusResponse19()` or
`ErrorResponse()`. Replaced by:
`SystemVoiceMessagingGroupGetVoicePortalMenusRequest19sp1()`

**Attributes:**

|Name                  |Type |Description        |
|----------------------|-----|-------------------|
|get_default_menu_keys |bool |getDefaultMenuKeys |
</div>


## `SystemVoiceMessagingGroupGetVoicePortalMenusRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the system voice portal Menus setting.

The response is either `SystemVoiceMessagingGroupGetVoicePortalMenusResponse19sp1()`
or `ErrorResponse()`. Replaced by
`SystemVoiceMessagingGroupGetVoicePortalMenusRequest20()`

**Attributes:**

|Name                  |Type |Description        |
|----------------------|-----|-------------------|
|get_default_menu_keys |bool |getDefaultMenuKeys |
</div>


## `SystemVoiceMessagingGroupGetVoicePortalMenusRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the system voice portal Menus setting.

The response is either `SystemVoiceMessagingGroupGetVoicePortalMenusResponse20()` or
`ErrorResponse()`.

**Attributes:**

|Name                  |Type |Description        |
|----------------------|-----|-------------------|
|get_default_menu_keys |bool |getDefaultMenuKeys |
</div>


## `SystemVoiceMessagingGroupGetVoicePortalMenusRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the system voice portal Menus setting.

The response is either `SystemVoiceMessagingGroupGetVoicePortalMenusResponse21()` or
`ErrorResponse()`.

**Attributes:**

|Name                  |Type |Description        |
|----------------------|-----|-------------------|
|get_default_menu_keys |bool |getDefaultMenuKeys |
</div>


## `SystemVoiceMessagingGroupModifyPasscodeRulesRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the system voice portal passcode rules setting.

The response is either `SuccessResponse()` or `ErrorResponse()`.

Replaced By: `SystemPortalPasscodeRulesModifyRequest()`

**Attributes:**

|Name                                          |Type |Description                                        |
|----------------------------------------------|-----|---------------------------------------------------|
|disallow_repeated_digits                      |bool |disallowRepeatedDigits *Optional*                  |
|disallow_user_number                          |bool |disallowUserNumber *Optional*                      |
|disallow_reversed_user_number                 |bool |disallowReversedUserNumber *Optional*              |
|disallow_old_passcode                         |bool |disallowOldPasscode *Optional*                     |
|disallow_reversed_old_passcode                |bool |disallowReversedOldPasscode *Optional*             |
|min_code_length                               |int  |minCodeLength *Optional*                           |
|max_code_length                               |int  |maxCodeLength *Optional*                           |
|disable_login_after_max_failed_login_attempts |bool |disableLoginAfterMaxFailedLoginAttempts *Optional* |
|max_failed_login_attempts                     |int  |maxFailedLoginAttempts *Optional*                  |
|expire_password                               |bool |expirePassword *Optional*                          |
|passcode_expires_days                         |int  |passcodeExpiresDays *Optional*                     |
|send_login_disabled_notify_email              |bool |sendLoginDisabledNotifyEmail *Optional*            |
|login_disabled_notify_email_address           |str  |loginDisabledNotifyEmailAddress *Optional*         |
|default_password                              |str  |defaultPassword *Optional*                         |
</div>


## `SystemVoiceMessagingGroupModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with Voice Messaging.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                      |Type |Description                                     |
|------------------------------------------|-----|------------------------------------------------|
|real_delete_for_imap                      |bool |realDeleteForImap *Optional*                    |
|use_dn_in_mail_body                       |bool |useDnInMailBody *Optional*                      |
|use_short_subject_line                    |bool |useShortSubjectLine *Optional*                  |
|max_greeting_length_minutes               |int  |maxGreetingLengthMinutes *Optional*             |
|max_message_length_minutes                |int  |maxMessageLengthMinutes *Optional*              |
|max_mailbox_length_minutes                |int  |maxMailboxLengthMinutes *Optional*              |
|does_message_age                          |bool |doesMessageAge *Optional*                       |
|hold_period_days                          |int  |holdPeriodDays *Optional*                       |
|mail_server_net_address                   |str  |mailServerNetAddress *Optional*                 |
|mail_server_protocol                      |str  |mailServerProtocol *Optional*                   |
|default_delivery_from_address             |str  |defaultDeliveryFromAddress *Optional*           |
|default_notification_from_address         |str  |defaultNotificationFromAddress *Optional*       |
|default_voice_portal_lockout_from_address |str  |defaultVoicePortalLockoutFromAddress *Optional* |
|use_outgoing_mwi_on_smdi                  |bool |useOutgoingMWIOnSMDI *Optional*                 |
|mwi_delay_in_seconds                      |int  |mwiDelayInSeconds *Optional*                    |
|voice_portal_scope                        |str  |voicePortalScope *Optional*                     |
|network_wide_messaging                    |bool |networkWideMessaging *Optional*                 |
|use_external_routing                      |bool |useExternalRouting *Optional*                   |
|default_external_routing_address          |str  |defaultExternalRoutingAddress *Optional*        |
</div>


## `SystemVoiceMessagingGroupModifyRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with Voice Messaging.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS/Amplify data mode: realDeleteForImap useDnInMailBody
useShortSubjectLine maxMessageLengthMinutes maxMailboxLengthMinutes doesMessageAge
holdPeriodDays mailServerNetAddress mailServerProtocol defaultDeliveryFromAddress
defaultNotificationFromAddress useOutgoingMWIOnSMDI mwiDelayInSeconds voicePortalScope
enterpriseVoicePortalLicensed networkWideMessaging useExternalRouting
defaultExternalRoutingAddress vmOnlySystem, element is ignored in Amplify data mode.
clientInitiatedMailServerSessionTimeoutMinutes recordingAudioFileFormat
allowVoicePortalAccessFromVMDepositMenu The following elements are only used in AS
data mode and ignored in XS data mode: storageSelection vmBucketName

**Attributes:**

|Name                                                 |Type |Description                                               |
|-----------------------------------------------------|-----|----------------------------------------------------------|
|real_delete_for_imap                                 |bool |realDeleteForImap *Optional*                              |
|use_dn_in_mail_body                                  |bool |useDnInMailBody *Optional*                                |
|use_short_subject_line                               |bool |useShortSubjectLine *Optional*                            |
|max_message_length_minutes                           |int  |maxMessageLengthMinutes *Optional*                        |
|max_mailbox_length_minutes                           |int  |maxMailboxLengthMinutes *Optional*                        |
|does_message_age                                     |bool |doesMessageAge *Optional*                                 |
|hold_period_days                                     |int  |holdPeriodDays *Optional*                                 |
|mail_server_net_address                              |str  |mailServerNetAddress *Optional*                           |
|mail_server_protocol                                 |str  |mailServerProtocol *Optional*                             |
|default_delivery_from_address                        |str  |defaultDeliveryFromAddress *Optional*                     |
|default_notification_from_address                    |str  |defaultNotificationFromAddress *Optional*                 |
|default_voice_portal_lockout_from_address            |str  |defaultVoicePortalLockoutFromAddress *Optional*           |
|use_outgoing_mwi_on_smdi                             |bool |useOutgoingMWIOnSMDI *Optional*                           |
|mwi_delay_in_seconds                                 |int  |mwiDelayInSeconds *Optional*                              |
|voice_portal_scope                                   |str  |voicePortalScope *Optional*                               |
|network_wide_messaging                               |bool |networkWideMessaging *Optional*                           |
|use_external_routing                                 |bool |useExternalRouting *Optional*                             |
|default_external_routing_address                     |str  |defaultExternalRoutingAddress *Optional*                  |
|vm_only_system                                       |bool |vmOnlySystem *Optional*                                   |
|client_initiated_mail_server_session_timeout_minutes |int  |clientInitiatedMailServerSessionTimeoutMinutes *Optional* |
|recording_audio_file_format                          |str  |recordingAudioFileFormat *Optional*                       |
|allow_voice_portal_access_from_vm_deposit_menu       |bool |allowVoicePortalAccessFromVMDepositMenu *Optional*        |
|storage_selection                                    |str  |storageSelection *Optional*                               |
|vm_bucket_name                                       |str  |vmBucketName *Optional*                                   |
</div>


## `SystemVoiceMessagingGroupModifyVoicePortalMenusRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the system voice portal menus setting.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                                      |Type                                                  |Description                                                  |
|----------------------------------------------------------|------------------------------------------------------|-------------------------------------------------------------|
|use_voice_portal_customization                            |bool                                                  |useVoicePortalCustomization *Optional*                       |
|voice_portal_main_menu_keys                               |OCI.voicePortalMainMenuKeys                           |voicePortalMainMenuKeys *Optional*                           |
|voice_messaging_menu_keys                                 |OCI.voiceMessagingMenuKeys                            |voiceMessagingMenuKeys *Optional*                            |
|play_greeting_menu_keys                                   |OCI.playGreetingMenuKeys                              |playGreetingMenuKeys *Optional*                              |
|change_busy_or_no_answer_greeting_menu_keys               |OCI.changeBusyOrNoAnswerGreetingMenuKeys              |changeBusyOrNoAnswerGreetingMenuKeys *Optional*              |
|change_extended_away_greeting_menu_keys                   |OCI.changeExtendedAwayGreetingMenuKeys                |changeExtendedAwayGreetingMenuKeys *Optional*                |
|record_new_greeting_or_personalized_name_menu_keys        |OCI.recordNewGreetingOrPersonalizedNameMenuKeys       |recordNewGreetingOrPersonalizedNameMenuKeys *Optional*       |
|delete_all_messages_menu_keys                             |OCI.deleteAllMessagesMenuKeys                         |deleteAllMessagesMenuKeys *Optional*                         |
|comm_pilot_express_profile_menu_keys                      |OCI.commPilotExpressProfileMenuKeys                   |commPilotExpressProfileMenuKeys *Optional*                   |
|personalized_name_menu_keys                               |OCI.personalizedNameMenuKeys                          |personalizedNameMenuKeys *Optional*                          |
|call_forwarding_options_menu_keys                         |OCI.callForwardingOptionsMenuKeys                     |callForwardingOptionsMenuKeys *Optional*                     |
|change_call_forwarding_destination_menu_keys              |OCI.changeCallForwardingDestinationMenuKeys           |changeCallForwardingDestinationMenuKeys *Optional*           |
|voice_portal_calling_menu_keys                            |OCI.voicePortalCallingMenuKeys                        |voicePortalCallingMenuKeys *Optional*                        |
|hoteling_menu_keys                                        |OCI.hotelingMenuKeys                                  |hotelingMenuKeys *Optional*                                  |
|passcode_menu_keys                                        |OCI.passcodeMenuKeys                                  |passcodeMenuKeys *Optional*                                  |
|play_messages_menu_keys                                   |OCI.playMessagesMenuKeys                              |playMessagesMenuKeys *Optional*                              |
|play_message_menu_keys                                    |OCI.playMessageMenuKeys                               |playMessageMenuKeys *Optional*                               |
|additional_message_options_menu_keys                      |OCI.additionalMessageOptionsMenuKeys                  |additionalMessageOptionsMenuKeys *Optional*                  |
|forward_or_compose_message_menu_keys                      |OCI.forwardOrComposeMessageMenuKeys                   |forwardOrComposeMessageMenuKeys *Optional*                   |
|reply_message_menu_keys                                   |OCI.replyMessageMenuKeys                              |replyMessageMenuKeys *Optional*                              |
|send_to_distribution_list_menu_keys                       |OCI.sendToDistributionListMenuKeys                    |sendToDistributionListMenuKeys *Optional*                    |
|select_distribution_list_menu_keys                        |OCI.selectDistributionListMenuKeys                    |selectDistributionListMenuKeys *Optional*                    |
|review_selected_distribution_list_menu_keys               |OCI.reviewSelectedDistributionListMenuKeys            |reviewSelectedDistributionListMenuKeys *Optional*            |
|send_message_to_selected_distribution_list_menu_keys      |OCI.sendMessageToSelectedDistributionListMenuKeys     |sendMessageToSelectedDistributionListMenuKeys *Optional*     |
|send_to_all_group_members_menu_keys                       |OCI.sendToAllGroupMembersMenuKeys                     |sendToAllGroupMembersMenuKeys *Optional*                     |
|send_to_person_menu_keys                                  |OCI.sendToPersonMenuKeys                              |sendToPersonMenuKeys *Optional*                              |
|change_current_introduction_or_message_or_reply_menu_keys |OCI.changeCurrentIntroductionOrMessageOrReplyMenuKeys |changeCurrentIntroductionOrMessageOrReplyMenuKeys *Optional* |
|voice_portal_login_menu_keys                              |OCI.voicePortalLoginMenuKeys                          |voicePortalLoginMenuKeys *Optional*                          |
|fax_messaging_menu_keys                                   |OCI.faxMessagingMenuKeys                              |faxMessagingMenuKeys *Optional*                              |
|message_deposit_menu_keys                                 |OCI.messageDepositMenuKeys                            |messageDepositMenuKeys *Optional*                            |
|disable_message_deposit_menu_keys                         |OCI.disableMessageDepositMenuKeys                     |disableMessageDepositMenuKeys *Optional*                     |
|greeting_only_forwarding_destination_menu_keys            |OCI.greetingOnlyForwardingDestinationMenuKeys         |greetingOnlyForwardingDestinationMenuKeys *Optional*         |
</div>


## `SystemVoiceMessagingGroupModifyVoicePortalMenusRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the system voice portal menus setting.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                                      |Type                                                  |Description                                                  |
|----------------------------------------------------------|------------------------------------------------------|-------------------------------------------------------------|
|use_voice_portal_customization                            |bool                                                  |useVoicePortalCustomization *Optional*                       |
|voice_portal_main_menu_keys                               |OCI.voicePortalMainMenuKeys                           |voicePortalMainMenuKeys *Optional*                           |
|announcement_menu_keys                                    |OCI.announcementMenuKeys                              |announcementMenuKeys *Optional*                              |
|announcement_recording_menu_keys                          |OCI.announcementRecordingMenuKeys                     |announcementRecordingMenuKeys *Optional*                     |
|greetings_menu_keys                                       |OCI.greetingsMenuKeys                                 |greetingsMenuKeys *Optional*                                 |
|conference_greeting_menu_keys                             |OCI.conferenceGreetingMenuKeys                        |conferenceGreetingMenuKeys *Optional*                        |
|voice_messaging_menu_keys                                 |OCI.voiceMessagingMenuKeys                            |voiceMessagingMenuKeys *Optional*                            |
|play_greeting_menu_keys                                   |OCI.playGreetingMenuKeys                              |playGreetingMenuKeys *Optional*                              |
|change_busy_or_no_answer_greeting_menu_keys               |OCI.changeBusyOrNoAnswerGreetingMenuKeys              |changeBusyOrNoAnswerGreetingMenuKeys *Optional*              |
|change_extended_away_greeting_menu_keys                   |OCI.changeExtendedAwayGreetingMenuKeys                |changeExtendedAwayGreetingMenuKeys *Optional*                |
|record_new_greeting_or_personalized_name_menu_keys        |OCI.recordNewGreetingOrPersonalizedNameMenuKeys       |recordNewGreetingOrPersonalizedNameMenuKeys *Optional*       |
|delete_all_messages_menu_keys                             |OCI.deleteAllMessagesMenuKeys                         |deleteAllMessagesMenuKeys *Optional*                         |
|comm_pilot_express_profile_menu_keys                      |OCI.commPilotExpressProfileMenuKeys                   |commPilotExpressProfileMenuKeys *Optional*                   |
|personalized_name_menu_keys                               |OCI.personalizedNameMenuKeys                          |personalizedNameMenuKeys *Optional*                          |
|call_forwarding_options_menu_keys                         |OCI.callForwardingOptionsMenuKeys                     |callForwardingOptionsMenuKeys *Optional*                     |
|change_call_forwarding_destination_menu_keys              |OCI.changeCallForwardingDestinationMenuKeys           |changeCallForwardingDestinationMenuKeys *Optional*           |
|voice_portal_calling_menu_keys                            |OCI.voicePortalCallingMenuKeys                        |voicePortalCallingMenuKeys *Optional*                        |
|hoteling_menu_keys                                        |OCI.hotelingMenuKeys                                  |hotelingMenuKeys *Optional*                                  |
|passcode_menu_keys                                        |OCI.passcodeMenuKeys                                  |passcodeMenuKeys *Optional*                                  |
|play_messages_menu_keys                                   |OCI.playMessagesMenuKeys                              |playMessagesMenuKeys *Optional*                              |
|play_message_menu_keys                                    |OCI.playMessageMenuKeys                               |playMessageMenuKeys *Optional*                               |
|additional_message_options_menu_keys                      |OCI.additionalMessageOptionsMenuKeys                  |additionalMessageOptionsMenuKeys *Optional*                  |
|forward_or_compose_message_menu_keys                      |OCI.forwardOrComposeMessageMenuKeys                   |forwardOrComposeMessageMenuKeys *Optional*                   |
|reply_message_menu_keys                                   |OCI.replyMessageMenuKeys                              |replyMessageMenuKeys *Optional*                              |
|send_to_distribution_list_menu_keys                       |OCI.sendToDistributionListMenuKeys                    |sendToDistributionListMenuKeys *Optional*                    |
|select_distribution_list_menu_keys                        |OCI.selectDistributionListMenuKeys                    |selectDistributionListMenuKeys *Optional*                    |
|review_selected_distribution_list_menu_keys               |OCI.reviewSelectedDistributionListMenuKeys            |reviewSelectedDistributionListMenuKeys *Optional*            |
|send_message_to_selected_distribution_list_menu_keys      |OCI.sendMessageToSelectedDistributionListMenuKeys     |sendMessageToSelectedDistributionListMenuKeys *Optional*     |
|send_to_all_group_members_menu_keys                       |OCI.sendToAllGroupMembersMenuKeys                     |sendToAllGroupMembersMenuKeys *Optional*                     |
|send_to_person_menu_keys                                  |OCI.sendToPersonMenuKeys                              |sendToPersonMenuKeys *Optional*                              |
|change_current_introduction_or_message_or_reply_menu_keys |OCI.changeCurrentIntroductionOrMessageOrReplyMenuKeys |changeCurrentIntroductionOrMessageOrReplyMenuKeys *Optional* |
|voice_portal_login_menu_keys                              |OCI.voicePortalLoginMenuKeys                          |voicePortalLoginMenuKeys *Optional*                          |
|fax_messaging_menu_keys                                   |OCI.faxMessagingMenuKeys                              |faxMessagingMenuKeys *Optional*                              |
|message_deposit_menu_keys                                 |OCI.messageDepositMenuKeys                            |messageDepositMenuKeys *Optional*                            |
|disable_message_deposit_menu_keys                         |OCI.disableMessageDepositMenuKeys                     |disableMessageDepositMenuKeys *Optional*                     |
|greeting_only_forwarding_destination_menu_keys            |OCI.greetingOnlyForwardingDestinationMenuKeys         |greetingOnlyForwardingDestinationMenuKeys *Optional*         |
|personal_assistant_menu_keys                              |OCI.personalAssistantMenuKeys                         |personalAssistantMenuKeys *Optional*                         |
</div>


## `SystemXsiApplicationIdDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete the entries from system Xsi application Id list.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name               |Type      |Description      |
|-------------------|----------|-----------------|
|xsi_application_id |List[str] |xsiApplicationId |
</div>


## `SystemXsiApplicationIdGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the system Xsi application Id white lists.

The response is either `SystemXsiApplicationIdGetListResponse()` or `ErrorResponse()`.

</div>


## `SystemXsiApplicationIdModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system Xsi applicaiton Id description.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name               |Type|Description            |
|-------------------|----|-----------------------|
|xsi_application_id |str |xsiApplicationId       |
|description        |str |description *Optional* |
</div>


## `SystemXsiApplicationIdParameterGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the Xsi application Id system parameters.

The response is either `SystemXsiApplictionIdParameterGetResponse()` or
`ErrorResponse()`.

</div>


## `SystemXsiApplicationIdParameterModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify Xsi application system parameter.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                      |Type |Description                       |
|--------------------------|-----|----------------------------------|
|screen_xsi_application_id |bool |screenXsiApplicationId *Optional* |
</div>


## `SystemXsiPolicyProfileAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add the system Xsi policy profile entry.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                    |Type|Description            |
|------------------------|----|-----------------------|
|name                    |str |name                   |
|level                   |str |level                  |
|description             |str |description *Optional* |
|max_target_subscription |int |maxTargetSubscription  |
</div>


## `SystemXsiPolicyProfileGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the system Xsi policy profile list.

The response is either `SystemXsiPolicyProfileGetListResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                     |Type|Description                      |
|-------------------------|----|---------------------------------|
|xsi_policy_profile_level |str |xsiPolicyProfileLevel *Optional* |
</div>


## `SystemZoneCallingRestrictionsZoneAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a zone.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`SystemZoneAddRequest()`

**Attributes:**

|Name              |Type|Description                 |
|------------------|----|----------------------------|
|zone_name         |str |zoneName                    |
|physical_location |str |physicalLocation *Optional* |
</div>


## `SystemZoneCallingRestrictionsZoneDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Deletes a zone from the system The response is either a `SuccessResponse()` or an
`ErrorResponse()`.

Replaced by: `SystemZoneDeleteRequest()`

**Attributes:**

|Name      |Type|Description|
|----------|----|-----------|
|zone_name |str |zoneName   |
</div>


## `SystemZoneCallingRestrictionsZoneGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Gets a list of all zones defined in the system The response is
`SystemZoneCallingRestrictionsZoneGetListResponse()` or an `ErrorResponse()`.

Replaced by: `SystemZoneGetListRequest()`

</div>


## `SystemZoneCallingRestrictionsZoneModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies attributes of a zone in the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`SystemZonePhysicalLocationAddListRequest()` and
`SystemZonePhysicalLocationDeleteListRequest()`

**Attributes:**

|Name              |Type|Description                 |
|------------------|----|----------------------------|
|zone_name         |str |zoneName                    |
|physical_location |str |physicalLocation *Optional* |
</div>


## `SystemZoneCallingZonePhysicalLocationGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Returns a zone calling physical location for a given zone.

Response is `SystemZoneCallingZonePhysicalLocationGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name      |Type|Description|
|----------|----|-----------|
|zone_name |str |zoneName   |
</div>


## `SystemZoneCallingZonePhysicalLocationModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies a zone calling physical location for a given zone.

Response is a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name              |Type|Description                 |
|------------------|----|----------------------------|
|zone_name         |str |zoneName                    |
|physical_location |str |physicalLocation *Optional* |
</div>


## `SystemZoneDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Zone.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name      |Type|Description|
|----------|----|-----------|
|zone_name |str |zoneName   |
</div>


## `SystemZoneGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of all Zones.

The response is either a `SystemZoneGetListResponse()` or an `ErrorResponse()`.

</div>


## `SystemZoneLocationBasedPhysicalLocationAddListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Adds a list of physical locations to a zone The response is `SuccessResponse()` or an
`ErrorResponse()`.


**Attributes:**

|Name              |Type      |Description                 |
|------------------|----------|----------------------------|
|zone_name         |str       |zoneName                    |
|physical_location |List[str] |physicalLocation *Optional* |
</div>


## `SystemZoneLocationBasedPhysicalLocationDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Deletes a list of physical addresses from a zone The response is `SuccessResponse()`
or an `ErrorResponse()`.


**Attributes:**

|Name              |Type      |Description                 |
|------------------|----------|----------------------------|
|zone_name         |str       |zoneName                    |
|physical_location |List[str] |physicalLocation *Optional* |
</div>


## `TutorialFlagGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the tutorial flag setting for a user or admin.

The response is either a `TutorialFlagGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `TutorialFlagModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the tutorial flag setting for a user or admin.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name            |Type |Description               |
|----------------|-----|--------------------------|
|user_id         |str  |userId                    |
|enable_tutorial |bool |enableTutorial *Optional* |
</div>


## `UserAccessDeviceDeviceActivationGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of access devices associated to a user and their device activation
information.

The response is either `UserAccessDeviceDeviceActivationGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserAdviceOfChargeGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Advice Of Charge.

The response is either a `UserAdviceOfChargeGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserAdviceOfChargeModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Advice of Charge.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name      |Type |Description         |
|----------|-----|--------------------|
|user_id   |str  |userId              |
|is_active |bool |isActive *Optional* |
|aoc_type  |str  |aocType *Optional*  |
</div>


## `UserAlternateNumbersGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Alternate Numbers.

The response is either a `UserAlternateNumbersGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserAlternateNumbersGetRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Alternate Numbers.

The response is either a `UserAlternateNumbersGetResponse17()` or an
`ErrorResponse()`. Replaced by: `UserAlternateNumbersGetRequest21()` in AS data mode

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserAlternateNumbersGetRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with alternate numbers.

The response is either a `UserAlternateNumbersGetResponse21()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserAlternateUserIdAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add an alternate user Id to an user.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name              |Type|Description            |
|------------------|----|-----------------------|
|user_id           |str |userId                 |
|alternate_user_id |str |alternateUserId        |
|description       |str |description *Optional* |
</div>


## `UserAlternateUserIdDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete an alternate user id of a user.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name              |Type|Description     |
|------------------|----|----------------|
|user_id           |str |userId          |
|alternate_user_id |str |alternateUserId |
</div>


## `UserAlternateUserIdGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the user id and the list of alternate user ids of an user.

The response is either `UserAlternateUserIdGetListResponse()` or `ErrorResponse()`.
The "userId" can be either the user Id or an alternate user Id.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserAlternateUserIdModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify an alternate user id of a user.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                  |Type|Description                   |
|----------------------|----|------------------------------|
|user_id               |str |userId                        |
|alternate_user_id     |str |alternateUserId               |
|new_alternate_user_id |str |newAlternateUserId *Optional* |
|description           |str |description *Optional*        |
</div>


## `UserAnnouncementFileGetAvailableListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of available announcement files for a User from the Announcement
Repository, for Virtual subscribers the list will also include the announcements for
it's group.


**Attributes:**

|Name                   |Type|Description                     |
|-----------------------|----|--------------------------------|
|user_id                |str |userId                          |
|announcement_file_type |str |announcementFileType *Optional* |
</div>


## `UserAnnouncementRepositoryGetSettingsRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Return the disk space being used.


**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserAnonymousCallRejectionGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Anonymous Call Rejection.

The response is either a `UserAnonymousCallRejectionGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserAnonymousCallRejectionModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Anonymous Call Rejection.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name      |Type |Description         |
|----------|-----|--------------------|
|user_id   |str  |userId              |
|is_active |bool |isActive *Optional* |
</div>


## `UserAssignedServicesGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of assigned User and Group Services for the specified user.

The response is either an `UserAssignedServicesGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description       |
|--------|----|------------------|
|user_id |str |userId *Optional* |
</div>


## `UserAuthenticationGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's authentication service information.

The response is either a `UserAuthenticationGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserAuthenticationModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's authentication service information.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type         |Description            |
|-------------|-------------|-----------------------|
|user_id      |str          |userId                 |
|user_name    |str          |userName *Optional*    |
|new_password |str          |newPassword *Optional* |
|password     |OCI.password |password *Optional*    |
</div>


## `UserAutomaticCallbackGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Automatic Callback.

The response is either a `UserAutomaticCallbackGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserAutomaticCallbackModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Automatic Callback.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name      |Type |Description         |
|----------|-----|--------------------|
|user_id   |str  |userId              |
|is_active |bool |isActive *Optional* |
</div>


## `UserAutomaticCollectCallGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get user Automatic Collect Call service settings.

The response is either `UserAutomaticCollectCallGetResponse()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserAutomaticCollectCallModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify user Automatic Collect Call service settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                          |Type |Description                           |
|------------------------------|-----|--------------------------------------|
|user_id                       |str  |userId                                |
|enable_automatic_collect_call |bool |enableAutomaticCollectCall *Optional* |
</div>


## `UserAutomaticHoldRetrieveGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Automatic Hold/Retrieve.

The response is either a `UserAutomaticHoldRetrieveGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserAutomaticHoldRetrieveModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Automatic Hold/Retrieve.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                 |Type |Description                   |
|---------------------|-----|------------------------------|
|user_id              |str  |userId                        |
|is_active            |bool |isActive *Optional*           |
|recall_timer_seconds |int  |recallTimerSeconds *Optional* |
</div>


## `UserBargeInExemptGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Barge In Exempt.

The response is either a `UserBargeInExemptGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserBargeInExemptModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Barge In Exempt.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name      |Type |Description         |
|----------|-----|--------------------|
|user_id   |str  |userId              |
|is_active |bool |isActive *Optional* |
</div>


## `UserBasicCallLogsGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request user's call logs.

If the callLogType is not specified, all types of calls are returned.

The response is either a `UserBasicCallLogsGetListResponse()` or an `ErrorResponse()`.

Replaced By: `UserBasicCallLogsGetListRequest14sp4()`

**Attributes:**

|Name          |Type|Description            |
|--------------|----|-----------------------|
|user_id       |str |userId                 |
|call_log_type |str |callLogType *Optional* |
</div>


## `UserBasicCallLogsGetListRequest14sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request user's call logs.

If the callLogType is not specified, all types of calls are returned.

The response is either a `UserBasicCallLogsGetListResponse14sp4()` or an
`ErrorResponse()`.

**Attributes:**

|Name                   |Type |Description                    |
|-----------------------|-----|-------------------------------|
|user_id                |str  |userId                         |
|call_log_type          |str  |callLogType *Optional*         |
|format_name_and_number |bool |formatNameAndNumber *Optional* |
</div>


## `UserBroadWorksAnywhereAddPhoneNumberRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a broadworks Anywhere phone number.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                         |Type |Description                        |
|-----------------------------|-----|-----------------------------------|
|user_id                      |str  |userId                             |
|phone_number                 |str  |phoneNumber                        |
|description                  |str  |description *Optional*             |
|is_active                    |bool |isActive                           |
|outbound_alternate_number    |str  |outboundAlternateNumber *Optional* |
|broadworks_call_control      |bool |broadworksCallControl              |
|use_diversion_inhibitor      |bool |useDiversionInhibitor              |
|answer_confirmation_required |bool |answerConfirmationRequired         |
</div>


## `UserBroadWorksAnywhereDeletePhoneNumberRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a broadworks anywhere phone number.

Also deletes all the selective criteria for the phone number.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type|Description |
|-------------|----|------------|
|user_id      |str |userId      |
|phone_number |str |phoneNumber |
</div>


## `UserBroadWorksAnywhereDeleteSelectiveCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a criteria from the user's BroadWorks Anywhere phone number.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|phone_number  |str |phoneNumber  |
|criteria_name |str |criteriaName |
</div>


## `UserBroadWorksAnywhereGetAvailablePortalListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of all the available BroadWorks Anywhere portal instances for a specific
user The response is either `UserBroadWorksAnywhereGetAvailableListResponse()` or
`ErrorResponse()`.

Replaced by `UserBroadWorksAnywhereGetAvailablePortalListRequest21sp1()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserBroadWorksAnywhereGetAvailablePortalListRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of all the available BroadWorks Anywhere portal instances for a specific
user The response is either `UserBroadWorksAnywhereGetAvailableListResponse21sp1()` or
`ErrorResponse()`.


**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserBroadWorksAnywhereGetPhoneNumberRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a broadworks anywhere phone number The response is
`UserBroadWorksAnywhereGetPhoneNumberResponse()`.


**Attributes:**

|Name         |Type|Description |
|-------------|----|------------|
|user_id      |str |userId      |
|phone_number |str |phoneNumber |
</div>


## `UserBroadWorksAnywhereGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of all the BroadWorks Anywhere phone numbers for the user.

The response is either a `UserBroadWorksAnywhereGetResponse()` or an
`ErrorResponse()`. Replaced by: `UserBroadWorksAnywhereGetRequest16sp2()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserBroadWorksAnywhereGetRequest16sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of all the BroadWorks Anywhere phone numbers for the user.

The response is either a `UserBroadWorksAnywhereGetResponse16sp2()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserBroadWorksAnywhereGetSelectiveCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a criteria for the user's BroadWorks Anywhere phone number.

The response is either a `UserBroadWorksAnywhereGetSelectiveCriteriaResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|phone_number  |str |phoneNumber  |
|criteria_name |str |criteriaName |
</div>


## `UserBroadWorksAnywhereGetSelectiveCriteriaRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a criteria for the user's BroadWorks Anywhere phone number.

The response is either a `UserBroadWorksAnywhereGetSelectiveCriteriaResponse16()` or
an `ErrorResponse()`. Replaced by:
`UserBroadWorksAnywhereGetSelectiveCriteriaRequest21()` in AS data mode

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|phone_number  |str |phoneNumber  |
|criteria_name |str |criteriaName |
</div>


## `UserBroadWorksAnywhereGetSelectiveCriteriaRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a criteria for the user's BroadWorks Anywhere phone number.

The response is either a `UserBroadWorksAnywhereGetSelectiveCriteriaResponse21()` or
an `ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|phone_number  |str |phoneNumber  |
|criteria_name |str |criteriaName |
</div>


## `UserBroadWorksAnywhereModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the user-level settings for the BroadWorks Anywhere service for a
specified user.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                        |Type |Description                                     |
|--------------------------------------------|-----|------------------------------------------------|
|user_id                                     |str  |userId                                          |
|alert_all_locations_for_click_to_dial_calls |bool |alertAllLocationsForClickToDialCalls *Optional* |
|alert_all_locations_for_group_paging_calls  |bool |alertAllLocationsForGroupPagingCalls *Optional* |
</div>


## `UserBroadWorksCommunicatorGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the Configuration Server for a specified user.

The response is either a `UserBroadWorksCommunicatorGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserBroadWorksMobilityGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's broadworks mobility service settings.

The response is either a `UserBroadWorksMobilityGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserBroadWorksMobilityGetRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's BroadWorks Mobility service settings.

The response is either a `UserBroadWorksMobilityGetResponse21()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserBroadWorksMobilityGetRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's BroadWorks Mobility service settings with details for DNs.

The response is either a `UserBroadWorksMobilityGetResponse21sp1()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserBroadWorksMobilityMobileIdentityConsolidatedDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a mobile identity from the user's list of mobile identities.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. An
`ErrorResponse()` will be returned if any device cannot be deleted because of
insufficient privilege.  When a delete request is attempted on the primary mobile
identity, the delete will fail unless it is the last mobile identity in the user's
list.  If deleteExistingDevices is set to true, after the mobile identity is deleted,
any device that is only used by the deleted mobile identity prior to the deletion will
be deleted if the command is executed with the correct priviledge.  Group
administrator or above running this command can delete any group level devices.
Service provider administrator or above can delete any service provider and group
devices.  Provisioning administrator or above can delete any devices.  An
`ErrorResponse()` with the type warning will be returned if any device cannot be
deleted because of insufficient privilege.

**Attributes:**

|Name                    |Type |Description                      |
|------------------------|-----|---------------------------------|
|user_id                 |str  |userId                           |
|mobile_number           |str  |mobileNumber                     |
|delete_existing_devices |bool |deleteExistingDevices *Optional* |
</div>


## `UserBroadWorksMobilityMobileIdentityDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a mobile identity from the user's list of mobile identities.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. If another
Mobile Identity is set to ring mobile only and only has this mobile identity in the
alerting list, the identity is deleted and `ErrorResponse()` is returned.  The
`ErrorResponse()` is info type and contains the affected mobile numbers in the
summary.  When a delete request is attempted on the primary mobile identity, the
delete will fail unless it is the last mobile identity in the user's list.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|mobile_number |str |mobileNumber |
</div>


## `UserBroadWorksMobilityMobileIdentityGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the settings for a user's specified mobile identity.

The response is either a `UserBroadWorksMobilityMobileIdentityGetResponse()` or an
`ErrorResponse()`. Replaced by:
`UserBroadWorksMobilityMobileIdentityGetRequest21sp1()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|mobile_number |str |mobileNumber |
</div>


## `UserBroadWorksMobilityMobileIdentityGetRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the settings for a user's specified mobile identity.

The response is either a `UserBroadWorksMobilityMobileIdentityGetResponse21sp1()` or
an `ErrorResponse()`. Replaced by:
UserBroadWorksMobilityMobileIdentityGetRequest21sp1V2.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|mobile_number |str |mobileNumber |
</div>


## `UserBroadWorksMobilityMobileIdentityGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the settings for a user's specified mobile identity.

The response is either a `UserBroadWorksMobilityMobileIdentityGetResponse22()` or an
`ErrorResponse()`. Replaced by `UserBroadWorksMobilityMobileIdentityGetRequest22V2()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|mobile_number |str |mobileNumber |
</div>


## `UserBroadWorksMobilityMobileIdentityGetRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the settings for a user's specified mobile identity.

The response is either a `UserBroadWorksMobilityMobileIdentityGetResponse22V2()` or an
`ErrorResponse()`.

Replaced By: `UserBroadWorksMobilityMobileIdentityGetRequest22V3()`

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|mobile_number |str |mobileNumber |
</div>


## `UserBroadWorksMobilityMobileIdentityGetRequest22V3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the settings for a user's specified mobile identity.

The response is either a `UserBroadWorksMobilityMobileIdentityGetResponse22V3()` or an
`ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|mobile_number |str |mobileNumber |
</div>


## `UserBroadWorksMobilityModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's broadworks mobility service settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                        |Type |Description                          |
|----------------------------|-----|-------------------------------------|
|user_id                     |str  |userId                               |
|is_active                   |bool |isActive *Optional*                  |
|phones_to_ring              |str  |phonesToRing *Optional*              |
|mobile_phone_number         |str  |mobilePhoneNumber *Optional*         |
|alert_click_to_dial_calls   |bool |alertClickToDialCalls *Optional*     |
|alert_group_paging_calls    |bool |alertGroupPagingCalls *Optional*     |
|enable_diversion_inhibitor  |bool |enableDiversionInhibitor *Optional*  |
|require_answer_confirmation |bool |requireAnswerConfirmation *Optional* |
|broadworks_call_control     |bool |broadworksCallControl *Optional*     |
|use_setting_level           |str  |useSettingLevel *Optional*           |
|deny_call_originations      |bool |denyCallOriginations *Optional*      |
|deny_call_terminations      |bool |denyCallTerminations *Optional*      |
</div>


## `UserBroadWorksMobilityModifyRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's broadworks mobility service settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. If the request
modifies the mobilePhoneNumber and the new number does not belong to the appropriate
Mobile Subscriber Directory Numbers pool, the request is rejected.  For a service
provider the number must belong to the group Mobile Subscriber Directory Numbers pool.
For an enterprise user, the number must belong to the enterprise Mobile Subscriber
Directory Numbers pool.  If the request is executed by a user and modifies the
mobilePhoneNumber, the request is rejected.

**Attributes:**

|Name                        |Type |Description                          |
|----------------------------|-----|-------------------------------------|
|user_id                     |str  |userId                               |
|is_active                   |bool |isActive *Optional*                  |
|phones_to_ring              |str  |phonesToRing *Optional*              |
|mobile_phone_number         |str  |mobilePhoneNumber *Optional*         |
|alert_click_to_dial_calls   |bool |alertClickToDialCalls *Optional*     |
|alert_group_paging_calls    |bool |alertGroupPagingCalls *Optional*     |
|enable_diversion_inhibitor  |bool |enableDiversionInhibitor *Optional*  |
|require_answer_confirmation |bool |requireAnswerConfirmation *Optional* |
|broadworks_call_control     |bool |broadworksCallControl *Optional*     |
|use_setting_level           |str  |useSettingLevel *Optional*           |
|deny_call_originations      |bool |denyCallOriginations *Optional*      |
|deny_call_terminations      |bool |denyCallTerminations *Optional*      |
</div>


## `UserBroadWorksReceptionistEnterpriseAddUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add users to the BroadWorks Receptionist - Enterprise monitored user list.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name              |Type      |Description     |
|------------------|----------|----------------|
|user_id           |str       |userId          |
|monitored_user_id |List[str] |monitoredUserId |
</div>


## `UserBroadWorksReceptionistEnterpriseDeleteUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Remove selected users from the BroadWorks Receptionist - Enterprise monitored user
list.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name              |Type      |Description     |
|------------------|----------|----------------|
|user_id           |str       |userId          |
|monitored_user_id |List[str] |monitoredUserId |
</div>


## `UserBroadWorksReceptionistEnterpriseGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the monitored users list for the BroadWorks Receptionist - Enterprise service.

The response is either a `UserBroadWorksReceptionistEnterpriseGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserBroadWorksReceptionistOfficeGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the Receptionist Office parameters.

The response is either a `UserBroadWorksReceptionistOfficeGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserBroadWorksReceptionistSmallBusinessGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the Receptionist Small Business parameters.

The response is either a `UserBroadWorksReceptionistSmallBusinessGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserBusyLampFieldGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the settings for the busy lamp field service.

The response is either a `UserBusyLampFieldGetResponse()` or an `ErrorResponse()`.
Replaced by: `UserBusyLampFieldGetRequest16sp2()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserBusyLampFieldGetRequest16sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the settings for the busy lamp field service.

The response is either a `UserBusyLampFieldGetResponse16sp2()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallCenterAddSupervisedAgentListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Assign agent(s) to a call center supervisor.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name               |Type      |Description      |
|-------------------|----------|-----------------|
|supervisor_user_id |str       |supervisorUserId |
|service_user_id    |str       |serviceUserId    |
|agent_user_id      |List[str] |agentUserId      |
</div>


## `UserCallCenterAgentDetailsGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the detail information of a Call Center Agent.

Administrator, supervisor and agent itself can send this command.

The response is either `UserCallCenterAgentDetailsGetResponse()` or `ErrorResponse()`.

**Attributes:**

|Name          |Type|Description |
|--------------|----|------------|
|agent_user_id |str |agentUserId |
</div>


## `UserCallCenterAgentSignOutRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
This request signs-out a call center agent.

Administrator, supervisor and agent itself can sign-out an agent.  An empty OCI table
in OCI-P response indicates success and the agent has been signed out.  This sign-out
command will fail if the agent is the last signed-in agent of any standard or premium
call center to which she is currently joined.  If the sign-out fails, the OCI-P
response will contain a list of Call Centers for which the agent is the last signed-in
agent.  If this special logic is not needed, `UserCallCenterModifyRequest19()` can
still be used to change the agents ACD state without checking if the agent is the last
signed-in agent.

The response is either a `UserCallCenterAgentSignOutResponse()` or `ErrorResponse()`.

**Attributes:**

|Name          |Type|Description |
|--------------|----|------------|
|agent_user_id |str |agentUserId |
</div>


## `UserCallCenterCallDispositionCodeGetAvailableListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of available Call Center Call Disposition Codes to be used by a client.

The response is either `UserCallCenterCallDispositionCodeGetAvailableListResponse()`
or `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `UserCallCenterDeleteSupervisedAgentListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete agent(s) from a call center supervisor.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name               |Type      |Description      |
|-------------------|----------|-----------------|
|supervisor_user_id |str       |supervisorUserId |
|service_user_id    |str       |serviceUserId    |
|agent_user_id      |List[str] |agentUserId      |
</div>


## `UserCallCenterEnhancedReportingScheduledReportDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a call center reporting scheduled report created by a supervisor.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name               |Type|Description      |
|-------------------|----|-----------------|
|supervisor_user_id |str |supervisorUserId |
|name               |str |name             |
</div>


## `UserCallCenterEnhancedReportingScheduledReportGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a call center reporting scheduled report created by supervisor.

The response is either a `UserCallCenterEnhancedReportingScheduledReportGetResponse()`
or an `ErrorResponse()`.

**Attributes:**

|Name               |Type|Description      |
|-------------------|----|-----------------|
|supervisor_user_id |str |supervisorUserId |
|name               |str |name             |
</div>


## `UserCallCenterGetAgentSupervisorListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of supervisors for an agent on a given call center.

The response is either a `UserCallCenterGetAgentSupervisorListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|agent_user_id   |str |agentUserId   |
|service_user_id |str |serviceUserId |
</div>


## `UserCallCenterGetAvailableCallCenterListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
This request gets a list of all call centers which the user can be assigned to as an
agent.

Some of the call centers may already have the user as an agent.  It is the clients
responsibility to discard the call centers that the user is already an agent of.

The response is either a `UserCallCenterGetAvailableCallCenterListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallCenterGetAvailableDNISListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a list of available DNIS for agent to select.

The response is either `UserCallCenterGetAvailableDNISListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name          |Type|Description |
|--------------|----|------------|
|agent_user_id |str |agentUserId |
</div>


## `UserCallCenterGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of call centers the specified user belongs to.

The response is either a `UserCallCenterGetListResponse()` or an `ErrorResponse()`.

Replaced By: `UserCallCenterGetRequest()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallCenterGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's ACD state and the list of call centers the specified user belongs to.

The response is either a `UserCallCenterGetResponse()` or an `ErrorResponse()`.

Replaced By: `UserCallCenterGetRequest16()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallCenterGetRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's call center settings and the list of call centers the specified user
belongs to.

The response is either a `UserCallCenterGetResponse16()` or an `ErrorResponse()`.
Replaced by: `UserCallCenterGetRequest17()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallCenterGetRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's call center settings and the list of call centers the specified user
belongs to.

The response is either a `UserCallCenterGetResponse17()` or an `ErrorResponse()`.
Replaced by `UserCallCenterGetRequest17sp4()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallCenterGetRequest17sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's call center settings and the list of call centers the specified user
belongs to.

The response is either a `UserCallCenterGetResponse17sp4()` or an `ErrorResponse()`.
Replaced by `UserCallCenterGetRequest19()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallCenterGetRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's call center settings and the list of call centers the specified user
belongs to.

The response is either a `UserCallCenterGetResponse19()` or an `ErrorResponse()`.
Replaced by `UserCallCenterGetRequest23()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallCenterGetRequest23`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's call center settings and the list of call centers the specified user
belongs to.

The response is either a `UserCallCenterGetResponse23()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallCenterGetSupervisorCallCenterListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of call centers the user is assigned to as a supervisor.

The response is either a `UserCallCenterGetSupervisorCallCenterListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name               |Type|Description      |
|-------------------|----|-----------------|
|supervisor_user_id |str |supervisorUserId |
</div>


## `UserCallCenterMonitoringGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user's Call Center Monitoring settings.

The response is either a `UserCallCenterMonitoringGetResponse()` or an
`ErrorResponse()`. Replaced by `UserCallCenterMonitoringGetRequest23()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallCenterMonitoringGetRequest23`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user's Call Center Monitoring settings.

The response is either a `UserCallCenterMonitoringGetResponse23()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallCenterMonitoringModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's Call Center Monitoring settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                       |Type |Description                                     |
|-------------------------------------------|-----|------------------------------------------------|
|user_id                                    |str  |userId                                          |
|play_tone_to_agent_for_silent_monitoring   |bool |playToneToAgentForSilentMonitoring *Optional*   |
|play_tone_to_agent_for_supervisor_coaching |bool |playToneToAgentForSupervisorCoaching *Optional* |
</div>


## `UserCallForwardingAlwaysGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Call Forwarding Always.

The response is either a `UserCallForwardingAlwaysGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallForwardingAlwaysModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Call Forwarding Always.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Engineering
Note: This command is used internally by Call Processing.

**Attributes:**

|Name                    |Type |Description                     |
|------------------------|-----|--------------------------------|
|user_id                 |str  |userId                          |
|is_active               |bool |isActive *Optional*             |
|forward_to_phone_number |str  |forwardToPhoneNumber *Optional* |
|is_ring_splash_active   |bool |isRingSplashActive *Optional*   |
</div>


## `UserCallForwardingAlwaysSecondaryGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Call Forwarding Always Secondary service.

The response is either a `UserCallForwardingAlwaysSecondaryGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallForwardingAlwaysSecondaryModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Call Forwarding Always Secondary service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                    |Type |Description                     |
|------------------------|-----|--------------------------------|
|user_id                 |str  |userId                          |
|is_active               |bool |isActive *Optional*             |
|forward_to_phone_number |str  |forwardToPhoneNumber *Optional* |
|is_ring_splash_active   |bool |isRingSplashActive *Optional*   |
</div>


## `UserCallForwardingBusyGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Call Forwarding Busy.

The response is either a `UserCallForwardingBusyGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallForwardingBusyModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Call Forwarding Busy.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Engineering
Note: This command is used internally by Call Processing.

**Attributes:**

|Name                    |Type |Description                     |
|------------------------|-----|--------------------------------|
|user_id                 |str  |userId                          |
|is_active               |bool |isActive *Optional*             |
|forward_to_phone_number |str  |forwardToPhoneNumber *Optional* |
</div>


## `UserCallForwardingNoAnswerGetRequest13mp16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Call Forwarding No Answer.

The response is either a `UserCallForwardingNoAnswerGetResponse13mp16()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallForwardingNoAnswerModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Call Forwarding No Answer.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Engineering
Note: This command is used internally by Call Processing.

**Attributes:**

|Name                    |Type |Description                     |
|------------------------|-----|--------------------------------|
|user_id                 |str  |userId                          |
|is_active               |bool |isActive *Optional*             |
|forward_to_phone_number |str  |forwardToPhoneNumber *Optional* |
|number_of_rings         |int  |numberOfRings *Optional*        |
</div>


## `UserCallForwardingNotReachableGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Call Forwarding Not Reachable.

The response is either a `UserCallForwardingNotReachableGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallForwardingNotReachableModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Call Forwarding Not Reachable.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Engineering
Note: This command is used internally by Call Processing.

**Attributes:**

|Name                    |Type |Description                     |
|------------------------|-----|--------------------------------|
|user_id                 |str  |userId                          |
|is_active               |bool |isActive *Optional*             |
|forward_to_phone_number |str  |forwardToPhoneNumber *Optional* |
</div>


## `UserCallForwardingSelectiveDeleteCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a criteria from the user's call forwarding selective service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserCallForwardingSelectiveGetCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a criteria for the user's call forwarding selective service.

The response is either a `UserCallForwardingSelectiveGetCriteriaResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserCallForwardingSelectiveGetCriteriaRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a criteria for the user's call forwarding selective service.

The response is either a `UserCallForwardingSelectiveGetCriteriaResponse16()` or an
`ErrorResponse()`. Replaced by: `UserCallForwardingSelectiveGetCriteriaRequest21()` in
AS data mode

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserCallForwardingSelectiveGetCriteriaRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a criteria for the user's call forwarding selective service.

The response is either a `UserCallForwardingSelectiveGetCriteriaResponse21()` or an
`ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserCallForwardingSelectiveGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's call forwarding selective service setting.

The response is either a `UserCallForwardingSelectiveGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallForwardingSelectiveGetRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's call forwarding selective service setting.

The response is either a `UserCallForwardingSelectiveGetResponse16()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallLogsClearRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Clear a user's call logs associated with Basic Call Logs and Enhanced Call Logs
features.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

Replaced By: `UserCallLogsClearRequest14sp4()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallLogsClearRequest14sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Clear a user's call logs associated with Basic Call Logs and Enhanced Call Logs
features.

The calls logs are deleted from both Basic Call Logs and Enhanced Call Logs if both
features are assigned.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                       |Type                        |Description                        |
|---------------------------|----------------------------|-----------------------------------|
|user_id                    |str                         |userId                             |
|delete_all_call_logs       |bool                        |deleteAllCallLogs *Optional*       |
|delete_specified_call_logs |OCI.deleteSpecifiedCallLogs |deleteSpecifiedCallLogs *Optional* |
</div>


## `UserCallMeNowDeleteCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a criteria from the user's call me now service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserCallMeNowGetCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a criteria for the user's call me now service.

The response is either a `UserCallMeNowGetCriteriaResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserCallMeNowGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's call me now service setting.

The response is either a `UserCallMeNowGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallNotifyDeleteCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a criteria from the user's call notify service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserCallNotifyGetCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a criteria for the user's call notify service.

The response is either a `UserCallNotifyGetCriteriaResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserCallNotifyGetCriteriaRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a criteria for the user's call notify service.

The response is either a `UserCallNotifyGetCriteriaResponse16()` or an
`ErrorResponse()`. Replaced by: `UserCallNotifyGetCriteriaRequest21()` in AS data mode

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserCallNotifyGetCriteriaRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a criteria for the user's call notify service.

The response is either a `UserCallNotifyGetCriteriaResponse21()` or an
`ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserCallNotifyGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's call notify service setting.

The response is either a `UserCallNotifyGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallParkGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Identifies which Call Park group the user belongs to if any and the list of users in
the group.

The response is either `UserCallParkGetResponse()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallPickupGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Gets the details of the Call Pickup group that a user belongs to (if any).

Any user can only belong to one Call Pickup group.

The response is either `UserCallPickupGetResponse()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallPoliciesGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Call Policies.

The response is either a `UserCallPoliciesGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallPoliciesGetRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Call Policies.

The response is either a `UserCallPoliciesGetResponse17()` or an `ErrorResponse()`.
Replaced by: `UserCallPoliciesGetRequest19sp1()` in AS data mode

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallPoliciesGetRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Call Policies.

The response is either a `UserCallPoliciesGetResponse19sp1()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallPoliciesModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Call Policies.

The following elements are only used in AS data mode:
callingLineIdentityForRedirectedCalls

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                       |Type|Description                                      |
|-------------------------------------------|----|-------------------------------------------------|
|user_id                                    |str |userId                                           |
|redirected_calls_colp_privacy              |str |redirectedCallsCOLPPrivacy *Optional*            |
|call_being_forwarded_response_call_type    |str |callBeingForwardedResponseCallType *Optional*    |
|calling_line_identity_for_redirected_calls |str |callingLineIdentityForRedirectedCalls *Optional* |
</div>


## `UserCallProcessingGetPolicyRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Call Processing Policy.

The response is either a `UserCallProcessingGetPolicyResponse14()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallProcessingGetPolicyRequest14sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Call Processing Policy.

The response is either a `UserCallProcessingGetPolicyResponse14sp1()` or an
`ErrorResponse()`.

Replaced By: `UserCallProcessingGetPolicyRequest14sp7()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallProcessingGetPolicyRequest14sp7`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Call Processing Policy.

The response is either a `UserCallProcessingGetPolicyResponse14sp7()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallProcessingGetPolicyRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Call Processing Policy.

The response is either a `UserCallProcessingGetPolicyResponse16()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallProcessingGetPolicyRequest16sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Call Processing Policy.

The response is either a `UserCallProcessingGetPolicyResponse16()` or an
`ErrorResponse()`. Replaced by: `UserCallProcessingGetPolicyRequest17sp4()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallProcessingGetPolicyRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Call Processing Policy.

The response is either a `UserCallProcessingGetPolicyResponse17()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallProcessingGetPolicyRequest17sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Call Processing Policy.

The response is either a `UserCallProcessingGetPolicyResponse17sp3()` or an
`ErrorResponse()`. Replaced by: UserCallProcessingGetPolicyRequest17Sp4

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallProcessingGetPolicyRequest17sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Call Processing Policy.

The response is either a `UserCallProcessingGetPolicyResponse17sp4()` or an
`ErrorResponse()`. Replaced by: `UserCallProcessingGetPolicyRequest18()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallProcessingGetPolicyRequest18`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Call Processing Policy.

The response is either a `UserCallProcessingGetPolicyResponse18()` or an
`ErrorResponse()`. Replaced by: `UserCallProcessingGetPolicyRequest19sp1()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallProcessingGetPolicyRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Call Processing Policy.

The response is either a `UserCallProcessingGetPolicyResponse19sp1()` or an
`ErrorResponse()`. Replaced by: `UserCallProcessingGetPolicyRequest21sp1()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallProcessingGetPolicyRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Call Processing Policy.

The response is either a `UserCallProcessingGetPolicyResponse21sp1()` or an
`ErrorResponse()`. Replaced by: `UserCallProcessingGetPolicyRequest21sp2()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallProcessingGetPolicyRequest21sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Call Processing Policy.

The response is either a `UserCallProcessingGetPolicyResponse21sp2()` or an
`ErrorResponse()`. Replaced by: `UserCallProcessingGetPolicyRequest22()` in AS data
mode

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallProcessingGetPolicyRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Call Processing Policy.

The response is either a `UserCallProcessingGetPolicyResponse22()` or an
`ErrorResponse()`. Replaced by: `UserCallProcessingGetPolicyRequest22V2()` in AS data
mode.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallProcessingGetPolicyRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Call Processing Policy.

The response is either a `UserCallProcessingGetPolicyResponse22V2()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallProcessingModifyPolicyRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Call Processing Policy.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

Replaced By: `UserCallProcessingModifyPolicyRequest14sp7()`

**Attributes:**

|Name                                             |Type |Description                                          |
|-------------------------------------------------|-----|-----------------------------------------------------|
|user_id                                          |str  |userId                                               |
|use_user_setting                                 |bool |useUserSetting *Optional*                            |
|use_max_simultaneous_calls                       |bool |useMaxSimultaneousCalls *Optional*                   |
|max_simultaneous_calls                           |int  |maxSimultaneousCalls *Optional*                      |
|use_max_simultaneous_video_calls                 |bool |useMaxSimultaneousVideoCalls *Optional*              |
|max_simultaneous_video_calls                     |int  |maxSimultaneousVideoCalls *Optional*                 |
|use_max_call_time_for_answered_calls             |bool |useMaxCallTimeForAnsweredCalls *Optional*            |
|max_call_time_for_answered_calls_minutes         |int  |maxCallTimeForAnsweredCallsMinutes *Optional*        |
|use_max_call_time_for_unanswered_calls           |bool |useMaxCallTimeForUnansweredCalls *Optional*          |
|max_call_time_for_unanswered_calls_minutes       |int  |maxCallTimeForUnansweredCallsMinutes *Optional*      |
|media_policy_selection                           |str  |mediaPolicySelection *Optional*                      |
|supported_media_set_name                         |str  |supportedMediaSetName *Optional*                     |
|use_max_concurrent_redirected_calls              |bool |useMaxConcurrentRedirectedCalls *Optional*           |
|max_concurrent_redirected_calls                  |int  |maxConcurrentRedirectedCalls *Optional*              |
|use_max_find_me_follow_me_depth                  |bool |useMaxFindMeFollowMeDepth *Optional*                 |
|max_find_me_follow_me_depth                      |int  |maxFindMeFollowMeDepth *Optional*                    |
|max_redirection_depth                            |int  |maxRedirectionDepth *Optional*                       |
|use_max_concurrent_find_me_follow_me_invocations |bool |useMaxConcurrentFindMeFollowMeInvocations *Optional* |
|max_concurrent_find_me_follow_me_invocations     |int  |maxConcurrentFindMeFollowMeInvocations *Optional*    |
</div>


## `UserCallProcessingModifyPolicyRequest14sp7`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Call Processing Policy.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The
useUserCLIDSetting attribute controls the CLID settings (clidPolicy,
emergencyClidPolicy, allowAlternateNumbersForRedirectingIdentity, useGroupName,
allowConfigurableCLIDForRedirectingIdentity, allowDepartmentCLIDNameOverride) The
useUserMediaSetting attribute controls the Media settings (medisPolicySelection,
supportedMediaSetName) The useUserCallLimitsSetting attribute controls the Call Limits
setting (useMaxSimultaneousCalls, maxSimultaneousCalls, useMaxSimultaneousVideoCalls,
maxSimultaneousVideoCalls, useMaxCallTimeForAnsweredCalls,
maxCallTimeForAnsweredCallsMinutes, useMaxCallTimeForUnansweredCalls,
maxCallTimeForUnansweredCallsMinutes, useMaxConcurrentRedirectedCalls,
useMaxFindMeFollowMeDepth, maxRedirectionDepth,
useMaxConcurrentFindMeFollowMeInvocations, maxConcurrentFindMeFollowMeInvocations,
useMaxConcurrentTerminatingAlertingRequests, maxConcurrentTerminatingAlertingRequests,
includeRedirectionsInMaximumNumberOfConcurrentCalls) The useUserDCLIDSetting controls
the Dialable Caller ID settings (enableDialableCallerID) The
useUserPhoneListLookupSetting controls the Caller ID Lookup settings
(enablePhoneListLookup) The useUserTranslationRoutingSetting attribute controls the
routing and translation settings (routeOverrideDomain, routeOverridePrefix) The
following elements are only used in AS data mode: useUserDCLIDSetting
enableDialableCallerID allowConfigurableCLIDForRedirectingIdentity
allowDepartmentCLIDNameOverride The following elements are only used in AS data mode
and ignored in XS data mode: useUserPhoneListLookupSetting enablePhoneListLookup
useMaxConcurrentTerminatingAlertingRequests maxConcurrentTerminatingAlertingRequests
includeRedirectionsInMaximumNumberOfConcurrentCalls
allowMobileDNForRedirectingIdentity The following elements are only used in XS data
mode and ignored in AS data mode: useUserTranslationRoutingSetting routeOverrideDomain
routeOverridePrefix

**Attributes:**

|Name                                                       |Type |Description                                                    |
|-----------------------------------------------------------|-----|---------------------------------------------------------------|
|user_id                                                    |str  |userId                                                         |
|use_user_clid_setting                                      |bool |useUserCLIDSetting *Optional*                                  |
|use_user_media_setting                                     |bool |useUserMediaSetting *Optional*                                 |
|use_user_call_limits_setting                               |bool |useUserCallLimitsSetting *Optional*                            |
|use_user_dclid_setting                                     |bool |useUserDCLIDSetting *Optional*                                 |
|use_user_translation_routing_setting                       |bool |useUserTranslationRoutingSetting *Optional*                    |
|use_max_simultaneous_calls                                 |bool |useMaxSimultaneousCalls *Optional*                             |
|max_simultaneous_calls                                     |int  |maxSimultaneousCalls *Optional*                                |
|use_max_simultaneous_video_calls                           |bool |useMaxSimultaneousVideoCalls *Optional*                        |
|max_simultaneous_video_calls                               |int  |maxSimultaneousVideoCalls *Optional*                           |
|use_max_call_time_for_answered_calls                       |bool |useMaxCallTimeForAnsweredCalls *Optional*                      |
|max_call_time_for_answered_calls_minutes                   |int  |maxCallTimeForAnsweredCallsMinutes *Optional*                  |
|use_max_call_time_for_unanswered_calls                     |bool |useMaxCallTimeForUnansweredCalls *Optional*                    |
|max_call_time_for_unanswered_calls_minutes                 |int  |maxCallTimeForUnansweredCallsMinutes *Optional*                |
|media_policy_selection                                     |str  |mediaPolicySelection *Optional*                                |
|supported_media_set_name                                   |str  |supportedMediaSetName *Optional*                               |
|use_max_concurrent_redirected_calls                        |bool |useMaxConcurrentRedirectedCalls *Optional*                     |
|max_concurrent_redirected_calls                            |int  |maxConcurrentRedirectedCalls *Optional*                        |
|use_max_find_me_follow_me_depth                            |bool |useMaxFindMeFollowMeDepth *Optional*                           |
|max_find_me_follow_me_depth                                |int  |maxFindMeFollowMeDepth *Optional*                              |
|max_redirection_depth                                      |int  |maxRedirectionDepth *Optional*                                 |
|use_max_concurrent_find_me_follow_me_invocations           |bool |useMaxConcurrentFindMeFollowMeInvocations *Optional*           |
|max_concurrent_find_me_follow_me_invocations               |int  |maxConcurrentFindMeFollowMeInvocations *Optional*              |
|clid_policy                                                |str  |clidPolicy *Optional*                                          |
|emergency_clid_policy                                      |str  |emergencyClidPolicy *Optional*                                 |
|allow_alternate_numbers_for_redirecting_identity           |bool |allowAlternateNumbersForRedirectingIdentity *Optional*         |
|use_group_name                                             |bool |useGroupName *Optional*                                        |
|enable_dialable_caller_id                                  |bool |enableDialableCallerID *Optional*                              |
|block_calling_name_for_external_calls                      |bool |blockCallingNameForExternalCalls *Optional*                    |
|allow_configurable_clid_for_redirecting_identity           |bool |allowConfigurableCLIDForRedirectingIdentity *Optional*         |
|allow_department_clid_name_override                        |bool |allowDepartmentCLIDNameOverride *Optional*                     |
|use_user_phone_list_lookup_setting                         |bool |useUserPhoneListLookupSetting *Optional*                       |
|enable_phone_list_lookup                                   |bool |enablePhoneListLookup *Optional*                               |
|use_max_concurrent_terminating_alerting_requests           |bool |useMaxConcurrentTerminatingAlertingRequests *Optional*         |
|max_concurrent_terminating_alerting_requests               |int  |maxConcurrentTerminatingAlertingRequests *Optional*            |
|include_redirections_in_maximum_number_of_concurrent_calls |bool |includeRedirectionsInMaximumNumberOfConcurrentCalls *Optional* |
|route_override_domain                                      |str  |routeOverrideDomain *Optional*                                 |
|route_override_prefix                                      |str  |routeOverridePrefix *Optional*                                 |
|allow_mobile_dn_for_redirecting_identity                   |bool |allowMobileDNForRedirectingIdentity *Optional*                 |
</div>


## `UserCallRecordingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the Call Recording attributes for a user.

The response is either a `UserCallRecordingGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallRecordingGetRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the Call Recording attributes for a user.

The response is either a `UserCallRecordingGetResponse20()` or an `ErrorResponse()`.
The following parameters are not returned for service instance: -
pauseResumeNotification - enableCallRecordingAnnouncement -
enableRecordCallRepeatWarningTone - recordCallRepeatWarningToneTimerSeconds Replaced
by: `UserCallRecordingGetRequest23()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallRecordingGetRequest23`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the Call Recording attributes for a user.

The response is either a `UserCallRecordingGetResponse23()` or an `ErrorResponse()`.
The following parameters are not returned for service instance: -
pauseResumeNotification - enableCallRecordingAnnouncement -
enableRecordCallRepeatWarningTone - recordCallRepeatWarningToneTimerSeconds

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallRecordingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Call Recording attributes for a user.

The recording options "Always with Pause/Resume", "On Demand", and "On Demand with
User Initiated Start" are not accepted for service instances.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
parameters are not accepted for service instance: - pauseResumeNotification -
enableCallRecordingAnnouncement - enableRecordCallRepeatWarningTone -
recordCallRepeatWarningToneTimerSeconds The enableVoiceMailRecording parameter is only
applicable if the Voice Messaging User service is assigned to the user.  This applies
to both users and service instances.  The following elements are only used in AS data
mode and ignored in XS data mode: mediaStream

**Attributes:**

|Name                                          |Type |Description                                        |
|----------------------------------------------|-----|---------------------------------------------------|
|user_id                                       |str  |userId                                             |
|recording_option                              |str  |recordingOption *Optional*                         |
|pause_resume_notification                     |str  |pauseResumeNotification *Optional*                 |
|enable_call_recording_announcement            |bool |enableCallRecordingAnnouncement *Optional*         |
|enable_record_call_repeat_warning_tone        |bool |enableRecordCallRepeatWarningTone *Optional*       |
|record_call_repeat_warning_tone_timer_seconds |int  |recordCallRepeatWarningToneTimerSeconds *Optional* |
|enable_voice_mail_recording                   |bool |enableVoiceMailRecording *Optional*                |
|media_stream                                  |str  |mediaStream *Optional*                             |
</div>


## `UserCallToNumberGetAvailableListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the user available Call to Number List information.

The response is either a `UserCallToNumberGetAvailableListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallTransferGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Call Transfer.

The response is either a `UserCallTransferGetResponse()` or an `ErrorResponse()`.

Replaced By: UserCallTransferGetRequest14Sp4

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallTransferGetRequest14sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Call Transfer.

The response is either a `UserCallTransferGetResponse14sp4()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallTransferModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Call Transfer.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                           |Type |Description                                          |
|-----------------------------------------------|-----|-----------------------------------------------------|
|user_id                                        |str  |userId                                               |
|is_recall_active                               |bool |isRecallActive *Optional*                            |
|recall_number_of_rings                         |int  |recallNumberOfRings *Optional*                       |
|use_diversion_inhibitor_for_blind_transfer     |bool |useDiversionInhibitorForBlindTransfer *Optional*     |
|use_diversion_inhibitor_for_consultative_calls |bool |useDiversionInhibitorForConsultativeCalls *Optional* |
|enable_busy_camp_on                            |bool |enableBusyCampOn *Optional*                          |
|busy_camp_on_seconds                           |int  |busyCampOnSeconds *Optional*                         |
</div>


## `UserCallWaitingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Call Waiting.

The response is either a `UserCallWaitingGetResponse()` or an `ErrorResponse()`.
Replaced by: `UserCallWaitingGetRequest17sp4()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallWaitingGetRequest17sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Call Waiting.

The response is either a `UserCallWaitingGetResponse17sp4()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallWaitingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Call Waiting.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode: disableCallingLineIdDelivery

**Attributes:**

|Name                             |Type |Description                             |
|---------------------------------|-----|----------------------------------------|
|user_id                          |str  |userId                                  |
|is_active                        |bool |isActive *Optional*                     |
|disable_calling_line_id_delivery |bool |disableCallingLineIdDelivery *Optional* |
</div>


## `UserCallingLineIDBlockingOverrideGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Calling Line ID Blocking Override.

The response is either a `UserCallingLineIDBlockingOverrideGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallingLineIDBlockingOverrideModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Calling Line ID Blocking Override.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name      |Type |Description         |
|----------|-----|--------------------|
|user_id   |str  |userId              |
|is_active |bool |isActive *Optional* |
</div>


## `UserCallingLineIDDeliveryBlockingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Calling Line ID Delivery Blocking.

The response is either a `UserCallingLineIDDeliveryBlockingGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallingLineIDDeliveryBlockingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Calling Line ID Delivery Blocking.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name      |Type |Description         |
|----------|-----|--------------------|
|user_id   |str  |userId              |
|is_active |bool |isActive *Optional* |
</div>


## `UserCallingNameDeliveryGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Calling Name Delivery.

The response is either a `UserCallingNameDeliveryGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallingNameDeliveryModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Calling Name Delivery.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                         |Type |Description                         |
|-----------------------------|-----|------------------------------------|
|user_id                      |str  |userId                              |
|is_active_for_external_calls |bool |isActiveForExternalCalls *Optional* |
|is_active_for_internal_calls |bool |isActiveForInternalCalls *Optional* |
</div>


## `UserCallingNameRetrievalGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Calling Name Retrieval.

The response is either a `UserCallingNameRetrievalGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallingNameRetrievalModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Calling Name Retrieval.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name      |Type |Description         |
|----------|-----|--------------------|
|user_id   |str  |userId              |
|is_active |bool |isActive *Optional* |
</div>


## `UserCallingNumberDeliveryGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Calling Name Delivery.

The response is either a `UserCallingNumberDeliveryGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallingNumberDeliveryModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Calling Number Delivery.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                         |Type |Description                         |
|-----------------------------|-----|------------------------------------|
|user_id                      |str  |userId                              |
|is_active_for_external_calls |bool |isActiveForExternalCalls *Optional* |
|is_active_for_internal_calls |bool |isActiveForInternalCalls *Optional* |
</div>


## `UserCallingPartyCategoryGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Calling Party Category.

The response is either a `UserCallingPartyCategoryGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallingPartyCategoryGetRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Calling Party Category.

The response is either a `UserCallingPartyCategoryGetResponse16()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCallingPartyCategoryModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Calling Party Category.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name     |Type|Description         |
|---------|----|--------------------|
|user_id  |str |userId              |
|category |str |category *Optional* |
</div>


## `UserCallingPartyCategoryModifyRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Calling Party Category.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name     |Type|Description         |
|---------|----|--------------------|
|user_id  |str |userId              |
|category |str |category *Optional* |
</div>


## `UserChargeNumberGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Charge Number.

The response is either a `UserChargeNumberGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserChargeNumberGetRequest14sp9`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Charge Number.

The response is either a `UserChargeNumberGetResponse14sp9()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserChargeNumberModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Charge Number.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                        |Type |Description                                       |
|--------------------------------------------|-----|--------------------------------------------------|
|user_id                                     |str  |userId                                            |
|phone_number                                |str  |phoneNumber *Optional*                            |
|use_charge_number_for_enhanced_translations |bool |useChargeNumberForEnhancedTranslations *Optional* |
|send_charge_number_to_network               |bool |sendChargeNumberToNetwork *Optional*              |
</div>


## `UserClassmarkGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the Class Mark data associated with User.

The response is either a `UserClassmarkGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserClassmarkModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Class Mark.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name      |Type|Description          |
|----------|----|---------------------|
|user_id   |str |userId               |
|classmark |str |classmark *Optional* |
</div>


## `UserCollaborateBridgeGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the collaborate bridged assigned to the user.

The user can only be assigned to one collaborate bridge at any given time.

The response is either `UserCollaborateBridgeGetResponse()` or `ErrorResponse()`.
Replaced by: `UserCollaborateBridgeGetRequest20sp1()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCollaborateBridgeGetRequest20sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the collaborate bridged assigned to the user.

The user can only be assigned to one collaborate bridge at any given time.

The response is either `UserCollaborateBridgeGetResponse20sp1()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCollaborateDeleteRoomRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a collaborate room.

The request only applies to project rooms and instant rooms.  The request fails when
deleting a collaborate My Room.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
|room_id |str |roomId     |
</div>


## `UserCollaborateInstantRoomAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add collaborate instant room.

The response is either a `UserCollaborateInstantRoomAddResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                     |Type |Description                    |
|-------------------------|-----|-------------------------------|
|user_id                  |str  |userId                         |
|room_name                |str  |roomName *Optional*            |
|use_room_id_as_room_name |bool |useRoomIdAsRoomName *Optional* |
</div>


## `UserCollaborateInstantRoomGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the collaborate room settings for an instant room.

The request fails when requesting collaborate room settings for My Room or project
rooms.

The response is either `UserCollaboratInstantRoomGetResponse()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
|room_id |str |roomId     |
</div>


## `UserCollaborateInstantRoomParametersGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request collaborate instant room settings.

The response is either `UserCollaborateInstantRoomParametersGetResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCollaborateInstantRoomParametersModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify collaborate instant room settings.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                       |Type |Description                                     |
|-------------------------------------------|-----|------------------------------------------------|
|user_id                                    |str  |userId                                          |
|attendee_notification                      |str  |attendeeNotification *Optional*                 |
|end_collaborate_room_session_on_owner_exit |bool |endCollaborateRoomSessionOnOwnerExit *Optional* |
|owner_required                             |bool |ownerRequired *Optional*                        |
</div>


## `UserCollaborateMyRoomGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request collaborate room settings for MyRoom.

The response is either `UserCollaboratMyRoomGetResponse()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCollaborateMyRoomModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify collaborate room settings for MyRoom.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                       |Type |Description                                     |
|-------------------------------------------|-----|------------------------------------------------|
|user_id                                    |str  |userId                                          |
|room_name                                  |str  |roomName *Optional*                             |
|attendee_notification                      |str  |attendeeNotification *Optional*                 |
|end_collaborate_room_session_on_owner_exit |bool |endCollaborateRoomSessionOnOwnerExit *Optional* |
|owner_required                             |bool |ownerRequired *Optional*                        |
</div>


## `UserCollaborateProjectRoomGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request collaborate room settings for a project room.

The request fails when requesting collaborate room settings for instant rooms or My
Room.

The response is either `UserCollaboratProjectRoomGetResponse()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
|room_id |str |roomId     |
</div>


## `UserCollaborateRoomGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the settings for My Room, Instant Room or Project Room.

The roomType and roomName parameters are returned for all rooms.  For My room and
Project Room, the following parameters are returned: attendeeNotification,
endRoomSessionOnOwnerExit and ownerRequired.  In addition, the roomSchedule is
returned for Project Room and the roomStartTime and roomEndTime are returned for
Instant Room.

The response is either `UserCollaboratetRoomGetResponse()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
|room_id |str |roomId     |
</div>


## `UserCollaborateRoomIDRegenerateRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to regenerate collaborate room id for MyRoom and project room.

The request fails when requesting to regenerate room ID for an instant room.

The response is either a `UserCollaborateRoomIDRegenerateResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
|room_id |str |roomId     |
</div>


## `UserCollaborateRoomListGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the list of collaborate room instances for this specific user.

The response is either a `UserCollaborateRoomListGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCommPilotExpressGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's commPilot express service setting.

The response is either a `UserCommPilotExpressGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCommunicationBarringAuthorizationCodeDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a list of Communication Barring Authorization codes from a user.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type      |Description|
|--------|----------|-----------|
|user_id |str       |userId     |
|code    |List[str] |code       |
</div>


## `UserCommunicationBarringAuthorizationCodeGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of Communication Barring Authorization Code for a user.

The response is either a `UserCommunicationBarringAuthorizationCodeGetListResponse()`
or an `ErorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCommunicationBarringGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Gets the Communication Barring settings for a user.

The response is either a `UserCommunicationBarringGetResponse()` or an
`ErrorResponse()`. This command only applies to groups in an Enterprise.  This command
will fail for groups in a Service Provider.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCommunicationBarringModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Communication Barring settings for a user.

If useDefaultServiceProviderProfile is set to false, a profile name must be present.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. This command
only applies to groups in an Enterprise.  This command will fail for groups in a
Service Provider.

**Attributes:**

|Name              |Type |Description                |
|------------------|-----|---------------------------|
|user_id           |str  |userId                     |
|use_group_setting |bool |useGroupSetting *Optional* |
|profile_name      |str  |profileName *Optional*     |
</div>


## `UserCommunicationBarringUserControlGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Lists the Communication Barring profiles available to a user and indicates which
profile if any is currently active for the user.

.

The response is either `UserCommunicationBarringUserControlGetResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCommunicationBarringUserControlModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Enabling a profile automatically disables the currently active profile.

Also allows the passcode for the service to be modified and the lockout to be reset.
Admins only need to populate the newPasscode field when changing the passcode.  Users
must populate both the oldPasscode and new Passcode fields when changing the passcode.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name           |Type |Description              |
|---------------|-----|-------------------------|
|user_id        |str  |userId                   |
|enable_profile |int  |enableProfile *Optional* |
|old_passcode   |str  |oldPasscode *Optional*   |
|new_passcode   |str  |newPasscode *Optional*   |
|reset_lockout  |bool |resetLockout *Optional*  |
</div>


## `UserConnectedLineIdentificationRestrictionGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Connected Line ID Restriction.

The response is either a `UserConnectedLineIdentificationRestrictionGetResponse()` or
an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserConnectedLineIdentificationRestrictionModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Connected Line ID Restriction.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name      |Type |Description         |
|----------|-----|--------------------|
|user_id   |str  |userId              |
|is_active |bool |isActive *Optional* |
</div>


## `UserConsolidatedDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a user.

If deleteExistingDevices is set to true, after the user is deleted, any device that is
only used by the deleted user prior to the deletion will be deleted if the command is
executed with the correct priviledge.  Group administrator or above running this
command can delete any group level devices.  Service provider administrator or above
can delete any service provider and group devices.  Provisioning administrator or
above can delete any devices.  An `ErrorResponse()` will be returned if any device
cannot be deleted because of insufficient privilege.  If UnassignPhoneNumbersLevel is
set to 'Group', the user's primary phone number, fax number and any alternate numbers,
will be un-assigned from the group if the command is executed by a service provider
administrator or above.  When set to 'Service Provider', they will be un-assigned from
the group and service provider if the command is executed by a provisioning
administrator or above.  When omitted, the number(s) will be left assigned to the
group.  An `ErrorResponse()` will be returned if any number cannot be unassigned
because of insufficient privilege.

**Attributes:**

|Name                    |Type |Description                      |
|------------------------|-----|---------------------------------|
|user_id                 |str  |userId                           |
|delete_existing_devices |bool |deleteExistingDevices *Optional* |
|unassign_phone_numbers  |str  |unassignPhoneNumbers *Optional*  |
</div>


## `UserCustomRingbackUserDeleteCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a criteria from the user's custom ringback service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserCustomRingbackUserGetCriteriaListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's custom ringback service criteria listing.

The response is either a `UserCustomRingbackUserGetCriteriaListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserCustomRingbackUserGetCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a criteria for the user's custom ringback service.

The response is either a `UserCustomRingbackUserGetCriteriaResponse()` or an
`ErrorResponse()`.

Replaced By: UserCustomRingbackUserGetCriteriaRequest15Sp2

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserCustomRingbackUserGetCriteriaRequest15sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a criteria for the user's custom ringback service.

The response is either a `UserCustomRingbackUserGetCriteriaResponse15sp2()` or an
`ErrorResponse()`.

Replaced By: `UserCustomRingbackUserGetCriteriaRequest16()`

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserCustomRingbackUserGetCriteriaRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a criteria for the user's custom ringback service.

The response is either a `UserCustomRingbackUserGetCriteriaResponse16()` or an
`ErrorResponse()`. Replaced by: `UserCustomRingbackUserGetCriteriaRequest20()` in AS
data mode

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserCustomRingbackUserGetCriteriaRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a criteria for the user's custom ringback service.

The response is either a `UserCustomRingbackUserGetCriteriaResponse20()` or an
`ErrorResponse()`. Replaced by: `UserCustomRingbackUserGetCriteriaRequest21()`

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserCustomRingbackUserGetCriteriaRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a criteria for the user's custom ringback service.

The response is either a `UserCustomRingbackUserGetCriteriaResponse21()` or an
`ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a user.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserDeviceActivationPolicyInEffectGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the Device Activation policies in effect for the user.

The response is either a `UserDeviceActivationPolicyInEffectGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserDevicePoliciesGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Device Policy.

The response is either a `UserDevicePoliciesGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserDevicePoliciesGetRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Device Policy.

The response is either a `UserDevicePoliciesGetResponse19sp1()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserDevicePoliciesGetRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Device Policy.

The response is either a `UserDevicePoliciesGetResponse20()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserDevicePoliciesGetRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Device Policy.

The response is either a `UserDevicePoliciesGetResponse21()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserDevicePoliciesModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Device Policy.

enableDeviceFeatureSynchronization and enableCallDecline can be configured by the
admin regardless of lineMode, but is ignored by the application server in Multiple
User Shared mode.  enableCallDecline can be modified by the user when the admin has
set the mode to ‘Single User Private and Shared Lines mode’. This is the only element
that the user can modify.  In XS data mode, the lineMode is ignored and
enabledCallDecline is the only element that can be configured.  The following elements
are only used in AS data mode and ignored in XS data mode: lineMode
enableDeviceFeatureSynchronization enableDnd enableCallForwardingAlways
enableCallForwardingBusy enableCallForwardingNoAnswer enableAcd enableExecutive
enableExecutiveAssistant enableSecurityClassification enableCallRecording

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                  |Type |Description                                   |
|--------------------------------------|-----|----------------------------------------------|
|user_id                               |str  |userId                                        |
|line_mode                             |str  |lineMode *Optional*                           |
|enable_device_feature_synchronization |bool |enableDeviceFeatureSynchronization *Optional* |
|enable_dnd                            |bool |enableDnd *Optional*                          |
|enable_call_forwarding_always         |bool |enableCallForwardingAlways *Optional*         |
|enable_call_forwarding_busy           |bool |enableCallForwardingBusy *Optional*           |
|enable_call_forwarding_no_answer      |bool |enableCallForwardingNoAnswer *Optional*       |
|enable_acd                            |bool |enableAcd *Optional*                          |
|enable_executive                      |bool |enableExecutive *Optional*                    |
|enable_executive_assistant            |bool |enableExecutiveAssistant *Optional*           |
|enable_security_classification        |bool |enableSecurityClassification *Optional*       |
|enable_call_recording                 |bool |enableCallRecording *Optional*                |
|enable_call_decline                   |bool |enableCallDecline *Optional*                  |
</div>


## `UserDirectRouteGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the direct route setting and the list of DTGs/Trunk Identities assigned to a user.

The response is either `UserDirectRouteGetResponse()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserDirectedCallPickupWithBargeInGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Directed Call Pickup With Barge In.

The response is either a `UserDirectedCallPickupWithBargeInGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserDirectedCallPickupWithBargeInGetRequest14sp7`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Directed Call Pickup With Barge In.

The response is either a `UserDirectedCallPickupWithBargeInGetResponse14sp7()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserDirectedCallPickupWithBargeInModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Directed Call Pickup With Barge In.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                              |Type |Description                               |
|----------------------------------|-----|------------------------------------------|
|user_id                           |str  |userId                                    |
|enable_barge_in_warning_tone      |bool |enableBargeInWarningTone *Optional*       |
|enable_automatic_target_selection |bool |enableAutomaticTargetSelection *Optional* |
</div>


## `UserDnGetActivationListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a list of DNs associated with a user and their activation state.

The response is either `UserDnGetActivationListResponse()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserDoNotDisturbGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Do Not Disturb.

The response is either a `UserDoNotDisturbGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserDoNotDisturbModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Do Not Disturb.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Engineering
Note: This command is used internally by Call Processing.

**Attributes:**

|Name        |Type |Description           |
|------------|-----|----------------------|
|user_id     |str  |userId                |
|is_active   |bool |isActive *Optional*   |
|ring_splash |bool |ringSplash *Optional* |
</div>


## `UserEnhancedCallLogsGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request user's call logs.

It is possible to get a subset of the total list of calls by specifying a starting
offset and the number of calls to get.  If the callLogType is not specified, all types
of calls are returned.

The response is either a `UserEnhancedCallLogsGetListResponse()` or an
`ErrorResponse()`.

Replaced By: `UserEnhancedCallLogsGetListRequest14sp4()`

**Attributes:**

|Name            |Type|Description            |
|----------------|----|-----------------------|
|user_id         |str |userId                 |
|call_log_type   |str |callLogType *Optional* |
|starting_offset |int |startingOffset         |
|num_calls       |int |numCalls               |
</div>


## `UserEnhancedCallLogsGetListRequest14sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request user's call logs.

It is possible to get a subset of the total list of calls by specifying a starting
offset and the number of calls to get.  If the callLogType is not specified, all types
of calls are returned.

The response is either a `UserEnhancedCallLogsGetListResponse14sp4()` or an
`ErrorResponse()`. Replaced by: `UserEnhancedCallLogsGetListRequest16()`

**Attributes:**

|Name            |Type|Description            |
|----------------|----|-----------------------|
|user_id         |str |userId                 |
|call_log_type   |str |callLogType *Optional* |
|starting_offset |int |startingOffset         |
|num_calls       |int |numCalls               |
</div>


## `UserExecutiveAssistantGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the setting of an executive assistant.

The response is either `UserExecutiveAssistantGetResponse()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserExecutiveDeleteFilteringSelectiveCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a filtering criteria from an executive user.

Both executive and the executive assistant can run this command.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserExecutiveGetAssistantRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the assistant setting and the list of assistants assigned to an executive.

The response is either `UserExecutiveGetAssistantsResponse()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserExecutiveGetFilteringRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the filtering setting and the list of filtering criteria defined for an executive
user.

Both executive and the executive assistant can run this command.

The response is either `UserExecutiveGetFilteringResponse()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserExecutiveGetFilteringSelectiveCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a filtering criteria for an executive user.

Both executive and the executive assistant can run this command.

The response is either `UserExecutiveGetSelectiveCriteriaResponse()` or
`ErrorResponse()`. Replaced by:
`UserExecutiveGetFilteringSelectiveCriteriaRequest21()`

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserExecutiveGetFilteringSelectiveCriteriaRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a filtering criteria for an executive user.

Both executive and the executive assistant can run this command.

The response is either `UserExecutiveGetSelectiveCriteriaResponse21()` or
`ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserExecutiveGetScreeningAlertingRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the screening and alerting setting of an executive.

Both executive and the executive assistant can run this command.

The response is either `UserExecutiveGetScreeningAlertingResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserExecutiveModifyScreeningAlertingRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the screening and alerting setting of an executive.

Both executive and the executive assistant can run this command.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                         |Type |Description                                       |
|---------------------------------------------|-----|--------------------------------------------------|
|user_id                                      |str  |userId                                            |
|enable_screening                             |bool |enableScreening *Optional*                        |
|screening_alert_type                         |str  |screeningAlertType *Optional*                     |
|alert_broad_works_mobility_location          |bool |alertBroadWorksMobilityLocation *Optional*        |
|alert_broad_works_anywhere_locations         |bool |alertBroadWorksAnywhereLocations *Optional*       |
|alert_shared_call_appearance_locations       |bool |alertSharedCallAppearanceLocations *Optional*     |
|alerting_mode                                |str  |alertingMode *Optional*                           |
|alerting_calling_line_id_name_mode           |str  |alertingCallingLineIdNameMode *Optional*          |
|alerting_custom_calling_line_id_name         |str  |alertingCustomCallingLineIdName *Optional*        |
|unicode_alerting_custom_calling_line_id_name |str  |unicodeAlertingCustomCallingLineIdName *Optional* |
|alerting_calling_line_id_phone_number_mode   |str  |alertingCallingLineIdPhoneNumberMode *Optional*   |
|alerting_custom_calling_line_id_phone_number |str  |alertingCustomCallingLineIdPhoneNumber *Optional* |
|call_push_recall_number_of_rings             |int  |callPushRecallNumberOfRings *Optional*            |
|next_assistant_number_of_rings               |int  |nextAssistantNumberOfRings *Optional*             |
|enable_rollover                              |bool |enableRollover *Optional*                         |
|rollover_wait_time_seconds                   |int  |rolloverWaitTimeSeconds *Optional*                |
|rollover_action                              |str  |rolloverAction *Optional*                         |
|rollover_forward_to_phone_number             |str  |rolloverForwardToPhoneNumber *Optional*           |
</div>


## `UserExternalCallingLineIDDeliveryGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with External Calling Line ID Delivery.

The response is either a `UserExternalCallingLineIDDeliveryGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserExternalCallingLineIDDeliveryModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with External Calling Line ID Delivery.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name      |Type |Description         |
|----------|-----|--------------------|
|user_id   |str  |userId              |
|is_active |bool |isActive *Optional* |
</div>


## `UserExternalCustomRingbackGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with External Custom Ringback.

The response is either a `UserExternalCustomRingbackGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserExternalCustomRingbackModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with External Custom Ringback.

The user SIP URI, when selected, it replaces the SP address, port and prefix.  The
user SIP URI, if selected, is the Request URI of the SIP INVITE sent to the external
server.  When the service provider data is used instead, the Request URI is
constructed using the prefix, address, port and the user DN. The timeout value is the
only SP configuration used when the user SIP URI is selected.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name              |Type |Description                |
|------------------|-----|---------------------------|
|user_id           |str  |userId                     |
|is_active         |bool |isActive *Optional*        |
|use_setting_level |str  |useSettingLevel *Optional* |
|sip_request_uri   |str  |sipRequestURI *Optional*   |
</div>


## `UserFaxMessagingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Fax Messaging.

The response is either a `UserFaxMessagingGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserFaxMessagingGetRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Fax Messaging.

The response is either a `UserFaxMessagingGetResponse17()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserFaxMessagingGetRequest17sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Fax Messaging.

The response is either a `UserFaxMessagingGetResponse17sp1()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserFeatureAccessCodeGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of feature access codes for a user.

The response is either a `UserFeatureAccessCodeGetListResponse()` or an
`ErrorResponse()`. Replaced by: `UserFeatureAccessCodeGetListRequest20()` in AS data
mode

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserFeatureAccessCodeGetListRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of feature access codes for a user.

The response is either a `UserFeatureAccessCodeGetListResponse20()` or an
`ErrorResponse()`. In release 20 the "Call Recording" FAC name is changed to "Call
Recording Start". Replaced by: `UserFeatureAccessCodeGetListRequest21()` in AS data
mode

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserFeatureAccessCodeGetListRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of feature access codes for a user.

The response is either a `UserFeatureAccessCodeGetListResponse20()` or an
`ErrorResponse()`. In release 20 the "Call Recording" FAC name is changed to "Call
Recording Start".

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserFlexibleSeatingGuestGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with flexible seating guest.

The response is either a `UserFlexibleSeatingGuestGetResponse()` or an
`ErrorResponse()`. Replaced by: `UserFlexibleSeatingGuestGetRequest22()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserFlexibleSeatingGuestGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with flexible seating guest.

The response is either a `UserFlexibleSeatingGuestGetResponse22()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserGetLoginInfoRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
`UserGetLoginInfoRequest()` is used to access login information for a user either by a
userId or dn.

The phone number may be any DN associated with a user.

The response is a `UserGetLoginInfoResponse()` or an `ErrorResponse()` Replaced by
`UserGetLoginInfoRequest22()`.

**Attributes:**

|Name         |Type|Description            |
|-------------|----|-----------------------|
|user_id      |str |userId *Optional*      |
|phone_number |str |phoneNumber *Optional* |
</div>


## `UserGetLoginInfoRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
`UserGetLoginInfoRequest21sp1()` is used to access login information for a user either
by a userId, dn or lineport.

The phone number may be any DN associated with a user.  The lineport may be any
lineport associated with a user.

The response is a `UserGetLoginInfoResponse21sp1()` or an `ErrorResponse()` Replaced
by `UserGetLoginInfoRequest22V2()`.

**Attributes:**

|Name         |Type|Description            |
|-------------|----|-----------------------|
|user_id      |str |userId *Optional*      |
|phone_number |str |phoneNumber *Optional* |
|line_port    |str |linePort *Optional*    |
</div>


## `UserGetLoginInfoRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
`UserGetLoginInfoRequest22()` is used to access login information for a user either by
a userId, dn or lineport.

The phone number may be any DN associated with a user.  The lineport may be any
lineport associated with a user.

The response is a `UserGetLoginInfoResponse22()` or an `ErrorResponse()` Replaced by
`UserGetLoginInfoRequest22V2()`.

**Attributes:**

|Name         |Type|Description            |
|-------------|----|-----------------------|
|user_id      |str |userId *Optional*      |
|phone_number |str |phoneNumber *Optional* |
|line_port    |str |linePort *Optional*    |
</div>


## `UserGetLoginInfoRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
`UserGetLoginInfoRequest22V2()` is used to access login information for a user either
by a userId, dn or lineport.

The phone number may be any DN associated with a user.  The lineport may be any
lineport associated with a user.

The response is a `UserGetLoginInfoResponse22V2()` or an `ErrorResponse()` Replaced by
`UserGetLoginInfoRequest22V3()`.

**Attributes:**

|Name         |Type|Description            |
|-------------|----|-----------------------|
|user_id      |str |userId *Optional*      |
|phone_number |str |phoneNumber *Optional* |
|line_port    |str |linePort *Optional*    |
</div>


## `UserGetLoginInfoRequest22V3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
`UserGetLoginInfoRequest22V3()` is used to access login information for a user either
by a userId, dn or lineport.

The phone number may be any DN associated with a user.  The lineport may be any
lineport associated with a user.

The response is a `UserGetLoginInfoResponse22V3()` or an `ErrorResponse()`. The
following elements are only used in AS data mode and ignored in XS and Amplify data
mode.  loginRole

**Attributes:**

|Name         |Type|Description            |
|-------------|----|-----------------------|
|user_id      |str |userId *Optional*      |
|login_role   |str |loginRole *Optional*   |
|phone_number |str |phoneNumber *Optional* |
|line_port    |str |linePort *Optional*    |
</div>


## `UserGetLoginInfoRequest22V4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
`UserGetLoginInfoRequest22V4()` is used to access login information for a user either
by a userId, dn or lineport.

The phone number may be any DN associated with a user.  The lineport may be any
lineport associated with a user.

The response is a `UserGetLoginInfoResponse22V4()` or an `ErrorResponse()`. The
following elements are only used in AS data mode and ignored in XS and Amplify data
mode.  loginRole

**Attributes:**

|Name         |Type|Description            |
|-------------|----|-----------------------|
|user_id      |str |userId *Optional*      |
|login_role   |str |loginRole *Optional*   |
|phone_number |str |phoneNumber *Optional* |
|line_port    |str |linePort *Optional*    |
</div>


## `UserGetRegistrationListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a list of registrations for a user.

The response is either a `UserGetRegistrationListResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserGetRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the user information.

The response is either `UserGetResponse14()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserGetRequest14sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the user information.

The response is either `UserGetResponse14sp4()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserGetRequest14sp9`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the user information.

The response is either `UserGetResponse14sp4()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserGetRequest15sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the user information.

The response is either `UserGetResponse15sp2()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserGetRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Replaced By `UserGetRequest17sp4()` Request to get the user information.

The response is either `UserGetResponse17()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserGetRequest17sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Replaced By `UserGetRequest18()` Request to get the user information.

The response is either `UserGetResponse17sp3()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserGetRequest17sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Replaced By `UserGetRequest18()` Request to get the user information.

The response is either `UserGetResponse17sp4()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserGetRequest18`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the user information.

The response is either `UserGetResponse18()` or `ErrorResponse()`. Replaced by:
`UserGetRequest19()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserGetRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the user information.

The response is either `UserGetResponse19()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserGetRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the user information.

The response is either `UserGetResponse20()` or `ErrorResponse()`. Replaced by:
`UserGetRequest21()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserGetRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the user information.

The response is either `UserGetResponse21()` or `ErrorResponse()`. Replaced by
`UserGetRequest21sp1()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserGetRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the user information.

The response is either `UserGetResponse21sp1()` or `ErrorResponse()`. Replaced by
`UserGetRequest22()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the user information.

The response is either `UserGetResponse22()` or `ErrorResponse()`. Replaced by
`UserGetRequest22V2()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserGetRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the user information.

The response is either `UserGetResponse22V2()` or `ErrorResponse()`. Replaced by
`UserGetRequest22V3()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserGetRequest22V3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the user information.

The response is either `UserGetResponse22V3()` or `ErrorResponse()`. Replaced by:
`UserGetRequest22V4()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserGetRequest22V4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the user information.

The response is either `UserGetResponse22V4()` or `ErrorResponse()`. Replaced by:
`UserGetResponse22V5()` in AS data mode

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserGetRequest22V5`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the user information.

The response is either `UserGetResponse22V5()` or `ErrorResponse()`. Replaced by:
`UserGetRequest22V6()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserGetRequest22V6`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the user information.

The response is either `UserGetResponse22V6()` or `ErrorResponse()`. Replaced by:
`UserGetRequest22V7()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserGetRequest22V7`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the user information.

The response is either `UserGetResponse22V7()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserGetRequest22V8`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the user information.

The response is either `UserGetResponse22V8()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserGroupNightForwardingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the Group Night Forwarding user parameters.

The response is either `UserGroupNightForwardingGetResponse()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserGroupNightForwardingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the Group Night Forwarding user parameters.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name             |Type|Description                |
|-----------------|----|---------------------------|
|user_id          |str |userId                     |
|night_forwarding |str |nightForwarding *Optional* |
</div>


## `UserGroupPagingGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of all the Paging Groups a user was assigned as an originator.

The response is either a `UserGroupPagingGetListResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserHolidayScheduleDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a holiday schedule from a user.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                  |Type|Description         |
|----------------------|----|--------------------|
|user_id               |str |userId              |
|holiday_schedule_name |str |holidayScheduleName |
</div>


## `UserHolidayScheduleGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a holiday schedule list for a user.

The response is either a `UserHolidayScheduleGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserHolidayScheduleGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a holiday schedule a user.

The response is either a `UserHolidayScheduleGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                  |Type|Description         |
|----------------------|----|--------------------|
|user_id               |str |userId              |
|holiday_schedule_name |str |holidayScheduleName |
</div>


## `UserHotelingGuestGetRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Hoteling Guest.

The response is either a `UserHotelingGuestGetResponse14()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserHotelingGuestGetRequest14sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Hoteling Guest.

The response is either a `UserHotelingGuestGetResponse14()` or an `ErrorResponse()`.
Replaced by: `UserHotelingGuestGetRequest14sp4()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserHotelingGuestGetRequest14sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Hoteling Guest.

The response is either a `UserHotelingGuestGetResponse14sp4()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserHotelingGuestModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Hoteling Guest.

There is no provisioning error will be given when setting hostUserId to not nil value
while Hoteling Guest feature is not active.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by
`UserHotelingGuestModifyRequest21()` in AS data mode

**Attributes:**

|Name                     |Type |Description                       |
|-------------------------|-----|----------------------------------|
|user_id                  |str  |userId                            |
|is_active                |bool |isActive *Optional*               |
|enable_association_limit |bool |enableAssociationLimit *Optional* |
|association_limit_hours  |int  |associationLimitHours *Optional*  |
|host_user_id             |str  |hostUserId *Optional*             |
</div>


## `UserHotelingGuestModifyRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Hoteling Guest.

Provisioning error will be given when setting hostUserId to not nil value while
Hoteling Guest feature is not active.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type |Description                       |
|-------------------------|-----|----------------------------------|
|user_id                  |str  |userId                            |
|is_active                |bool |isActive *Optional*               |
|enable_association_limit |bool |enableAssociationLimit *Optional* |
|association_limit_hours  |int  |associationLimitHours *Optional*  |
|host_user_id             |str  |hostUserId *Optional*             |
</div>


## `UserHotelingHostGetRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Hoteling Host.

The response is either a `UserHotelingHostGetResponse14()` or an `ErrorResponse()`.
Replaced by: `UserHotelingHostGetRequest14sp4()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserHotelingHostGetRequest14sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Hoteling Host.

The response is either a `UserHotelingHostGetResponse14sp4()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserHotelingHostGetRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Hoteling Host.

The response is either a `UserHotelingHostGetResponse17()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserHotelingHostModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Hoteling Host.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                      |Type |Description                        |
|--------------------------|-----|-----------------------------------|
|user_id                   |str  |userId                             |
|is_active                 |bool |isActive *Optional*                |
|enforce_association_limit |bool |enforceAssociationLimit *Optional* |
|association_limit_hours   |int  |associationLimitHours *Optional*   |
|access_level              |str  |accessLevel *Optional*             |
|remove_guest_association  |bool |removeGuestAssociation *Optional*  |
</div>


## `UserINIntegrationGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the user level IN Integration service attributes Response is either
`UserINIntegrationGetResponse()` or `ErrorResponse()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserINIntegrationModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the user level IN Integration service attributes Response is either
`SuccessResponse()` or `ErrorResponse()`

**Attributes:**

|Name                    |Type|Description                      |
|------------------------|----|---------------------------------|
|user_id                 |str |userId                           |
|originating_service_key |int |originatingServiceKey *Optional* |
|terminating_service_key |int |terminatingServiceKey *Optional* |
</div>


## `UserInCallServiceActivationGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with In-Call Service Activation.

The response is either a `UserInCallServiceActivationGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserInCallServiceActivationModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with In-Call Service Activation.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name      |Type |Description         |
|----------|-----|--------------------|
|user_id   |str  |userId              |
|is_active |bool |isActive *Optional* |
</div>


## `UserIncomingCallingPlanGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user's incoming calling plan settings.

The response is either a `UserIncomingCallingPlanGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserIntegratedIMPGeneratePasswordRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Generate a new IMP password for the user.

The new generated password is synchronized to BroadCloud/service Messaging Server.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserIntegratedIMPGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the Integrated IMP specific service attribute for the user.

The response is either `UserIMPGetResponse()` or `ErrorResponse()`. Replaced by:
`UserIntegratedIMPGetRequest21sp1()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserIntegratedIMPGetRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the Integrated IMP specific service attribute for the user.

The response is either `UserIMPGetResponse21sp1()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserIntegratedIMPModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the Integrated IMP specific service attribute for the user.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. If the impId
element is set in the request, the impId element does not take effect on the service
for the user unless the request also has the isActive element set to true to turn the
service from off to on.  If impId is based on an alternate user ID and the impId and
userId are identical, isAlternateImpId should be set to true to determine that impId
is the user's alternate ID. The following elements are only used in AS data mode and
ignored in XS data mode: impId isAlternateImpId

**Attributes:**

|Name                |Type |Description                 |
|--------------------|-----|----------------------------|
|user_id             |str  |userId                      |
|is_active           |bool |isActive *Optional*         |
|imp_id              |str  |impId *Optional*            |
|is_alternate_imp_id |bool |isAlternateImpId *Optional* |
</div>


## `UserInterceptUserGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's intercept user service settings.

The response is either a `UserInterceptUserGetResponse()` or an `ErrorResponse()`.

Replaced By: `UserInterceptUserGetRequest16()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserInterceptUserGetRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's intercept user service settings.

The response is either a `UserInterceptUserGetResponse16()` or an `ErrorResponse()`.

Replaced By: `UserInterceptUserGetRequest16sp1()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserInterceptUserGetRequest16sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's intercept user service settings.

The response is either a `UserInterceptUserGetResponse16sp1()` or an
`ErrorResponse()`. Replaced by: `UserInterceptUserGetRequest21sp1()` in AS data mode

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserInterceptUserGetRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's intercept user service settings.

The response is either a `UserInterceptUserGetResponse21sp1()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserInternalCallingLineIDDeliveryGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Internal Calling Line ID Delivery.

The response is either a `UserInternalCallingLineIDDeliveryGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserInternalCallingLineIDDeliveryModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Internal Calling Line ID Delivery.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name      |Type |Description         |
|----------|-----|--------------------|
|user_id   |str  |userId              |
|is_active |bool |isActive *Optional* |
</div>


## `UserLegacyAutomaticCallbackGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Legacy Automatic Callback.

The response is either a `UserLegacyAutomaticCallbackGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserLegacyAutomaticCallbackModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Legacy Automatic Callback.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name      |Type |Description         |
|----------|-----|--------------------|
|user_id   |str  |userId              |
|is_active |bool |isActive *Optional* |
</div>


## `UserLinePortGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all user's configured line ports.


**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserMWIDeliveryToMobileEndpointGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with MWI Delivery to Mobile Endpoint service.

The response is either a `UserMWIDeliveryToMobileEndpointGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserMWIDeliveryToMobileEndpointModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the user level data associated with MWI Delivery to Mobile Endpoint
service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type |Description                  |
|--------------------|-----|-----------------------------|
|user_id             |str  |userId                       |
|is_active           |bool |isActive *Optional*          |
|mobile_phone_number |str  |mobilePhoneNumber *Optional* |
</div>


## `UserMaliciousCallTraceGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Malicious Call Trace.

The response is either a `UserMaliciousCallTraceGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserMeetMeConferencingGetBridgeListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of Meet-Me Conferencing bridges for which the user is a host.

The response is either `UserMeetMeConferencingGetBridgeListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserMeetMeConferencingGetConferenceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of all conferences for which user is a host or a delegate.

The response is either `UserMeetMeConferencingGetConferenceListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name      |Type|Description         |
|----------|----|--------------------|
|user_id   |str |userId              |
|bridge_id |str |bridgeId *Optional* |
</div>


## `UserMeetMeConferencingGetConferenceRecordingListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of recordings of the conferences owned by the host.

The response is either `UserMeetMeConferencingGetConferenceRecordingListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserModifyGroupIdRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Move the user from one group to another group within the same enterprise.

If evaluateOnly is specified, no actual move will happen.  The command only tests the
move and reports the impacts or possible conditions preventing the move.

The response is either `UserModifyGroupIdResponse()` or `ErrorResponse()`.

**Attributes:**

|Name          |Type |Description             |
|--------------|-----|------------------------|
|user_id       |str  |userId                  |
|new_group_id  |str  |newGroupId              |
|evaluate_only |bool |evaluateOnly *Optional* |
</div>


## `UserModifyUserIdRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user id of a real or virtual user.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|user_id     |str |userId     |
|new_user_id |str |newUserId  |
</div>


## `UserMusicOnHoldGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Music On Hold.

The response is either a `UserMusicOnHoldGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserMusicOnHoldModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Music On Hold.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name      |Type |Description         |
|----------|-----|--------------------|
|user_id   |str  |userId              |
|is_active |bool |isActive *Optional* |
</div>


## `UserMusicOnHoldUserGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Music On Hold User.

The response is either a `UserMusicOnHoldUserGetResponse()` or an `ErrorResponse()`.

Replaced By: `UserMusicOnHoldUserGetRequest16()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserMusicOnHoldUserGetRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Music On Hold User.

The response is either a `UserMusicOnHoldUserGetResponse16()` or an `ErrorResponse()`.
Replaced by: `UserMusicOnHoldUserGetRequest20()` in AS data mode

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserMusicOnHoldUserGetRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Music On Hold User.

The response is either a `UserMusicOnHoldUserGetResponse20()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserNetworkConferencingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the Network-Based Conferencing data for a specified user.

The response is either a `UserNetworkConferencingGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserNumberPortabilityAnnouncementGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the Number Portability Announcement attributes for the user.

The response is either `UserNumberPortabilityAnnouncementGetResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserNumberPortabilityAnnouncementModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Number Portability Announcement attributes for the user.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type |Description       |
|--------|-----|------------------|
|user_id |str  |userId            |
|enable  |bool |enable *Optional* |
</div>


## `UserOCICallControlApplicationGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the OCI call control application list that can be used by the user.

The response is either `UserOCICallControlApplicationGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserOutgoingCallingPlanAuthorizationCodeDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a list of authorization codes from a user.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type      |Description|
|--------|----------|-----------|
|user_id |str       |userId     |
|code    |List[str] |code       |
</div>


## `UserOutgoingCallingPlanAuthorizationCodeGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the list of authorization codes for a user.

The response is either a `UserOutgoingCallingPlanAuthorizationCodeGetListResponse()`
or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserOutgoingCallingPlanAuthorizationCodeGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the authorization code setting for a user.

The response is either a `UserOutgoingCallingPlanAuthorizationCodeGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserOutgoingCallingPlanAuthorizationCodeModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the authorization setting for a user.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type |Description                  |
|--------------------|-----|-----------------------------|
|user_id             |str  |userId                       |
|use_custom_settings |bool |useCustomSettings *Optional* |
</div>


## `UserOutgoingCallingPlanCallMeNowGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the Call Me Now call permissions for a user.

The response is either a `UserOutgoingCallingPlanCallMeNowGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserOutgoingCallingPlanDigitPlanCallMeNowGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the Call Me Now call permissions for digit patterns for a user.

The response is either a `UserOutgoingCallingPlanDigitPlanCallMeNowGetResponse()` or
an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserOutgoingCallingPlanDigitPlanOriginatingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the originating permissions for digit patterns for a user.

The response is either a `UserOutgoingCallingPlanDigitPlanOriginatingGetResponse()` or
an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserOutgoingCallingPlanDigitPlanRedirectingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the redirecting permissions for digit patterns for a user.

The response is either a `UserOutgoingCallingPlanDigitPlanRedirectingGetResponse()` or
an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserOutgoingCallingPlanOriginatingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the originating permissions for a user.

The response is either a `UserOutgoingCallingPlanOriginatingGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserOutgoingCallingPlanPinholeDigitPlanCallMeNowGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the Call Me Now permissions for Pinhole digit patterns for a user.

The response is either a
`UserOutgoingCallingPlanPinholeDigitPlanCallMeNowgGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserOutgoingCallingPlanPinholeDigitPlanOriginatingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the originating permissions for Pinhole digit patterns for a user.

The response is either a
`UserOutgoingCallingPlanPinholeDigitPlanOriginatingGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserOutgoingCallingPlanPinholeDigitPlanRedirectingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the redirecting permissions for Pinhole digit patterns for a user.

The response is either a
`UserOutgoingCallingPlanPinholeDigitPlanRedirectingGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserOutgoingCallingPlanRedirectedGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the call forwarded/transferred permissions for a user.

The response is either a `UserOutgoingCallingPlanRedirectedGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserOutgoingCallingPlanRedirectingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the initiating call forwards/transfer permissions for a user.

The response is either a `UserOutgoingCallingPlanRedirectingGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserOutgoingCallingPlanSustainedAuthorizationCodeGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the sustained authorization code setting for a user.

The response is either a
`UserOutgoingCallingPlanSustainedAuthorizationCodeGetResponse()` or an
`ErrorResponse()`. Engineering Note: This command is used internally by Call
Processing.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserOutgoingCallingPlanSustainedAuthorizationCodeModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify or clear the sustained authorization code for a user.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Engineering
Note: This command is used internally by Call Processing.

**Attributes:**

|Name    |Type|Description     |
|--------|----|----------------|
|user_id |str |userId          |
|code    |str |code *Optional* |
</div>


## `UserOutgoingCallingPlanTransferNumbersGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the transfer numbers for a user.

The response is either a `UserOutgoingCallingPlanTransferNumbersGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserPBXIntegrationGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with PBX Integration service.

The response is either a `UserPBXIntegrationGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserPBXIntegrationModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with PBX Integration service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                         |Type |Description                         |
|-----------------------------|-----|------------------------------------|
|user_id                      |str  |userId                              |
|proxy_to_header_from_network |bool |proxyToHeaderFromNetwork *Optional* |
</div>


## `UserPasswordInfoGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user's Web password information.

The response is either a `UserPasswordInfoGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserPersonalAssistantCallToNumberGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the user assigned Call to Number List information.

The response is either a `UserPersonalAssistantCallToNumberGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserPersonalAssistantExclusionNumberAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a User Personal Assistant Exclusion Number.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name             |Type|Description            |
|-----------------|----|-----------------------|
|user_id          |str |userId                 |
|exclusion_number |str |exclusionNumber        |
|description      |str |description *Optional* |
</div>


## `UserPersonalAssistantExclusionNumberDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a list of User Personal Assistant Exclusion Number.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name             |Type      |Description     |
|-----------------|----------|----------------|
|user_id          |str       |userId          |
|exclusion_number |List[str] |exclusionNumber |
</div>


## `UserPersonalAssistantExclusionNumberGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a Personal Assistant Exclusion Number.

The response is either `UserPersonalAssistantExclusionNumberGetResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name             |Type|Description     |
|-----------------|----|----------------|
|user_id          |str |userId          |
|exclusion_number |str |exclusionNumber |
</div>


## `UserPersonalAssistantExclusionNumberModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an existing User Personal Assistant Exclusion Number description.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name             |Type|Description            |
|-----------------|----|-----------------------|
|user_id          |str |userId                 |
|exclusion_number |str |exclusionNumber        |
|description      |str |description *Optional* |
</div>


## `UserPersonalAssistantGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the User Personal Assistant information.

The response is either a `UserPersonalAssistantGetResponse()` or an `ErrorResponse()`.
Replaced by: `UserPersonalAssistantGetRequest22()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserPersonalAssistantGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the User Personal Assistant information.

The response is either a `UserPersonalAssistantGetResponse22()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserPersonalAssistantModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the User Personal Assistant information.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                           |Type |Description                          |
|-------------------------------|-----|-------------------------------------|
|user_id                        |str  |userId                               |
|presence                       |str  |presence *Optional*                  |
|enable_transfer_to_attendant   |bool |enableTransferToAttendant *Optional* |
|attendant_number               |str  |attendantNumber *Optional*           |
|enable_ring_splash             |bool |enableRingSplash *Optional*          |
|enable_expiration_time         |bool |enableExpirationTime *Optional*      |
|expiration_time                |str  |expirationTime *Optional*            |
|alert_me_first                 |bool |alertMeFirst *Optional*              |
|alert_me_first_number_of_rings |int  |alertMeFirstNumberOfRings *Optional* |
</div>


## `UserPersonalPhoneListDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete one or more entries from a user's personal phone list.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name       |Type      |Description|
|-----------|----------|-----------|
|user_id    |str       |userId     |
|entry_name |List[str] |entryName  |
</div>


## `UserPersonalPhoneListModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an entry in a user's personal phone list.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name           |Type|Description             |
|---------------|----|------------------------|
|user_id        |str |userId                  |
|entry_name     |str |entryName               |
|new_entry_name |str |newEntryName *Optional* |
|phone_number   |str |phoneNumber *Optional*  |
</div>


## `UserPhoneDirectoryGetSearchedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a table containing the phone directory for a user.

If the specified user is part of an enterprise, the directory includes all users in
the enterprise and all entries in the enterprise common phone list and the common
phone list of the specified user's group.  If the specified user is part of a service
provider, the directory includes all users in the user's group and all entries in the
common phone list of the specified user's group.  It is possible to search the
directory for names containing a specified search string.  The search includes matches
on first name or last name or common phone list names.

The response is either `UserPhoneDirectoryGetSearchedListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name               |Type|Description                 |
|-------------------|----|----------------------------|
|user_id            |str |userId                      |
|name_search_string |str |nameSearchString *Optional* |
</div>


## `UserPhysicalLocationGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Physical Location.

The response is either a `UserPhysicalLocationGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserPhysicalLocationModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Physical Location.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name      |Type |Description         |
|----------|-----|--------------------|
|user_id   |str  |userId              |
|is_active |bool |isActive *Optional* |
</div>


## `UserPolycomPhoneServicesGetPrimaryEndpointListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user's list of device profiles on which the user is the primary user.

The response is either a `UserPolycomPhoneServicesGetPrimaryEndpointListResponse()` or
an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserPortalPasscodeGetInfoRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user's portal passcode information.

The response is either a `UserPortalPasscodeGetInfoResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserPortalPasscodeModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's Portal passcode The response is either a `SuccessResponse()` or an
`ErrorResponse()`.

The following elements are only used in XS data mode and ignored in AS data mode:
oldPasscode

**Attributes:**

|Name         |Type|Description            |
|-------------|----|-----------------------|
|user_id      |str |userId                 |
|old_passcode |str |oldPasscode *Optional* |
|new_passcode |str |newPasscode            |
</div>


## `UserPortalPasscodeRulesGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the effective passcode rules setting for a user.

The response is either `UserPortalPasscodeRulesGetResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description                  |
|--------------------|----|-----------------------------|
|user_id             |str |userId *Optional*            |
|service_provider_id |str |serviceProviderId *Optional* |
|group_id            |str |groupId *Optional*           |
</div>


## `UserPreAlertingAnnouncementDeleteCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a criteria from the user's pre-alerting service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserPreAlertingAnnouncementGetCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a criteria for the user's pre-alerting service.

The response is either a `UserPreAlertingAnnouncementGetCriteriaResponse()` or an
`ErrorResponse()`. Replaced by: `UserPreAlertingAnnouncementGetCriteriaRequest21()` in
AS data mode

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserPreAlertingAnnouncementGetCriteriaRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a criteria for the user's pre-alerting service.

The response is either a `UserPreAlertingAnnouncementGetCriteriaResponse21()` or an
`ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserPreAlertingAnnouncementGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's pre-alerting service setting.

The response is either a `UserPreAlertingAnnouncementGetResponse()` or an
`ErrorResponse()`. Replaced by: `UserPreAlertingAnnouncementGetRequest20()` in AS data
mode

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserPreAlertingAnnouncementGetRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's pre-alerting service setting.

The response is either a `UserPreAlertingAnnouncementGetResponse20()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserPreferredCarrierUserGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the currently configured preferred carriers for a user.

The response is either a `UserPreferredCarrierUserGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserPrepaidGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Prepaid.

The response is either a `UserPrepaidGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserPrepaidModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Prepaid.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Engineering
Note: This command is used internally by Call Processing.

**Attributes:**

|Name      |Type |Description         |
|----------|-----|--------------------|
|user_id   |str  |userId              |
|is_active |bool |isActive *Optional* |
</div>


## `UserPrimaryEndpointAdvancedSettingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the Users Primary Endpoint setting.

The response is either a `UserPrimaryEndpointAdvancedSettingGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserPrimaryEndpointAdvancedSettingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Users Primary Endpoint line control settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in XS data mode and ignored in AS data mode: allowVideo

**Attributes:**

|Name              |Type |Description                 |
|------------------|-----|----------------------------|
|user_id           |str  |userId                      |
|allow_origination |bool |allowOrigination *Optional* |
|allow_termination |bool |allowTermination *Optional* |
|allow_video       |bool |allowVideo *Optional*       |
</div>


## `UserPriorityAlertDeleteCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a criteria from the user's priority alert service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserPriorityAlertGetCriteriaListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's priority alert criteria listing.

The response is either a `UserPriorityAlertGetCriteriaListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserPriorityAlertGetCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a criteria for the user's priority alert service.

The response is either a `UserPriorityAlertGetCriteriaResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserPriorityAlertGetCriteriaRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a criteria for the user's priority alert service.

The response is either a `UserPriorityAlertGetCriteriaResponse16()` or an
`ErrorResponse()`. Replaced by: `UserPriorityAlertGetCriteriaRequest21()` in AS data
mode

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserPriorityAlertGetCriteriaRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a criteria for the user's priority alert service.

The response is either a `UserPriorityAlertGetCriteriaResponse21()` or an
`ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserPrivacyGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Privacy.

The response is either a `UserPrivacyGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserPrivacyGetRequest13mp17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Privacy.

This command is supported for regular users only.

The response is either a `UserPrivacyGetResponse13mp17()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserPushNotificationGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the push notification settings for a user.

The response is either `UserPushNotificationGetResponse()` or `ErrorResponse()`.
Replaced by: `UserPushNotificationRequest24()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserPushNotificationGetRequest24`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the push notification settings for a user.

The response is either `UserPushNotificationGetResponse24()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserPushNotificationModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the push notification settings for a user.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                     |Type |Description                                   |
|-----------------------------------------|-----|----------------------------------------------|
|user_id                                  |str  |userId                                        |
|send_push_notification_for_click_to_dial |bool |sendPushNotificationForClickToDial *Optional* |
|send_push_notification_for_group_paging  |bool |sendPushNotificationForGroupPaging *Optional* |
</div>


## `UserPushNotificationRegistrationDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to remove a push notification registration.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description    |
|----------------|----|---------------|
|registration_id |str |registrationId |
</div>


## `UserPushNotificationRegistrationGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a table containing all of the push notification registrations for a user by
either registration id or user id.

The response is either `UserPushNotificationRegistrationGetListResponse()` or
`ErrorResponse()`. Replaced by:
`UserPushNotificationRegistrationGetListRequest21sp1()`

**Attributes:**

|Name            |Type|Description               |
|----------------|----|--------------------------|
|registration_id |str |registrationId *Optional* |
|user_id         |str |userId *Optional*         |
</div>


## `UserPushNotificationRegistrationGetListRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a list of all of the push notification registrations for a user by either
registration id or user id.

The response is either `UserPushNotificationRegistrationGetListResponse21sp1()` or
`ErrorResponse()`.

**Attributes:**

|Name            |Type|Description               |
|----------------|----|--------------------------|
|registration_id |str |registrationId *Optional* |
|user_id         |str |userId *Optional*         |
</div>


## `UserPushToTalkGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the push to talk service setting.

The response is either a `UserPushToTalkGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserRemoteOfficeGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Remote Office.

The response is either a `UserRemoteOfficeGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserRemoteOfficeModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Remote Office.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                       |Type |Description                        |
|---------------------------|-----|-----------------------------------|
|user_id                    |str  |userId                             |
|is_active                  |bool |isActive *Optional*                |
|remote_office_phone_number |str  |remoteOfficePhoneNumber *Optional* |
</div>


## `UserResourcePriorityGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the Resource Priority settings of a user.

The response is either `UserResourcePriorityGetResponse()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserResourcePriorityModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Resource Priority settings of a user.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                          |Type |Description                           |
|------------------------------|-----|--------------------------------------|
|user_id                       |str  |userId                                |
|use_default_resource_priority |bool |useDefaultResourcePriority *Optional* |
|user_resource_priority        |str  |userResourcePriority *Optional*       |
</div>


## `UserRouteListGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the route list setting and the list of number ranges assigned to a user.

The response is either `UserRouteListGetResponse()` or `ErrorResponse()`. Replaced by:
`UserRouteListGetRequest22()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserRouteListGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the route list setting and the list of number ranges assigned to a user.

The response is either `UserRouteListGetResponse22()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserRoutePointCallDispositionCodeGetAvailableListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of available Route Point Call Disposition Codes to be used by a client.

The response is either `UserRoutePointCallDispositionCodeGetAvailableListResponse()`
or `ErrorResponse()`.

**Attributes:**

|Name            |Type|Description   |
|----------------|----|--------------|
|service_user_id |str |serviceUserId |
</div>


## `UserRoutePointSupervisorGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of Route Point supervisors assigned to a user.

The response is either a `UserRoutePointSupervisorGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserSMDIMessageDeskAddServerRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a SMDI Server for a user.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type|Description|
|------------|----|-----------|
|user_id     |str |userId     |
|device_name |str |deviceName |
|net_address |str |netAddress |
|port        |int |port       |
</div>


## `UserSMDIMessageDeskDeleteServerListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete a list of SMDI Servers for a user.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type      |Description|
|------------|----------|-----------|
|user_id     |str       |userId     |
|device_name |List[str] |deviceName |
</div>


## `UserSMDIMessageDeskGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's SMDI Message Desk service personal setting.

The response is either a `UserSMDIMessageDeskGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserSMDIMessageDeskGetServerListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a list of SMDI Servers defined for a user.

The response is either a `UserSMDIMessageDeskGetServerListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserSMDIMessageDeskModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's SMDI Message Desk service setting.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type |Description                  |
|--------------------|-----|-----------------------------|
|user_id             |str  |userId                       |
|is_active           |bool |isActive *Optional*          |
|message_desk_number |str  |messageDeskNumber *Optional* |
</div>


## `UserScheduleAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a user schedule.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|schedule_name |str |scheduleName |
|schedule_type |str |scheduleType |
</div>


## `UserScheduleGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of a user schedules.

The list can be filtered by schedule type.

The response is either a `UserScheduleGetListResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name          |Type|Description             |
|--------------|----|------------------------|
|user_id       |str |userId                  |
|schedule_type |str |scheduleType *Optional* |
</div>


## `UserScheduleGetListRequest17sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of schedules viewable by a User.

The list can be filtered by schedule type.

The response is either a `UserScheduleGetListResponse17sp1()` or an `ErrorResponse()`.
This command is authorized to user who is Executive-Assistant of the Executive.

**Attributes:**

|Name          |Type|Description             |
|--------------|----|------------------------|
|user_id       |str |userId                  |
|schedule_type |str |scheduleType *Optional* |
</div>


## `UserSecurityClassificationGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a user's Security Classifications configuration.

The response is either `UserSecurityClassificationGetResponse()` or `ErrorResponse()`.

Replaced By: `UserSecurityClassificationGetRequest22()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserSecurityClassificationGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a user's Security Classifications configuration.

The response is either `UserSecurityClassificationGetResponse22()` or
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserSecurityClassificationModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a user's Security Classification configuration The response is either a
`SuccessResponse()` or an `ErrorResponse()`.


**Attributes:**

|Name                    |Type|Description            |
|------------------------|----|-----------------------|
|user_id                 |str |userId                 |
|security_classification |str |securityClassification |
</div>


## `UserSelectiveCallAcceptanceDeleteCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a criteria from the user's selective call acceptance service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserSelectiveCallAcceptanceGetCriteriaListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's selective call acceptance criteria listing.

The response is either a `UserSelectiveCallAcceptanceGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserSelectiveCallAcceptanceGetCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a criteria for the user's selective call acceptance service.

The response is either a `UserSelectiveCallAcceptanceGetCriteriaResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserSelectiveCallAcceptanceGetCriteriaRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a criteria for the user's selective call acceptance service.

The response is either a `UserSelectiveCallAcceptanceGetCriteriaResponse16()` or an
`ErrorResponse()`. Replaced by: `UserSelectiveCallAcceptanceGetCriteriaRequest21()` in
AS data mode

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserSelectiveCallAcceptanceGetCriteriaRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a criteria for the user's selective call acceptance service.

The response is either a `UserSelectiveCallAcceptanceGetCriteriaResponse21()` or an
`ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserSelectiveCallRejectionDeleteCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a criteria from the user's selective call rejection service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserSelectiveCallRejectionGetCriteriaListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's selective call rejection criteria listing.

The response is either a `UserSelectiveCallRejectionGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserSelectiveCallRejectionGetCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a criteria for the user's selective call rejection service.

The response is either a `UserSelectiveCallRejectionGetCriteriaResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserSelectiveCallRejectionGetCriteriaRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a criteria for the user's selective call rejection service.

The response is either a `UserSelectiveCallRejectionGetCriteriaResponse16()` or an
`ErrorResponse()`. Replaced by: `UserSelectiveCallRejectionGetCriteriaRequest16sp1()`

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserSelectiveCallRejectionGetCriteriaRequest16sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a criteria for the user's selective call rejection service.

The response is either a `UserSelectiveCallRejectionGetCriteriaResponse16sp1()` or an
`ErrorResponse()`. Replaced by: `UserSelectiveCallRejectionGetCriteriaRequest21()` in
AS data mode

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserSelectiveCallRejectionGetCriteriaRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a criteria for the user's selective call rejection service.

The response is either a `UserSelectiveCallRejectionGetCriteriaResponse21()` or an
`ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserSequentialRingDeleteCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a criteria from the user's sequential ring service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserSequentialRingGetCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a criteria for the user's sequential ring service.

The response is either a `UserSequentialRingGetCriteriaResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserSequentialRingGetCriteriaRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a criteria for the user's sequential ring service.

The response is either a `UserSequentialRingGetCriteriaResponse16()` or an
`ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserSequentialRingGetRequest13mp16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's sequential ring service setting.

The response is either a `UserSequentialRingGetResponse13mp16()` or an
`ErrorResponse()`.

Replaced By: `UserSequentialRingGetRequest14sp4()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserSequentialRingGetRequest14sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's sequential ring service setting.

The response is either a `UserSequentialRingGetResponse14sp4()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserSeriesCompletionGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Gets the details of the Series Completion group that a user belongs to (if any).

Any user can only belong to one Series Completion group.

The response is either `UserSeriesCompletionGetResponse()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserServiceAssignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to assign the user services and service packs for a user.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name              |Type      |Description                |
|------------------|----------|---------------------------|
|user_id           |str       |userId                     |
|service_name      |List[str] |serviceName *Optional*     |
|service_pack_name |List[str] |servicePackName *Optional* |
</div>


## `UserServiceGetAssignmentListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the user's service and service pack assignment list with status.

The response is either `UserServiceGetAssignmentListResponse()` or `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserServiceIsAssignedRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to determine if a UserService or service pack is assigned to the user.


**Attributes:**

|Name              |Type|Description                |
|------------------|----|---------------------------|
|user_id           |str |userId                     |
|service_name      |str |serviceName *Optional*     |
|service_pack_name |str |servicePackName *Optional* |
</div>


## `UserServiceUnassignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests to unassign the user services and service packs for a user.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name              |Type      |Description                |
|------------------|----------|---------------------------|
|user_id           |str       |userId                     |
|service_name      |List[str] |serviceName *Optional*     |
|service_pack_name |List[str] |servicePackName *Optional* |
</div>


## `UserShInterfaceGetUserIdDataRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Returns the Sh non-transparent data stored against a userId.

The response is either a `UserShInterfaceGetUserIdDataResponse()` or an
`ErrorResponse()`. Replaced by: `UserShInterfaceGetUserIdDataRequest21sp1()` in AS
data mode.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserShInterfaceGetUserIdDataRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Returns the Sh non-transparent data stored against a userId.

The response is either a `UserShInterfaceGetUserIdDataResponse21sp1()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserSharedCallAppearanceGetRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's Shared Call Appearance service setting.

The response is either a `UserSharedCallAppearanceGetResponse14()` or an
`ErrorResponse()`.

Replaced By: `UserSharedCallAppearanceGetRequest14sp2()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserSharedCallAppearanceGetRequest14sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's Shared Call Appearance service setting.

The response is either a `UserSharedCallAppearanceGetResponse14sp2()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserSharedCallAppearanceGetRequest16sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's Shared Call Appearance service setting.

The response is either a `UserSharedCallAppearanceGetResponse16sp2()` or an
`ErrorResponse()`. Replaced by: `UserSharedCallAppearanceGetRequest21sp1()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserSharedCallAppearanceGetRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's Shared Call Appearance service setting.

The response is either a `UserSharedCallAppearanceGetResponse21sp1()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserSharedCallAppearanceModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's Shared Call Appearance service setting.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in XS data mode and ignored in AS data mode:
useUserPrimaryWithAlternateCallsSetting allowSimultaneousPrimaryAndAlternate
restrictCallRetrieveOfPrimary restrictCallBridgingOfPrimary

**Attributes:**

|Name                                           |Type |Description                                          |
|-----------------------------------------------|-----|-----------------------------------------------------|
|user_id                                        |str  |userId                                               |
|alert_all_appearances_for_click_to_dial_calls  |bool |alertAllAppearancesForClickToDialCalls *Optional*    |
|alert_all_appearances_for_group_paging_calls   |bool |alertAllAppearancesForGroupPagingCalls *Optional*    |
|allow_sca_call_retrieve                        |bool |allowSCACallRetrieve *Optional*                      |
|multiple_call_arrangement_is_active            |bool |multipleCallArrangementIsActive *Optional*           |
|allow_bridging_between_locations               |bool |allowBridgingBetweenLocations *Optional*             |
|bridge_warning_tone                            |str  |bridgeWarningTone *Optional*                         |
|enable_call_park_notification                  |bool |enableCallParkNotification *Optional*                |
|use_user_primary_with_alternate_calls_setting  |bool |useUserPrimaryWithAlternateCallsSetting *Optional*   |
|allow_simultaneous_primary_and_alternate_calls |bool |allowSimultaneousPrimaryAndAlternateCalls *Optional* |
|restrict_call_retrieve_of_primary_call         |bool |restrictCallRetrieveOfPrimaryCall *Optional*         |
|restrict_call_bridging_of_primary_call         |bool |restrictCallBridgingOfPrimaryCall *Optional*         |
</div>


## `UserSilentAlertingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Silent Alerting service.

The response is either a `UserSilentAlertingGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserSilentAlertingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Silent Alerting service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name      |Type |Description         |
|----------|-----|--------------------|
|user_id   |str  |userId              |
|is_active |bool |isActive *Optional* |
</div>


## `UserSimultaneousRingFamilyAddPhoneNumberRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a new phone number and set the answer confirmation setting.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                         |Type |Description                |
|-----------------------------|-----|---------------------------|
|user_id                      |str  |userId                     |
|phone_number                 |str  |phoneNumber                |
|answer_confirmation_required |bool |answerConfirmationRequired |
</div>


## `UserSimultaneousRingFamilyDeleteCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a criteria from the user's simultaneous ring family service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserSimultaneousRingFamilyDeletePhoneNumberRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete the phone number specified.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type|Description |
|-------------|----|------------|
|user_id      |str |userId      |
|phone_number |str |phoneNumber |
</div>


## `UserSimultaneousRingFamilyGetCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a criteria for the user's simultaneous ring family service.

The response is either a `UserSimultaneousRingFamilyGetCriteriaResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserSimultaneousRingFamilyGetPhoneNumberRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the answer confirmation setting for the phone number specified.

The response is either a `UserSimultaneousRingFamilyGetPhoneNumberResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name         |Type|Description |
|-------------|----|------------|
|user_id      |str |userId      |
|phone_number |str |phoneNumber |
</div>


## `UserSimultaneousRingFamilyGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's simultaneous ring service family setting.

The response is either a `UserSimultaneousRingFamilyGetResponse()` or an
`ErrorResponse()`.

Replaced By: `UserSimultaneousRingFamilyGetRequest14sp4()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserSimultaneousRingFamilyGetRequest14sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's simultaneous ring service Family setting.

The response is either a `UserSimultaneousRingFamilyGetResponse14sp4()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserSimultaneousRingFamilyGetRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's simultaneous ring family service setting.

The response is either a `UserSimultaneousRingFamilyGetResponse17()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserSimultaneousRingFamilyModifyPhoneNumberRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the require confirmation setting for the destination.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                         |Type |Description                           |
|-----------------------------|-----|--------------------------------------|
|user_id                      |str  |userId                                |
|phone_number                 |str  |phoneNumber                           |
|answer_confirmation_required |bool |answerConfirmationRequired *Optional* |
</div>


## `UserSimultaneousRingFamilyModifyRequest14sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's simultaneous ring family service setting.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name           |Type |Description              |
|---------------|-----|-------------------------|
|user_id        |str  |userId                   |
|is_active      |bool |isActive *Optional*      |
|incoming_calls |str  |incomingCalls *Optional* |
</div>


## `UserSimultaneousRingPersonalAddPhoneNumberRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a new phone number and set the answer confirmation setting.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                         |Type |Description                |
|-----------------------------|-----|---------------------------|
|user_id                      |str  |userId                     |
|phone_number                 |str  |phoneNumber                |
|answer_confirmation_required |bool |answerConfirmationRequired |
</div>


## `UserSimultaneousRingPersonalDeleteCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a criteria from the user's simultaneous ring personal service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserSimultaneousRingPersonalDeletePhoneNumberRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete the phone number specified.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type|Description |
|-------------|----|------------|
|user_id      |str |userId      |
|phone_number |str |phoneNumber |
</div>


## `UserSimultaneousRingPersonalGetCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a criteria for the user's simultaneous ring personal service.

The response is either a `UserSimultaneousRingPersonalGetCriteriaResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name          |Type|Description  |
|--------------|----|-------------|
|user_id       |str |userId       |
|criteria_name |str |criteriaName |
</div>


## `UserSimultaneousRingPersonalGetPhoneNumberRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the answer confirmation setting for the phone number specified.

The response is either a `UserSimultaneousRingPersonalGetPhoneNumberResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name         |Type|Description |
|-------------|----|------------|
|user_id      |str |userId      |
|phone_number |str |phoneNumber |
</div>


## `UserSimultaneousRingPersonalGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's simultaneous ring service personal setting.

The response is either a `UserSimultaneousRingPersonalGetResponse()` or an
`ErrorResponse()`.

Replaced By: `UserSimultaneousRingPersonalGetRequest14sp4()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserSimultaneousRingPersonalGetRequest14sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's simultaneous ring service personal setting.

The response is either a `UserSimultaneousRingPersonalGetResponse14sp4()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserSimultaneousRingPersonalGetRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's simultaneous ring personal service setting.

The response is either a `UserSimultaneousRingPersonalGetResponse17()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserSimultaneousRingPersonalModifyPhoneNumberRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the require confirmation setting for the destination.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                         |Type |Description                           |
|-----------------------------|-----|--------------------------------------|
|user_id                      |str  |userId                                |
|phone_number                 |str  |phoneNumber                           |
|answer_confirmation_required |bool |answerConfirmationRequired *Optional* |
</div>


## `UserSimultaneousRingPersonalModifyRequest14sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's simultaneous ring personal service setting.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name           |Type |Description              |
|---------------|-----|-------------------------|
|user_id        |str  |userId                   |
|is_active      |bool |isActive *Optional*      |
|incoming_calls |str  |incomingCalls *Optional* |
</div>


## `UserSingleSignOnCreateDeviceTokenRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
This command allows a BroadWorks or Third-Party Client Application to create a Single
Sign-On token for a device of a user.

The token is created only if: 1. the specified user is the owner of a lineport on the
specified device (including a trunk user on a trunk device). 2. and, the specified
device is not in locked state.  3. and, the device type of the device does support
Device Management.

The response is either `UserSingleSignOnCreateDeviceTokenResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name         |Type|Description |
|-------------|----|------------|
|user_id      |str |userId      |
|device_level |str |deviceLevel |
|device_name  |str |deviceName  |
</div>


## `UserSpeedDial100DeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete one or more speed dial 100 settings for a user.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name       |Type      |Description          |
|-----------|----------|---------------------|
|user_id    |str       |userId               |
|speed_code |List[int] |speedCode *Optional* |
</div>


## `UserSpeedDial100GetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the speed dial 100 settings for a user.

The response is either a `UserSpeedDial100GetListResponse()` or an `ErrorResponse()`.
Replaced by: UserSpeedDial100GetListRequest17Sp1

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserSpeedDial100GetListRequest17sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the speed dial 100 settings for a user.

The response is either a `UserSpeedDial100GetListResponse17sp1()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserSpeedDial100GetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get speed dial 100 settings for a speed code.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name       |Type|Description|
|-----------|----|-----------|
|user_id    |str |userId     |
|speed_code |int |speedCode  |
</div>


## `UserSpeedDial8GetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the speed dial 8 settings for a user.

The response is either a `UserSpeedDial8GetListResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserTerminatingAlternateTrunkIdentityGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Terminating Alternate Trunk Identity.

The response is either a `UserTerminatingAlternateTrunkIdentityGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserTerminatingAlternateTrunkIdentityModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Terminating Alternate Trunk Identity.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                       |Type|Description                         |
|---------------------------|----|------------------------------------|
|user_id                    |str |userId                              |
|terminating_trunk_identity |str |terminatingTrunkIdentity *Optional* |
</div>


## `UserTerminatingClosedUserGroupGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get user Terminating CUG service settings.

The response is either `UserTerminatingClosedUserGroupGetResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserTerminatingClosedUserGroupModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify user Terminating CUG service settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type|Description                  |
|--------------------|----|-----------------------------|
|user_id             |str |userId                       |
|user_interlock_code |str |userInterlockCode *Optional* |
</div>


## `UserThirdPartyVoiceMailSupportGetRequest13mp16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Third-Party Voice Mail Support.

The response is either a `UserThirdPartyVoiceMailSupportGetResponse13mp16()` or an
`ErrorResponse()`. Replaced by: `UserThirdPartyVoiceMailSupportGetRequest17()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserThirdPartyVoiceMailSupportGetRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Third-Party Voice Mail Support.

The response is either a `UserThirdPartyVoiceMailSupportGetResponse17()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserThirdPartyVoiceMailSupportModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Third Party Voice Mail Support settings for a user.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                       |Type |Description                                    |
|-------------------------------------------|-----|-----------------------------------------------|
|user_id                                    |str  |userId                                         |
|is_active                                  |bool |isActive *Optional*                            |
|busy_redirect_to_voice_mail                |bool |busyRedirectToVoiceMail *Optional*             |
|no_answer_redirect_to_voice_mail           |bool |noAnswerRedirectToVoiceMail *Optional*         |
|server_selection                           |str  |serverSelection *Optional*                     |
|user_server                                |str  |userServer *Optional*                          |
|mailbox_id_type                            |str  |mailboxIdType *Optional*                       |
|mailbox_url                                |str  |mailboxURL *Optional*                          |
|no_answer_number_of_rings                  |int  |noAnswerNumberOfRings *Optional*               |
|always_redirect_to_voice_mail              |bool |alwaysRedirectToVoiceMail *Optional*           |
|out_of_primary_zone_redirect_to_voice_mail |bool |outOfPrimaryZoneRedirectToVoiceMail *Optional* |
</div>


## `UserTimeScheduleDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a user time schedule.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name               |Type|Description      |
|-------------------|----|-----------------|
|user_id            |str |userId           |
|time_schedule_name |str |timeScheduleName |
</div>


## `UserTimeScheduleGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get all time schedules for a user.

This includes the user's personal schedules and user's group's schedules.

The response is either a `UserTimeScheduleGetListResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserTimeScheduleGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a user time schedule.

The response is either a `UserTimeScheduleGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name               |Type|Description      |
|-------------------|----|-----------------|
|user_id            |str |userId           |
|time_schedule_name |str |timeScheduleName |
</div>


## `UserTwoStageDialingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Two Stage Dialing.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                 |Type |Description                                 |
|-------------------------------------|-----|--------------------------------------------|
|user_id                              |str  |userId                                      |
|is_active                            |bool |isActive *Optional*                         |
|allow_activation_with_user_addresses |bool |allowActivationWithUserAddresses *Optional* |
</div>


## `UserVideoAddOnGetRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's Video Add-On service setting.

The response is either a `UserVideoAddOnGetResponse14()` or an `ErrorResponse()`.
Replaced by: `UserVideoAddOnGetRequest19()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserVideoAddOnGetRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's Video Add-On service setting.

The response is either a `UserVideoAddOnGetResponse19()` or an `ErrorResponse()`.
Replaced by: `UserVideoAddOnGetRequest22()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserVideoAddOnGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's Video Add-On service setting.

The response is either a `UserVideoAddOnGetResponse22()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserVoiceMessagingUserAddAliasListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add one or more voice mail aliases to a users voice message.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type      |Description |
|-------------|----------|------------|
|user_id      |str       |userId      |
|phone_number |List[str] |phoneNumber |
</div>


## `UserVoiceMessagingUserDeleteAliasListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete one or more voice mail aliases from a users voice message.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type      |Description |
|-------------|----------|------------|
|user_id      |str       |userId      |
|phone_number |List[str] |phoneNumber |
</div>


## `UserVoiceMessagingUserGetAdvancedVoiceManagementRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's voice messaging advanced voice management service setting.

The response is either a `UserVoiceMessagingUserGetAdvancedVoiceManagementResponse()`
or an `ErrorResponse()`.

Replaced By: `UserVoiceMessagingUserGetAdvancedVoiceManagementRequest14sp3()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserVoiceMessagingUserGetAdvancedVoiceManagementRequest14sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's voice messaging advanced voice management service setting.

The response is either a
`UserVoiceMessagingUserGetAdvancedVoiceManagementResponse14sp3()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserVoiceMessagingUserGetAliasListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the voice mail aliases for a users voice message.

The response is either a `UserVoiceMessagingUserGetAliasListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserVoiceMessagingUserGetDistributionListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a voice mail distribution list for a users voice message.

The response is either `UserVoiceMessagingUserGetDistributionListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
|list_id |int |listId     |
</div>


## `UserVoiceMessagingUserGetGreetingRequest13mp16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's voice messaging greeting information.

The response is either a `UserVoiceMessagingUserGetGreetingResponse13mp16()` or an
`ErrorResponse()`.

Replaced By: `UserVoiceMessagingUserGetGreetingRequest16()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserVoiceMessagingUserGetGreetingRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's voice messaging greeting information.

The response is either a `UserVoiceMessagingUserGetGreetingResponse16()` or an
`ErrorResponse()`. Replaced by: `UserVoiceMessagingUserGetGreetingRequest18()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserVoiceMessagingUserGetGreetingRequest18`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's voice messaging greeting information.

The response is either a `UserVoiceMessagingUserGetGreetingResponse18()` or an
`ErrorResponse()`. Replaced by `UserVoiceMessagingUserGetGreetingRequest18sp1()` in AS
data mode

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserVoiceMessagingUserGetGreetingRequest18sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's voice messaging greeting information.

The response is either a `UserVoiceMessagingUserGetGreetingResponse18sp1()` or an
`ErrorResponse()`. Replaced by: `UserVoiceMessagingUserGetGreetingRequest20()` in AS
data mode

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserVoiceMessagingUserGetGreetingRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's voice messaging greeting information.

The response is either a `UserVoiceMessagingUserGetGreetingResponse20()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserVoiceMessagingUserGetOutgoingSMDIMWIRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's voice messaging outgoing SMDI message waiting indicator service
setting.

The response is either a `UserVoiceMessagingUserGetOutgoingSMDIMWIResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserVoiceMessagingUserGetVoiceManagementRequest13mp8`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's voice messaging voice management service settings.

The response is either a `UserVoiceMessagingUserGetVoiceManagementResponse13mp8()` or
an `ErrorResponse()`. Replaced by:
`UserVoiceMessagingUserGetVoiceManagementRequest17()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserVoiceMessagingUserGetVoiceManagementRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's voice messaging voice management service settings.

The response is either a `UserVoiceMessagingUserGetVoiceManagementResponse17()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserVoiceMessagingUserGetVoicePortalPasswordInfoRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user's voice portal password information.

The response is either a `UserVoiceMessagingUserGetVoicePortalPasswordInfoResponse()`
or an `ErrorResponse()`.

Replaced By: `UserPortalPasscodeGetInfoRequest()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserVoiceMessagingUserGetVoicePortalRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's voice messaging voice portal settings.

The response is either a `UserVoiceMessagingUserGetVoicePortalResponse()` or an
`ErrorResponse()`.

Replaced By: `UserVoiceMessagingUserGetVoicePortalRequest16()`

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserVoiceMessagingUserGetVoicePortalRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's voice messaging voice portal settings.

The response is either a `UserVoiceMessagingUserGetVoicePortalResponse16()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserVoiceMessagingUserGetVoicePortalRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's voice messaging voice portal settings.

The response is either a `UserVoiceMessagingUserGetVoicePortalResponse20()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserVoiceMessagingUserModifyAdvancedVoiceManagementRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's voice messaging advanced voice management service setting.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                             |Type |Description                                          |
|-------------------------------------------------|-----|-----------------------------------------------------|
|user_id                                          |str  |userId                                               |
|mail_server_selection                            |str  |mailServerSelection *Optional*                       |
|group_mail_server_email_address                  |str  |groupMailServerEmailAddress *Optional*               |
|group_mail_server_user_id                        |str  |groupMailServerUserId *Optional*                     |
|group_mail_server_password                       |str  |groupMailServerPassword *Optional*                   |
|use_group_default_mail_server_full_mailbox_limit |bool |useGroupDefaultMailServerFullMailboxLimit *Optional* |
|group_mail_server_full_mailbox_limit             |int  |groupMailServerFullMailboxLimit *Optional*           |
|personal_mail_server_net_address                 |str  |personalMailServerNetAddress *Optional*              |
|personal_mail_server_protocol                    |str  |personalMailServerProtocol *Optional*                |
|personal_mail_server_real_delete_for_imap        |bool |personalMailServerRealDeleteForImap *Optional*       |
|personal_mail_server_email_address               |str  |personalMailServerEmailAddress *Optional*            |
|personal_mail_server_user_id                     |str  |personalMailServerUserId *Optional*                  |
|personal_mail_server_password                    |str  |personalMailServerPassword *Optional*                |
</div>


## `UserVoiceMessagingUserModifyVoiceManagementRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's voice messaging voice management service setting.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                       |Type |Description                                    |
|-------------------------------------------|-----|-----------------------------------------------|
|user_id                                    |str  |userId                                         |
|is_active                                  |bool |isActive *Optional*                            |
|processing                                 |str  |processing *Optional*                          |
|voice_message_delivery_email_address       |str  |voiceMessageDeliveryEmailAddress *Optional*    |
|use_phone_message_waiting_indicator        |bool |usePhoneMessageWaitingIndicator *Optional*     |
|send_voice_message_notify_email            |bool |sendVoiceMessageNotifyEmail *Optional*         |
|voice_message_notify_email_address         |str  |voiceMessageNotifyEmailAddress *Optional*      |
|send_carbon_copy_voice_message             |bool |sendCarbonCopyVoiceMessage *Optional*          |
|voice_message_carbon_copy_email_address    |str  |voiceMessageCarbonCopyEmailAddress *Optional*  |
|transfer_on_zero_to_phone_number           |bool |transferOnZeroToPhoneNumber *Optional*         |
|transfer_phone_number                      |str  |transferPhoneNumber *Optional*                 |
|always_redirect_to_voice_mail              |bool |alwaysRedirectToVoiceMail *Optional*           |
|busy_redirect_to_voice_mail                |bool |busyRedirectToVoiceMail *Optional*             |
|no_answer_redirect_to_voice_mail           |bool |noAnswerRedirectToVoiceMail *Optional*         |
|out_of_primary_zone_redirect_to_voice_mail |bool |outOfPrimaryZoneRedirectToVoiceMail *Optional* |
</div>


## `UserVoiceMessagingUserModifyVoicePortalPasswordRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's Voice Portal password The response is either a `SuccessResponse()`
or an `ErrorResponse()`.

Engineering Note: This command is used internally by Call Processing.

Replaced By: `UserPortalPasscodeModifyRequest()`

**Attributes:**

|Name         |Type|Description            |
|-------------|----|-----------------------|
|user_id      |str |userId                 |
|old_password |str |oldPassword *Optional* |
|new_password |str |newPassword            |
</div>


## `UserVoicePortalCallingGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user level data associated with Voice Portal Calling.

The response is either a `UserVoicePortalCallingGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserVoicePortalCallingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Voice Portal Calling.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name      |Type |Description         |
|----------|-----|--------------------|
|user_id   |str  |userId              |
|is_active |bool |isActive *Optional* |
</div>


## `UserXsiPolicyProfileGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user Xsi policy profile.

The response is either a `UserXsiPolicyProfileGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserZoneCallingRestrictionsGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Gets the home zone for a user The response is either a
`UserZoneCallingRestrictionsGetResponse()` or an `ErrorResponse()`.


**Attributes:**

|Name    |Type|Description|
|--------|----|-----------|
|user_id |str |userId     |
</div>


## `UserZoneCallingRestrictionsModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the home zone for a user The response is either a `SuccessResponse()` or an
`ErrorResponse()`.


**Attributes:**

|Name           |Type|Description             |
|---------------|----|------------------------|
|user_id        |str |userId                  |
|home_zone_name |str |homeZoneName *Optional* |
</div>


## `VerifySessionIsValidRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Query the provisioning server to verify the session is authorized.

Most applications should not need this command, because the provisioning server
verifies the session is authorized for all commands.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

</div>


## `EnterpriseCallCenterAgentThresholdProfileModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies an existing Call Center Agent Threshold Profile in the Enterprise.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                                  |Type                             |Description                                                |
|------------------------------------------------------|---------------------------------|-----------------------------------------------------------|
|service_provider_id                                   |str                              |serviceProviderId                                          |
|profile_name                                          |str                              |profileName                                                |
|new_profile_name                                      |str                              |newProfileName *Optional*                                  |
|profile_description                                   |str                              |profileDescription *Optional*                              |
|threshold_current_call_state_idle_time_yellow         |int                              |thresholdCurrentCallStateIdleTimeYellow *Optional*         |
|threshold_current_call_state_idle_time_red            |int                              |thresholdCurrentCallStateIdleTimeRed *Optional*            |
|threshold_current_call_state_on_call_time_yellow      |int                              |thresholdCurrentCallStateOnCallTimeYellow *Optional*       |
|threshold_current_call_state_on_call_time_red         |int                              |thresholdCurrentCallStateOnCallTimeRed *Optional*          |
|threshold_current_agent_state_unavailable_time_yellow |int                              |thresholdCurrentAgentStateUnavailableTimeYellow *Optional* |
|threshold_current_agent_state_unavailable_time_red    |int                              |thresholdCurrentAgentStateUnavailableTimeRed *Optional*    |
|threshold_average_busy_in_time_yellow                 |int                              |thresholdAverageBusyInTimeYellow *Optional*                |
|threshold_average_busy_in_time_red                    |int                              |thresholdAverageBusyInTimeRed *Optional*                   |
|threshold_average_busy_out_time_yellow                |int                              |thresholdAverageBusyOutTimeYellow *Optional*               |
|threshold_average_busy_out_time_red                   |int                              |thresholdAverageBusyOutTimeRed *Optional*                  |
|threshold_average_wrap_up_time_yellow                 |int                              |thresholdAverageWrapUpTimeYellow *Optional*                |
|threshold_average_wrap_up_time_red                    |int                              |thresholdAverageWrapUpTimeRed *Optional*                   |
|enable_notification_email                             |bool                             |enableNotificationEmail *Optional*                         |
|notification_email_address_list                       |OCI.notificationEmailAddressList |notificationEmailAddressList *Optional*                    |
|agent_user_id_list                                    |OCI.agentUserIdList              |agentUserIdList *Optional*                                 |
</div>


## `EnterpriseCallCenterAgentUnavailableCodeSettingsModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the enterprise level data associated with Call Center Agents Unavailable Code
Settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                                  |Type                    |Description                                                |
|------------------------------------------------------|------------------------|-----------------------------------------------------------|
|service_provider_id                                   |str                     |serviceProviderId                                          |
|enable_agent_unavailable_codes                        |bool                    |enableAgentUnavailableCodes *Optional*                     |
|default_agent_unavailable_code_on_dnd                 |str                     |defaultAgentUnavailableCodeOnDND *Optional*                |
|default_agent_unavailable_code_on_personal_calls      |str                     |defaultAgentUnavailableCodeOnPersonalCalls *Optional*      |
|default_agent_unavailable_code_on_consecutive_bounces |str                     |defaultAgentUnavailableCodeOnConsecutiveBounces *Optional* |
|default_agent_unavailable_code_on_not_reachable       |str                     |defaultAgentUnavailableCodeOnNotReachable *Optional*       |
|force_use_of_agent_unavailable_codes                  |bool                    |forceUseOfAgentUnavailableCodes *Optional*                 |
|default_agent_unavailable_code                        |str                     |defaultAgentUnavailableCode *Optional*                     |
|code_state_list                                       |List[OCI.codeStateList] |codeStateList *Optional*                                   |
</div>


## `EnterpriseCallCenterCallDispositionCodeModifyActiveListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to set the active status of Call Center Call Disposition Codes.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                             |Type                                    |Description                              |
|---------------------------------|----------------------------------------|-----------------------------------------|
|service_provider_id              |str                                     |serviceProviderId                        |
|call_disposition_code_activation |List[OCI.callDispositionCodeActivation] |callDispositionCodeActivation *Optional* |
</div>


## `EnterpriseCallCenterEnhancedReportingBrandingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the enterprise branding configuration.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type             |Description               |
|--------------------|-----------------|--------------------------|
|service_provider_id |str              |serviceProviderId         |
|branding_choice     |str              |brandingChoice *Optional* |
|branding_file       |OCI.brandingFile |brandingFile *Optional*   |
</div>


## `EnterpriseCallCenterEnhancedReportingReportTemplateAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add an Enterprise level call center report template.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                    |Type             |Description                                    |
|----------------------------------------|-----------------|-----------------------------------------------|
|service_provider_id                     |str              |serviceProviderId                              |
|name                                    |str              |name                                           |
|description                             |str              |description *Optional*                         |
|data_template                           |str              |dataTemplate                                   |
|filter_number                           |int              |filterNumber *Optional*                        |
|xslt_template                           |OCI.xsltTemplate |xsltTemplate                                   |
|scope                                   |str              |scope                                          |
|is_enabled                              |bool             |isEnabled                                      |
|is_realtime_report                      |bool             |isRealtimeReport *Optional*                    |
|call_completion_threshold_param         |str              |callCompletionThresholdParam *Optional*        |
|short_duration_threshold_param          |str              |shortDurationThresholdParam *Optional*         |
|service_level_threshold_param           |str              |serviceLevelThresholdParam *Optional*          |
|service_level_inclusions_param          |str              |serviceLevelInclusionsParam *Optional*         |
|service_level_objective_threshold_param |str              |serviceLevelObjectiveThresholdParam *Optional* |
|abandoned_call_threshold_param          |str              |abandonedCallThresholdParam *Optional*         |
|service_level_threshold_param_number    |int              |serviceLevelThresholdParamNumber *Optional*    |
|abandoned_call_threshold_param_number   |int              |abandonedCallThresholdParamNumber *Optional*   |
|filter_value                            |List[str]        |filterValue *Optional*                         |
</div>


## `EnterpriseCallCenterEnhancedReportingReportTemplateModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify an enterprise level call center report template.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type             |Description                 |
|--------------------|-----------------|----------------------------|
|service_provider_id |str              |serviceProviderId           |
|name                |str              |name                        |
|new_name            |str              |newName *Optional*          |
|description         |str              |description *Optional*      |
|xslt_template       |OCI.xsltTemplate |xsltTemplate *Optional*     |
|scope               |str              |scope *Optional*            |
|is_enabled          |bool             |isEnabled *Optional*        |
|is_realtime_report  |bool             |isRealtimeReport *Optional* |
|filter_number       |int              |filterNumber *Optional*     |
|filter_value        |OCI.filterValue  |filterValue *Optional*      |
</div>


## `EnterpriseCallCenterModifyRoutingPolicyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the enterprise call center routing policy.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type                           |Description                     |
|-----------------------|-------------------------------|--------------------------------|
|service_provider_id    |str                            |serviceProviderId               |
|routing_policy         |str                            |routingPolicy *Optional*        |
|routing_priority_order |List[OCI.routingPriorityOrder] |routingPriorityOrder *Optional* |
</div>


## `EnterpriseCommonPhoneListAddListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add one or more entries to an enterprise's common phone list.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type            |Description       |
|--------------------|----------------|------------------|
|service_provider_id |str             |serviceProviderId |
|entry               |List[OCI.entry] |entry             |
</div>


## `EnterpriseCommunicationBarringAuthorizationCodeAddListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a list of Communication Barring Authorization codes to an enterprise.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type           |Description       |
|--------------------|---------------|------------------|
|service_provider_id |str            |serviceProviderId |
|code                |List[OCI.code] |code              |
</div>


## `EnterpriseVoiceVPNAddPolicyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add the enterprise level data associated with a Voice VPN location code.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                  |Type                        |Description                  |
|----------------------|----------------------------|-----------------------------|
|service_provider_id   |str                         |serviceProviderId            |
|location_dialing_code |str                         |locationDialingCode          |
|min_extension_length  |int                         |minExtensionLength           |
|max_extension_length  |int                         |maxExtensionLength           |
|description           |str                         |description *Optional*       |
|route_group_id        |str                         |routeGroupId *Optional*      |
|policy_selection      |str                         |policySelection              |
|digit_manipulation    |List[OCI.digitManipulation] |digitManipulation *Optional* |
|treatment_id          |str                         |treatmentId *Optional*       |
</div>


## `EnterpriseVoiceVPNModifyPolicyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the enterprise level data associated with a Voice VPN location code.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                  |Type                        |Description                   |
|----------------------|----------------------------|------------------------------|
|service_provider_id   |str                         |serviceProviderId             |
|location_dialing_code |str                         |locationDialingCode           |
|min_extension_length  |int                         |minExtensionLength *Optional* |
|max_extension_length  |int                         |maxExtensionLength *Optional* |
|description           |str                         |description *Optional*        |
|route_group_id        |str                         |routeGroupId *Optional*       |
|policy_selection      |str                         |policySelection *Optional*    |
|digit_manipulation    |List[OCI.digitManipulation] |digitManipulation *Optional*  |
|treatment_id          |str                         |treatmentId *Optional*        |
</div>


## `GroupAccessDeviceAddRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a group access device.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by:
`GroupAccessDeviceAddRequest22()`

**Attributes:**

|Name                                             |Type                        |Description                                            |
|-------------------------------------------------|----------------------------|-------------------------------------------------------|
|service_provider_id                              |str                         |serviceProviderId                                      |
|group_id                                         |str                         |groupId                                                |
|device_name                                      |str                         |deviceName                                             |
|device_type                                      |str                         |deviceType                                             |
|protocol                                         |str                         |protocol *Optional*                                    |
|net_address                                      |str                         |netAddress *Optional*                                  |
|port                                             |int                         |port *Optional*                                        |
|outbound_proxy_server_net_address                |str                         |outboundProxyServerNetAddress *Optional*               |
|stun_server_net_address                          |str                         |stunServerNetAddress *Optional*                        |
|mac_address                                      |str                         |macAddress *Optional*                                  |
|serial_number                                    |str                         |serialNumber *Optional*                                |
|description                                      |str                         |description *Optional*                                 |
|physical_location                                |str                         |physicalLocation *Optional*                            |
|transport_protocol                               |str                         |transportProtocol *Optional*                           |
|mobility_manager_provisioning_url                |str                         |mobilityManagerProvisioningURL *Optional*              |
|mobility_manager_provisioning_user_name          |str                         |mobilityManagerProvisioningUserName *Optional*         |
|mobility_manager_provisioning_password           |str                         |mobilityManagerProvisioningPassword *Optional*         |
|mobility_manager_default_originating_service_key |int                         |mobilityManagerDefaultOriginatingServiceKey *Optional* |
|mobility_manager_default_terminating_service_key |int                         |mobilityManagerDefaultTerminatingServiceKey *Optional* |
|use_custom_user_name_password                    |bool                        |useCustomUserNamePassword *Optional*                   |
|access_device_credentials                        |OCI.accessDeviceCredentials |accessDeviceCredentials *Optional*                     |
</div>


## `GroupAccessDeviceAddRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a group access device.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode: hotlineContact
useHotline groupExternalId deviceExternalId Replaced by:
`GroupAccessDeviceAddRequest22V2()`

**Attributes:**

|Name                                             |Type                        |Description                                            |
|-------------------------------------------------|----------------------------|-------------------------------------------------------|
|service_provider_id                              |str                         |serviceProviderId *Optional*                           |
|group_id                                         |str                         |groupId *Optional*                                     |
|device_name                                      |str                         |deviceName *Optional*                                  |
|group_external_id                                |str                         |groupExternalId *Optional*                             |
|device_external_id                               |str                         |deviceExternalId *Optional*                            |
|device_type                                      |str                         |deviceType                                             |
|protocol                                         |str                         |protocol *Optional*                                    |
|net_address                                      |str                         |netAddress *Optional*                                  |
|port                                             |int                         |port *Optional*                                        |
|outbound_proxy_server_net_address                |str                         |outboundProxyServerNetAddress *Optional*               |
|stun_server_net_address                          |str                         |stunServerNetAddress *Optional*                        |
|mac_address                                      |str                         |macAddress *Optional*                                  |
|serial_number                                    |str                         |serialNumber *Optional*                                |
|description                                      |str                         |description *Optional*                                 |
|physical_location                                |str                         |physicalLocation *Optional*                            |
|transport_protocol                               |str                         |transportProtocol *Optional*                           |
|mobility_manager_provisioning_url                |str                         |mobilityManagerProvisioningURL *Optional*              |
|mobility_manager_provisioning_user_name          |str                         |mobilityManagerProvisioningUserName *Optional*         |
|mobility_manager_provisioning_password           |str                         |mobilityManagerProvisioningPassword *Optional*         |
|mobility_manager_default_originating_service_key |int                         |mobilityManagerDefaultOriginatingServiceKey *Optional* |
|mobility_manager_default_terminating_service_key |int                         |mobilityManagerDefaultTerminatingServiceKey *Optional* |
|use_custom_user_name_password                    |bool                        |useCustomUserNamePassword *Optional*                   |
|access_device_credentials                        |OCI.accessDeviceCredentials |accessDeviceCredentials *Optional*                     |
|use_hotline                                      |bool                        |useHotline                                             |
|hotline_contact                                  |str                         |hotlineContact *Optional*                              |
</div>


## `GroupAccessDeviceAddRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a group access device.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode: groupExternalId
deviceExternalId

**Attributes:**

|Name                              |Type                        |Description                              |
|----------------------------------|----------------------------|-----------------------------------------|
|service_provider_id               |str                         |serviceProviderId *Optional*             |
|group_id                          |str                         |groupId *Optional*                       |
|device_name                       |str                         |deviceName *Optional*                    |
|group_external_id                 |str                         |groupExternalId *Optional*               |
|device_external_id                |str                         |deviceExternalId *Optional*              |
|device_type                       |str                         |deviceType                               |
|protocol                          |str                         |protocol *Optional*                      |
|net_address                       |str                         |netAddress *Optional*                    |
|port                              |int                         |port *Optional*                          |
|outbound_proxy_server_net_address |str                         |outboundProxyServerNetAddress *Optional* |
|stun_server_net_address           |str                         |stunServerNetAddress *Optional*          |
|mac_address                       |str                         |macAddress *Optional*                    |
|serial_number                     |str                         |serialNumber *Optional*                  |
|description                       |str                         |description *Optional*                   |
|physical_location                 |str                         |physicalLocation *Optional*              |
|transport_protocol                |str                         |transportProtocol *Optional*             |
|use_custom_user_name_password     |bool                        |useCustomUserNamePassword *Optional*     |
|access_device_credentials         |OCI.accessDeviceCredentials |accessDeviceCredentials *Optional*       |
</div>


## `GroupAccessDeviceAvailablePortGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of available ports in a device.

The response is either `GroupAccessDeviceAvailablePortGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type             |Description       |
|--------------------|-----------------|------------------|
|service_provider_id |str              |serviceProviderId |
|group_id            |str              |groupId           |
|access_device       |OCI.accessDevice |accessDevice      |
</div>


## `GroupAccessDeviceCustomTagAddOrModifyListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add or modify a list of static configuration tag for a group access device.

If the tag does not exist, it is added.  If the tag exists, its value is updated.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type          |Description       |
|--------------------|--------------|------------------|
|service_provider_id |str           |serviceProviderId |
|group_id            |str           |groupId           |
|device_name         |str           |deviceName        |
|tag                 |List[OCI.tag] |tag               |
</div>


## `GroupAccessDeviceFileModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a specified group access device file.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

Replaced By: `GroupAccessDeviceFileModifyRequest14sp8()`

**Attributes:**

|Name                |Type           |Description           |
|--------------------|---------------|----------------------|
|service_provider_id |str            |serviceProviderId     |
|group_id            |str            |groupId               |
|device_name         |str            |deviceName            |
|file_type           |str            |fileType              |
|file_source         |str            |fileSource *Optional* |
|upload_file         |OCI.uploadFile |uploadFile *Optional* |
</div>


## `GroupAccessDeviceFileModifyRequest14sp8`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a specified group access device file.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type           |Description                       |
|-------------------------|---------------|----------------------------------|
|service_provider_id      |str            |serviceProviderId                 |
|group_id                 |str            |groupId                           |
|device_name              |str            |deviceName                        |
|file_format              |str            |fileFormat                        |
|file_source              |str            |fileSource *Optional*             |
|upload_file              |OCI.uploadFile |uploadFile *Optional*             |
|extended_capture_enabled |bool           |extendedCaptureEnabled *Optional* |
</div>


## `GroupAccessDeviceLinkDeviceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to link one or more leaf devices to a group level tree device.

A tree device is a device associated with a device type that has the option
supportLinks set to "Support Links from Devices". Many leaf devices can be linked to
it.  A leaf device is a device associated with a device type that has the option
supportLinks set to "Support Link to Device". It can be linked to only one tree
device.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type                    |Description       |
|--------------------|------------------------|------------------|
|service_provider_id |str                     |serviceProviderId |
|group_id            |str                     |groupId           |
|device_name         |str                     |deviceName        |
|leaf_device_key     |List[OCI.leafDeviceKey] |leafDeviceKey     |
</div>


## `GroupAccessDeviceModifyRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a specified group access device.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode: hotlineContact
useHotline deviceExternalId Replaced by: `GroupAccessDeviceModifyRequest22()`

**Attributes:**

|Name                                             |Type                        |Description                                            |
|-------------------------------------------------|----------------------------|-------------------------------------------------------|
|service_provider_id                              |str                         |serviceProviderId *Optional*                           |
|group_id                                         |str                         |groupId *Optional*                                     |
|device_name                                      |str                         |deviceName *Optional*                                  |
|device_external_id                               |str                         |deviceExternalId *Optional*                            |
|protocol                                         |str                         |protocol *Optional*                                    |
|net_address                                      |str                         |netAddress *Optional*                                  |
|port                                             |int                         |port *Optional*                                        |
|outbound_proxy_server_net_address                |str                         |outboundProxyServerNetAddress *Optional*               |
|stun_server_net_address                          |str                         |stunServerNetAddress *Optional*                        |
|mac_address                                      |str                         |macAddress *Optional*                                  |
|serial_number                                    |str                         |serialNumber *Optional*                                |
|description                                      |str                         |description *Optional*                                 |
|configuration_mode                               |str                         |configurationMode *Optional*                           |
|configuration_file                               |OCI.configurationFile       |configurationFile *Optional*                           |
|physical_location                                |str                         |physicalLocation *Optional*                            |
|transport_protocol                               |str                         |transportProtocol *Optional*                           |
|mobility_manager_provisioning_url                |str                         |mobilityManagerProvisioningURL *Optional*              |
|mobility_manager_provisioning_user_name          |str                         |mobilityManagerProvisioningUserName *Optional*         |
|mobility_manager_provisioning_password           |str                         |mobilityManagerProvisioningPassword *Optional*         |
|mobility_manager_default_originating_service_key |int                         |mobilityManagerDefaultOriginatingServiceKey *Optional* |
|mobility_manager_default_terminating_service_key |int                         |mobilityManagerDefaultTerminatingServiceKey *Optional* |
|use_custom_user_name_password                    |bool                        |useCustomUserNamePassword *Optional*                   |
|access_device_credentials                        |OCI.accessDeviceCredentials |accessDeviceCredentials *Optional*                     |
|hotline_contact                                  |str                         |hotlineContact *Optional*                              |
|use_hotline                                      |bool                        |useHotline *Optional*                                  |
</div>


## `GroupAccessDeviceModifyRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a specified group access device.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode: deviceExternalId

**Attributes:**

|Name                              |Type                        |Description                              |
|----------------------------------|----------------------------|-----------------------------------------|
|service_provider_id               |str                         |serviceProviderId *Optional*             |
|group_id                          |str                         |groupId *Optional*                       |
|device_name                       |str                         |deviceName *Optional*                    |
|device_external_id                |str                         |deviceExternalId *Optional*              |
|protocol                          |str                         |protocol *Optional*                      |
|net_address                       |str                         |netAddress *Optional*                    |
|port                              |int                         |port *Optional*                          |
|outbound_proxy_server_net_address |str                         |outboundProxyServerNetAddress *Optional* |
|stun_server_net_address           |str                         |stunServerNetAddress *Optional*          |
|mac_address                       |str                         |macAddress *Optional*                    |
|serial_number                     |str                         |serialNumber *Optional*                  |
|description                       |str                         |description *Optional*                   |
|configuration_mode                |str                         |configurationMode *Optional*             |
|configuration_file                |OCI.configurationFile       |configurationFile *Optional*             |
|physical_location                 |str                         |physicalLocation *Optional*              |
|transport_protocol                |str                         |transportProtocol *Optional*             |
|use_custom_user_name_password     |bool                        |useCustomUserNamePassword *Optional*     |
|access_device_credentials         |OCI.accessDeviceCredentials |accessDeviceCredentials *Optional*       |
</div>


## `GroupAccessDeviceUnlinkDeviceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to unlink one or more leaf access devices from a tree device.

A leaf device is a device associated with a device type that has the option
supportLinks set to "Support Link to Device". It can be linked to only one tree
device.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name            |Type                    |Description   |
|----------------|------------------------|--------------|
|leaf_device_key |List[OCI.leafDeviceKey] |leafDeviceKey |
</div>


## `GroupAccountAuthorizationCodesAddListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a list of account/authorization codes to a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type                |Description       |
|--------------------|--------------------|------------------|
|service_provider_id |str                 |serviceProviderId |
|group_id            |str                 |groupId           |
|code_entry          |List[OCI.codeEntry] |codeEntry         |
</div>


## `GroupAccountAuthorizationCodesModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Change the group's account/authorization codes setting.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                            |Type                         |Description                           |
|--------------------------------|-----------------------------|--------------------------------------|
|service_provider_id             |str                          |serviceProviderId                     |
|group_id                        |str                          |groupId                               |
|code_type                       |str                          |codeType *Optional*                   |
|number_of_digits                |int                          |numberOfDigits *Optional*             |
|allow_local_and_toll_free_calls |bool                         |allowLocalAndTollFreeCalls *Optional* |
|mandatory_usage_user_id_list    |OCI.mandatoryUsageUserIdList |mandatoryUsageUserIdList *Optional*   |
|optional_usage_user_id_list     |OCI.optionalUsageUserIdList  |optionalUsageUserIdList *Optional*    |
</div>


## `GroupAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in Amplify data mode and ignored in AS and XS data mode:
servicePolicy, callProcessingSliceId, provisioningSliceId, subscriberPartition.  When
the callProcessingSliceId or provisioningSliceId is not specified in the
AmplifyDataMode, the default slice Id is assigned to the Group.  Only Provisioning
admin and above can change the callProcessingSliceId, provisioningSliceId, and
subscriberPartition.  The following elements are only used in Amplify and XS data mode
and ignored in AS mode: preferredDataCenter.  Only Provisioning admin and above can
change the preferredDataCenter.  The following elements are only used in XS data mode
and ignored in Amplify and AS data mode: defaultUserCallingLineIdPhoneNumber.
Replaced by: `GroupConsolidatedAddRequest()` in AS data mode

**Attributes:**

|Name                                      |Type        |Description                                    |
|------------------------------------------|------------|-----------------------------------------------|
|service_provider_id                       |str         |serviceProviderId                              |
|group_id                                  |str         |groupId                                        |
|default_domain                            |str         |defaultDomain                                  |
|user_limit                                |int         |userLimit                                      |
|group_name                                |str         |groupName *Optional*                           |
|calling_line_id_name                      |str         |callingLineIdName *Optional*                   |
|time_zone                                 |str         |timeZone *Optional*                            |
|location_dialing_code                     |str         |locationDialingCode *Optional*                 |
|contact                                   |OCI.contact |contact *Optional*                             |
|address                                   |OCI.address |address *Optional*                             |
|service_policy                            |str         |servicePolicy *Optional*                       |
|call_processing_slice_id                  |str         |callProcessingSliceId *Optional*               |
|provisioning_slice_id                     |str         |provisioningSliceId *Optional*                 |
|subscriber_partition                      |str         |subscriberPartition *Optional*                 |
|preferred_data_center                     |str         |preferredDataCenter *Optional*                 |
|default_user_calling_line_id_phone_number |str         |defaultUserCallingLineIdPhoneNumber *Optional* |
</div>


## `GroupAnnouncementFileAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add an announcement to the group announcement repository The following elements are
only used in AS data mode and ignored in XS data mode: groupExternalId
announcementFileExternalId The response is either a `SuccessResponse()` or an
`ErrorResponse()`.


**Attributes:**

|Name                          |Type                 |Description                           |
|------------------------------|---------------------|--------------------------------------|
|service_provider_id           |str                  |serviceProviderId *Optional*          |
|group_id                      |str                  |groupId *Optional*                    |
|announcement_file_name        |str                  |announcementFileName *Optional*       |
|group_external_id             |str                  |groupExternalId *Optional*            |
|announcement_file_external_id |str                  |announcementFileExternalId *Optional* |
|announcement_file             |OCI.announcementFile |announcementFile                      |
</div>


## `GroupAnnouncementFileDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete one or more announcements from the group announcement repository The following
elements are only used in AS data mode and ignored in XS data mode: groupExternalId
announcementFileExternalId The response is either a `SuccessResponse()` or an
`ErrorResponse()`.


**Attributes:**

|Name                          |Type                          |Description                           |
|------------------------------|------------------------------|--------------------------------------|
|service_provider_id           |str                           |serviceProviderId *Optional*          |
|group_id                      |str                           |groupId *Optional*                    |
|announcement_file_key         |List[OCI.announcementFileKey] |announcementFileKey *Optional*        |
|group_external_id             |str                           |groupExternalId *Optional*            |
|announcement_file_external_id |List[str]                     |announcementFileExternalId *Optional* |
</div>


## `GroupAnnouncementFileGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the announcement repository file information.

The response is either `GroupAnnouncementFileGetResponse()` or `ErrorResponse()`.
Replaced by: `GroupAnnouncementFileGetRequest22()`.

**Attributes:**

|Name                  |Type                    |Description         |
|----------------------|------------------------|--------------------|
|service_provider_id   |str                     |serviceProviderId   |
|group_id              |str                     |groupId             |
|announcement_file_key |OCI.announcementFileKey |announcementFileKey |
</div>


## `GroupAnnouncementFileGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the announcement repository file information.

The following elements are only used in AS data mode and ignored in XS data mode:
announcementFileExternalId

The response is either `GroupAnnouncementFileGetResponse22()` or `ErrorResponse()`.

**Attributes:**

|Name                          |Type                    |Description                           |
|------------------------------|------------------------|--------------------------------------|
|service_provider_id           |str                     |serviceProviderId *Optional*          |
|group_id                      |str                     |groupId *Optional*                    |
|announcement_file_key         |OCI.announcementFileKey |announcementFileKey *Optional*        |
|announcement_file_external_id |str                     |announcementFileExternalId *Optional* |
</div>


## `GroupAnnouncementFileModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an existing announcement in the group repository The following elements are
only used in AS data mode and ignored in XS data mode: announcementFileExternalId The
response is either a `SuccessResponse()` or an `ErrorResponse()`.


**Attributes:**

|Name                          |Type                    |Description                           |
|------------------------------|------------------------|--------------------------------------|
|service_provider_id           |str                     |serviceProviderId *Optional*          |
|group_id                      |str                     |groupId *Optional*                    |
|announcement_file_key         |OCI.announcementFileKey |announcementFileKey *Optional*        |
|announcement_file_external_id |str                     |announcementFileExternalId *Optional* |
|new_announcement_file_name    |str                     |newAnnouncementFileName *Optional*    |
|announcement_file             |OCI.announcementFile    |announcementFile *Optional*           |
</div>


## `GroupAutoAttendantModifyActiveInstanceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to set the active status of Auto Attendant instances.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name               |Type                        |Description                  |
|-------------------|----------------------------|-----------------------------|
|service_activation |List[OCI.serviceActivation] |serviceActivation *Optional* |
</div>


## `GroupBroadWorksAnywhereModifyActiveInstanceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to set the active status of BroadWorks Anywhere instances.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name               |Type                        |Description                  |
|-------------------|----------------------------|-----------------------------|
|service_activation |List[OCI.serviceActivation] |serviceActivation *Optional* |
</div>


## `GroupBroadWorksMobilityModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the group level broadworks mobility service settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                           |Type                 |Description                                          |
|-----------------------------------------------|---------------------|-----------------------------------------------------|
|service_provider_id                            |str                  |serviceProviderId                                    |
|group_id                                       |str                  |groupId                                              |
|use_setting_level                              |str                  |useSettingLevel *Optional*                           |
|enable_location_services                       |bool                 |enableLocationServices *Optional*                    |
|enable_msrn_lookup                             |bool                 |enableMSRNLookup *Optional*                          |
|enable_mobile_state_checking                   |bool                 |enableMobileStateChecking *Optional*                 |
|deny_call_originations                         |bool                 |denyCallOriginations *Optional*                      |
|deny_call_terminations                         |bool                 |denyCallTerminations *Optional*                      |
|enable_announcement_suppression                |bool                 |enableAnnouncementSuppression *Optional*             |
|enable_internal_clid_delivery                  |bool                 |enableInternalCLIDDelivery *Optional*                |
|enable_internal_clid_delivery_access_locations |bool                 |enableInternalCLIDDeliveryAccessLocations *Optional* |
|enable_enhanced_unreachable_state_checking     |bool                 |enableEnhancedUnreachableStateChecking *Optional*    |
|enable_network_call_barring_status_check       |bool                 |enableNetworkCallBarringStatusCheck *Optional*       |
|network_translation_index                      |str                  |networkTranslationIndex *Optional*                   |
|enable_pbx_route_policy                        |bool                 |enablePBXRoutePolicy *Optional*                      |
|pbx_route_identity                             |OCI.pbxRouteIdentity |pbxRouteIdentity *Optional*                          |
</div>


## `GroupCPEConfigSetConfigFileRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to set a new group default configuration file for a device type.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. When the element
configFile is set to nil, the configuration file defined at the parent level is used.

**Attributes:**

|Name                |Type           |Description       |
|--------------------|---------------|------------------|
|service_provider_id |str            |serviceProviderId |
|group_id            |str            |groupId           |
|device_type         |str            |deviceType        |
|config_file         |OCI.configFile |configFile        |
</div>


## `GroupCallCapacityManagementModifyInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies a Call Capacity Management group.

Replaces the entire list of users in the group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                               |Type           |Description                              |
|-----------------------------------|---------------|-----------------------------------------|
|service_provider_id                |str            |serviceProviderId                        |
|group_id                           |str            |groupId                                  |
|name                               |str            |name                                     |
|new_name                           |str            |newName *Optional*                       |
|max_active_calls_allowed           |int            |maxActiveCallsAllowed *Optional*         |
|max_incoming_active_calls_allowed  |int            |maxIncomingActiveCallsAllowed *Optional* |
|max_outgoing_active_calls_allowed  |int            |maxOutgoingActiveCallsAllowed *Optional* |
|become_default_group_for_new_users |bool           |becomeDefaultGroupForNewUsers *Optional* |
|user_id_list                       |OCI.userIdList |userIdList *Optional*                    |
</div>


## `GroupCallCenterAddAgentListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add agent(s) to a call center.

The response is either `SuccessResponse()` or `ErrorResponse()`. If the skill level is
not present for skill based premium call centers, the users will be set to skill level
1. The following element is only used in AS data mode and ignored in XS data mode:
agentSkillList

**Attributes:**

|Name             |Type                     |Description               |
|-----------------|-------------------------|--------------------------|
|service_user_id  |str                      |serviceUserId             |
|agent_user_id    |List[str]                |agentUserId *Optional*    |
|agent_skill_list |List[OCI.agentSkillList] |agentSkillList *Optional* |
</div>


## `GroupCallCenterAddDNISRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Call Center DNIS The response is either a `SuccessResponse()` or an
`ErrorResponse()`.


**Attributes:**

|Name                                  |Type        |Description                         |
|--------------------------------------|------------|------------------------------------|
|dnis_key                              |OCI.dnisKey |dnisKey                             |
|dnis_phone_number                     |str         |dnisPhoneNumber *Optional*          |
|extension                             |str         |extension *Optional*                |
|use_custom_clid_settings              |bool        |useCustomCLIDSettings               |
|calling_line_id_phone_number          |str         |callingLineIdPhoneNumber *Optional* |
|calling_line_id_last_name             |str         |callingLineIdLastName *Optional*    |
|calling_line_id_first_name            |str         |callingLineIdFirstName *Optional*   |
|use_custom_dnis_announcement_settings |bool        |useCustomDnisAnnouncementSettings   |
|priority                              |str         |priority                            |
|allow_outgoing_acd_call               |bool        |allowOutgoingACDCall                |
</div>


## `GroupCallCenterAgentThresholdProfileModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies an existing Call Center Agent Threshold Profile in the Group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                                  |Type                             |Description                                                |
|------------------------------------------------------|---------------------------------|-----------------------------------------------------------|
|service_provider_id                                   |str                              |serviceProviderId                                          |
|group_id                                              |str                              |groupId                                                    |
|profile_name                                          |str                              |profileName                                                |
|new_profile_name                                      |str                              |newProfileName *Optional*                                  |
|profile_description                                   |str                              |profileDescription *Optional*                              |
|threshold_current_call_state_idle_time_yellow         |int                              |thresholdCurrentCallStateIdleTimeYellow *Optional*         |
|threshold_current_call_state_idle_time_red            |int                              |thresholdCurrentCallStateIdleTimeRed *Optional*            |
|threshold_current_call_state_on_call_time_yellow      |int                              |thresholdCurrentCallStateOnCallTimeYellow *Optional*       |
|threshold_current_call_state_on_call_time_red         |int                              |thresholdCurrentCallStateOnCallTimeRed *Optional*          |
|threshold_current_agent_state_unavailable_time_yellow |int                              |thresholdCurrentAgentStateUnavailableTimeYellow *Optional* |
|threshold_current_agent_state_unavailable_time_red    |int                              |thresholdCurrentAgentStateUnavailableTimeRed *Optional*    |
|threshold_average_busy_in_time_yellow                 |int                              |thresholdAverageBusyInTimeYellow *Optional*                |
|threshold_average_busy_in_time_red                    |int                              |thresholdAverageBusyInTimeRed *Optional*                   |
|threshold_average_busy_out_time_yellow                |int                              |thresholdAverageBusyOutTimeYellow *Optional*               |
|threshold_average_busy_out_time_red                   |int                              |thresholdAverageBusyOutTimeRed *Optional*                  |
|threshold_average_wrap_up_time_yellow                 |int                              |thresholdAverageWrapUpTimeYellow *Optional*                |
|threshold_average_wrap_up_time_red                    |int                              |thresholdAverageWrapUpTimeRed *Optional*                   |
|enable_notification_email                             |bool                             |enableNotificationEmail *Optional*                         |
|notification_email_address_list                       |OCI.notificationEmailAddressList |notificationEmailAddressList *Optional*                    |
|agent_user_id_list                                    |OCI.agentUserIdList              |agentUserIdList *Optional*                                 |
</div>


## `GroupCallCenterAgentUnavailableCodeSettingsModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the group level data associated with Call Center Agents Unavailable Code
Settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                                  |Type                    |Description                                                |
|------------------------------------------------------|------------------------|-----------------------------------------------------------|
|service_provider_id                                   |str                     |serviceProviderId                                          |
|group_id                                              |str                     |groupId                                                    |
|enable_agent_unavailable_codes                        |bool                    |enableAgentUnavailableCodes *Optional*                     |
|default_agent_unavailable_code_on_dnd                 |str                     |defaultAgentUnavailableCodeOnDND *Optional*                |
|default_agent_unavailable_code_on_personal_calls      |str                     |defaultAgentUnavailableCodeOnPersonalCalls *Optional*      |
|default_agent_unavailable_code_on_consecutive_bounces |str                     |defaultAgentUnavailableCodeOnConsecutiveBounces *Optional* |
|default_agent_unavailable_code_on_not_reachable       |str                     |defaultAgentUnavailableCodeOnNotReachable *Optional*       |
|force_use_of_agent_unavailable_codes                  |bool                    |forceUseOfAgentUnavailableCodes *Optional*                 |
|default_agent_unavailable_code                        |str                     |defaultAgentUnavailableCode *Optional*                     |
|code_state_list                                       |List[OCI.codeStateList] |codeStateList *Optional*                                   |
</div>


## `GroupCallCenterCallDispositionCodeModifyActiveListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to set the active status of Call Center Call Disposition Codes.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                             |Type                                    |Description                              |
|---------------------------------|----------------------------------------|-----------------------------------------|
|service_provider_id              |str                                     |serviceProviderId                        |
|group_id                         |str                                     |groupId                                  |
|call_disposition_code_activation |List[OCI.callDispositionCodeActivation] |callDispositionCodeActivation *Optional* |
</div>


## `GroupCallCenterDeleteDNISRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a call center's DNIS.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name     |Type        |Description|
|---------|------------|-----------|
|dnis_key |OCI.dnisKey |dnisKey    |
</div>


## `GroupCallCenterEnhancedReportingBrandingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the group branding configuration.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type             |Description               |
|--------------------|-----------------|--------------------------|
|service_provider_id |str              |serviceProviderId         |
|group_id            |str              |groupId                   |
|branding_choice     |str              |brandingChoice *Optional* |
|branding_file       |OCI.brandingFile |brandingFile *Optional*   |
</div>


## `GroupCallCenterEnhancedReportingReportTemplateAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a group level call center report template.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                    |Type             |Description                                    |
|----------------------------------------|-----------------|-----------------------------------------------|
|service_provider_id                     |str              |serviceProviderId                              |
|group_id                                |str              |groupId                                        |
|name                                    |str              |name                                           |
|description                             |str              |description *Optional*                         |
|data_template                           |str              |dataTemplate                                   |
|filter_number                           |int              |filterNumber *Optional*                        |
|xslt_template                           |OCI.xsltTemplate |xsltTemplate                                   |
|scope                                   |str              |scope                                          |
|is_enabled                              |bool             |isEnabled                                      |
|is_realtime_report                      |bool             |isRealtimeReport *Optional*                    |
|call_completion_threshold_param         |str              |callCompletionThresholdParam *Optional*        |
|short_duration_threshold_param          |str              |shortDurationThresholdParam *Optional*         |
|service_level_threshold_param           |str              |serviceLevelThresholdParam *Optional*          |
|service_level_inclusions_param          |str              |serviceLevelInclusionsParam *Optional*         |
|service_level_objective_threshold_param |str              |serviceLevelObjectiveThresholdParam *Optional* |
|abandoned_call_threshold_param          |str              |abandonedCallThresholdParam *Optional*         |
|service_level_threshold_param_number    |int              |serviceLevelThresholdParamNumber *Optional*    |
|abandoned_call_threshold_param_number   |int              |abandonedCallThresholdParamNumber *Optional*   |
|filter_value                            |List[str]        |filterValue *Optional*                         |
</div>


## `GroupCallCenterEnhancedReportingReportTemplateModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a group level call center report template.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type             |Description                 |
|--------------------|-----------------|----------------------------|
|service_provider_id |str              |serviceProviderId           |
|group_id            |str              |groupId                     |
|name                |str              |name                        |
|new_name            |str              |newName *Optional*          |
|description         |str              |description *Optional*      |
|xslt_template       |OCI.xsltTemplate |xsltTemplate *Optional*     |
|scope               |str              |scope *Optional*            |
|is_enabled          |bool             |isEnabled *Optional*        |
|is_realtime_report  |bool             |isRealtimeReport *Optional* |
|filter_number       |int              |filterNumber *Optional*     |
|filter_value        |OCI.filterValue  |filterValue *Optional*      |
</div>


## `GroupCallCenterGetDNISAgentListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of agent who selected the DNIS as the outgoing call.

The response is either `GroupCallCenterGetDNISAgentListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name     |Type        |Description|
|---------|------------|-----------|
|dnis_key |OCI.dnisKey |dnisKey    |
</div>


## `GroupCallCenterGetDNISAnnouncementRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's DNIS Announcements The response is either a
`GroupCallCenterGetDNISAnnouncementRequest()` or an `ErrorResponse()`.

Replaced by `GroupCallCenterGetDNISAnnouncementRequest17sp4()`

**Attributes:**

|Name     |Type        |Description|
|---------|------------|-----------|
|dnis_key |OCI.dnisKey |dnisKey    |
</div>


## `GroupCallCenterGetDNISAnnouncementRequest17sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's DNIS Announcements The response is either a
`GroupCallCenterGetDNISAnnouncementRequest17sp4()` or an `ErrorResponse()`.

Replaced by: `GroupCallCenterGetDNISAnnouncementRequest19()`.

**Attributes:**

|Name     |Type        |Description|
|---------|------------|-----------|
|dnis_key |OCI.dnisKey |dnisKey    |
</div>


## `GroupCallCenterGetDNISAnnouncementRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's DNIS Announcements The response is either a
`GroupCallCenterGetDNISAnnouncementRequest19()` or an `ErrorResponse()`.


**Attributes:**

|Name     |Type        |Description|
|---------|------------|-----------|
|dnis_key |OCI.dnisKey |dnisKey    |
</div>


## `GroupCallCenterGetDNISAnnouncementRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's DNIS Announcements The response is either a
`GroupCallCenterGetDNISAnnouncementResponse20()` or an `ErrorResponse()`.

Replaced by: `GroupCallCenterGetDNISAnnouncementRequest22()`.

**Attributes:**

|Name     |Type        |Description|
|---------|------------|-----------|
|dnis_key |OCI.dnisKey |dnisKey    |
</div>


## `GroupCallCenterGetDNISAnnouncementRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's DNIS Announcements The response is either a
`GroupCallCenterGetDNISAnnouncementRequest22()` or an `ErrorResponse()`.


**Attributes:**

|Name     |Type        |Description|
|---------|------------|-----------|
|dnis_key |OCI.dnisKey |dnisKey    |
</div>


## `GroupCallCenterGetDNISRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a call center's DNIS.

The response is either a `GroupCallCenterGetDNISRequest()` or an `ErrorResponse()`.

**Attributes:**

|Name     |Type        |Description|
|---------|------------|-----------|
|dnis_key |OCI.dnisKey |dnisKey    |
</div>


## `GroupCallCenterGetInstanceStatisticsRequest14sp9`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get Call Center queue and agent statistics.

The response is either `GroupCallCenterGetInstanceStatisticsResponse14sp9()` or
`ErrorResponse()`.

**Attributes:**

|Name             |Type                |Description     |
|-----------------|--------------------|----------------|
|service_user_id  |str                 |serviceUserId   |
|statistics_range |OCI.statisticsRange |statisticsRange |
</div>


## `GroupCallCenterModifyActiveInstanceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to set the active status of Call Center instances.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name               |Type                        |Description                  |
|-------------------|----------------------------|-----------------------------|
|service_activation |List[OCI.serviceActivation] |serviceActivation *Optional* |
</div>


## `GroupCallCenterModifyAnnouncementRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call center's announcement settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                |Type                                |Description                                |
|------------------------------------|------------------------------------|-------------------------------------------|
|service_user_id                     |str                                 |serviceUserId                              |
|entrance_message_selection          |str                                 |entranceMessageSelection *Optional*        |
|entrance_message_audio_file         |OCI.entranceMessageAudioFile        |entranceMessageAudioFile *Optional*        |
|entrance_message_video_file         |OCI.entranceMessageVideoFile        |entranceMessageVideoFile *Optional*        |
|periodic_comfort_message_selection  |str                                 |periodicComfortMessageSelection *Optional* |
|periodic_comfort_message_audio_file |OCI.periodicComfortMessageAudioFile |periodicComfortMessageAudioFile *Optional* |
|periodic_comfort_message_video_file |OCI.periodicComfortMessageVideoFile |periodicComfortMessageVideoFile *Optional* |
|on_hold_message_selection           |str                                 |onHoldMessageSelection *Optional*          |
|on_hold_message_audio_file          |OCI.onHoldMessageAudioFile          |onHoldMessageAudioFile *Optional*          |
|on_hold_message_video_file          |OCI.onHoldMessageVideoFile          |onHoldMessageVideoFile *Optional*          |
</div>


## `GroupCallCenterModifyAnnouncementRequest14sp6`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call center's announcement settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

Replaced By: `GroupCallCenterModifyAnnouncementRequest16()`

**Attributes:**

|Name                                            |Type                                |Description                                         |
|------------------------------------------------|------------------------------------|----------------------------------------------------|
|service_user_id                                 |str                                 |serviceUserId                                       |
|entrance_message_selection                      |str                                 |entranceMessageSelection *Optional*                 |
|entrance_message_audio_file                     |OCI.entranceMessageAudioFile        |entranceMessageAudioFile *Optional*                 |
|entrance_message_video_file                     |OCI.entranceMessageVideoFile        |entranceMessageVideoFile *Optional*                 |
|periodic_comfort_message_selection              |str                                 |periodicComfortMessageSelection *Optional*          |
|periodic_comfort_message_audio_file             |OCI.periodicComfortMessageAudioFile |periodicComfortMessageAudioFile *Optional*          |
|periodic_comfort_message_video_file             |OCI.periodicComfortMessageVideoFile |periodicComfortMessageVideoFile *Optional*          |
|on_hold_source                                  |OCI.onHoldSource                    |onHoldSource *Optional*                             |
|on_hold_use_alternate_source_for_internal_calls |bool                                |onHoldUseAlternateSourceForInternalCalls *Optional* |
|on_hold_internal_source                         |OCI.onHoldInternalSource            |onHoldInternalSource *Optional*                     |
</div>


## `GroupCallCenterModifyDNISRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call center's DNIS settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                  |Type        |Description                                  |
|--------------------------------------|------------|---------------------------------------------|
|dnis_key                              |OCI.dnisKey |dnisKey                                      |
|new_dnis_name                         |str         |newDNISName *Optional*                       |
|dnis_phone_number                     |str         |dnisPhoneNumber *Optional*                   |
|extension                             |str         |extension *Optional*                         |
|use_custom_clid_settings              |bool        |useCustomCLIDSettings *Optional*             |
|calling_line_id_phone_number          |str         |callingLineIdPhoneNumber *Optional*          |
|calling_line_id_last_name             |str         |callingLineIdLastName *Optional*             |
|calling_line_id_first_name            |str         |callingLineIdFirstName *Optional*            |
|use_custom_dnis_announcement_settings |bool        |useCustomDnisAnnouncementSettings *Optional* |
|priority                              |str         |priority *Optional*                          |
|allow_outgoing_acd_call               |bool        |allowOutgoingACDCall *Optional*              |
</div>


## `GroupCallCenterModifyInstanceWeightedCallDistributionRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the weighted call distribution of a Call Center instance.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type                  |Description            |
|----------------|----------------------|-----------------------|
|service_user_id |str                   |serviceUserId          |
|agent_weight    |List[OCI.agentWeight] |agentWeight *Optional* |
</div>


## `GroupCallCenterModifyRoutingPolicyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the group call center routing policy.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type                           |Description                     |
|-----------------------|-------------------------------|--------------------------------|
|service_provider_id    |str                            |serviceProviderId               |
|group_id               |str                            |groupId                         |
|routing_policy         |str                            |routingPolicy *Optional*        |
|routing_priority_order |List[OCI.routingPriorityOrder] |routingPriorityOrder *Optional* |
</div>


## `GroupCallCenterModifySupervisorListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Replaces a list of users as supervisors for a call center.

Also allows the modification of the reporting server URL address.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Element
"reportingServerURL"" will always be ignored.

Replaced By: `GroupCallCenterSupervisorReportingModifyRequest()`

**Attributes:**

|Name                    |Type                     |Description                     |
|------------------------|-------------------------|--------------------------------|
|service_user_id         |str                      |serviceUserId                   |
|reporting_server_url    |str                      |reportingServerURL *Optional*   |
|supervisor_user_id_list |OCI.supervisorUserIdList |supervisorUserIdList *Optional* |
</div>


## `GroupCallCenterModifySupervisorListRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the supervisor list for a call center.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                    |Type                     |Description                     |
|------------------------|-------------------------|--------------------------------|
|service_user_id         |str                      |serviceUserId                   |
|supervisor_user_id_list |OCI.supervisorUserIdList |supervisorUserIdList *Optional* |
</div>


## `GroupCallCenterQueueCallDispositionCodeSettingsModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the enterprise level data associated with Call Center Agents Unavailable Code
Settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                |Type                                    |Description                               |
|------------------------------------|----------------------------------------|------------------------------------------|
|service_user_id                     |str                                     |serviceUserId                             |
|enable_call_disposition_codes       |bool                                    |enableCallDispositionCodes *Optional*     |
|include_organization_codes          |bool                                    |includeOrganizationCodes *Optional*       |
|force_use_of_call_disposition_codes |bool                                    |forceUseOfCallDispositionCodes *Optional* |
|default_call_disposition_code       |OCI.defaultCallDispositionCode          |defaultCallDispositionCode *Optional*     |
|call_disposition_code_activation    |List[OCI.callDispositionCodeActivation] |callDispositionCodeActivation *Optional*  |
</div>


## `GroupCallCenterQueueThresholdsModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call center's queue Thresholds settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                          |Type                             |Description                                         |
|----------------------------------------------|---------------------------------|----------------------------------------------------|
|service_user_id                               |str                              |serviceUserId                                       |
|is_active                                     |bool                             |isActive *Optional*                                 |
|threshold_current_calls_in_queue_yellow       |int                              |thresholdCurrentCallsInQueueYellow *Optional*       |
|threshold_current_calls_in_queue_red          |int                              |thresholdCurrentCallsInQueueRed *Optional*          |
|threshold_current_longest_waiting_call_yellow |int                              |thresholdCurrentLongestWaitingCallYellow *Optional* |
|threshold_current_longest_waiting_call_red    |int                              |thresholdCurrentLongestWaitingCallRed *Optional*    |
|threshold_average_estimated_wait_time_yellow  |int                              |thresholdAverageEstimatedWaitTimeYellow *Optional*  |
|threshold_average_estimated_wait_time_red     |int                              |thresholdAverageEstimatedWaitTimeRed *Optional*     |
|threshold_average_handling_time_yellow        |int                              |thresholdAverageHandlingTimeYellow *Optional*       |
|threshold_average_handling_time_red           |int                              |thresholdAverageHandlingTimeRed *Optional*          |
|threshold_average_speed_of_answer_yellow      |int                              |thresholdAverageSpeedOfAnswerYellow *Optional*      |
|threshold_average_speed_of_answer_red         |int                              |thresholdAverageSpeedOfAnswerRed *Optional*         |
|enable_notification_email                     |bool                             |enableNotificationEmail *Optional*                  |
|notification_email_address_list               |OCI.notificationEmailAddressList |notificationEmailAddressList *Optional*             |
</div>


## `GroupCallCenterSupervisorReportingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Replaces a list of users as supervisors for a call center.

Also allows the modification of the reporting server URL address.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

Replaced By: `GroupCallCenterModifySupervisorListRequest16()`

**Attributes:**

|Name                    |Type                     |Description                     |
|------------------------|-------------------------|--------------------------------|
|service_user_id         |str                      |serviceUserId                   |
|reporting_server_name   |str                      |reportingServerName *Optional*  |
|supervisor_user_id_list |OCI.supervisorUserIdList |supervisorUserIdList *Optional* |
</div>


## `GroupCallParkModifyInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies a Call Park group.

Replaces the entire list of users in the group.  The users are in the list are in the
order they will try to be parked on.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                     |Type           |Description                      |
|-------------------------|---------------|---------------------------------|
|service_provider_id      |str            |serviceProviderId                |
|group_id                 |str            |groupId                          |
|name                     |str            |name                             |
|new_name                 |str            |newName *Optional*               |
|user_id_list             |OCI.userIdList |userIdList *Optional*            |
|recall_alternate_user_id |str            |recallAlternateUserId *Optional* |
|recall_to                |str            |recallTo *Optional*              |
</div>


## `GroupCallPickupModifyInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies a Call Pickup group.

Replaces the entire list of users in the group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type           |Description           |
|--------------------|---------------|----------------------|
|service_provider_id |str            |serviceProviderId     |
|group_id            |str            |groupId               |
|name                |str            |name                  |
|new_name            |str            |newName *Optional*    |
|user_id_list        |OCI.userIdList |userIdList *Optional* |
</div>


## `GroupCommonPhoneListAddListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add one or more entries to a group's common phone list.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type            |Description       |
|--------------------|----------------|------------------|
|service_provider_id |str             |serviceProviderId |
|group_id            |str             |groupId           |
|entry               |List[OCI.entry] |entry             |
</div>


## `GroupCommunicationBarringAuthorizationCodeAddListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a list of Communication Barring Authorization codes to a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`GroupCommunicationBarringAuthorizationCodeAddListRequest21sp1()` in AS data mode

**Attributes:**

|Name                |Type           |Description       |
|--------------------|---------------|------------------|
|service_provider_id |str            |serviceProviderId |
|group_id            |str            |groupId           |
|code                |List[OCI.code] |code              |
</div>


## `GroupCommunicationBarringAuthorizationCodeAddListRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a list of Communication Barring Authorization codes to a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type           |Description       |
|--------------------|---------------|------------------|
|service_provider_id |str            |serviceProviderId |
|group_id            |str            |groupId           |
|code                |List[OCI.code] |code              |
</div>


## `GroupCommunicationBarringProfileModifyListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Assign a replacement list of Communication Barring Profiles to a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. This command
only applies to groups in an Enterprise.  This command will fail for groups in a
Service Provider.

**Attributes:**

|Name                |Type            |Description            |
|--------------------|----------------|-----------------------|
|service_provider_id |str             |serviceProviderId      |
|group_id            |str             |groupId                |
|profile_name        |OCI.profileName |profileName *Optional* |
</div>


## `GroupConsolidatedDnAssignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Adds DNs to enterprise and group and activates the DNs on assignment.

It is possible to add either: a single DN, or a list of DNs, or a range of DNs, or any
combination thereof.

The response is either `SuccessResponse()` or
`GroupConsolidatedDnAssignListResponse()`.

**Attributes:**

|Name                |Type                  |Description            |
|--------------------|----------------------|-----------------------|
|service_provider_id |str                   |serviceProviderId      |
|group_id            |str                   |groupId                |
|phone_number        |List[OCI.phoneNumber] |phoneNumber *Optional* |
|dn_range            |List[OCI.dnRange]     |dnRange *Optional*     |
</div>


## `GroupCustomContactDirectoryAddRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Adds a Custom Contact Directory to a group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type            |Description       |
|--------------------|----------------|------------------|
|service_provider_id |str             |serviceProviderId |
|group_id            |str             |groupId           |
|name                |str             |name              |
|entry               |List[OCI.entry] |entry *Optional*  |
</div>


## `GroupCustomContactDirectoryModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Adds a Custom Contact Directory to a group.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replace by:
`GroupCustomContactDirectoryModifyRequest17()`

**Attributes:**

|Name                |Type           |Description           |
|--------------------|---------------|----------------------|
|service_provider_id |str            |serviceProviderId     |
|group_id            |str            |groupId               |
|name                |str            |name                  |
|new_name            |str            |newName *Optional*    |
|user_id_list        |OCI.userIdList |userIdList *Optional* |
</div>


## `GroupDepartmentAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a department to a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode: callingLineIdName caliingLineIdPhoneNumber

**Attributes:**

|Name                         |Type                    |Description                         |
|-----------------------------|------------------------|------------------------------------|
|service_provider_id          |str                     |serviceProviderId                   |
|group_id                     |str                     |groupId                             |
|department_name              |str                     |departmentName                      |
|parent_department_key        |OCI.parentDepartmentKey |parentDepartmentKey *Optional*      |
|calling_line_id_name         |str                     |callingLineIdName *Optional*        |
|calling_line_id_phone_number |str                     |callingLineIdPhoneNumber *Optional* |
</div>


## `GroupDepartmentModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a department of a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode: callingLineIdName caliingLineIdPhoneNumber

**Attributes:**

|Name                         |Type                       |Description                         |
|-----------------------------|---------------------------|------------------------------------|
|service_provider_id          |str                        |serviceProviderId                   |
|group_id                     |str                        |groupId                             |
|department_name              |str                        |departmentName                      |
|new_department_name          |str                        |newDepartmentName *Optional*        |
|new_parent_department_key    |OCI.newParentDepartmentKey |newParentDepartmentKey *Optional*   |
|calling_line_id_name         |str                        |callingLineIdName *Optional*        |
|calling_line_id_phone_number |str                        |callingLineIdPhoneNumber *Optional* |
</div>


## `GroupDeviceTypeFileModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a specified device type file for a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

Replaced By: `GroupDeviceTypeFileModifyRequest14sp8()`

**Attributes:**

|Name                |Type           |Description           |
|--------------------|---------------|----------------------|
|service_provider_id |str            |serviceProviderId     |
|group_id            |str            |groupId               |
|device_type         |str            |deviceType            |
|file_type           |str            |fileType              |
|file_source         |str            |fileSource *Optional* |
|upload_file         |OCI.uploadFile |uploadFile *Optional* |
</div>


## `GroupDeviceTypeFileModifyRequest14sp8`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a specified device type file for a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type           |Description           |
|--------------------|---------------|----------------------|
|service_provider_id |str            |serviceProviderId     |
|group_id            |str            |groupId               |
|device_type         |str            |deviceType            |
|file_format         |str            |fileFormat            |
|file_source         |str            |fileSource *Optional* |
|upload_file         |OCI.uploadFile |uploadFile *Optional* |
</div>


## `GroupDialableCallerIDCriteriaModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a Dialable Caller ID Criteria.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                           |Type                            |Description                            |
|-------------------------------|--------------------------------|---------------------------------------|
|service_provider_id            |str                             |serviceProviderId                      |
|group_id                       |str                             |groupId                                |
|name                           |str                             |name                                   |
|new_name                       |str                             |newName *Optional*                     |
|description                    |str                             |description *Optional*                 |
|prefix_digits                  |str                             |prefixDigits *Optional*                |
|match_call_type                |OCI.matchCallType               |matchCallType *Optional*               |
|match_alternate_call_indicator |OCI.matchAlternateCallIndicator |matchAlternateCallIndicator *Optional* |
|match_local_category           |bool                            |matchLocalCategory *Optional*          |
|match_national_category        |bool                            |matchNationalCategory *Optional*       |
|match_interlata_category       |bool                            |matchInterlataCategory *Optional*      |
|match_intralata_category       |bool                            |matchIntralataCategory *Optional*      |
|match_international_category   |bool                            |matchInternationalCategory *Optional*  |
|match_private_category         |bool                            |matchPrivateCategory *Optional*        |
|match_emergency_category       |bool                            |matchEmergencyCategory *Optional*      |
|match_other_category           |bool                            |matchOtherCategory *Optional*          |
</div>


## `GroupDialableCallerIDModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the group's Dialable Caller ID settings and criteria list.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                        |Type                            |Description                         |
|----------------------------|--------------------------------|------------------------------------|
|service_provider_id         |str                             |serviceProviderId                   |
|group_id                    |str                             |groupId                             |
|use_group_criteria          |bool                            |useGroupCriteria *Optional*         |
|ns_screening_failure_policy |str                             |nsScreeningFailurePolicy *Optional* |
|criteria_priority_order     |List[OCI.criteriaPriorityOrder] |criteriaPriorityOrder *Optional*    |
</div>


## `GroupDirectoryNumberHuntingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Replaces a list of users as agents for a directory number hunting group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                                     |Type                |Description                                                |
|---------------------------------------------------------|--------------------|-----------------------------------------------------------|
|service_user_id                                          |str                 |serviceUserId                                              |
|agent_user_id_list                                       |OCI.agentUserIdList |agentUserIdList *Optional*                                 |
|use_terminate_call_to_agent_first                        |bool                |useTerminateCallToAgentFirst *Optional*                    |
|use_original_agent_services_for_busy_and_no_answer_calls |bool                |useOriginalAgentServicesForBusyAndNoAnswerCalls *Optional* |
</div>


## `GroupDnActivateListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Activate a list of assigned DNs on a group.

It is possible to activate either: a single DN, or a list of DNs, or a range of DNs,
or any combination thereof.  It is not an error to activate an already activated DN

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type              |Description            |
|--------------------|------------------|-----------------------|
|service_provider_id |str               |serviceProviderId      |
|group_id            |str               |groupId                |
|phone_number        |List[str]         |phoneNumber *Optional* |
|dn_range            |List[OCI.dnRange] |dnRange *Optional*     |
</div>


## `GroupDnAssignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Assign a list of service provider DNs to a group.

It is possible to assign either: a single DN, or a list of DNs, or a range of DNs, or
any combination thereof.  The DNs must have previously been added to the service
provider or enterprise.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type              |Description            |
|--------------------|------------------|-----------------------|
|service_provider_id |str               |serviceProviderId      |
|group_id            |str               |groupId                |
|phone_number        |List[str]         |phoneNumber *Optional* |
|dn_range            |List[OCI.dnRange] |dnRange *Optional*     |
</div>


## `GroupDnDeactivateListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Deactivate a list of activated DNs on a group.

The DNs then become available for activation again.  It is possible to deactivate
either: a single DN, or a list of DNs, or a range of DNs, or any combination thereof.
It is not an error to deactivate an already deactivated DN.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type              |Description            |
|--------------------|------------------|-----------------------|
|service_provider_id |str               |serviceProviderId      |
|group_id            |str               |groupId                |
|phone_number        |List[str]         |phoneNumber *Optional* |
|dn_range            |List[OCI.dnRange] |dnRange *Optional*     |
</div>


## `GroupDnListAssignDepartmentRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Assign a list of group DNs to a department.

If the department is not specified, this will make the DNs become unassigned from any
department.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type              |Description              |
|--------------------|------------------|-------------------------|
|service_provider_id |str               |serviceProviderId        |
|group_id            |str               |groupId                  |
|department_key      |OCI.departmentKey |departmentKey *Optional* |
|phone_number        |List[str]         |phoneNumber *Optional*   |
|dn_range            |List[OCI.dnRange] |dnRange *Optional*       |
</div>


## `GroupDnUnassignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Unassign a list of service provider DNs from a group.

The DNs then become available for assignment to other groups.  It is possible to
unassign either: a single DN, or a list of DNs, or a range of DNs, or any combination
thereof.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type              |Description            |
|--------------------|------------------|-----------------------|
|service_provider_id |str               |serviceProviderId      |
|group_id            |str               |groupId                |
|phone_number        |List[str]         |phoneNumber *Optional* |
|dn_range            |List[OCI.dnRange] |dnRange *Optional*     |
</div>


## `GroupEmergencyZonesAddHomeZoneListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a list of home zones and/or home zone ranges to the group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                       |Type                             |Description                       |
|---------------------------|---------------------------------|----------------------------------|
|service_provider_id        |str                              |serviceProviderId                 |
|group_id                   |str                              |groupId                           |
|home_zone_ip_address       |List[str]                        |homeZoneIpAddress *Optional*      |
|home_zone_ip_address_range |List[OCI.homeZoneIpAddressRange] |homeZoneIpAddressRange *Optional* |
</div>


## `GroupEmergencyZonesDeleteHomeZoneListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a list of home zones and/or home zone ranges to the group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                       |Type                             |Description                       |
|---------------------------|---------------------------------|----------------------------------|
|service_provider_id        |str                              |serviceProviderId                 |
|group_id                   |str                              |groupId                           |
|home_zone_ip_address       |List[str]                        |homeZoneIpAddress *Optional*      |
|home_zone_ip_address_range |List[OCI.homeZoneIpAddressRange] |homeZoneIpAddressRange *Optional* |
</div>


## `GroupExchangeIntegrationModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the group level configuration for Exchange Integration.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                        |Type                    |Description                          |
|----------------------------|------------------------|-------------------------------------|
|service_provider_id         |str                     |serviceProviderId                    |
|group_id                    |str                     |groupId                              |
|enable_exchange_integration |bool                    |enableExchangeIntegration *Optional* |
|exchange_url                |str                     |exchangeURL *Optional*               |
|exchange_credentials        |OCI.exchangeCredentials |exchangeCredentials *Optional*       |
</div>


## `GroupFeatureAccessCodeModifyListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a list of feature access codes for a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`GroupFeatureAccessCodeModifyRequest()`

**Attributes:**

|Name                  |Type                        |Description                    |
|----------------------|----------------------------|-------------------------------|
|service_provider_id   |str                         |serviceProviderId              |
|group_id              |str                         |groupId                        |
|feature_access_code   |List[OCI.featureAccessCode] |featureAccessCode *Optional*   |
|restore_default_codes |bool                        |restoreDefaultCodes *Optional* |
</div>


## `GroupFeatureAccessCodeModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify group FAC code level and the list of feature access codes for a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Note: choice
element is only valid when useFeatureAccessCodeLevel is set to "Group", otherwise an
`ErrorResponse()` will be returned.  Replaced by:
`GroupFeatureAccessCodeModifyRequest21()` in AS data mode

**Attributes:**

|Name                          |Type                        |Description                          |
|------------------------------|----------------------------|-------------------------------------|
|service_provider_id           |str                         |serviceProviderId                    |
|group_id                      |str                         |groupId                              |
|use_feature_access_code_level |str                         |useFeatureAccessCodeLevel *Optional* |
|restore_default_codes         |bool                        |restoreDefaultCodes *Optional*       |
|feature_access_code           |List[OCI.featureAccessCode] |featureAccessCode *Optional*         |
</div>


## `GroupFeatureAccessCodeModifyRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify group FAC code level and the list of feature access codes for a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Note: choice
element is only valid when useFeatureAccessCodeLevel is set to "Group", otherwise an
`ErrorResponse()` will be returned.  In release 20 the "Call Recording" FAC name is
changed to "Call Recording - Start". Replaced by:
`GroupFeatureAccessCodeModifyRequest21()`

**Attributes:**

|Name                          |Type                        |Description                          |
|------------------------------|----------------------------|-------------------------------------|
|service_provider_id           |str                         |serviceProviderId                    |
|group_id                      |str                         |groupId                              |
|use_feature_access_code_level |str                         |useFeatureAccessCodeLevel *Optional* |
|restore_default_codes         |bool                        |restoreDefaultCodes *Optional*       |
|feature_access_code           |List[OCI.featureAccessCode] |featureAccessCode *Optional*         |
</div>


## `GroupFeatureAccessCodeModifyRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify group FAC code level and the list of feature access codes for a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Note: choice
element is only valid when useFeatureAccessCodeLevel is set to "Group", otherwise an
`ErrorResponse()` will be returned.  In release 20 the "Call Recording" FAC name is
changed to "Call Recording - Start".

**Attributes:**

|Name                          |Type                        |Description                          |
|------------------------------|----------------------------|-------------------------------------|
|service_provider_id           |str                         |serviceProviderId                    |
|group_id                      |str                         |groupId                              |
|use_feature_access_code_level |str                         |useFeatureAccessCodeLevel *Optional* |
|restore_default_codes         |bool                        |restoreDefaultCodes *Optional*       |
|feature_access_code           |List[OCI.featureAccessCode] |featureAccessCode *Optional*         |
</div>


## `GroupFindMeFollowMeAddAlertingGroupSelectiveCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a criteria to the Find-me/Follow-me alerting group.

For the callToNumber, the extension and number elements are not used and the only
types accepted for each number are Primary and Alternates.  If other type is specified
the command fails.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type                   |Description                |
|--------------------|-----------------------|---------------------------|
|service_user_id     |str                    |serviceUserId              |
|alerting_group_name |str                    |alertingGroupName          |
|criteria_name       |str                    |criteriaName               |
|time_schedule       |OCI.timeSchedule       |timeSchedule *Optional*    |
|holiday_schedule    |OCI.holidaySchedule    |holidaySchedule *Optional* |
|blacklisted         |bool                   |blacklisted                |
|from_dn_criteria    |OCI.fromDnCriteria     |fromDnCriteria             |
|call_to_number      |List[OCI.callToNumber] |callToNumber *Optional*    |
</div>


## `GroupFindMeFollowMeModifyActiveInstanceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to set the active status of Find-me/Follow-me instances.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name               |Type                        |Description                  |
|-------------------|----------------------------|-----------------------------|
|service_activation |List[OCI.serviceActivation] |serviceActivation *Optional* |
</div>


## `GroupFindMeFollowMeModifyAlertingGroupRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a Find-me/Follow-me alerting group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                         |Type                         |Description                           |
|-----------------------------|-----------------------------|--------------------------------------|
|service_user_id              |str                          |serviceUserId                         |
|alerting_group_name          |str                          |alertingGroupName                     |
|new_alerting_group_name      |str                          |newAlertingGroupName *Optional*       |
|alerting_group_description   |str                          |alertingGroupDescription *Optional*   |
|use_diversion_inhibitor      |bool                         |useDiversionInhibitor *Optional*      |
|answer_confirmation_required |bool                         |answerConfirmationRequired *Optional* |
|number_of_rings              |int                          |numberOfRings *Optional*              |
|phone_number_or_user_list    |OCI.phoneNumberOrUserList    |phoneNumberOrUserList *Optional*      |
|criteria_activation          |List[OCI.criteriaActivation] |criteriaActivation *Optional*         |
</div>


## `GroupFlexibleSeatingHostModifyActiveInstanceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to set the active status of flexible seating host instances.

Host cannot be disabled when a flexible seating guest is associated.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name               |Type                        |Description                  |
|-------------------|----------------------------|-----------------------------|
|service_activation |List[OCI.serviceActivation] |serviceActivation *Optional* |
</div>


## `GroupGroupNightForwardingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the Group Night Forwarding group parameters.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                    |Type                |Description                     |
|------------------------|--------------------|--------------------------------|
|service_provider_id     |str                 |serviceProviderId               |
|group_id                |str                 |groupId                         |
|night_forwarding        |str                 |nightForwarding *Optional*      |
|business_hours          |OCI.businessHours   |businessHours *Optional*        |
|holiday_schedule        |OCI.holidaySchedule |holidaySchedule *Optional*      |
|forward_to_phone_number |str                 |forwardToPhoneNumber *Optional* |
</div>


## `GroupGroupPagingModifyActiveInstanceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to set the active status of Group Paging instances.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name               |Type                        |Description                  |
|-------------------|----------------------------|-----------------------------|
|service_activation |List[OCI.serviceActivation] |serviceActivation *Optional* |
</div>


## `GroupGroupPagingModifyOriginatorListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the originator list for a paging group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                    |Type                     |Description                     |
|------------------------|-------------------------|--------------------------------|
|service_user_id         |str                      |serviceUserId                   |
|originator_user_id_list |OCI.originatorUserIdList |originatorUserIdList *Optional* |
</div>


## `GroupGroupPagingModifyTargetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the target list for a paging group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type                 |Description                 |
|--------------------|---------------------|----------------------------|
|service_user_id     |str                  |serviceUserId               |
|target_user_id_list |OCI.targetUserIdList |targetUserIdList *Optional* |
</div>


## `GroupHolidayScheduleAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a holiday schedule to a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                  |Type          |Description          |
|----------------------|--------------|---------------------|
|service_provider_id   |str           |serviceProviderId    |
|group_id              |str           |groupId              |
|holiday_schedule_name |str           |holidayScheduleName  |
|holiday01             |OCI.holiday01 |holiday01 *Optional* |
|holiday02             |OCI.holiday02 |holiday02 *Optional* |
|holiday03             |OCI.holiday03 |holiday03 *Optional* |
|holiday04             |OCI.holiday04 |holiday04 *Optional* |
|holiday05             |OCI.holiday05 |holiday05 *Optional* |
|holiday06             |OCI.holiday06 |holiday06 *Optional* |
|holiday07             |OCI.holiday07 |holiday07 *Optional* |
|holiday08             |OCI.holiday08 |holiday08 *Optional* |
|holiday09             |OCI.holiday09 |holiday09 *Optional* |
|holiday10             |OCI.holiday10 |holiday10 *Optional* |
|holiday11             |OCI.holiday11 |holiday11 *Optional* |
|holiday12             |OCI.holiday12 |holiday12 *Optional* |
|holiday13             |OCI.holiday13 |holiday13 *Optional* |
|holiday14             |OCI.holiday14 |holiday14 *Optional* |
|holiday15             |OCI.holiday15 |holiday15 *Optional* |
|holiday16             |OCI.holiday16 |holiday16 *Optional* |
|holiday17             |OCI.holiday17 |holiday17 *Optional* |
|holiday18             |OCI.holiday18 |holiday18 *Optional* |
|holiday19             |OCI.holiday19 |holiday19 *Optional* |
|holiday20             |OCI.holiday20 |holiday20 *Optional* |
</div>


## `GroupHolidayScheduleModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a holiday schedule in a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                      |Type          |Description                       |
|--------------------------|--------------|----------------------------------|
|service_provider_id       |str           |serviceProviderId                 |
|group_id                  |str           |groupId                           |
|holiday_schedule_name     |str           |holidayScheduleName               |
|new_holiday_schedule_name |str           |newHolidayScheduleName *Optional* |
|holiday01                 |OCI.holiday01 |holiday01 *Optional*              |
|holiday02                 |OCI.holiday02 |holiday02 *Optional*              |
|holiday03                 |OCI.holiday03 |holiday03 *Optional*              |
|holiday04                 |OCI.holiday04 |holiday04 *Optional*              |
|holiday05                 |OCI.holiday05 |holiday05 *Optional*              |
|holiday06                 |OCI.holiday06 |holiday06 *Optional*              |
|holiday07                 |OCI.holiday07 |holiday07 *Optional*              |
|holiday08                 |OCI.holiday08 |holiday08 *Optional*              |
|holiday09                 |OCI.holiday09 |holiday09 *Optional*              |
|holiday10                 |OCI.holiday10 |holiday10 *Optional*              |
|holiday11                 |OCI.holiday11 |holiday11 *Optional*              |
|holiday12                 |OCI.holiday12 |holiday12 *Optional*              |
|holiday13                 |OCI.holiday13 |holiday13 *Optional*              |
|holiday14                 |OCI.holiday14 |holiday14 *Optional*              |
|holiday15                 |OCI.holiday15 |holiday15 *Optional*              |
|holiday16                 |OCI.holiday16 |holiday16 *Optional*              |
|holiday17                 |OCI.holiday17 |holiday17 *Optional*              |
|holiday18                 |OCI.holiday18 |holiday18 *Optional*              |
|holiday19                 |OCI.holiday19 |holiday19 *Optional*              |
|holiday20                 |OCI.holiday20 |holiday20 *Optional*              |
</div>


## `GroupHuntGroupModifyActiveInstanceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to set the active status of Hunt Group instances.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name               |Type                        |Description                  |
|-------------------|----------------------------|-----------------------------|
|service_activation |List[OCI.serviceActivation] |serviceActivation *Optional* |
</div>


## `GroupHuntGroupModifyInstanceWeightedCallDistributionRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the weighted call distribution of a Hunt Group instance.

The response is either `SuccessResponse()` or `ErrorResponse()`. NOTE: Prior to
release 14, any agents who were not in the list kept their existing weight setting.
In release 14, any agents who are not in the list will have their weight set to 0.

**Attributes:**

|Name            |Type                  |Description            |
|----------------|----------------------|-----------------------|
|service_user_id |str                   |serviceUserId          |
|agent_weight    |List[OCI.agentWeight] |agentWeight *Optional* |
</div>


## `GroupIMRNAssignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Assign a list of group DNs to the IMRN pool.

It is possible to assign either: a single DN, or a list of DNs, or a range of DNs, or
any combination thereof.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type                |Description          |
|--------------------|--------------------|---------------------|
|service_provider_id |str                 |serviceProviderId    |
|group_id            |str                 |groupId              |
|imrn                |List[str]           |imrn *Optional*      |
|imrn_range          |List[OCI.imrnRange] |imrnRange *Optional* |
</div>


## `GroupIMRNUnassignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Unassign a list of group DNs from the group IMRN pool.

The DNs then become available for assignment to users.  It is possible to delete
either: a single DN, or a list of DNs, or a range of DNs, or any combination thereof.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type                |Description          |
|--------------------|--------------------|---------------------|
|service_provider_id |str                 |serviceProviderId    |
|group_id            |str                 |groupId              |
|imrn                |List[str]           |imrn *Optional*      |
|imrn_range          |List[OCI.imrnRange] |imrnRange *Optional* |
</div>


## `GroupInstantGroupCallModifyActiveInstanceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to set the active status of Instant Group Call service instances.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name               |Type                        |Description                  |
|-------------------|----------------------------|-----------------------------|
|service_activation |List[OCI.serviceActivation] |serviceActivation *Optional* |
</div>


## `GroupInterceptGroupModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the group's intercept group service settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

Replaced By: `GroupInterceptGroupModifyRequest16()`

**Attributes:**

|Name                             |Type          |Description                            |
|---------------------------------|--------------|---------------------------------------|
|service_provider_id              |str           |serviceProviderId                      |
|group_id                         |str           |groupId                                |
|is_active                        |bool          |isActive *Optional*                    |
|announcement_selection           |str           |announcementSelection *Optional*       |
|audio_file                       |OCI.audioFile |audioFile *Optional*                   |
|video_file                       |OCI.videoFile |videoFile *Optional*                   |
|play_new_phone_number            |bool          |playNewPhoneNumber *Optional*          |
|new_phone_number                 |str           |newPhoneNumber *Optional*              |
|transfer_on_zero_to_phone_number |bool          |transferOnZeroToPhoneNumber *Optional* |
|transfer_phone_number            |str           |transferPhoneNumber *Optional*         |
</div>


## `GroupInterceptGroupModifyRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the group's intercept group service settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`GroupInterceptGroupModifyResponse21sp1()` in AS data mode

**Attributes:**

|Name                             |Type          |Description                              |
|---------------------------------|--------------|-----------------------------------------|
|service_provider_id              |str           |serviceProviderId                        |
|group_id                         |str           |groupId                                  |
|is_active                        |bool          |isActive *Optional*                      |
|announcement_selection           |str           |announcementSelection *Optional*         |
|audio_file                       |OCI.audioFile |audioFile *Optional*                     |
|video_file                       |OCI.videoFile |videoFile *Optional*                     |
|play_new_phone_number            |bool          |playNewPhoneNumber *Optional*            |
|new_phone_number                 |str           |newPhoneNumber *Optional*                |
|transfer_on_zero_to_phone_number |bool          |transferOnZeroToPhoneNumber *Optional*   |
|transfer_phone_number            |str           |transferPhoneNumber *Optional*           |
|reroute_outbound_calls           |bool          |rerouteOutboundCalls *Optional*          |
|outbound_reroute_phone_number    |str           |outboundReroutePhoneNumber *Optional*    |
|allow_outbound_local_calls       |bool          |allowOutboundLocalCalls *Optional*       |
|inbound_call_mode                |str           |inboundCallMode *Optional*               |
|alternate_blocking_announcement  |bool          |alternateBlockingAnnouncement *Optional* |
|route_to_voice_mail              |bool          |routeToVoiceMail *Optional*              |
</div>


## `GroupInterceptGroupModifyRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the group's intercept group service settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode:
exemptInboundMobilityCalls exemptOutboundMobilityCalls
disableParallelRingingToNetworkLocations

**Attributes:**

|Name                                          |Type          |Description                                         |
|----------------------------------------------|--------------|----------------------------------------------------|
|service_provider_id                           |str           |serviceProviderId                                   |
|group_id                                      |str           |groupId                                             |
|is_active                                     |bool          |isActive *Optional*                                 |
|announcement_selection                        |str           |announcementSelection *Optional*                    |
|audio_file                                    |OCI.audioFile |audioFile *Optional*                                |
|video_file                                    |OCI.videoFile |videoFile *Optional*                                |
|inbound_call_mode                             |str           |inboundCallMode *Optional*                          |
|alternate_blocking_announcement               |bool          |alternateBlockingAnnouncement *Optional*            |
|exempt_inbound_mobility_calls                 |bool          |exemptInboundMobilityCalls *Optional*               |
|disable_parallel_ringing_to_network_locations |bool          |disableParallelRingingToNetworkLocations *Optional* |
|route_to_voice_mail                           |bool          |routeToVoiceMail *Optional*                         |
|play_new_phone_number                         |bool          |playNewPhoneNumber *Optional*                       |
|new_phone_number                              |str           |newPhoneNumber *Optional*                           |
|transfer_on_zero_to_phone_number              |bool          |transferOnZeroToPhoneNumber *Optional*              |
|transfer_phone_number                         |str           |transferPhoneNumber *Optional*                      |
|outbound_call_mode                            |str           |outboundCallMode *Optional*                         |
|exempt_outbound_mobility_calls                |bool          |exemptOutboundMobilityCalls *Optional*              |
|reroute_outbound_calls                        |bool          |rerouteOutboundCalls *Optional*                     |
|outbound_reroute_phone_number                 |str           |outboundReroutePhoneNumber *Optional*               |
</div>


## `GroupMWIDeliveryToMobileEndpointModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the group level MWI custom notifications settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. If the request
is executed by a group administrator and modifies the useSettingLevel, the request is
rejected.

**Attributes:**

|Name                |Type                         |Description                   |
|--------------------|-----------------------------|------------------------------|
|service_provider_id |str                          |serviceProviderId             |
|group_id            |str                          |groupId                       |
|use_setting_level   |str                          |useSettingLevel *Optional*    |
|template_activation |List[OCI.templateActivation] |templateActivation *Optional* |
</div>


## `GroupMeetMeConferencingModifyActiveInstanceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to set the active status of Meet-Me Conferencing instances.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name               |Type                        |Description                  |
|-------------------|----------------------------|-----------------------------|
|service_activation |List[OCI.serviceActivation] |serviceActivation *Optional* |
</div>


## `GroupMeetMeConferencingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the group level data associated with Meet-Me Conferencing functions.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type               |Description               |
|--------------------|-------------------|--------------------------|
|service_provider_id |str                |serviceProviderId         |
|group_id            |str                |groupId                   |
|allocated_ports     |OCI.allocatedPorts |allocatedPorts *Optional* |
</div>


## `GroupModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the profile for a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in Amplify data mode and ignored in AS and XS data mode:
servicePolicy, callProcessingSliceId, provisioningSliceId, subscriberPartition.  When
the callProcessingSliceId or provisioningSliceId is set to nillable, it will be
assigned to the default Slice.  Only Provisioning admin and above can change the
callProcessingSliceId, provisioningSliceId, and subscriberPartition.  The following
elements are only used in Amplify and XS data mode and ignored in AS data mode:
preferredDataCenter.  Only Provisioning admin and above can change the
preferredDataCenter.  The following elements are only used in XS data mode and ignored
in Amplify and AS data mode: defaultUserCallingLineIdPhoneNumber.  The following
elements are only used in AS data mode and ignored in the XS data mode:
extensionLengthSettings dialPlanAccessCode dialPlanPolicy

**Attributes:**

|Name                                      |Type                        |Description                                    |
|------------------------------------------|----------------------------|-----------------------------------------------|
|service_provider_id                       |str                         |serviceProviderId                              |
|group_id                                  |str                         |groupId                                        |
|default_domain                            |str                         |defaultDomain *Optional*                       |
|user_limit                                |int                         |userLimit *Optional*                           |
|group_name                                |str                         |groupName *Optional*                           |
|calling_line_id_name                      |str                         |callingLineIdName *Optional*                   |
|calling_line_id_phone_number              |str                         |callingLineIdPhoneNumber *Optional*            |
|time_zone                                 |str                         |timeZone *Optional*                            |
|location_dialing_code                     |str                         |locationDialingCode *Optional*                 |
|contact                                   |OCI.contact                 |contact *Optional*                             |
|address                                   |OCI.address                 |address *Optional*                             |
|service_policy                            |str                         |servicePolicy *Optional*                       |
|call_processing_slice_id                  |str                         |callProcessingSliceId *Optional*               |
|provisioning_slice_id                     |str                         |provisioningSliceId *Optional*                 |
|subscriber_partition                      |str                         |subscriberPartition *Optional*                 |
|preferred_data_center                     |str                         |preferredDataCenter *Optional*                 |
|default_user_calling_line_id_phone_number |str                         |defaultUserCallingLineIdPhoneNumber *Optional* |
|extension_length_settings                 |OCI.extensionLengthSettings |extensionLengthSettings *Optional*             |
|dial_plan_access_code                     |OCI.dialPlanAccessCode      |dialPlanAccessCode *Optional*                  |
|dial_plan_policy                          |OCI.dialPlanPolicy          |dialPlanPolicy *Optional*                      |
</div>


## `GroupMusicOnHoldAddInstanceRequest14sp6`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Music on Hold Instance to a department.

The response is either `SuccessResponse()` or `ErrorResponse()`.

Replaced By: `GroupMusicOnHoldAddInstanceRequest16()`

**Attributes:**

|Name                                    |Type               |Description                        |
|----------------------------------------|-------------------|-----------------------------------|
|service_provider_id                     |str                |serviceProviderId                  |
|group_id                                |str                |groupId                            |
|department                              |OCI.department     |department                         |
|is_active_during_call_hold              |bool               |isActiveDuringCallHold             |
|is_active_during_call_park              |bool               |isActiveDuringCallPark             |
|is_active_during_busy_camp_on           |bool               |isActiveDuringBusyCampOn           |
|source                                  |OCI.source         |source                             |
|use_alternate_source_for_internal_calls |bool               |useAlternateSourceForInternalCalls |
|internal_source                         |OCI.internalSource |internalSource *Optional*          |
</div>


## `GroupMusicOnHoldAddInstanceRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Music on Hold Instance to a department.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                    |Type               |Description                        |
|----------------------------------------|-------------------|-----------------------------------|
|service_provider_id                     |str                |serviceProviderId                  |
|group_id                                |str                |groupId                            |
|department                              |OCI.department     |department                         |
|is_active_during_call_hold              |bool               |isActiveDuringCallHold             |
|is_active_during_call_park              |bool               |isActiveDuringCallPark             |
|is_active_during_busy_camp_on           |bool               |isActiveDuringBusyCampOn           |
|source                                  |OCI.source         |source                             |
|use_alternate_source_for_internal_calls |bool               |useAlternateSourceForInternalCalls |
|internal_source                         |OCI.internalSource |internalSource *Optional*          |
</div>


## `GroupMusicOnHoldAddInstanceRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Music on Hold Instance to a department.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by:
`GroupMusicOnHoldAddInstanceRequest21()`

**Attributes:**

|Name                                    |Type               |Description                        |
|----------------------------------------|-------------------|-----------------------------------|
|service_provider_id                     |str                |serviceProviderId                  |
|group_id                                |str                |groupId                            |
|department                              |OCI.department     |department                         |
|is_active_during_call_hold              |bool               |isActiveDuringCallHold             |
|is_active_during_call_park              |bool               |isActiveDuringCallPark             |
|is_active_during_busy_camp_on           |bool               |isActiveDuringBusyCampOn           |
|source                                  |OCI.source         |source                             |
|use_alternate_source_for_internal_calls |bool               |useAlternateSourceForInternalCalls |
|internal_source                         |OCI.internalSource |internalSource *Optional*          |
</div>


## `GroupMusicOnHoldAddInstanceRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Music on Hold Instance to a department.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by
`GroupMusicOnHoldAddInstanceRequest22()`.

**Attributes:**

|Name                                    |Type               |Description                        |
|----------------------------------------|-------------------|-----------------------------------|
|service_provider_id                     |str                |serviceProviderId                  |
|group_id                                |str                |groupId                            |
|department                              |OCI.department     |department                         |
|is_active_during_call_hold              |bool               |isActiveDuringCallHold             |
|is_active_during_call_park              |bool               |isActiveDuringCallPark             |
|is_active_during_busy_camp_on           |bool               |isActiveDuringBusyCampOn           |
|source                                  |OCI.source         |source                             |
|use_alternate_source_for_internal_calls |bool               |useAlternateSourceForInternalCalls |
|internal_source                         |OCI.internalSource |internalSource *Optional*          |
</div>


## `GroupMusicOnHoldAddInstanceRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Music on Hold Instance to a department.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by
`GroupMusicOnHoldAddInstanceRequest23()`.

**Attributes:**

|Name                                    |Type               |Description                        |
|----------------------------------------|-------------------|-----------------------------------|
|service_provider_id                     |str                |serviceProviderId                  |
|group_id                                |str                |groupId                            |
|department                              |OCI.department     |department                         |
|is_active_during_call_hold              |bool               |isActiveDuringCallHold             |
|is_active_during_call_park              |bool               |isActiveDuringCallPark             |
|is_active_during_busy_camp_on           |bool               |isActiveDuringBusyCampOn           |
|source                                  |OCI.source         |source                             |
|use_alternate_source_for_internal_calls |bool               |useAlternateSourceForInternalCalls |
|internal_source                         |OCI.internalSource |internalSource *Optional*          |
</div>


## `GroupMusicOnHoldAddInstanceRequest23`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Music on Hold Instance to a department.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode: -
useDynamicMOHDuringCallHold

**Attributes:**

|Name                                    |Type               |Description                        |
|----------------------------------------|-------------------|-----------------------------------|
|service_provider_id                     |str                |serviceProviderId                  |
|group_id                                |str                |groupId                            |
|department                              |OCI.department     |department                         |
|is_active_during_call_hold              |bool               |isActiveDuringCallHold             |
|is_active_during_call_park              |bool               |isActiveDuringCallPark             |
|is_active_during_busy_camp_on           |bool               |isActiveDuringBusyCampOn           |
|source                                  |OCI.source         |source                             |
|use_alternate_source_for_internal_calls |bool               |useAlternateSourceForInternalCalls |
|internal_source                         |OCI.internalSource |internalSource *Optional*          |
|use_dynamic_moh_during_call_hold        |bool               |useDynamicMOHDuringCallHold        |
</div>


## `GroupMusicOnHoldDeleteInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Music On Hold department instance.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type           |Description       |
|--------------------|---------------|------------------|
|service_provider_id |str            |serviceProviderId |
|group_id            |str            |groupId           |
|department          |OCI.department |department        |
</div>


## `GroupMusicOnHoldGetInstanceRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a Music On Hold data for a group or department instance.

The response is either `GroupMusicOnHoldGetInstanceResponse14()` or `ErrorResponse()`.

Replaced By: GroupMusicOnHoldGetInstanceRequest14Sp4

**Attributes:**

|Name                |Type           |Description           |
|--------------------|---------------|----------------------|
|service_provider_id |str            |serviceProviderId     |
|group_id            |str            |groupId               |
|department          |OCI.department |department *Optional* |
</div>


## `GroupMusicOnHoldGetInstanceRequest14sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a Music On Hold data for a group or department instance.

The response is either `GroupMusicOnHoldGetInstanceResponse14sp4()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type           |Description           |
|--------------------|---------------|----------------------|
|service_provider_id |str            |serviceProviderId     |
|group_id            |str            |groupId               |
|department          |OCI.department |department *Optional* |
</div>


## `GroupMusicOnHoldGetInstanceRequest14sp6`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a Music On Hold data for a group or department instance.

The response is either `GroupMusicOnHoldGetInstanceResponse14sp6()` or
`ErrorResponse()`.

Replaced By: `GroupMusicOnHoldGetInstanceRequest16()`

**Attributes:**

|Name                |Type           |Description           |
|--------------------|---------------|----------------------|
|service_provider_id |str            |serviceProviderId     |
|group_id            |str            |groupId               |
|department          |OCI.department |department *Optional* |
</div>


## `GroupMusicOnHoldGetInstanceRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a Music On Hold data for a group or department instance.

The response is either `GroupMusicOnHoldGetInstanceResponse16()` or `ErrorResponse()`.
Replaced by: `GroupMusicOnHoldGetInstanceRequest19()`.

**Attributes:**

|Name                |Type           |Description           |
|--------------------|---------------|----------------------|
|service_provider_id |str            |serviceProviderId     |
|group_id            |str            |groupId               |
|department          |OCI.department |department *Optional* |
</div>


## `GroupMusicOnHoldGetInstanceRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a Music On Hold data for a group or department instance.

The response is either `GroupMusicOnHoldGetInstanceResponse19()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type           |Description           |
|--------------------|---------------|----------------------|
|service_provider_id |str            |serviceProviderId     |
|group_id            |str            |groupId               |
|department          |OCI.department |department *Optional* |
</div>


## `GroupMusicOnHoldGetInstanceRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a Music On Hold data for a group or department instance.

The response is either `GroupMusicOnHoldGetInstanceResponse20()` or `ErrorResponse()`.
Replaced by: `GroupMusicOnHoldGetInstanceRequest21()`

**Attributes:**

|Name                |Type           |Description           |
|--------------------|---------------|----------------------|
|service_provider_id |str            |serviceProviderId     |
|group_id            |str            |groupId               |
|department          |OCI.department |department *Optional* |
</div>


## `GroupMusicOnHoldGetInstanceRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a Music On Hold data for a group or department instance.

The response is either `GroupMusicOnHoldGetInstanceResponse21()` or `ErrorResponse()`.
Replaced by `GroupMusicOnHoldGetInstanceRequest22()`

**Attributes:**

|Name                |Type           |Description           |
|--------------------|---------------|----------------------|
|service_provider_id |str            |serviceProviderId     |
|group_id            |str            |groupId               |
|department          |OCI.department |department *Optional* |
</div>


## `GroupMusicOnHoldGetInstanceRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a Music On Hold data for a group or department instance.

The response is either `GroupMusicOnHoldGetInstanceResponse22()` or `ErrorResponse()`.
Replaced by: `GroupMusicOnHoldGetInstanceRequest22V2()` in AS mode

**Attributes:**

|Name                |Type           |Description           |
|--------------------|---------------|----------------------|
|service_provider_id |str            |serviceProviderId     |
|group_id            |str            |groupId               |
|department          |OCI.department |department *Optional* |
</div>


## `GroupMusicOnHoldGetInstanceRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a Music On Hold data for a group or department instance.

The response is either `GroupMusicOnHoldGetInstanceResponse22V2()` or
`ErrorResponse()`. Replaced by: `GroupMusicOnHoldGetInstanceRequest23()`

**Attributes:**

|Name                |Type           |Description           |
|--------------------|---------------|----------------------|
|service_provider_id |str            |serviceProviderId     |
|group_id            |str            |groupId               |
|department          |OCI.department |department *Optional* |
</div>


## `GroupMusicOnHoldGetInstanceRequest22V3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a Music On Hold data for a group or department instance.

The response is either `GroupMusicOnHoldGetInstanceResponse22V3()` or
`ErrorResponse()`. Replaced by: `GroupMusicOnHoldGetInstanceRequest23V2()`

**Attributes:**

|Name                |Type           |Description           |
|--------------------|---------------|----------------------|
|service_provider_id |str            |serviceProviderId     |
|group_id            |str            |groupId               |
|department          |OCI.department |department *Optional* |
</div>


## `GroupMusicOnHoldGetInstanceRequest23`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a Music On Hold data for a group or department instance.

The response is either `GroupMusicOnHoldGetInstanceResponse23()` or `ErrorResponse()`.
Replaced by: `GroupMusicOnHoldGetInstanceRequest23V2()`

**Attributes:**

|Name                |Type           |Description           |
|--------------------|---------------|----------------------|
|service_provider_id |str            |serviceProviderId     |
|group_id            |str            |groupId               |
|department          |OCI.department |department *Optional* |
</div>


## `GroupMusicOnHoldGetInstanceRequest23V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a Music On Hold data for a group or department instance.

The response is either `GroupMusicOnHoldGetInstanceResponse23V2()` or
`ErrorResponse()`.

**Attributes:**

|Name                |Type           |Description           |
|--------------------|---------------|----------------------|
|service_provider_id |str            |serviceProviderId     |
|group_id            |str            |groupId               |
|department          |OCI.department |department *Optional* |
</div>


## `GroupMusicOnHoldModifyInstanceRequest14sp6`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify data for a group or department Music On Hold Instance.

The response is either `SuccessResponse()` or `ErrorResponse()`.

Replaced By: `GroupMusicOnHoldModifyInstanceRequest16()`

**Attributes:**

|Name                                    |Type               |Description                                   |
|----------------------------------------|-------------------|----------------------------------------------|
|service_provider_id                     |str                |serviceProviderId                             |
|group_id                                |str                |groupId                                       |
|department                              |OCI.department     |department *Optional*                         |
|is_active_during_call_hold              |bool               |isActiveDuringCallHold *Optional*             |
|is_active_during_call_park              |bool               |isActiveDuringCallPark *Optional*             |
|is_active_during_busy_camp_on           |bool               |isActiveDuringBusyCampOn *Optional*           |
|source                                  |OCI.source         |source *Optional*                             |
|use_alternate_source_for_internal_calls |bool               |useAlternateSourceForInternalCalls *Optional* |
|internal_source                         |OCI.internalSource |internalSource *Optional*                     |
</div>


## `GroupMusicOnHoldModifyInstanceRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify data for a group or department Music On Hold Instance.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                    |Type               |Description                                   |
|----------------------------------------|-------------------|----------------------------------------------|
|service_provider_id                     |str                |serviceProviderId                             |
|group_id                                |str                |groupId                                       |
|department                              |OCI.department     |department *Optional*                         |
|is_active_during_call_hold              |bool               |isActiveDuringCallHold *Optional*             |
|is_active_during_call_park              |bool               |isActiveDuringCallPark *Optional*             |
|is_active_during_busy_camp_on           |bool               |isActiveDuringBusyCampOn *Optional*           |
|source                                  |OCI.source         |source *Optional*                             |
|use_alternate_source_for_internal_calls |bool               |useAlternateSourceForInternalCalls *Optional* |
|internal_source                         |OCI.internalSource |internalSource *Optional*                     |
</div>


## `GroupMusicOnHoldModifyInstanceRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify data for a group or department Music On Hold Instance.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by:
`GroupMusicOnHoldModifyInstanceRequest21()`

**Attributes:**

|Name                                    |Type               |Description                                   |
|----------------------------------------|-------------------|----------------------------------------------|
|service_provider_id                     |str                |serviceProviderId                             |
|group_id                                |str                |groupId                                       |
|department                              |OCI.department     |department *Optional*                         |
|is_active_during_call_hold              |bool               |isActiveDuringCallHold *Optional*             |
|is_active_during_call_park              |bool               |isActiveDuringCallPark *Optional*             |
|is_active_during_busy_camp_on           |bool               |isActiveDuringBusyCampOn *Optional*           |
|source                                  |OCI.source         |source *Optional*                             |
|use_alternate_source_for_internal_calls |bool               |useAlternateSourceForInternalCalls *Optional* |
|internal_source                         |OCI.internalSource |internalSource *Optional*                     |
</div>


## `GroupMusicOnHoldModifyInstanceRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify data for a group or department Music On Hold Instance.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                    |Type               |Description                                   |
|----------------------------------------|-------------------|----------------------------------------------|
|service_provider_id                     |str                |serviceProviderId                             |
|group_id                                |str                |groupId                                       |
|department                              |OCI.department     |department *Optional*                         |
|is_active_during_call_hold              |bool               |isActiveDuringCallHold *Optional*             |
|is_active_during_call_park              |bool               |isActiveDuringCallPark *Optional*             |
|is_active_during_busy_camp_on           |bool               |isActiveDuringBusyCampOn *Optional*           |
|source                                  |OCI.source         |source *Optional*                             |
|use_alternate_source_for_internal_calls |bool               |useAlternateSourceForInternalCalls *Optional* |
|internal_source                         |OCI.internalSource |internalSource *Optional*                     |
</div>


## `GroupMusicOnHoldModifyInstanceRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify data for a group or department Music On Hold Instance.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                    |Type               |Description                                   |
|----------------------------------------|-------------------|----------------------------------------------|
|service_provider_id                     |str                |serviceProviderId                             |
|group_id                                |str                |groupId                                       |
|department                              |OCI.department     |department *Optional*                         |
|is_active_during_call_hold              |bool               |isActiveDuringCallHold *Optional*             |
|is_active_during_call_park              |bool               |isActiveDuringCallPark *Optional*             |
|is_active_during_busy_camp_on           |bool               |isActiveDuringBusyCampOn *Optional*           |
|source                                  |OCI.source         |source *Optional*                             |
|use_alternate_source_for_internal_calls |bool               |useAlternateSourceForInternalCalls *Optional* |
|internal_source                         |OCI.internalSource |internalSource *Optional*                     |
|use_dynamic_moh_during_call_hold        |bool               |useDynamicMOHDuringCallHold *Optional*        |
</div>


## `GroupNetworkClassOfServiceAssignListRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Assign a list of Network Classes of Service to a group.

A default Network Class of Service must be specified unless there is already one
assigned to the group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                             |Type                             |Description                      |
|---------------------------------|---------------------------------|---------------------------------|
|service_provider_id              |str                              |serviceProviderId                |
|group_id                         |str                              |groupId                          |
|network_class_of_service         |List[str]                        |networkClassOfService *Optional* |
|default_network_class_of_service |OCI.defaultNetworkClassOfService |defaultNetworkClassOfService     |
</div>


## `GroupNetworkClassOfServiceUnassignListRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Unassign a list of Network Classes of Service from a group.

If the default Network Class of Service is being unassigned, a new one must be
specified unless there are no more Network Classes of Service assigned to the group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                             |Type                             |Description                      |
|---------------------------------|---------------------------------|---------------------------------|
|service_provider_id              |str                              |serviceProviderId                |
|group_id                         |str                              |groupId                          |
|network_class_of_service         |List[str]                        |networkClassOfService *Optional* |
|default_network_class_of_service |OCI.defaultNetworkClassOfService |defaultNetworkClassOfService     |
</div>


## `GroupOutgoingCallingPlanDepartmentAuthorizationCodeAddListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a list of authorization codes to the group's default or a department.

When department is not specified, it is for the group default.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type                |Description              |
|--------------------|--------------------|-------------------------|
|service_provider_id |str                 |serviceProviderId        |
|group_id            |str                 |groupId                  |
|department_key      |OCI.departmentKey   |departmentKey *Optional* |
|code_entry          |List[OCI.codeEntry] |codeEntry                |
</div>


## `GroupOutgoingCallingPlanDepartmentAuthorizationCodeDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a list of authorization codes from the group's default or a department.

When department is not specified, it is for the group default.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type              |Description              |
|--------------------|------------------|-------------------------|
|service_provider_id |str               |serviceProviderId        |
|group_id            |str               |groupId                  |
|department_key      |OCI.departmentKey |departmentKey *Optional* |
|code                |List[str]         |code                     |
</div>


## `GroupOutgoingCallingPlanDepartmentAuthorizationCodeGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the list of authorization codes for a group default or a department.

When department is not specified, it is for the group default.

The response is either a
`GroupOutgoingCallingPlanDepartmentAuthorizationCodeGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type              |Description              |
|--------------------|------------------|-------------------------|
|service_provider_id |str               |serviceProviderId        |
|group_id            |str               |groupId                  |
|department_key      |OCI.departmentKey |departmentKey *Optional* |
</div>


## `GroupPreferredCarrierGroupModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the currently configured carriers for a group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                  |Type                     |Description                     |
|----------------------|-------------------------|--------------------------------|
|service_provider_id   |str                      |serviceProviderId               |
|group_id              |str                      |groupId                         |
|intra_lata_carrier    |OCI.intraLataCarrier     |intraLataCarrier *Optional*     |
|inter_lata_carrier    |OCI.interLataCarrier     |interLataCarrier *Optional*     |
|international_carrier |OCI.internationalCarrier |internationalCarrier *Optional* |
</div>


## `GroupRoutePointAddDNISRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Route Point DNIS.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                  |Type        |Description                         |
|--------------------------------------|------------|------------------------------------|
|dnis_key                              |OCI.dnisKey |dnisKey                             |
|dnis_phone_number                     |str         |dnisPhoneNumber *Optional*          |
|extension                             |str         |extension *Optional*                |
|use_custom_clid_settings              |bool        |useCustomCLIDSettings               |
|calling_line_id_phone_number          |str         |callingLineIdPhoneNumber *Optional* |
|calling_line_id_last_name             |str         |callingLineIdLastName *Optional*    |
|calling_line_id_first_name            |str         |callingLineIdFirstName *Optional*   |
|use_custom_dnis_announcement_settings |bool        |useCustomDnisAnnouncementSettings   |
|allow_outgoing_acd_call               |bool        |allowOutgoingACDCall                |
</div>


## `GroupRoutePointDeleteDNISRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a route point's DNIS.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name     |Type        |Description|
|---------|------------|-----------|
|dnis_key |OCI.dnisKey |dnisKey    |
</div>


## `GroupRoutePointGetDNISAgentListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of agent who selected the DNIS as the outgoing call.

The response is either `GroupRoutePointGetDNISAgentListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name     |Type        |Description|
|---------|------------|-----------|
|dnis_key |OCI.dnisKey |dnisKey    |
</div>


## `GroupRoutePointGetDNISAnnouncementRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a route point's DNIS Announcements The response is either a
`GroupRoutePointGetDNISAnnouncementResponse()` or an `ErrorResponse()`.

Replaced by: `GroupRoutePointGetDNISAnnouncementRequest19()`.

**Attributes:**

|Name     |Type        |Description|
|---------|------------|-----------|
|dnis_key |OCI.dnisKey |dnisKey    |
</div>


## `GroupRoutePointGetDNISAnnouncementRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a route point's DNIS Announcements The response is either a
`GroupRoutePointGetDNISAnnouncementResponse19()` or an `ErrorResponse()`.


**Attributes:**

|Name     |Type        |Description|
|---------|------------|-----------|
|dnis_key |OCI.dnisKey |dnisKey    |
</div>


## `GroupRoutePointGetDNISAnnouncementRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a route point's DNIS Announcements The response is either a
`GroupRoutePointGetDNISAnnouncementResponse20()` or an `ErrorResponse()`.

Replaced by: `GroupRoutePointGetDNISAnnouncementRequest22()`

**Attributes:**

|Name     |Type        |Description|
|---------|------------|-----------|
|dnis_key |OCI.dnisKey |dnisKey    |
</div>


## `GroupRoutePointGetDNISAnnouncementRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a route point's DNIS Announcements The response is either a
`GroupRoutePointGetDNISAnnouncementResponse22()` or an `ErrorResponse()`.


**Attributes:**

|Name     |Type        |Description|
|---------|------------|-----------|
|dnis_key |OCI.dnisKey |dnisKey    |
</div>


## `GroupRoutePointGetDNISRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a route point's DNIS.

The response is either a `GroupRoutePointGetDNISResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name     |Type        |Description|
|---------|------------|-----------|
|dnis_key |OCI.dnisKey |dnisKey    |
</div>


## `GroupRoutePointModifyActiveInstanceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to set the active status of Route Point instances.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name               |Type                        |Description                  |
|-------------------|----------------------------|-----------------------------|
|service_activation |List[OCI.serviceActivation] |serviceActivation *Optional* |
</div>


## `GroupRoutePointModifyDNISRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a route point's DNIS settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                  |Type        |Description                                  |
|--------------------------------------|------------|---------------------------------------------|
|dnis_key                              |OCI.dnisKey |dnisKey                                      |
|new_dnis_name                         |str         |newDNISName *Optional*                       |
|dnis_phone_number                     |str         |dnisPhoneNumber *Optional*                   |
|extension                             |str         |extension *Optional*                         |
|use_custom_clid_settings              |bool        |useCustomCLIDSettings *Optional*             |
|calling_line_id_phone_number          |str         |callingLineIdPhoneNumber *Optional*          |
|calling_line_id_last_name             |str         |callingLineIdLastName *Optional*             |
|calling_line_id_first_name            |str         |callingLineIdFirstName *Optional*            |
|use_custom_dnis_announcement_settings |bool        |useCustomDnisAnnouncementSettings *Optional* |
|allow_outgoing_acd_call               |bool        |allowOutgoingACDCall *Optional*              |
</div>


## `GroupRoutePointQueueCallDispositionCodeSettingsModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the queue level data associated with Route Point Agents Unavailable Code
Settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                |Type                                    |Description                               |
|------------------------------------|----------------------------------------|------------------------------------------|
|service_user_id                     |str                                     |serviceUserId                             |
|enable_call_disposition_codes       |bool                                    |enableCallDispositionCodes *Optional*     |
|include_organization_codes          |bool                                    |includeOrganizationCodes *Optional*       |
|force_use_of_call_disposition_codes |bool                                    |forceUseOfCallDispositionCodes *Optional* |
|default_call_disposition_code       |OCI.defaultCallDispositionCode          |defaultCallDispositionCode *Optional*     |
|call_disposition_code_activation    |List[OCI.callDispositionCodeActivation] |callDispositionCodeActivation *Optional*  |
</div>


## `GroupScheduleAddEventRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add an event to group schedule.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The startDate
element is adjusted to the first occurrence of the recurrent schedule that comes at or
after the startDate.  The endDate element is set to the sum of the adjusted starDate
element value and the event duration.

**Attributes:**

|Name                |Type            |Description            |
|--------------------|----------------|-----------------------|
|service_provider_id |str             |serviceProviderId      |
|group_id            |str             |groupId                |
|schedule_key        |OCI.scheduleKey |scheduleKey            |
|event_name          |str             |eventName              |
|start_date          |str             |startDate              |
|all_day_event       |bool            |allDayEvent *Optional* |
|start_time          |OCI.startTime   |startTime *Optional*   |
|end_time            |OCI.endTime     |endTime *Optional*     |
|end_date            |str             |endDate                |
|recurrence          |OCI.recurrence  |recurrence *Optional*  |
</div>


## `GroupScheduleDeleteEventListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a list of events from a group schedule.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type            |Description       |
|--------------------|----------------|------------------|
|service_provider_id |str             |serviceProviderId |
|group_id            |str             |groupId           |
|schedule_key        |OCI.scheduleKey |scheduleKey       |
|event_name          |List[str]       |eventName         |
</div>


## `GroupScheduleDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a list of group schedule.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type                  |Description       |
|--------------------|----------------------|------------------|
|service_provider_id |str                   |serviceProviderId |
|group_id            |str                   |groupId           |
|schedule_key        |List[OCI.scheduleKey] |scheduleKey       |
</div>


## `GroupScheduleGetEventDetailListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of events of a group schedule.

The response is either a `GroupScheduleGetEventDetailListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type            |Description       |
|--------------------|----------------|------------------|
|service_provider_id |str             |serviceProviderId |
|group_id            |str             |groupId           |
|schedule_key        |OCI.scheduleKey |scheduleKey       |
</div>


## `GroupScheduleGetEventListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of events of a group schedule.

The response is either a `GroupScheduleGetEventListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type            |Description       |
|--------------------|----------------|------------------|
|service_provider_id |str             |serviceProviderId |
|group_id            |str             |groupId           |
|schedule_key        |OCI.scheduleKey |scheduleKey       |
</div>


## `GroupScheduleGetEventRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get an event from a group schedule.

The response is either a `GroupScheduleGetEventResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type            |Description       |
|--------------------|----------------|------------------|
|service_provider_id |str             |serviceProviderId |
|group_id            |str             |groupId           |
|schedule_key        |OCI.scheduleKey |scheduleKey       |
|event_name          |str             |eventName         |
</div>


## `GroupScheduleModifyEventRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an event of a group schedule.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The startDate
element is adjusted to the first occurrence of the recurrent schedule that comes at or
after the startDate.  The endDate element is set to the sum of the adjusted starDate
element value and the event duration.

**Attributes:**

|Name                |Type            |Description             |
|--------------------|----------------|------------------------|
|service_provider_id |str             |serviceProviderId       |
|group_id            |str             |groupId                 |
|schedule_key        |OCI.scheduleKey |scheduleKey             |
|event_name          |str             |eventName               |
|new_event_name      |str             |newEventName *Optional* |
|start_date          |str             |startDate *Optional*    |
|all_day_event       |bool            |allDayEvent *Optional*  |
|start_time          |OCI.startTime   |startTime *Optional*    |
|end_time            |OCI.endTime     |endTime *Optional*      |
|end_date            |str             |endDate *Optional*      |
|recurrence          |OCI.recurrence  |recurrence *Optional*   |
</div>


## `GroupScheduleModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a group schedule.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type            |Description                |
|--------------------|----------------|---------------------------|
|service_provider_id |str             |serviceProviderId          |
|group_id            |str             |groupId                    |
|schedule_key        |OCI.scheduleKey |scheduleKey                |
|new_schedule_name   |str             |newScheduleName *Optional* |
</div>


## `GroupScheduleUsageRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of services using a group schedule.

The response is either a `GroupScheduleUsageResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type            |Description       |
|--------------------|----------------|------------------|
|service_provider_id |str             |serviceProviderId |
|group_id            |str             |groupId           |
|schedule_key        |OCI.scheduleKey |scheduleKey       |
</div>


## `GroupSeriesCompletionModifyInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies a Series Completion group.

Replaces the entire list of users in the group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type           |Description           |
|--------------------|---------------|----------------------|
|service_provider_id |str            |serviceProviderId     |
|group_id            |str            |groupId               |
|name                |str            |name                  |
|new_name            |str            |newName *Optional*    |
|user_id_list        |OCI.userIdList |userIdList *Optional* |
</div>


## `GroupSessionAdmissionControlGroupAddDeviceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add one ore more devices to a group level session admission control group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type              |Description       |
|--------------------|------------------|------------------|
|service_provider_id |str               |serviceProviderId |
|group_id            |str               |groupId           |
|name                |str               |name              |
|devices             |List[OCI.devices] |devices           |
</div>


## `GroupSessionAdmissionControlGroupAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a session admission control group for the group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                               |Type              |Description                                |
|-----------------------------------|------------------|-------------------------------------------|
|service_provider_id                |str               |serviceProviderId                          |
|group_id                           |str               |groupId                                    |
|name                               |str               |name                                       |
|max_session                        |int               |maxSession                                 |
|max_user_originating_sessions      |int               |maxUserOriginatingSessions *Optional*      |
|max_user_terminating_sessions      |int               |maxUserTerminatingSessions *Optional*      |
|reserved_session                   |int               |reservedSession                            |
|reserved_user_originating_sessions |int               |reservedUserOriginatingSessions *Optional* |
|reserved_user_terminating_sessions |int               |reservedUserTerminatingSessions *Optional* |
|become_default_group               |bool              |becomeDefaultGroup                         |
|count_intra_sac_group_sessions     |bool              |countIntraSACGroupSessions                 |
|devices                            |List[OCI.devices] |devices *Optional*                         |
</div>


## `GroupSessionAdmissionControlGroupAddRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a session admission control group for the group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Note that to
provision the accessInfoPattern element, the captureAccessInfoInPaniHeader system
parameter needs to be set to "true".

**Attributes:**

|Name                                               |Type              |Description                                |
|---------------------------------------------------|------------------|-------------------------------------------|
|service_provider_id                                |str               |serviceProviderId                          |
|group_id                                           |str               |groupId                                    |
|name                                               |str               |name                                       |
|max_session                                        |int               |maxSession                                 |
|max_user_originating_sessions                      |int               |maxUserOriginatingSessions *Optional*      |
|max_user_terminating_sessions                      |int               |maxUserTerminatingSessions *Optional*      |
|reserved_session                                   |int               |reservedSession                            |
|reserved_user_originating_sessions                 |int               |reservedUserOriginatingSessions *Optional* |
|reserved_user_terminating_sessions                 |int               |reservedUserTerminatingSessions *Optional* |
|become_default_group                               |bool              |becomeDefaultGroup                         |
|count_intra_sac_group_sessions                     |bool              |countIntraSACGroupSessions                 |
|devices                                            |List[OCI.devices] |devices *Optional*                         |
|block_emergency_and_repair_calls_due_to_sac_limits |bool              |blockEmergencyAndRepairCallsDueToSACLimits |
|media_group_name                                   |str               |mediaGroupName *Optional*                  |
|access_info_pattern                                |str               |accessInfoPattern *Optional*               |
</div>


## `GroupSessionAdmissionControlGroupDeleteDeviceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete one or more devices from a group level session admission control
group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type              |Description       |
|--------------------|------------------|------------------|
|service_provider_id |str               |serviceProviderId |
|group_id            |str               |groupId           |
|name                |str               |name              |
|devices             |List[OCI.devices] |devices           |
</div>


## `GroupTimeScheduleAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a time schedule to a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type               |Description               |
|--------------------|-------------------|--------------------------|
|service_provider_id |str                |serviceProviderId         |
|group_id            |str                |groupId                   |
|time_schedule_name  |str                |timeScheduleName          |
|time_interval01     |OCI.timeInterval01 |timeInterval01 *Optional* |
|time_interval02     |OCI.timeInterval02 |timeInterval02 *Optional* |
|time_interval03     |OCI.timeInterval03 |timeInterval03 *Optional* |
|time_interval04     |OCI.timeInterval04 |timeInterval04 *Optional* |
|time_interval05     |OCI.timeInterval05 |timeInterval05 *Optional* |
|time_interval06     |OCI.timeInterval06 |timeInterval06 *Optional* |
|time_interval07     |OCI.timeInterval07 |timeInterval07 *Optional* |
|time_interval08     |OCI.timeInterval08 |timeInterval08 *Optional* |
|time_interval09     |OCI.timeInterval09 |timeInterval09 *Optional* |
|time_interval10     |OCI.timeInterval10 |timeInterval10 *Optional* |
|time_interval11     |OCI.timeInterval11 |timeInterval11 *Optional* |
|time_interval12     |OCI.timeInterval12 |timeInterval12 *Optional* |
|time_interval13     |OCI.timeInterval13 |timeInterval13 *Optional* |
|time_interval14     |OCI.timeInterval14 |timeInterval14 *Optional* |
|time_interval15     |OCI.timeInterval15 |timeInterval15 *Optional* |
|time_interval16     |OCI.timeInterval16 |timeInterval16 *Optional* |
|time_interval17     |OCI.timeInterval17 |timeInterval17 *Optional* |
|time_interval18     |OCI.timeInterval18 |timeInterval18 *Optional* |
|time_interval19     |OCI.timeInterval19 |timeInterval19 *Optional* |
|time_interval20     |OCI.timeInterval20 |timeInterval20 *Optional* |
</div>


## `GroupTimeScheduleModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a specified time schedule in a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type               |Description                    |
|-----------------------|-------------------|-------------------------------|
|service_provider_id    |str                |serviceProviderId              |
|group_id               |str                |groupId                        |
|time_schedule_name     |str                |timeScheduleName               |
|new_time_schedule_name |str                |newTimeScheduleName *Optional* |
|time_interval01        |OCI.timeInterval01 |timeInterval01 *Optional*      |
|time_interval02        |OCI.timeInterval02 |timeInterval02 *Optional*      |
|time_interval03        |OCI.timeInterval03 |timeInterval03 *Optional*      |
|time_interval04        |OCI.timeInterval04 |timeInterval04 *Optional*      |
|time_interval05        |OCI.timeInterval05 |timeInterval05 *Optional*      |
|time_interval06        |OCI.timeInterval06 |timeInterval06 *Optional*      |
|time_interval07        |OCI.timeInterval07 |timeInterval07 *Optional*      |
|time_interval08        |OCI.timeInterval08 |timeInterval08 *Optional*      |
|time_interval09        |OCI.timeInterval09 |timeInterval09 *Optional*      |
|time_interval10        |OCI.timeInterval10 |timeInterval10 *Optional*      |
|time_interval11        |OCI.timeInterval11 |timeInterval11 *Optional*      |
|time_interval12        |OCI.timeInterval12 |timeInterval12 *Optional*      |
|time_interval13        |OCI.timeInterval13 |timeInterval13 *Optional*      |
|time_interval14        |OCI.timeInterval14 |timeInterval14 *Optional*      |
|time_interval15        |OCI.timeInterval15 |timeInterval15 *Optional*      |
|time_interval16        |OCI.timeInterval16 |timeInterval16 *Optional*      |
|time_interval17        |OCI.timeInterval17 |timeInterval17 *Optional*      |
|time_interval18        |OCI.timeInterval18 |timeInterval18 *Optional*      |
|time_interval19        |OCI.timeInterval19 |timeInterval19 *Optional*      |
|time_interval20        |OCI.timeInterval20 |timeInterval20 *Optional*      |
</div>


## `GroupTrunkGroupDeleteInstanceRequest14sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a Trunk Group Instance from a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name            |Type              |Description   |
|----------------|------------------|--------------|
|trunk_group_key |OCI.trunkGroupKey |trunkGroupKey |
</div>


## `GroupTrunkGroupGetInstanceRequest14sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a Trunk Group Instance's profile.

The response is either a `GroupTrunkGroupGetInstanceResponse14sp4()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type              |Description   |
|----------------|------------------|--------------|
|trunk_group_key |OCI.trunkGroupKey |trunkGroupKey |
</div>


## `GroupTrunkGroupGetInstanceRequest14sp5`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a Trunk Group Instance's profile.

The response is either a `GroupTrunkGroupGetInstanceResponse14sp5()` or an
`ErrorResponse()`. The response contains a hosted user table with column headings:
"User Id", "Last Name", "First Name", "Hiragana Last Name", "Hiragana First Name".

**Attributes:**

|Name            |Type              |Description   |
|----------------|------------------|--------------|
|trunk_group_key |OCI.trunkGroupKey |trunkGroupKey |
</div>


## `GroupTrunkGroupGetInstanceRequest14sp9`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a Trunk Group Instance's profile.

The response is either a `GroupTrunkGroupGetInstanceResponse14sp9()` or an
`ErrorResponse()`. The response contains a hosted user table with column headings:
"User Id", "Last Name", "First Name", "Hiragana Last Name", "Hiragana First Name".

**Attributes:**

|Name            |Type              |Description   |
|----------------|------------------|--------------|
|trunk_group_key |OCI.trunkGroupKey |trunkGroupKey |
</div>


## `GroupTrunkGroupGetInstanceRequest15`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a Trunk Group Instance's profile.

The response is either a `GroupTrunkGroupGetInstanceResponse15()` or an
`ErrorResponse()`. The response contains a hosted user table with column headings:
"User Id", "Last Name", "First Name", "Hiragana Last Name", "Hiragana First Name".

**Attributes:**

|Name            |Type              |Description   |
|----------------|------------------|--------------|
|trunk_group_key |OCI.trunkGroupKey |trunkGroupKey |
</div>


## `GroupTrunkGroupGetInstanceRequest15sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a Trunk Group Instance's profile.

The response is either a `GroupTrunkGroupGetInstanceResponse15sp2()` or an
`ErrorResponse()`. The response contains a hosted user table with column headings:
"User Id", "Last Name", "First Name", "Hiragana Last Name", "Hiragana First Name".

**Attributes:**

|Name            |Type              |Description   |
|----------------|------------------|--------------|
|trunk_group_key |OCI.trunkGroupKey |trunkGroupKey |
</div>


## `GroupTrunkGroupGetInstanceRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a Trunk Group Instance's profile.

The response is either a `GroupTrunkGroupGetInstanceResponse17()` or an
`ErrorResponse()`. The response contains a hosted user table with column headings:
"User Id", "Last Name", "First Name", "Hiragana Last Name", "Hiragana First Name".

**Attributes:**

|Name            |Type              |Description   |
|----------------|------------------|--------------|
|trunk_group_key |OCI.trunkGroupKey |trunkGroupKey |
</div>


## `GroupTrunkGroupGetInstanceRequest17sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a Trunk Group Instance's profile.

The response is either a `GroupTrunkGroupGetInstanceResponse17sp3()` or an
`ErrorResponse()`. The response contains a hosted user table with column headings:
"User Id", "Last Name", "First Name", "Hiragana Last Name", "Hiragana First Name".
Replaced by: `GroupTrunkGroupGetInstanceRequest17sp4()`

**Attributes:**

|Name            |Type              |Description   |
|----------------|------------------|--------------|
|trunk_group_key |OCI.trunkGroupKey |trunkGroupKey |
</div>


## `GroupTrunkGroupGetInstanceRequest17sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a Trunk Group Instance's profile.

The response is either a `GroupTrunkGroupGetInstanceResponse17sp4()` or an
`ErrorResponse()`. The response contains a hosted user table with column headings:
"User Id", "Last Name", "First Name", "Hiragana Last Name", "Hiragana First Name",
"Phone Number", "Extension", "Department", "Email Address".

**Attributes:**

|Name            |Type              |Description   |
|----------------|------------------|--------------|
|trunk_group_key |OCI.trunkGroupKey |trunkGroupKey |
</div>


## `GroupTrunkGroupGetInstanceRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a Trunk Group Instance's profile.

The response is either a `GroupTrunkGroupGetInstanceResponse19()` or an
`ErrorResponse()`. The response contains a hosted user table with column headings:
"User Id", "Last Name", "First Name", "Hiragana Last Name", "Hiragana First Name",
"Phone Number", "Extension", "Department", "Email Address". Replaced by
`GroupTrunkGroupGetInstanceRequest19sp1()`.

**Attributes:**

|Name            |Type              |Description   |
|----------------|------------------|--------------|
|trunk_group_key |OCI.trunkGroupKey |trunkGroupKey |
</div>


## `GroupTrunkGroupGetInstanceRequest19V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a Trunk Group Instance's profile.

The response is either a `GroupTrunkGroupGetInstanceResponse19V2()` or an
`ErrorResponse()`. The response contains a hosted user table with column headings:
"User Id", "Last Name", "First Name", "Hiragana Last Name", "Hiragana First Name",
"Phone Number", "Extension", "Department", "Email Address". Replaced by
GroupTrunkGroupGetInstanceRequest19sp1V2.

**Attributes:**

|Name            |Type              |Description   |
|----------------|------------------|--------------|
|trunk_group_key |OCI.trunkGroupKey |trunkGroupKey |
</div>


## `GroupTrunkGroupGetInstanceRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a Trunk Group Instance's profile.

The response is either a `GroupTrunkGroupGetInstanceResponse19sp1()` or an
`ErrorResponse()`. The response contains a hosted user table with column headings:
"User Id", "Last Name", "First Name", "Hiragana Last Name", "Hiragana First Name",
"Phone Number", "Extension", "Department", "Email Address". Replaced by
GroupTrunkGroupGetInstanceRequest19sp1V2.

**Attributes:**

|Name            |Type              |Description   |
|----------------|------------------|--------------|
|trunk_group_key |OCI.trunkGroupKey |trunkGroupKey |
</div>


## `GroupTrunkGroupGetInstanceRequest20sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a Trunk Group Instance's profile.

The response is either a `GroupTrunkGroupGetInstanceResponse20sp1()` or an
`ErrorResponse()`. The response contains a hosted user table with column headings:
"User Id", "Last Name", "First Name", "Hiragana Last Name", "Hiragana First Name",
"Phone Number", "Extension", "Department", "Email Address". Replaced by:
`GroupTrunkGroupGetInstanceRequest21()`

**Attributes:**

|Name            |Type              |Description   |
|----------------|------------------|--------------|
|trunk_group_key |OCI.trunkGroupKey |trunkGroupKey |
</div>


## `GroupTrunkGroupGetInstanceRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a Trunk Group Instance's profile.

The response is either a `GroupTrunkGroupGetInstanceResponse21()` or an
`ErrorResponse()`. The response contains a hosted user table with column headings:
"User Id", "Last Name", "First Name", "Hiragana Last Name", "Hiragana First Name",
"Phone Number", "Extension", "Department", "Email Address". Replaced by:
`GroupTrunkGroupGetInstanceResponse23()`

**Attributes:**

|Name            |Type              |Description   |
|----------------|------------------|--------------|
|trunk_group_key |OCI.trunkGroupKey |trunkGroupKey |
</div>


## `GroupTrunkGroupGetInstanceRequest23`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a Trunk Group Instance's profile.

The response is either a `GroupTrunkGroupGetInstanceResponse23()` or an
`ErrorResponse()`. The response contains a hosted user table with column headings:
"User Id", "Last Name", "First Name", "Hiragana Last Name", "Hiragana First Name",
"Phone Number", "Extension", "Department", "Email Address".

**Attributes:**

|Name            |Type              |Description   |
|----------------|------------------|--------------|
|trunk_group_key |OCI.trunkGroupKey |trunkGroupKey |
</div>


## `GroupTrunkGroupModifyInstanceRequest14sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a Trunk Group Instance in a group.

The access device cannot be modified or cleared if there are any users assigned to the
Trunk Group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                            |Type                                           |Description                                           |
|------------------------------------------------|-----------------------------------------------|------------------------------------------------------|
|trunk_group_key                                 |OCI.trunkGroupKey                              |trunkGroupKey                                         |
|new_name                                        |str                                            |newName *Optional*                                    |
|pilot_user_id                                   |str                                            |pilotUserId *Optional*                                |
|department                                      |OCI.department                                 |department *Optional*                                 |
|access_device                                   |OCI.accessDevice                               |accessDevice *Optional*                               |
|max_active_calls                                |int                                            |maxActiveCalls *Optional*                             |
|max_incoming_calls                              |int                                            |maxIncomingCalls *Optional*                           |
|max_outgoing_calls                              |int                                            |maxOutgoingCalls *Optional*                           |
|enable_bursting                                 |bool                                           |enableBursting *Optional*                             |
|bursting_max_active_calls                       |int                                            |burstingMaxActiveCalls *Optional*                     |
|bursting_max_incoming_calls                     |int                                            |burstingMaxIncomingCalls *Optional*                   |
|bursting_max_outgoing_calls                     |int                                            |burstingMaxOutgoingCalls *Optional*                   |
|capacity_exceeded_action                        |str                                            |capacityExceededAction *Optional*                     |
|capacity_exceeded_forward_address               |str                                            |capacityExceededForwardAddress *Optional*             |
|capacity_exceeded_reroute_trunk_group_key       |OCI.capacityExceededRerouteTrunkGroupKey       |capacityExceededRerouteTrunkGroupKey *Optional*       |
|capacity_exceeded_trap_initial_calls            |int                                            |capacityExceededTrapInitialCalls *Optional*           |
|capacity_exceeded_trap_offset_calls             |int                                            |capacityExceededTrapOffsetCalls *Optional*            |
|unreachable_destination_action                  |str                                            |unreachableDestinationAction *Optional*               |
|unreachable_destination_forward_address         |str                                            |unreachableDestinationForwardAddress *Optional*       |
|unreachable_destination_reroute_trunk_group_key |OCI.unreachableDestinationRerouteTrunkGroupKey |unreachableDestinationRerouteTrunkGroupKey *Optional* |
|unreachable_destination_trap_initial_calls      |int                                            |unreachableDestinationTrapInitialCalls *Optional*     |
|unreachable_destination_trap_offset_calls       |int                                            |unreachableDestinationTrapOffsetCalls *Optional*      |
|invitation_timeout                              |int                                            |invitationTimeout *Optional*                          |
|require_authentication                          |bool                                           |requireAuthentication *Optional*                      |
|sip_authentication_user_name                    |str                                            |sipAuthenticationUserName *Optional*                  |
|sip_authentication_password                     |str                                            |sipAuthenticationPassword *Optional*                  |
|hosted_user_id_list                             |OCI.hostedUserIdList                           |hostedUserIdList *Optional*                           |
|trunk_group_identity                            |str                                            |trunkGroupIdentity *Optional*                         |
|otg_dtg_identity                                |str                                            |otgDtgIdentity *Optional*                             |
|include_trunk_group_identity                    |bool                                           |includeTrunkGroupIdentity *Optional*                  |
|include_dtg_identity                            |bool                                           |includeDtgIdentity *Optional*                         |
|enable_network_address_identity                 |bool                                           |enableNetworkAddressIdentity *Optional*               |
|allow_unscreened_calls                          |bool                                           |allowUnscreenedCalls *Optional*                       |
|allow_unscreened_emergency_calls                |bool                                           |allowUnscreenedEmergencyCalls *Optional*              |
|use_pilot_user_calling_line_identity            |bool                                           |usePilotUserCallingLineIdentity *Optional*            |
|use_pilot_user_charge_number                    |bool                                           |usePilotUserChargeNumber *Optional*                   |
|call_forwarding_always_action                   |str                                            |callForwardingAlwaysAction *Optional*                 |
|call_forwarding_always_forward_address          |str                                            |callForwardingAlwaysForwardAddress *Optional*         |
|call_forwarding_always_reroute_trunk_group_key  |OCI.callForwardingAlwaysRerouteTrunkGroupKey   |callForwardingAlwaysRerouteTrunkGroupKey *Optional*   |
</div>


## `GroupTrunkGroupModifyInstanceRequest15`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a Trunk Group Instance in a group.

The access device cannot be modified or cleared if there are any users assigned to the
Trunk Group.  The command will fail if enableNetworkAddressIdentity is set and
administrator is not System/Provisioning level administrator.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by
`GroupTrunkGroupModifyInstanceRequest19sp1()`.

**Attributes:**

|Name                                             |Type                                           |Description                                           |
|-------------------------------------------------|-----------------------------------------------|------------------------------------------------------|
|trunk_group_key                                  |OCI.trunkGroupKey                              |trunkGroupKey                                         |
|new_name                                         |str                                            |newName *Optional*                                    |
|pilot_user_id                                    |str                                            |pilotUserId *Optional*                                |
|department                                       |OCI.department                                 |department *Optional*                                 |
|access_device                                    |OCI.accessDevice                               |accessDevice *Optional*                               |
|max_active_calls                                 |int                                            |maxActiveCalls *Optional*                             |
|max_incoming_calls                               |int                                            |maxIncomingCalls *Optional*                           |
|max_outgoing_calls                               |int                                            |maxOutgoingCalls *Optional*                           |
|enable_bursting                                  |bool                                           |enableBursting *Optional*                             |
|bursting_max_active_calls                        |int                                            |burstingMaxActiveCalls *Optional*                     |
|bursting_max_incoming_calls                      |int                                            |burstingMaxIncomingCalls *Optional*                   |
|bursting_max_outgoing_calls                      |int                                            |burstingMaxOutgoingCalls *Optional*                   |
|capacity_exceeded_action                         |str                                            |capacityExceededAction *Optional*                     |
|capacity_exceeded_forward_address                |str                                            |capacityExceededForwardAddress *Optional*             |
|capacity_exceeded_reroute_trunk_group_key        |OCI.capacityExceededRerouteTrunkGroupKey       |capacityExceededRerouteTrunkGroupKey *Optional*       |
|capacity_exceeded_trap_initial_calls             |int                                            |capacityExceededTrapInitialCalls *Optional*           |
|capacity_exceeded_trap_offset_calls              |int                                            |capacityExceededTrapOffsetCalls *Optional*            |
|unreachable_destination_action                   |str                                            |unreachableDestinationAction *Optional*               |
|unreachable_destination_forward_address          |str                                            |unreachableDestinationForwardAddress *Optional*       |
|unreachable_destination_reroute_trunk_group_key  |OCI.unreachableDestinationRerouteTrunkGroupKey |unreachableDestinationRerouteTrunkGroupKey *Optional* |
|invitation_timeout                               |int                                            |invitationTimeout *Optional*                          |
|require_authentication                           |bool                                           |requireAuthentication *Optional*                      |
|sip_authentication_user_name                     |str                                            |sipAuthenticationUserName *Optional*                  |
|sip_authentication_password                      |str                                            |sipAuthenticationPassword *Optional*                  |
|hosted_user_id_list                              |OCI.hostedUserIdList                           |hostedUserIdList *Optional*                           |
|trunk_group_identity                             |str                                            |trunkGroupIdentity *Optional*                         |
|otg_dtg_identity                                 |str                                            |otgDtgIdentity *Optional*                             |
|allow_termination_to_trunk_group_identity        |bool                                           |allowTerminationToTrunkGroupIdentity *Optional*       |
|allow_termination_to_dtg_identity                |bool                                           |allowTerminationToDtgIdentity *Optional*              |
|include_trunk_group_identity                     |bool                                           |includeTrunkGroupIdentity *Optional*                  |
|include_dtg_identity                             |bool                                           |includeDtgIdentity *Optional*                         |
|include_trunk_group_identity_for_network_calls   |bool                                           |includeTrunkGroupIdentityForNetworkCalls *Optional*   |
|include_otg_identity_for_network_calls           |bool                                           |includeOtgIdentityForNetworkCalls *Optional*          |
|enable_network_address_identity                  |bool                                           |enableNetworkAddressIdentity *Optional*               |
|allow_unscreened_calls                           |bool                                           |allowUnscreenedCalls *Optional*                       |
|allow_unscreened_emergency_calls                 |bool                                           |allowUnscreenedEmergencyCalls *Optional*              |
|pilot_user_calling_line_identity_policy          |str                                            |pilotUserCallingLineIdentityPolicy *Optional*         |
|pilot_user_charge_number_policy                  |str                                            |pilotUserChargeNumberPolicy *Optional*                |
|call_forwarding_always_action                    |str                                            |callForwardingAlwaysAction *Optional*                 |
|call_forwarding_always_forward_address           |str                                            |callForwardingAlwaysForwardAddress *Optional*         |
|call_forwarding_always_reroute_trunk_group_key   |OCI.callForwardingAlwaysRerouteTrunkGroupKey   |callForwardingAlwaysRerouteTrunkGroupKey *Optional*   |
|peering_domain                                   |str                                            |peeringDomain *Optional*                              |
|route_to_peering_domain                          |bool                                           |routeToPeeringDomain *Optional*                       |
|prefix_enabled                                   |bool                                           |prefixEnabled *Optional*                              |
|prefix                                           |str                                            |prefix *Optional*                                     |
|stateful_rerouting_enabled                       |bool                                           |statefulReroutingEnabled *Optional*                   |
|send_continuous_options_message                  |bool                                           |sendContinuousOptionsMessage *Optional*               |
|continuous_options_sending_interval_seconds      |int                                            |continuousOptionsSendingIntervalSeconds *Optional*    |
|failure_options_sending_interval_seconds         |int                                            |failureOptionsSendingIntervalSeconds *Optional*       |
|failure_threshold_counter                        |int                                            |failureThresholdCounter *Optional*                    |
|success_threshold_counter                        |int                                            |successThresholdCounter *Optional*                    |
|invite_failure_threshold_counter                 |int                                            |inviteFailureThresholdCounter *Optional*              |
|invite_failure_threshold_window_seconds          |int                                            |inviteFailureThresholdWindowSeconds *Optional*        |
|pilot_user_calling_line_asserted_identity_policy |str                                            |pilotUserCallingLineAssertedIdentityPolicy *Optional* |
|use_system_calling_line_asserted_identity_policy |bool                                           |useSystemCallingLineAssertedIdentityPolicy *Optional* |
|pilot_user_call_optimization_policy              |str                                            |pilotUserCallOptimizationPolicy *Optional*            |
</div>


## `GroupTrunkGroupModifyInstanceRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a Trunk Group Instance in a group.

The access device cannot be modified or cleared if there are any users assigned to the
Trunk Group.  The command will fail if enableNetworkAddressIdentity is set and
administrator is not System/Provisioning level administrator.  Following attributes
are only used in IMS mode: implicitRegistrationSetSupportPolicy
useSystemImplicitRegistrationSetSupportPolicy
sipIdentityForPilotAndProxyTrunkModesPolicy
useSystemSIPIdentityForPilotAndProxyTrunkModesPolicy

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`GroupTrunkGroupModifyInstanceRequest20sp1()`

**Attributes:**

|Name                                                           |Type                                           |Description                                                     |
|---------------------------------------------------------------|-----------------------------------------------|----------------------------------------------------------------|
|trunk_group_key                                                |OCI.trunkGroupKey                              |trunkGroupKey                                                   |
|new_name                                                       |str                                            |newName *Optional*                                              |
|pilot_user_id                                                  |str                                            |pilotUserId *Optional*                                          |
|department                                                     |OCI.department                                 |department *Optional*                                           |
|access_device                                                  |OCI.accessDevice                               |accessDevice *Optional*                                         |
|max_active_calls                                               |int                                            |maxActiveCalls *Optional*                                       |
|max_incoming_calls                                             |int                                            |maxIncomingCalls *Optional*                                     |
|max_outgoing_calls                                             |int                                            |maxOutgoingCalls *Optional*                                     |
|enable_bursting                                                |bool                                           |enableBursting *Optional*                                       |
|bursting_max_active_calls                                      |int                                            |burstingMaxActiveCalls *Optional*                               |
|bursting_max_incoming_calls                                    |int                                            |burstingMaxIncomingCalls *Optional*                             |
|bursting_max_outgoing_calls                                    |int                                            |burstingMaxOutgoingCalls *Optional*                             |
|capacity_exceeded_action                                       |str                                            |capacityExceededAction *Optional*                               |
|capacity_exceeded_forward_address                              |str                                            |capacityExceededForwardAddress *Optional*                       |
|capacity_exceeded_reroute_trunk_group_key                      |OCI.capacityExceededRerouteTrunkGroupKey       |capacityExceededRerouteTrunkGroupKey *Optional*                 |
|capacity_exceeded_trap_initial_calls                           |int                                            |capacityExceededTrapInitialCalls *Optional*                     |
|capacity_exceeded_trap_offset_calls                            |int                                            |capacityExceededTrapOffsetCalls *Optional*                      |
|unreachable_destination_action                                 |str                                            |unreachableDestinationAction *Optional*                         |
|unreachable_destination_forward_address                        |str                                            |unreachableDestinationForwardAddress *Optional*                 |
|unreachable_destination_reroute_trunk_group_key                |OCI.unreachableDestinationRerouteTrunkGroupKey |unreachableDestinationRerouteTrunkGroupKey *Optional*           |
|invitation_timeout                                             |int                                            |invitationTimeout *Optional*                                    |
|require_authentication                                         |bool                                           |requireAuthentication *Optional*                                |
|sip_authentication_user_name                                   |str                                            |sipAuthenticationUserName *Optional*                            |
|sip_authentication_password                                    |str                                            |sipAuthenticationPassword *Optional*                            |
|hosted_user_id_list                                            |OCI.hostedUserIdList                           |hostedUserIdList *Optional*                                     |
|trunk_group_identity                                           |str                                            |trunkGroupIdentity *Optional*                                   |
|otg_dtg_identity                                               |str                                            |otgDtgIdentity *Optional*                                       |
|allow_termination_to_trunk_group_identity                      |bool                                           |allowTerminationToTrunkGroupIdentity *Optional*                 |
|allow_termination_to_dtg_identity                              |bool                                           |allowTerminationToDtgIdentity *Optional*                        |
|include_trunk_group_identity                                   |bool                                           |includeTrunkGroupIdentity *Optional*                            |
|include_dtg_identity                                           |bool                                           |includeDtgIdentity *Optional*                                   |
|include_trunk_group_identity_for_network_calls                 |bool                                           |includeTrunkGroupIdentityForNetworkCalls *Optional*             |
|include_otg_identity_for_network_calls                         |bool                                           |includeOtgIdentityForNetworkCalls *Optional*                    |
|enable_network_address_identity                                |bool                                           |enableNetworkAddressIdentity *Optional*                         |
|allow_unscreened_calls                                         |bool                                           |allowUnscreenedCalls *Optional*                                 |
|allow_unscreened_emergency_calls                               |bool                                           |allowUnscreenedEmergencyCalls *Optional*                        |
|pilot_user_calling_line_identity_for_external_calls_policy     |str                                            |pilotUserCallingLineIdentityForExternalCallsPolicy *Optional*   |
|pilot_user_charge_number_policy                                |str                                            |pilotUserChargeNumberPolicy *Optional*                          |
|call_forwarding_always_action                                  |str                                            |callForwardingAlwaysAction *Optional*                           |
|call_forwarding_always_forward_address                         |str                                            |callForwardingAlwaysForwardAddress *Optional*                   |
|call_forwarding_always_reroute_trunk_group_key                 |OCI.callForwardingAlwaysRerouteTrunkGroupKey   |callForwardingAlwaysRerouteTrunkGroupKey *Optional*             |
|peering_domain                                                 |str                                            |peeringDomain *Optional*                                        |
|route_to_peering_domain                                        |bool                                           |routeToPeeringDomain *Optional*                                 |
|prefix_enabled                                                 |bool                                           |prefixEnabled *Optional*                                        |
|prefix                                                         |str                                            |prefix *Optional*                                               |
|stateful_rerouting_enabled                                     |bool                                           |statefulReroutingEnabled *Optional*                             |
|send_continuous_options_message                                |bool                                           |sendContinuousOptionsMessage *Optional*                         |
|continuous_options_sending_interval_seconds                    |int                                            |continuousOptionsSendingIntervalSeconds *Optional*              |
|failure_options_sending_interval_seconds                       |int                                            |failureOptionsSendingIntervalSeconds *Optional*                 |
|failure_threshold_counter                                      |int                                            |failureThresholdCounter *Optional*                              |
|success_threshold_counter                                      |int                                            |successThresholdCounter *Optional*                              |
|invite_failure_threshold_counter                               |int                                            |inviteFailureThresholdCounter *Optional*                        |
|invite_failure_threshold_window_seconds                        |int                                            |inviteFailureThresholdWindowSeconds *Optional*                  |
|pilot_user_calling_line_asserted_identity_policy               |str                                            |pilotUserCallingLineAssertedIdentityPolicy *Optional*           |
|use_system_calling_line_asserted_identity_policy               |bool                                           |useSystemCallingLineAssertedIdentityPolicy *Optional*           |
|pilot_user_call_optimization_policy                            |str                                            |pilotUserCallOptimizationPolicy *Optional*                      |
|clid_source_for_screened_calls_policy                          |str                                            |clidSourceForScreenedCallsPolicy *Optional*                     |
|use_system_clid_source_for_screened_calls_policy               |bool                                           |useSystemCLIDSourceForScreenedCallsPolicy *Optional*            |
|user_lookup_policy                                             |str                                            |userLookupPolicy *Optional*                                     |
|use_system_user_lookup_policy                                  |bool                                           |useSystemUserLookupPolicy *Optional*                            |
|pilot_user_calling_line_identity_for_emergency_calls_policy    |str                                            |pilotUserCallingLineIdentityForEmergencyCallsPolicy *Optional*  |
|implicit_registration_set_support_policy                       |str                                            |implicitRegistrationSetSupportPolicy *Optional*                 |
|use_system_implicit_registration_set_support_policy            |bool                                           |useSystemImplicitRegistrationSetSupportPolicy *Optional*        |
|sip_identity_for_pilot_and_proxy_trunk_modes_policy            |str                                            |sipIdentityForPilotAndProxyTrunkModesPolicy *Optional*          |
|use_system_sip_identity_for_pilot_and_proxy_trunk_modes_policy |bool                                           |useSystemSIPIdentityForPilotAndProxyTrunkModesPolicy *Optional* |
|use_system_support_connected_identity_policy                   |bool                                           |useSystemSupportConnectedIdentityPolicy *Optional*              |
|support_connected_identity_policy                              |str                                            |supportConnectedIdentityPolicy *Optional*                       |
|use_system_options_message_response_status_codes               |bool                                           |useSystemOptionsMessageResponseStatusCodes *Optional*           |
|delete_options_message_response_status_code                    |List[str]                                      |deleteOptionsMessageResponseStatusCode *Optional*               |
</div>


## `GroupTrunkGroupModifyInstanceRequest20sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a Trunk Group Instance in a group.

The access device cannot be modified or cleared if there are any users assigned to the
Trunk Group.  The command will fail if enableNetworkAddressIdentity is set and
administrator is not System/Provisioning level administrator.  Following attributes
are only used in IMS mode: implicitRegistrationSetSupportPolicy
useSystemImplicitRegistrationSetSupportPolicy
sipIdentityForPilotAndProxyTrunkModesPolicy
useSystemSIPIdentityForPilotAndProxyTrunkModesPolicy

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                                           |Type                                           |Description                                                     |
|---------------------------------------------------------------|-----------------------------------------------|----------------------------------------------------------------|
|trunk_group_key                                                |OCI.trunkGroupKey                              |trunkGroupKey                                                   |
|new_name                                                       |str                                            |newName *Optional*                                              |
|pilot_user_id                                                  |str                                            |pilotUserId *Optional*                                          |
|department                                                     |OCI.department                                 |department *Optional*                                           |
|access_device                                                  |OCI.accessDevice                               |accessDevice *Optional*                                         |
|max_active_calls                                               |int                                            |maxActiveCalls *Optional*                                       |
|max_incoming_calls                                             |int                                            |maxIncomingCalls *Optional*                                     |
|max_outgoing_calls                                             |int                                            |maxOutgoingCalls *Optional*                                     |
|enable_bursting                                                |bool                                           |enableBursting *Optional*                                       |
|bursting_max_active_calls                                      |int                                            |burstingMaxActiveCalls *Optional*                               |
|bursting_max_incoming_calls                                    |int                                            |burstingMaxIncomingCalls *Optional*                             |
|bursting_max_outgoing_calls                                    |int                                            |burstingMaxOutgoingCalls *Optional*                             |
|capacity_exceeded_action                                       |str                                            |capacityExceededAction *Optional*                               |
|capacity_exceeded_forward_address                              |str                                            |capacityExceededForwardAddress *Optional*                       |
|capacity_exceeded_reroute_trunk_group_key                      |OCI.capacityExceededRerouteTrunkGroupKey       |capacityExceededRerouteTrunkGroupKey *Optional*                 |
|capacity_exceeded_trap_initial_calls                           |int                                            |capacityExceededTrapInitialCalls *Optional*                     |
|capacity_exceeded_trap_offset_calls                            |int                                            |capacityExceededTrapOffsetCalls *Optional*                      |
|unreachable_destination_action                                 |str                                            |unreachableDestinationAction *Optional*                         |
|unreachable_destination_forward_address                        |str                                            |unreachableDestinationForwardAddress *Optional*                 |
|unreachable_destination_reroute_trunk_group_key                |OCI.unreachableDestinationRerouteTrunkGroupKey |unreachableDestinationRerouteTrunkGroupKey *Optional*           |
|invitation_timeout                                             |int                                            |invitationTimeout *Optional*                                    |
|require_authentication                                         |bool                                           |requireAuthentication *Optional*                                |
|sip_authentication_user_name                                   |str                                            |sipAuthenticationUserName *Optional*                            |
|sip_authentication_password                                    |str                                            |sipAuthenticationPassword *Optional*                            |
|hosted_user_id_list                                            |OCI.hostedUserIdList                           |hostedUserIdList *Optional*                                     |
|trunk_group_identity                                           |str                                            |trunkGroupIdentity *Optional*                                   |
|otg_dtg_identity                                               |str                                            |otgDtgIdentity *Optional*                                       |
|allow_termination_to_trunk_group_identity                      |bool                                           |allowTerminationToTrunkGroupIdentity *Optional*                 |
|allow_termination_to_dtg_identity                              |bool                                           |allowTerminationToDtgIdentity *Optional*                        |
|include_trunk_group_identity                                   |bool                                           |includeTrunkGroupIdentity *Optional*                            |
|include_dtg_identity                                           |bool                                           |includeDtgIdentity *Optional*                                   |
|include_trunk_group_identity_for_network_calls                 |bool                                           |includeTrunkGroupIdentityForNetworkCalls *Optional*             |
|include_otg_identity_for_network_calls                         |bool                                           |includeOtgIdentityForNetworkCalls *Optional*                    |
|enable_network_address_identity                                |bool                                           |enableNetworkAddressIdentity *Optional*                         |
|allow_unscreened_calls                                         |bool                                           |allowUnscreenedCalls *Optional*                                 |
|allow_unscreened_emergency_calls                               |bool                                           |allowUnscreenedEmergencyCalls *Optional*                        |
|pilot_user_calling_line_identity_for_external_calls_policy     |str                                            |pilotUserCallingLineIdentityForExternalCallsPolicy *Optional*   |
|pilot_user_charge_number_policy                                |str                                            |pilotUserChargeNumberPolicy *Optional*                          |
|call_forwarding_always_action                                  |str                                            |callForwardingAlwaysAction *Optional*                           |
|call_forwarding_always_forward_address                         |str                                            |callForwardingAlwaysForwardAddress *Optional*                   |
|call_forwarding_always_reroute_trunk_group_key                 |OCI.callForwardingAlwaysRerouteTrunkGroupKey   |callForwardingAlwaysRerouteTrunkGroupKey *Optional*             |
|peering_domain                                                 |str                                            |peeringDomain *Optional*                                        |
|route_to_peering_domain                                        |bool                                           |routeToPeeringDomain *Optional*                                 |
|prefix_enabled                                                 |bool                                           |prefixEnabled *Optional*                                        |
|prefix                                                         |str                                            |prefix *Optional*                                               |
|stateful_rerouting_enabled                                     |bool                                           |statefulReroutingEnabled *Optional*                             |
|send_continuous_options_message                                |bool                                           |sendContinuousOptionsMessage *Optional*                         |
|continuous_options_sending_interval_seconds                    |int                                            |continuousOptionsSendingIntervalSeconds *Optional*              |
|failure_options_sending_interval_seconds                       |int                                            |failureOptionsSendingIntervalSeconds *Optional*                 |
|failure_threshold_counter                                      |int                                            |failureThresholdCounter *Optional*                              |
|success_threshold_counter                                      |int                                            |successThresholdCounter *Optional*                              |
|invite_failure_threshold_counter                               |int                                            |inviteFailureThresholdCounter *Optional*                        |
|invite_failure_threshold_window_seconds                        |int                                            |inviteFailureThresholdWindowSeconds *Optional*                  |
|pilot_user_calling_line_asserted_identity_policy               |str                                            |pilotUserCallingLineAssertedIdentityPolicy *Optional*           |
|use_system_calling_line_asserted_identity_policy               |bool                                           |useSystemCallingLineAssertedIdentityPolicy *Optional*           |
|pilot_user_call_optimization_policy                            |str                                            |pilotUserCallOptimizationPolicy *Optional*                      |
|clid_source_for_screened_calls_policy                          |str                                            |clidSourceForScreenedCallsPolicy *Optional*                     |
|use_system_clid_source_for_screened_calls_policy               |bool                                           |useSystemCLIDSourceForScreenedCallsPolicy *Optional*            |
|user_lookup_policy                                             |str                                            |userLookupPolicy *Optional*                                     |
|use_system_user_lookup_policy                                  |bool                                           |useSystemUserLookupPolicy *Optional*                            |
|pilot_user_calling_line_identity_for_emergency_calls_policy    |str                                            |pilotUserCallingLineIdentityForEmergencyCallsPolicy *Optional*  |
|implicit_registration_set_support_policy                       |str                                            |implicitRegistrationSetSupportPolicy *Optional*                 |
|use_system_implicit_registration_set_support_policy            |bool                                           |useSystemImplicitRegistrationSetSupportPolicy *Optional*        |
|sip_identity_for_pilot_and_proxy_trunk_modes_policy            |str                                            |sipIdentityForPilotAndProxyTrunkModesPolicy *Optional*          |
|use_system_sip_identity_for_pilot_and_proxy_trunk_modes_policy |bool                                           |useSystemSIPIdentityForPilotAndProxyTrunkModesPolicy *Optional* |
|use_system_support_connected_identity_policy                   |bool                                           |useSystemSupportConnectedIdentityPolicy *Optional*              |
|support_connected_identity_policy                              |str                                            |supportConnectedIdentityPolicy *Optional*                       |
|use_system_options_message_response_status_codes               |bool                                           |useSystemOptionsMessageResponseStatusCodes *Optional*           |
|delete_options_message_response_status_code                    |List[str]                                      |deleteOptionsMessageResponseStatusCode *Optional*               |
</div>


## `GroupTrunkGroupModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the maximum and bursting maximum permissible active Trunk Group calls for the
group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                      |Type                       |Description                       |
|--------------------------|---------------------------|----------------------------------|
|service_provider_id       |str                        |serviceProviderId                 |
|group_id                  |str                        |groupId                           |
|max_active_calls          |OCI.maxActiveCalls         |maxActiveCalls *Optional*         |
|bursting_max_active_calls |OCI.burstingMaxActiveCalls |burstingMaxActiveCalls *Optional* |
</div>


## `GroupTrunkGroupModifyRequest14sp9`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the maximum and bursting maximum permissible active Trunk Group calls for the
group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                      |Type                       |Description                       |
|--------------------------|---------------------------|----------------------------------|
|service_provider_id       |str                        |serviceProviderId                 |
|group_id                  |str                        |groupId                           |
|max_active_calls          |int                        |maxActiveCalls *Optional*         |
|bursting_max_active_calls |OCI.burstingMaxActiveCalls |burstingMaxActiveCalls *Optional* |
|number_of_bursting_btl_us |int                        |numberOfBurstingBTLUs *Optional*  |
</div>


## `GroupTrunkGroupOptionsMessageResponseStatusCodeAddListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a list of trunk group level successful SIP OPTIONS message respoonse status codes.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name            |Type              |Description   |
|----------------|------------------|--------------|
|trunk_group_key |OCI.trunkGroupKey |trunkGroupKey |
|status_code     |List[str]         |statusCode    |
</div>


## `GroupTrunkGroupSecurityClassificationGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a trunk group's Security Classifications configuration.

The response is either `GroupTrunkGroupSecurityClassificationGetResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name            |Type              |Description   |
|----------------|------------------|--------------|
|trunk_group_key |OCI.trunkGroupKey |trunkGroupKey |
</div>


## `GroupTrunkGroupSecurityClassificationModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a trunk group's Security Classification configuration The response is either a
`SuccessResponse()` or an `ErrorResponse()`.


**Attributes:**

|Name                            |Type              |Description                   |
|--------------------------------|------------------|------------------------------|
|trunk_group_key                 |OCI.trunkGroupKey |trunkGroupKey                 |
|default_security_classification |str               |defaultSecurityClassification |
</div>


## `GroupTrunkGroupStirShakenGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get Group Trunk Group Stir Shaken service settings.

The response is either `GroupTrunkGroupStirShakenGetResponse()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type              |Description   |
|----------------|------------------|--------------|
|trunk_group_key |OCI.trunkGroupKey |trunkGroupKey |
</div>


## `GroupTrunkGroupStirShakenModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify group trunk group Stir Shaken service settings.


**Attributes:**

|Name                                                   |Type              |Description                                                 |
|-------------------------------------------------------|------------------|------------------------------------------------------------|
|trunk_group_key                                        |OCI.trunkGroupKey |trunkGroupKey                                               |
|use_parent_level_settings                              |bool              |useParentLevelSettings *Optional*                           |
|signing_policy                                         |str               |signingPolicy *Optional*                                    |
|tagging_policy                                         |str               |taggingPolicy *Optional*                                    |
|signing_service_url                                    |str               |signingServiceURL *Optional*                                |
|tag_from_or_pai                                        |str               |tagFromOrPAI *Optional*                                     |
|verstat_tag                                            |str               |verstatTag *Optional*                                       |
|use_os_value_for_orig_id                               |bool              |useOSValueForOrigId *Optional*                              |
|orig_uuid                                              |str               |origUUID *Optional*                                         |
|attestation_level                                      |str               |attestationLevel *Optional*                                 |
|enable_signing_for_unscreened_trunk_group_originations |bool              |enableSigningForUnscreenedTrunkGroupOriginations *Optional* |
|enable_tagging_for_unscreened_trunk_group_originations |bool              |enableTaggingForUnscreenedTrunkGroupOriginations *Optional* |
|unscreened_trunk_group_origination_attestation_level   |str               |unscreenedTrunkGroupOriginationAttestationLevel *Optional*  |
</div>


## `GroupTrunkGroupUserCreationTaskAddRequest14sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a user creation task for a trunk group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name               |Type                 |Description                 |
|-------------------|---------------------|----------------------------|
|trunk_group_key    |OCI.trunkGroupKey    |trunkGroupKey               |
|task_name          |str                  |taskName                    |
|user_id_format     |str                  |userIdFormat                |
|user_id_domain     |str                  |userIdDomain                |
|populate_extension |bool                 |populateExtension           |
|line_port_format   |str                  |linePortFormat              |
|line_port_domain   |str                  |linePortDomain              |
|populate_contact   |bool                 |populateContact             |
|contact_format     |str                  |contactFormat *Optional*    |
|contact_domain     |str                  |contactDomain *Optional*    |
|user_phone_numbers |OCI.userPhoneNumbers |userPhoneNumbers *Optional* |
|user_extensions    |OCI.userExtensions   |userExtensions *Optional*   |
|service_pack_name  |List[str]            |servicePackName *Optional*  |
|user_service       |List[str]            |userService *Optional*      |
</div>


## `GroupTrunkGroupUserCreationTaskDeleteRequest14sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a user creation task for a trunk group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name            |Type              |Description   |
|----------------|------------------|--------------|
|trunk_group_key |OCI.trunkGroupKey |trunkGroupKey |
|task_name       |str               |taskName      |
</div>


## `GroupTrunkGroupUserCreationTaskGetListRequest14sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of user creation tasks for a trunk group.

The response is either `GroupTrunkGroupUserCreationTaskGetListResponse14sp4()` or
`ErrorResponse()`.

**Attributes:**

|Name            |Type              |Description   |
|----------------|------------------|--------------|
|trunk_group_key |OCI.trunkGroupKey |trunkGroupKey |
</div>


## `GroupTrunkGroupUserCreationTaskGetRequest14sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the details of a specified user creation task for a trunk group.

The response is either `GroupTrunkGroupUserCreationTaskGetResponse14sp4()` or
`ErrorResponse()`.

**Attributes:**

|Name            |Type              |Description   |
|----------------|------------------|--------------|
|trunk_group_key |OCI.trunkGroupKey |trunkGroupKey |
|task_name       |str               |taskName      |
</div>


## `GroupVoiceMessagingGroupModifyVoicePortalBrandingRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the group's voice portal branding settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

Replaced By: `GroupVoiceMessagingGroupModifyVoicePortalBrandingRequest16()`

**Attributes:**

|Name                               |Type                           |Description                                |
|-----------------------------------|-------------------------------|-------------------------------------------|
|service_provider_id                |str                            |serviceProviderId                          |
|group_id                           |str                            |groupId                                    |
|voice_portal_greeting_selection    |str                            |voicePortalGreetingSelection *Optional*    |
|voice_portal_greeting_file         |OCI.voicePortalGreetingFile    |voicePortalGreetingFile *Optional*         |
|voice_messaging_greeting_selection |str                            |voiceMessagingGreetingSelection *Optional* |
|voice_messaging_greeting_file      |OCI.voiceMessagingGreetingFile |voiceMessagingGreetingFile *Optional*      |
</div>


## `GroupVoiceMessagingGroupModifyVoicePortalBrandingRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the group's voice portal branding settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`GroupVoiceMessagingGroupModifyVoicePortalBrandingRequest20()` in AS data mode

**Attributes:**

|Name                               |Type                           |Description                                |
|-----------------------------------|-------------------------------|-------------------------------------------|
|service_provider_id                |str                            |serviceProviderId                          |
|group_id                           |str                            |groupId                                    |
|voice_portal_greeting_selection    |str                            |voicePortalGreetingSelection *Optional*    |
|voice_portal_greeting_file         |OCI.voicePortalGreetingFile    |voicePortalGreetingFile *Optional*         |
|voice_messaging_greeting_selection |str                            |voiceMessagingGreetingSelection *Optional* |
|voice_messaging_greeting_file      |OCI.voiceMessagingGreetingFile |voiceMessagingGreetingFile *Optional*      |
</div>


## `GroupVoiceMessagingGroupModifyVoicePortalBrandingRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the group's voice portal branding settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                               |Type                           |Description                                |
|-----------------------------------|-------------------------------|-------------------------------------------|
|service_provider_id                |str                            |serviceProviderId                          |
|group_id                           |str                            |groupId                                    |
|voice_portal_greeting_selection    |str                            |voicePortalGreetingSelection *Optional*    |
|voice_portal_greeting_file         |OCI.voicePortalGreetingFile    |voicePortalGreetingFile *Optional*         |
|voice_messaging_greeting_selection |str                            |voiceMessagingGreetingSelection *Optional* |
|voice_messaging_greeting_file      |OCI.voiceMessagingGreetingFile |voiceMessagingGreetingFile *Optional*      |
</div>


## `GroupVoiceXmlModifyActiveInstanceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to set the active status of VoiceXML instances.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name               |Type                        |Description                  |
|-------------------|----------------------------|-----------------------------|
|service_activation |List[OCI.serviceActivation] |serviceActivation *Optional* |
</div>


## `GroupXsiPolicyProfileAssignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Assign a group level Xsi policy profile and a list of user Xsi policy profiles to a
group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type                     |Description                      |
|-------------------------|-------------------------|---------------------------------|
|service_provider_id      |str                      |serviceProviderId                |
|group_id                 |str                      |groupId                          |
|group_xsi_policy_profile |str                      |groupXsiPolicyProfile *Optional* |
|user_xsi_policy_profile  |OCI.userXsiPolicyProfile |userXsiPolicyProfile *Optional*  |
</div>


## `GroupXsiPolicyProfileUnassignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Unassign a list of Xsi policy profile.

Only user level Xsi policy profile can be unassigned.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                    |Type                     |Description                     |
|------------------------|-------------------------|--------------------------------|
|service_provider_id     |str                      |serviceProviderId               |
|group_id                |str                      |groupId                         |
|user_xsi_policy_profile |OCI.userXsiPolicyProfile |userXsiPolicyProfile *Optional* |
</div>


## `PasswordGenerateRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Generate passwords based on the corresponding password/passcode rules.

The response is either `PasswordGenerateResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                    |Type                                     |Description                                     |
|----------------------------------------|-----------------------------------------|------------------------------------------------|
|system_administrator_password           |OCI.systemAdministratorPassword          |systemAdministratorPassword *Optional*          |
|service_provider_administrator_password |OCI.serviceProviderAdministratorPassword |serviceProviderAdministratorPassword *Optional* |
|group_administrator_password            |OCI.groupAdministratorPassword           |groupAdministratorPassword *Optional*           |
|user_password                           |OCI.userPassword                         |userPassword *Optional*                         |
|access_device_authentication_password   |OCI.accessDeviceAuthenticationPassword   |accessDeviceAuthenticationPassword *Optional*   |
|trunk_group_authentication_password     |OCI.trunkGroupAuthenticationPassword     |trunkGroupAuthenticationPassword *Optional*     |
</div>


## `ResellerNetworkClassOfServiceAssignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Assign a list of Network Classes of Service to a reseller.

A default Network Class of Service is optional.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                             |Type                             |Description                             |
|---------------------------------|---------------------------------|----------------------------------------|
|reseller_id                      |str                              |resellerId                              |
|network_class_of_service         |List[str]                        |networkClassOfService *Optional*        |
|default_network_class_of_service |OCI.defaultNetworkClassOfService |defaultNetworkClassOfService *Optional* |
</div>


## `ResellerNetworkClassOfServiceUnassignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Unassign a list of Network Classes of Service from a reseller.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                             |Type                             |Description                             |
|---------------------------------|---------------------------------|----------------------------------------|
|reseller_id                      |str                              |resellerId                              |
|network_class_of_service         |List[str]                        |networkClassOfService *Optional*        |
|default_network_class_of_service |OCI.defaultNetworkClassOfService |defaultNetworkClassOfService *Optional* |
</div>


## `ResellerServiceAuthorizationModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the reseller service authorization file.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name             |Type                |Description                |
|-----------------|--------------------|---------------------------|
|reseller_id      |str                 |resellerId                 |
|service_offering |OCI.serviceOffering |serviceOffering *Optional* |
</div>


## `ResellerXsiPolicyProfileAssignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Assign a list of Xsi policy profile to a reseller.

It contains the service provider, group, user level Xsi policy profile.  Each level
has one default Xsi policy profile assigned.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type                      |Description                      |
|-------------------------|--------------------------|---------------------------------|
|reseller_id              |str                       |resellerId                       |
|sp_xsi_policy_profile    |OCI.spXsiPolicyProfile    |spXsiPolicyProfile *Optional*    |
|group_xsi_policy_profile |OCI.groupXsiPolicyProfile |groupXsiPolicyProfile *Optional* |
|user_xsi_policy_profile  |OCI.userXsiPolicyProfile  |userXsiPolicyProfile *Optional*  |
</div>


## `ResellerXsiPolicyProfileUnassignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Unassign a list of Xsi policy profile.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type                      |Description                      |
|-------------------------|--------------------------|---------------------------------|
|reseller_id              |str                       |resellerId                       |
|sp_xsi_policy_profile    |OCI.spXsiPolicyProfile    |spXsiPolicyProfile *Optional*    |
|group_xsi_policy_profile |OCI.groupXsiPolicyProfile |groupXsiPolicyProfile *Optional* |
|user_xsi_policy_profile  |OCI.userXsiPolicyProfile  |userXsiPolicyProfile *Optional*  |
</div>


## `ServiceProviderAccessDeviceAddRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a service provider access device.

The response is either `SuccessResponse()` or `ErrorResponse()`.

Replaced By: `ServiceProviderAccessDeviceAddRequest22()`

**Attributes:**

|Name                                             |Type                        |Description                                            |
|-------------------------------------------------|----------------------------|-------------------------------------------------------|
|service_provider_id                              |str                         |serviceProviderId                                      |
|device_name                                      |str                         |deviceName                                             |
|device_type                                      |str                         |deviceType                                             |
|protocol                                         |str                         |protocol *Optional*                                    |
|net_address                                      |str                         |netAddress *Optional*                                  |
|port                                             |int                         |port *Optional*                                        |
|outbound_proxy_server_net_address                |str                         |outboundProxyServerNetAddress *Optional*               |
|stun_server_net_address                          |str                         |stunServerNetAddress *Optional*                        |
|mac_address                                      |str                         |macAddress *Optional*                                  |
|serial_number                                    |str                         |serialNumber *Optional*                                |
|description                                      |str                         |description *Optional*                                 |
|physical_location                                |str                         |physicalLocation *Optional*                            |
|transport_protocol                               |str                         |transportProtocol *Optional*                           |
|mobility_manager_provisioning_url                |str                         |mobilityManagerProvisioningURL *Optional*              |
|mobility_manager_provisioning_user_name          |str                         |mobilityManagerProvisioningUserName *Optional*         |
|mobility_manager_provisioning_password           |str                         |mobilityManagerProvisioningPassword *Optional*         |
|mobility_manager_default_originating_service_key |int                         |mobilityManagerDefaultOriginatingServiceKey *Optional* |
|mobility_manager_default_terminating_service_key |int                         |mobilityManagerDefaultTerminatingServiceKey *Optional* |
|use_custom_user_name_password                    |bool                        |useCustomUserNamePassword *Optional*                   |
|access_device_credentials                        |OCI.accessDeviceCredentials |accessDeviceCredentials *Optional*                     |
</div>


## `ServiceProviderAccessDeviceAddRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a service provider access device.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode: useHotline
hotlineContact serviceProviderExternalId deviceExternalId

**Attributes:**

|Name                                             |Type                        |Description                                            |
|-------------------------------------------------|----------------------------|-------------------------------------------------------|
|service_provider_id                              |str                         |serviceProviderId *Optional*                           |
|device_name                                      |str                         |deviceName *Optional*                                  |
|service_provider_external_id                     |str                         |serviceProviderExternalId *Optional*                   |
|device_external_id                               |str                         |deviceExternalId *Optional*                            |
|device_type                                      |str                         |deviceType                                             |
|protocol                                         |str                         |protocol *Optional*                                    |
|net_address                                      |str                         |netAddress *Optional*                                  |
|port                                             |int                         |port *Optional*                                        |
|outbound_proxy_server_net_address                |str                         |outboundProxyServerNetAddress *Optional*               |
|stun_server_net_address                          |str                         |stunServerNetAddress *Optional*                        |
|mac_address                                      |str                         |macAddress *Optional*                                  |
|serial_number                                    |str                         |serialNumber *Optional*                                |
|description                                      |str                         |description *Optional*                                 |
|physical_location                                |str                         |physicalLocation *Optional*                            |
|transport_protocol                               |str                         |transportProtocol *Optional*                           |
|mobility_manager_provisioning_url                |str                         |mobilityManagerProvisioningURL *Optional*              |
|mobility_manager_provisioning_user_name          |str                         |mobilityManagerProvisioningUserName *Optional*         |
|mobility_manager_provisioning_password           |str                         |mobilityManagerProvisioningPassword *Optional*         |
|mobility_manager_default_originating_service_key |int                         |mobilityManagerDefaultOriginatingServiceKey *Optional* |
|mobility_manager_default_terminating_service_key |int                         |mobilityManagerDefaultTerminatingServiceKey *Optional* |
|use_custom_user_name_password                    |bool                        |useCustomUserNamePassword *Optional*                   |
|access_device_credentials                        |OCI.accessDeviceCredentials |accessDeviceCredentials *Optional*                     |
|use_hotline                                      |bool                        |useHotline                                             |
|hotline_contact                                  |str                         |hotlineContact *Optional*                              |
</div>


## `ServiceProviderAccessDeviceAddRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a service provider access device.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                              |Type                        |Description                              |
|----------------------------------|----------------------------|-----------------------------------------|
|service_provider_id               |str                         |serviceProviderId *Optional*             |
|device_name                       |str                         |deviceName *Optional*                    |
|service_provider_external_id      |str                         |serviceProviderExternalId *Optional*     |
|device_external_id                |str                         |deviceExternalId *Optional*              |
|device_type                       |str                         |deviceType                               |
|protocol                          |str                         |protocol *Optional*                      |
|net_address                       |str                         |netAddress *Optional*                    |
|port                              |int                         |port *Optional*                          |
|outbound_proxy_server_net_address |str                         |outboundProxyServerNetAddress *Optional* |
|stun_server_net_address           |str                         |stunServerNetAddress *Optional*          |
|mac_address                       |str                         |macAddress *Optional*                    |
|serial_number                     |str                         |serialNumber *Optional*                  |
|description                       |str                         |description *Optional*                   |
|physical_location                 |str                         |physicalLocation *Optional*              |
|transport_protocol                |str                         |transportProtocol *Optional*             |
|use_custom_user_name_password     |bool                        |useCustomUserNamePassword *Optional*     |
|access_device_credentials         |OCI.accessDeviceCredentials |accessDeviceCredentials *Optional*       |
</div>


## `ServiceProviderAccessDeviceCustomTagAddOrModifyListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add or modify a list of static configuration tag for a service provider
access device.

If the tag does not exist, it is added.  If the tag exists, its value is updated.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type          |Description       |
|--------------------|--------------|------------------|
|service_provider_id |str           |serviceProviderId |
|device_name         |str           |deviceName        |
|tag                 |List[OCI.tag] |tag               |
</div>


## `ServiceProviderAccessDeviceFileModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a specified service provider/enterprise access device file.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

Replaced By: `ServiceProviderAccessDeviceFileModifyRequest14sp8()`

**Attributes:**

|Name                |Type           |Description           |
|--------------------|---------------|----------------------|
|service_provider_id |str            |serviceProviderId     |
|device_name         |str            |deviceName            |
|file_type           |str            |fileType              |
|file_source         |str            |fileSource *Optional* |
|upload_file         |OCI.uploadFile |uploadFile *Optional* |
</div>


## `ServiceProviderAccessDeviceFileModifyRequest14sp8`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a specified service provider/enterprise access device file.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type           |Description                       |
|-------------------------|---------------|----------------------------------|
|service_provider_id      |str            |serviceProviderId                 |
|device_name              |str            |deviceName                        |
|file_format              |str            |fileFormat                        |
|file_source              |str            |fileSource *Optional*             |
|upload_file              |OCI.uploadFile |uploadFile *Optional*             |
|extended_capture_enabled |bool           |extendedCaptureEnabled *Optional* |
</div>


## `ServiceProviderAccessDeviceLinkDeviceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to link one or more leaf devices to a service provider level tree device.

A tree device is a device associated with a device type that has the option
supportLinks set to "Support Links from Devices". Many leaf devices can be linked to
it.  A leaf device is a device associated with a device type that has the option
supportLinks set to "Support Link to Device". It can be linked to only one tree
device.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type                    |Description       |
|--------------------|------------------------|------------------|
|service_provider_id |str                     |serviceProviderId |
|device_name         |str                     |deviceName        |
|leaf_device_key     |List[OCI.leafDeviceKey] |leafDeviceKey     |
</div>


## `ServiceProviderAccessDeviceModifyRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a specified service provider access device.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode: useHotline
hotlineContact deviceExternalId

**Attributes:**

|Name                                             |Type                        |Description                                            |
|-------------------------------------------------|----------------------------|-------------------------------------------------------|
|service_provider_id                              |str                         |serviceProviderId *Optional*                           |
|device_name                                      |str                         |deviceName *Optional*                                  |
|device_external_id                               |str                         |deviceExternalId *Optional*                            |
|protocol                                         |str                         |protocol *Optional*                                    |
|net_address                                      |str                         |netAddress *Optional*                                  |
|port                                             |int                         |port *Optional*                                        |
|outbound_proxy_server_net_address                |str                         |outboundProxyServerNetAddress *Optional*               |
|stun_server_net_address                          |str                         |stunServerNetAddress *Optional*                        |
|mac_address                                      |str                         |macAddress *Optional*                                  |
|serial_number                                    |str                         |serialNumber *Optional*                                |
|description                                      |str                         |description *Optional*                                 |
|physical_location                                |str                         |physicalLocation *Optional*                            |
|transport_protocol                               |str                         |transportProtocol *Optional*                           |
|mobility_manager_provisioning_url                |str                         |mobilityManagerProvisioningURL *Optional*              |
|mobility_manager_provisioning_user_name          |str                         |mobilityManagerProvisioningUserName *Optional*         |
|mobility_manager_provisioning_password           |str                         |mobilityManagerProvisioningPassword *Optional*         |
|mobility_manager_default_originating_service_key |int                         |mobilityManagerDefaultOriginatingServiceKey *Optional* |
|mobility_manager_default_terminating_service_key |int                         |mobilityManagerDefaultTerminatingServiceKey *Optional* |
|use_custom_user_name_password                    |bool                        |useCustomUserNamePassword *Optional*                   |
|access_device_credentials                        |OCI.accessDeviceCredentials |accessDeviceCredentials *Optional*                     |
|use_hotline                                      |bool                        |useHotline *Optional*                                  |
|hotline_contact                                  |str                         |hotlineContact *Optional*                              |
</div>


## `ServiceProviderAccessDeviceModifyRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a specified service provider access device.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode: deviceExternalId

**Attributes:**

|Name                              |Type                        |Description                              |
|----------------------------------|----------------------------|-----------------------------------------|
|service_provider_id               |str                         |serviceProviderId *Optional*             |
|device_name                       |str                         |deviceName *Optional*                    |
|device_external_id                |str                         |deviceExternalId *Optional*              |
|protocol                          |str                         |protocol *Optional*                      |
|net_address                       |str                         |netAddress *Optional*                    |
|port                              |int                         |port *Optional*                          |
|outbound_proxy_server_net_address |str                         |outboundProxyServerNetAddress *Optional* |
|stun_server_net_address           |str                         |stunServerNetAddress *Optional*          |
|mac_address                       |str                         |macAddress *Optional*                    |
|serial_number                     |str                         |serialNumber *Optional*                  |
|description                       |str                         |description *Optional*                   |
|physical_location                 |str                         |physicalLocation *Optional*              |
|transport_protocol                |str                         |transportProtocol *Optional*             |
|use_custom_user_name_password     |bool                        |useCustomUserNamePassword *Optional*     |
|access_device_credentials         |OCI.accessDeviceCredentials |accessDeviceCredentials *Optional*       |
</div>


## `ServiceProviderAccessDeviceUnlinkDeviceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to unlink one or more leaf access devices from a tree device.

A leaf device is a device associated with a device type that has the option
supportLinks set to "Support Link to Device". It can be linked to only one tree
device.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name            |Type                    |Description   |
|----------------|------------------------|--------------|
|leaf_device_key |List[OCI.leafDeviceKey] |leafDeviceKey |
</div>


## `ServiceProviderAddRequest13mp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a service provider or enterprise.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in Amplify data mode and ignored in AS and XS data mode:
servicePolicy, callProcessingSliceId, provisioningSliceId, subscriberPartition.  When
the callProcessingSliceId or provisioningSliceId is not specified in the
AmplifyDataMode, the default slice Id is assigned to the service provider.  Only
Provisioning admin and above can change the callProcessingSliceId,
provisioningSliceId, andsubscriberPartition.  The following elements are only used in
Amplify and XS data mode and ignored in AS data mode: preferredDataCenter.  Only
Provisioning admin and above can change the preferredDataCenter.  The following data
elements are only used in AS data mode: resellerId If reseller administrator sends the
request, resellerId is ignored.  The reseller administrator's reseller id is used.
Replaced by: `ServiceProviderConsolidatedAddRequest()` in AS data mode.

**Attributes:**

|Name                       |Type        |Description                        |
|---------------------------|------------|-----------------------------------|
|is_enterprise              |bool        |isEnterprise *Optional*            |
|use_custom_routing_profile |bool        |useCustomRoutingProfile *Optional* |
|service_provider_id        |str         |serviceProviderId                  |
|default_domain             |str         |defaultDomain                      |
|service_provider_name      |str         |serviceProviderName *Optional*     |
|support_email              |str         |supportEmail *Optional*            |
|contact                    |OCI.contact |contact *Optional*                 |
|address                    |OCI.address |address *Optional*                 |
|service_policy             |str         |servicePolicy *Optional*           |
|call_processing_slice_id   |str         |callProcessingSliceId *Optional*   |
|provisioning_slice_id      |str         |provisioningSliceId *Optional*     |
|subscriber_partition       |str         |subscriberPartition *Optional*     |
|preferred_data_center      |str         |preferredDataCenter *Optional*     |
|reseller_id                |str         |resellerId *Optional*              |
</div>


## `ServiceProviderAnswerConfirmationModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a service provider or enterprise's answer confirmation settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

Replaced By: `ServiceProviderAnswerConfirmationModifyRequest16()`

**Attributes:**

|Name                            |Type                             |Description                             |
|--------------------------------|---------------------------------|----------------------------------------|
|service_provider_id             |str                              |serviceProviderId                       |
|announcement_message_selection  |str                              |announcementMessageSelection *Optional* |
|confirmation_message_audio_file |OCI.confirmationMessageAudioFile |confirmationMessageAudioFile *Optional* |
|confirmation_timout_seconds     |int                              |confirmationTimoutSeconds *Optional*    |
</div>


## `ServiceProviderAnswerConfirmationModifyRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a service provider or enterprise's answer confirmation settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                            |Type                             |Description                             |
|--------------------------------|---------------------------------|----------------------------------------|
|service_provider_id             |str                              |serviceProviderId                       |
|announcement_message_selection  |str                              |announcementMessageSelection *Optional* |
|confirmation_message_audio_file |OCI.confirmationMessageAudioFile |confirmationMessageAudioFile *Optional* |
|confirmation_timout_seconds     |int                              |confirmationTimoutSeconds *Optional*    |
</div>


## `ServiceProviderCPEConfigSetConfigFileRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to set a new service provider default configuration file for a device type.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. When the element
configFile is set to nil, the configuration file defined at the parent level is used.

**Attributes:**

|Name                |Type           |Description       |
|--------------------|---------------|------------------|
|service_provider_id |str            |serviceProviderId |
|device_type         |str            |deviceType        |
|config_file         |OCI.configFile |configFile        |
</div>


## `ServiceProviderCommunicationBarringProfileAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a new Communication Barring Profile.

The priorities for OriginatingRules, RedirectingRules and IncomingRules are
requantized to consecutive integers as part of the add.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                |Type                      |Description                                 |
|------------------------------------|--------------------------|--------------------------------------------|
|service_provider_id                 |str                       |serviceProviderId                           |
|name                                |str                       |name                                        |
|description                         |str                       |description *Optional*                      |
|originating_default_action          |str                       |originatingDefaultAction                    |
|originating_default_treatment_id    |str                       |originatingDefaultTreatmentId *Optional*    |
|originating_default_transfer_number |str                       |originatingDefaultTransferNumber *Optional* |
|originating_default_call_timeout    |int                       |originatingDefaultCallTimeout *Optional*    |
|originating_rule                    |List[OCI.originatingRule] |originatingRule *Optional*                  |
|redirecting_default_action          |str                       |redirectingDefaultAction                    |
|redirecting_default_call_timeout    |int                       |redirectingDefaultCallTimeout *Optional*    |
|redirecting_rule                    |List[OCI.redirectingRule] |redirectingRule *Optional*                  |
|incoming_default_action             |str                       |incomingDefaultAction                       |
|incoming_default_call_timeout       |int                       |incomingDefaultCallTimeout *Optional*       |
|incoming_rule                       |List[OCI.incomingRule]    |incomingRule *Optional*                     |
|become_default                      |bool                      |becomeDefault                               |
</div>


## `ServiceProviderCommunicationBarringProfileAddRequest17sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a new Communication Barring Profile.

The priorities for OriginatingRules, RedirectingRules, CallMeNowRules and
IncomingRules are requantized to consecutive integers as part of the add.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode: callMeNowDefaultAction, use value "Block" in
XS data mode The following elements are only used in AS data mode and ignored in XS
data mode callMeNowDefaultCallTimeout callMeNowRule

Replaced By : `ServiceProviderCommunicationBarringProfileAddRequest19sp1()` in AS data
mode

**Attributes:**

|Name                                |Type                      |Description                                 |
|------------------------------------|--------------------------|--------------------------------------------|
|service_provider_id                 |str                       |serviceProviderId                           |
|name                                |str                       |name                                        |
|description                         |str                       |description *Optional*                      |
|originating_default_action          |str                       |originatingDefaultAction                    |
|originating_default_treatment_id    |str                       |originatingDefaultTreatmentId *Optional*    |
|originating_default_transfer_number |str                       |originatingDefaultTransferNumber *Optional* |
|originating_default_call_timeout    |int                       |originatingDefaultCallTimeout *Optional*    |
|originating_rule                    |List[OCI.originatingRule] |originatingRule *Optional*                  |
|redirecting_default_action          |str                       |redirectingDefaultAction                    |
|redirecting_default_call_timeout    |int                       |redirectingDefaultCallTimeout *Optional*    |
|redirecting_rule                    |List[OCI.redirectingRule] |redirectingRule *Optional*                  |
|call_me_now_default_action          |str                       |callMeNowDefaultAction                      |
|call_me_now_default_call_timeout    |int                       |callMeNowDefaultCallTimeout *Optional*      |
|call_me_now_rule                    |List[OCI.callMeNowRule]   |callMeNowRule *Optional*                    |
|incoming_default_action             |str                       |incomingDefaultAction                       |
|incoming_default_call_timeout       |int                       |incomingDefaultCallTimeout *Optional*       |
|incoming_rule                       |List[OCI.incomingRule]    |incomingRule *Optional*                     |
|become_default                      |bool                      |becomeDefault                               |
</div>


## `ServiceProviderCommunicationBarringProfileAddRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a new Communication Barring Profile.

The priorities for OriginatingRules, RedirectingRules, CallMeNowRules and
IncomingRules are requantized to consecutive integers as part of the add.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode: callMeNowDefaultAction, use value "Block" in
XS data mode callMeNowDefaultCallTimeout callMeNowRule applyToAttendedCallTransfers,
use value "false" in XS data mode

**Attributes:**

|Name                                |Type                      |Description                                 |
|------------------------------------|--------------------------|--------------------------------------------|
|service_provider_id                 |str                       |serviceProviderId                           |
|name                                |str                       |name                                        |
|description                         |str                       |description *Optional*                      |
|originating_default_action          |str                       |originatingDefaultAction                    |
|originating_default_treatment_id    |str                       |originatingDefaultTreatmentId *Optional*    |
|originating_default_transfer_number |str                       |originatingDefaultTransferNumber *Optional* |
|originating_default_call_timeout    |int                       |originatingDefaultCallTimeout *Optional*    |
|originating_rule                    |List[OCI.originatingRule] |originatingRule *Optional*                  |
|redirecting_default_action          |str                       |redirectingDefaultAction                    |
|redirecting_default_call_timeout    |int                       |redirectingDefaultCallTimeout *Optional*    |
|redirecting_rule                    |List[OCI.redirectingRule] |redirectingRule *Optional*                  |
|call_me_now_default_action          |str                       |callMeNowDefaultAction                      |
|call_me_now_default_call_timeout    |int                       |callMeNowDefaultCallTimeout *Optional*      |
|call_me_now_rule                    |List[OCI.callMeNowRule]   |callMeNowRule *Optional*                    |
|incoming_default_action             |str                       |incomingDefaultAction                       |
|incoming_default_call_timeout       |int                       |incomingDefaultCallTimeout *Optional*       |
|incoming_rule                       |List[OCI.incomingRule]    |incomingRule *Optional*                     |
|become_default                      |bool                      |becomeDefault                               |
|apply_to_attended_call_transfers    |bool                      |applyToAttendedCallTransfers                |
</div>


## `ServiceProviderDeviceTypeFileModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a specified device type file for a service provider.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type           |Description           |
|--------------------|---------------|----------------------|
|service_provider_id |str            |serviceProviderId     |
|device_type         |str            |deviceType            |
|file_format         |str            |fileFormat            |
|file_source         |str            |fileSource *Optional* |
|upload_file         |OCI.uploadFile |uploadFile *Optional* |
</div>


## `ServiceProviderDialableCallerIDCriteriaModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a Dialable Caller ID Criteria.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                           |Type                            |Description                            |
|-------------------------------|--------------------------------|---------------------------------------|
|service_provider_id            |str                             |serviceProviderId                      |
|name                           |str                             |name                                   |
|new_name                       |str                             |newName *Optional*                     |
|description                    |str                             |description *Optional*                 |
|prefix_digits                  |str                             |prefixDigits *Optional*                |
|match_call_type                |OCI.matchCallType               |matchCallType *Optional*               |
|match_alternate_call_indicator |OCI.matchAlternateCallIndicator |matchAlternateCallIndicator *Optional* |
|match_local_category           |bool                            |matchLocalCategory *Optional*          |
|match_national_category        |bool                            |matchNationalCategory *Optional*       |
|match_interlata_category       |bool                            |matchInterlataCategory *Optional*      |
|match_intralata_category       |bool                            |matchIntralataCategory *Optional*      |
|match_international_category   |bool                            |matchInternationalCategory *Optional*  |
|match_private_category         |bool                            |matchPrivateCategory *Optional*        |
|match_emergency_category       |bool                            |matchEmergencyCategory *Optional*      |
|match_other_category           |bool                            |matchOtherCategory *Optional*          |
</div>


## `ServiceProviderDialableCallerIDModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the service provider?s Dialable Caller ID settings and criteria list.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                          |Type                            |Description                           |
|------------------------------|--------------------------------|--------------------------------------|
|service_provider_id           |str                             |serviceProviderId                     |
|use_service_provider_criteria |bool                            |useServiceProviderCriteria *Optional* |
|ns_screening_failure_policy   |str                             |nsScreeningFailurePolicy *Optional*   |
|criteria_priority_order       |List[OCI.criteriaPriorityOrder] |criteriaPriorityOrder *Optional*      |
</div>


## `ServiceProviderDnAddListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Adds DNs to a service provider.

It is possible to add either: a single DN, or a list of DNs, or a range of DNs, or any
combination thereof.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type              |Description            |
|--------------------|------------------|-----------------------|
|service_provider_id |str               |serviceProviderId      |
|phone_number        |List[str]         |phoneNumber *Optional* |
|dn_range            |List[OCI.dnRange] |dnRange *Optional*     |
</div>


## `ServiceProviderDnDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Deletes DNs from a service provider.

It is possible to delete either: a single DN, or a list of DNs, or a range of DNs, or
any combination thereof.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type              |Description            |
|--------------------|------------------|-----------------------|
|service_provider_id |str               |serviceProviderId      |
|phone_number        |List[str]         |phoneNumber *Optional* |
|dn_range            |List[OCI.dnRange] |dnRange *Optional*     |
</div>


## `ServiceProviderFeatureAccessCodeModifyListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a list of feature access codes for a service provider or enterprise.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

Replaced By : `ServiceProviderFeatureAccessCodeModifyListRequest20()` in AS data mode

**Attributes:**

|Name                |Type                        |Description                  |
|--------------------|----------------------------|-----------------------------|
|service_provider_id |str                         |serviceProviderId            |
|feature_access_code |List[OCI.featureAccessCode] |featureAccessCode *Optional* |
</div>


## `ServiceProviderFeatureAccessCodeModifyListRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a list of feature access codes for a service provider or enterprise.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. In release 20
the "Call Recording" FAC name is changed to "Call Recording - Start". Replaced by:
`ServiceProviderFeatureAccessCodeModifyListRequest21()`

**Attributes:**

|Name                |Type                        |Description                  |
|--------------------|----------------------------|-----------------------------|
|service_provider_id |str                         |serviceProviderId            |
|feature_access_code |List[OCI.featureAccessCode] |featureAccessCode *Optional* |
</div>


## `ServiceProviderFeatureAccessCodeModifyListRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a list of feature access codes for a service provider or enterprise.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. In release 20
the "Call Recording" FAC name is changed to "Call Recording - Start".

**Attributes:**

|Name                |Type                        |Description                  |
|--------------------|----------------------------|-----------------------------|
|service_provider_id |str                         |serviceProviderId            |
|feature_access_code |List[OCI.featureAccessCode] |featureAccessCode *Optional* |
</div>


## `ServiceProviderIMRNAssignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Assign a list of service provider DNs to the IMRN pool.

It is possible to assign either: a single DN, or a list of DNs, or a range of DNs, or
any combination thereof.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type                |Description          |
|--------------------|--------------------|---------------------|
|service_provider_id |str                 |serviceProviderId    |
|imrn                |List[str]           |imrn *Optional*      |
|imrn_range          |List[OCI.imrnRange] |imrnRange *Optional* |
</div>


## `ServiceProviderIMRNUnassignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Unassign a list of service provider DNs from the service provider IMRN pool.

The DNs then become available for assignment to groups.  It is possible to delete
either: a single DN, or a list of DNs, or a range of DNs, or any combination thereof.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type                |Description          |
|--------------------|--------------------|---------------------|
|service_provider_id |str                 |serviceProviderId    |
|imrn                |List[str]           |imrn *Optional*      |
|imrn_range          |List[OCI.imrnRange] |imrnRange *Optional* |
</div>


## `ServiceProviderMWIDeliveryToMobileEndpointModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the service provider level MWI custom notifications settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type                         |Description                   |
|--------------------|-----------------------------|------------------------------|
|service_provider_id |str                          |serviceProviderId             |
|template_activation |List[OCI.templateActivation] |templateActivation *Optional* |
</div>


## `ServiceProviderMeetMeConferencingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the service provider/enterprise level data associated with Meet-Me Conferencing
functions.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type               |Description               |
|--------------------|-------------------|--------------------------|
|service_provider_id |str                |serviceProviderId         |
|allocated_ports     |OCI.allocatedPorts |allocatedPorts *Optional* |
</div>


## `ServiceProviderModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the profile for a service provider or enterprise.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in Amplify data mode and ignored in AS and XS data mode:
servicePolicy, callProcessingSliceId, provisioningSliceId, subscriberPartition.  When
the callProcessingSliceId or provisioningSliceId is set to nillable, it will be
assigned to the default Slice.  Only Provisioning admin and above can change the
callProcessingSliceId, provisioningSliceId, and subscriberPartition.  The following
element is only used in AS data mode and ignored in Amplify and XS data mode:
resellerId resellerName resellerId and resellerName can only be configured by a
Reseller or higher level administrator.  The following behavior is only applicable in
CloudPBX: - when existing resellerId is specified, enterprise/Service Provider shall
be moved to requesting reseller.  - when new resellerId, that does not exist in the
system, is specified, the new Reseller is created the given resellerId and
resellerName (if provided) and enterprise/Service Provider is moved to the newly
created Reseller.  resellerName element is ignored if the reseller the service
provider is being moved to already exists.  The following elements are only used in
Amplify and XS data mode and ignored in AS data mode: preferredDataCenter.  Only
Provisioning admin and above can change the preferredDataCenter.  The following
elements are only used in AS data mode and ignored in XS data mode:
defaultExtensionLength locationRoutingPrefixDigit locationCodeLength

**Attributes:**

|Name                           |Type        |Description                            |
|-------------------------------|------------|---------------------------------------|
|service_provider_id            |str         |serviceProviderId                      |
|default_domain                 |str         |defaultDomain *Optional*               |
|service_provider_name          |str         |serviceProviderName *Optional*         |
|support_email                  |str         |supportEmail *Optional*                |
|contact                        |OCI.contact |contact *Optional*                     |
|address                        |OCI.address |address *Optional*                     |
|use_service_provider_languages |bool        |useServiceProviderLanguages *Optional* |
|service_policy                 |str         |servicePolicy *Optional*               |
|call_processing_slice_id       |str         |callProcessingSliceId *Optional*       |
|provisioning_slice_id          |str         |provisioningSliceId *Optional*         |
|subscriber_partition           |str         |subscriberPartition *Optional*         |
|preferred_data_center          |str         |preferredDataCenter *Optional*         |
|default_extension_length       |int         |defaultExtensionLength *Optional*      |
|location_routing_prefix_digit  |int         |locationRoutingPrefixDigit *Optional*  |
|location_code_length           |int         |locationCodeLength *Optional*          |
|reseller_id                    |str         |resellerId *Optional*                  |
|reseller_name                  |str         |resellerName *Optional*                |
</div>


## `ServiceProviderNetworkClassOfServiceAssignListRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Assign a list of Network Classes of Service to a service provider.

A default Network Class of Service must be specified unless there is already one
assigned to the service provider.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                             |Type                             |Description                      |
|---------------------------------|---------------------------------|---------------------------------|
|service_provider_id              |str                              |serviceProviderId                |
|network_class_of_service         |List[str]                        |networkClassOfService *Optional* |
|default_network_class_of_service |OCI.defaultNetworkClassOfService |defaultNetworkClassOfService     |
</div>


## `ServiceProviderNetworkClassOfServiceUnassignListRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Unassign a list of Network Classes of Service from a service provider.

If the default Network Class of Service is being unassigned, a new one must be
specified unless there are no more Network Classes of Service assigned to the service
provider.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                             |Type                             |Description                      |
|---------------------------------|---------------------------------|---------------------------------|
|service_provider_id              |str                              |serviceProviderId                |
|network_class_of_service         |List[str]                        |networkClassOfService *Optional* |
|default_network_class_of_service |OCI.defaultNetworkClassOfService |defaultNetworkClassOfService     |
</div>


## `ServiceProviderRouteListEnterpriseTrunkNumberRangeAddListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add number ranges to a service provider.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type                  |Description            |
|--------------------|----------------------|-----------------------|
|service_provider_id |str                   |serviceProviderId      |
|number_range        |List[OCI.numberRange] |numberRange *Optional* |
</div>


## `ServiceProviderRouteListEnterpriseTrunkNumberRangeModifyListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a list of number ranges in a service provider The response is either
`SuccessResponse()` or `ErrorResponse()`.


**Attributes:**

|Name                |Type                  |Description            |
|--------------------|----------------------|-----------------------|
|service_provider_id |str                   |serviceProviderId      |
|number_range        |List[OCI.numberRange] |numberRange *Optional* |
</div>


## `ServiceProviderScheduleAddEventRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add an event to service provider schedule.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The startDate
element is adjusted to the first occurrence of the recurrent schedule that comes at or
after the startDate.  The endDate element is set to the sum of the adjusted starDate
element value and the event duration.

**Attributes:**

|Name                |Type            |Description            |
|--------------------|----------------|-----------------------|
|service_provider_id |str             |serviceProviderId      |
|schedule_key        |OCI.scheduleKey |scheduleKey            |
|event_name          |str             |eventName              |
|start_date          |str             |startDate              |
|all_day_event       |bool            |allDayEvent *Optional* |
|start_time          |OCI.startTime   |startTime *Optional*   |
|end_time            |OCI.endTime     |endTime *Optional*     |
|end_date            |str             |endDate                |
|recurrence          |OCI.recurrence  |recurrence *Optional*  |
</div>


## `ServiceProviderScheduleDeleteEventListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a list of events from a service provider schedule.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type            |Description       |
|--------------------|----------------|------------------|
|service_provider_id |str             |serviceProviderId |
|schedule_key        |OCI.scheduleKey |scheduleKey       |
|event_name          |List[str]       |eventName         |
</div>


## `ServiceProviderScheduleDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a list of service provider schedule.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type                  |Description       |
|--------------------|----------------------|------------------|
|service_provider_id |str                   |serviceProviderId |
|schedule_key        |List[OCI.scheduleKey] |scheduleKey       |
</div>


## `ServiceProviderScheduleGetEventDetailListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of events of a service provider schedule.

The response is either a `ServiceProviderScheduleGetEventDetailListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type            |Description       |
|--------------------|----------------|------------------|
|service_provider_id |str             |serviceProviderId |
|schedule_key        |OCI.scheduleKey |scheduleKey       |
</div>


## `ServiceProviderScheduleGetEventListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of events of a service provider schedule.

The response is either a `ServiceProviderScheduleGetEventListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type            |Description       |
|--------------------|----------------|------------------|
|service_provider_id |str             |serviceProviderId |
|schedule_key        |OCI.scheduleKey |scheduleKey       |
</div>


## `ServiceProviderScheduleGetEventRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get an event from a service provider schedule.

The response is either a `ServiceProviderScheduleGetEventResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type            |Description       |
|--------------------|----------------|------------------|
|service_provider_id |str             |serviceProviderId |
|schedule_key        |OCI.scheduleKey |scheduleKey       |
|event_name          |str             |eventName         |
</div>


## `ServiceProviderScheduleModifyEventRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an event of a service provider schedule.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The startDate
element is adjusted to the first occurrence of the recurrent schedule that comes at or
after the startDate.  The endDate element is set to the sum of the adjusted starDate
element value and the event duration.

**Attributes:**

|Name                |Type            |Description             |
|--------------------|----------------|------------------------|
|service_provider_id |str             |serviceProviderId       |
|schedule_key        |OCI.scheduleKey |scheduleKey             |
|event_name          |str             |eventName               |
|new_event_name      |str             |newEventName *Optional* |
|start_date          |str             |startDate *Optional*    |
|all_day_event       |bool            |allDayEvent *Optional*  |
|start_time          |OCI.startTime   |startTime *Optional*    |
|end_time            |OCI.endTime     |endTime *Optional*      |
|end_date            |str             |endDate *Optional*      |
|recurrence          |OCI.recurrence  |recurrence *Optional*   |
</div>


## `ServiceProviderScheduleModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a service provider schedule.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type            |Description                |
|--------------------|----------------|---------------------------|
|service_provider_id |str             |serviceProviderId          |
|schedule_key        |OCI.scheduleKey |scheduleKey                |
|new_schedule_name   |str             |newScheduleName *Optional* |
</div>


## `ServiceProviderServicePackAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a service pack to a service provider.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                     |Type                    |Description                       |
|-------------------------|------------------------|----------------------------------|
|service_provider_id      |str                     |serviceProviderId                 |
|service_pack_name        |str                     |servicePackName                   |
|service_pack_description |str                     |servicePackDescription *Optional* |
|is_available_for_use     |bool                    |isAvailableForUse                 |
|service_pack_quantity    |OCI.servicePackQuantity |servicePackQuantity               |
|service_name             |List[str]               |serviceName *Optional*            |
</div>


## `ServiceProviderServicePackMigrationTaskModifyAssignmentListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Replace the list of services and packs to be assigned to users during the service pack
migration.

Modification is only allowed prior to task execution.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                   |Type                    |Description                    |
|-----------------------|------------------------|-------------------------------|
|service_provider_id    |str                     |serviceProviderId              |
|task_name              |str                     |taskName                       |
|user_service_name_list |OCI.userServiceNameList |userServiceNameList *Optional* |
|service_pack_name_list |OCI.servicePackNameList |servicePackNameList *Optional* |
</div>


## `ServiceProviderServicePackMigrationTaskModifyRemovalListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Replace the list of services and packs to be removed from users during the service
pack migration.

Modification is only allowed prior to task execution.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                   |Type                    |Description                    |
|-----------------------|------------------------|-------------------------------|
|service_provider_id    |str                     |serviceProviderId              |
|task_name              |str                     |taskName                       |
|user_service_name_list |OCI.userServiceNameList |userServiceNameList *Optional* |
|service_pack_name_list |OCI.servicePackNameList |servicePackNameList *Optional* |
</div>


## `ServiceProviderServicePackMigrationTaskModifyUserSelectionRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Replace the list of services and packs used to select which users will be migrated.

Modification is only allowed prior to task execution.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                   |Type                    |Description                    |
|-----------------------|------------------------|-------------------------------|
|service_provider_id    |str                     |serviceProviderId              |
|task_name              |str                     |taskName                       |
|user_selection_type    |str                     |userSelectionType *Optional*   |
|user_service_name_list |OCI.userServiceNameList |userServiceNameList *Optional* |
|service_pack_name_list |OCI.servicePackNameList |servicePackNameList *Optional* |
</div>


## `ServiceProviderServicePackModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests to modify a service pack for a service provider.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                     |Type                    |Description                       |
|-------------------------|------------------------|----------------------------------|
|service_provider_id      |str                     |serviceProviderId                 |
|service_pack_name        |str                     |servicePackName                   |
|new_service_pack_name    |str                     |newServicePackName *Optional*     |
|service_pack_description |str                     |servicePackDescription *Optional* |
|is_available_for_use     |bool                    |isAvailableForUse *Optional*      |
|service_pack_quantity    |OCI.servicePackQuantity |servicePackQuantity *Optional*    |
</div>


## `ServiceProviderTrunkGroupModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the maximum and bursting maximum permissible active Trunk Group calls for the
service provider.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                      |Type                       |Description                       |
|--------------------------|---------------------------|----------------------------------|
|service_provider_id       |str                        |serviceProviderId                 |
|max_active_calls          |OCI.maxActiveCalls         |maxActiveCalls *Optional*         |
|bursting_max_active_calls |OCI.burstingMaxActiveCalls |burstingMaxActiveCalls *Optional* |
|number_of_bursting_btl_us |OCI.numberOfBurstingBTLUs  |numberOfBurstingBTLUs *Optional*  |
</div>


## `ServiceProviderVoiceMessagingGroupModifyVoicePortalBrandingRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the service provider's voice portal branding settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

Replaced By: `ServiceProviderVoiceMessagingGroupModifyVoicePortalBrandingRequest16()`

**Attributes:**

|Name                               |Type                           |Description                                |
|-----------------------------------|-------------------------------|-------------------------------------------|
|service_provider_id                |str                            |serviceProviderId                          |
|voice_portal_greeting_selection    |str                            |voicePortalGreetingSelection *Optional*    |
|voice_portal_greeting_file         |OCI.voicePortalGreetingFile    |voicePortalGreetingFile *Optional*         |
|voice_messaging_greeting_selection |str                            |voiceMessagingGreetingSelection *Optional* |
|voice_messaging_greeting_file      |OCI.voiceMessagingGreetingFile |voiceMessagingGreetingFile *Optional*      |
</div>


## `ServiceProviderVoiceMessagingGroupModifyVoicePortalBrandingRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the service provider's voice portal branding settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                               |Type                           |Description                                |
|-----------------------------------|-------------------------------|-------------------------------------------|
|service_provider_id                |str                            |serviceProviderId                          |
|voice_portal_greeting_selection    |str                            |voicePortalGreetingSelection *Optional*    |
|voice_portal_greeting_file         |OCI.voicePortalGreetingFile    |voicePortalGreetingFile *Optional*         |
|voice_messaging_greeting_selection |str                            |voiceMessagingGreetingSelection *Optional* |
|voice_messaging_greeting_file      |OCI.voiceMessagingGreetingFile |voiceMessagingGreetingFile *Optional*      |
</div>


## `ServiceProviderXsiPolicyProfileAssignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Assign a list of group and user Xsi policy profile to a service provider.

At service provider level, only one service provider Xsi policy profile can be
assigned to service provider.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type                      |Description                      |
|-------------------------|--------------------------|---------------------------------|
|service_provider_id      |str                       |serviceProviderId                |
|sp_xsi_policy_profile    |str                       |spXsiPolicyProfile *Optional*    |
|group_xsi_policy_profile |OCI.groupXsiPolicyProfile |groupXsiPolicyProfile *Optional* |
|user_xsi_policy_profile  |OCI.userXsiPolicyProfile  |userXsiPolicyProfile *Optional*  |
</div>


## `ServiceProviderXsiPolicyProfileUnassignListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Unassign a list of Xsi policy profile.

Unassign a list of Xsi policy profile.  Only group and user level Xsi policy profile
can be unassigned.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type                      |Description                      |
|-------------------------|--------------------------|---------------------------------|
|service_provider_id      |str                       |serviceProviderId                |
|group_xsi_policy_profile |OCI.groupXsiPolicyProfile |groupXsiPolicyProfile *Optional* |
|user_xsi_policy_profile  |OCI.userXsiPolicyProfile  |userXsiPolicyProfile *Optional*  |
</div>


## `SystemAccessDeviceAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a system-level access device.

The response is either `SuccessResponse()` or `ErrorResponse()`. Repaced By:
`SystemAccessDeviceAddRequest22()`

**Attributes:**

|Name                                             |Type                        |Description                                            |
|-------------------------------------------------|----------------------------|-------------------------------------------------------|
|device_name                                      |str                         |deviceName                                             |
|device_type                                      |str                         |deviceType                                             |
|protocol                                         |str                         |protocol *Optional*                                    |
|net_address                                      |str                         |netAddress *Optional*                                  |
|port                                             |int                         |port *Optional*                                        |
|outbound_proxy_server_net_address                |str                         |outboundProxyServerNetAddress *Optional*               |
|stun_server_net_address                          |str                         |stunServerNetAddress *Optional*                        |
|mac_address                                      |str                         |macAddress *Optional*                                  |
|serial_number                                    |str                         |serialNumber *Optional*                                |
|description                                      |str                         |description *Optional*                                 |
|physical_location                                |str                         |physicalLocation *Optional*                            |
|transport_protocol                               |str                         |transportProtocol *Optional*                           |
|mobility_manager_provisioning_url                |str                         |mobilityManagerProvisioningURL *Optional*              |
|mobility_manager_provisioning_user_name          |str                         |mobilityManagerProvisioningUserName *Optional*         |
|mobility_manager_provisioning_password           |str                         |mobilityManagerProvisioningPassword *Optional*         |
|mobility_manager_default_originating_service_key |int                         |mobilityManagerDefaultOriginatingServiceKey *Optional* |
|mobility_manager_default_terminating_service_key |int                         |mobilityManagerDefaultTerminatingServiceKey *Optional* |
|use_custom_user_name_password                    |bool                        |useCustomUserNamePassword *Optional*                   |
|access_device_credentials                        |OCI.accessDeviceCredentials |accessDeviceCredentials *Optional*                     |
</div>


## `SystemAccessDeviceAddRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a system-level access device.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode: useHotline
hotlineContact deviceExternalId Replaced by: `SystemAccessDeviceAddRequest22V2()`

**Attributes:**

|Name                                             |Type                        |Description                                            |
|-------------------------------------------------|----------------------------|-------------------------------------------------------|
|device_name                                      |str                         |deviceName *Optional*                                  |
|device_external_id                               |str                         |deviceExternalId *Optional*                            |
|device_type                                      |str                         |deviceType                                             |
|protocol                                         |str                         |protocol *Optional*                                    |
|net_address                                      |str                         |netAddress *Optional*                                  |
|port                                             |int                         |port *Optional*                                        |
|outbound_proxy_server_net_address                |str                         |outboundProxyServerNetAddress *Optional*               |
|stun_server_net_address                          |str                         |stunServerNetAddress *Optional*                        |
|mac_address                                      |str                         |macAddress *Optional*                                  |
|serial_number                                    |str                         |serialNumber *Optional*                                |
|description                                      |str                         |description *Optional*                                 |
|physical_location                                |str                         |physicalLocation *Optional*                            |
|transport_protocol                               |str                         |transportProtocol *Optional*                           |
|mobility_manager_provisioning_url                |str                         |mobilityManagerProvisioningURL *Optional*              |
|mobility_manager_provisioning_user_name          |str                         |mobilityManagerProvisioningUserName *Optional*         |
|mobility_manager_provisioning_password           |str                         |mobilityManagerProvisioningPassword *Optional*         |
|mobility_manager_default_originating_service_key |int                         |mobilityManagerDefaultOriginatingServiceKey *Optional* |
|mobility_manager_default_terminating_service_key |int                         |mobilityManagerDefaultTerminatingServiceKey *Optional* |
|use_custom_user_name_password                    |bool                        |useCustomUserNamePassword *Optional*                   |
|access_device_credentials                        |OCI.accessDeviceCredentials |accessDeviceCredentials *Optional*                     |
|use_hotline                                      |bool                        |useHotline                                             |
|hotline_contact                                  |str                         |hotlineContact *Optional*                              |
</div>


## `SystemAccessDeviceAddRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a system-level access device.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode: useHotline
hotlineContact isWebexTeamsDevice defaultPathHeader deviceExternalId

**Attributes:**

|Name                                             |Type                        |Description                                            |
|-------------------------------------------------|----------------------------|-------------------------------------------------------|
|device_name                                      |str                         |deviceName *Optional*                                  |
|device_external_id                               |str                         |deviceExternalId *Optional*                            |
|device_type                                      |str                         |deviceType                                             |
|protocol                                         |str                         |protocol *Optional*                                    |
|net_address                                      |str                         |netAddress *Optional*                                  |
|port                                             |int                         |port *Optional*                                        |
|outbound_proxy_server_net_address                |str                         |outboundProxyServerNetAddress *Optional*               |
|stun_server_net_address                          |str                         |stunServerNetAddress *Optional*                        |
|mac_address                                      |str                         |macAddress *Optional*                                  |
|serial_number                                    |str                         |serialNumber *Optional*                                |
|description                                      |str                         |description *Optional*                                 |
|physical_location                                |str                         |physicalLocation *Optional*                            |
|transport_protocol                               |str                         |transportProtocol *Optional*                           |
|mobility_manager_provisioning_url                |str                         |mobilityManagerProvisioningURL *Optional*              |
|mobility_manager_provisioning_user_name          |str                         |mobilityManagerProvisioningUserName *Optional*         |
|mobility_manager_provisioning_password           |str                         |mobilityManagerProvisioningPassword *Optional*         |
|mobility_manager_default_originating_service_key |int                         |mobilityManagerDefaultOriginatingServiceKey *Optional* |
|mobility_manager_default_terminating_service_key |int                         |mobilityManagerDefaultTerminatingServiceKey *Optional* |
|use_custom_user_name_password                    |bool                        |useCustomUserNamePassword *Optional*                   |
|access_device_credentials                        |OCI.accessDeviceCredentials |accessDeviceCredentials *Optional*                     |
|use_hotline                                      |bool                        |useHotline                                             |
|hotline_contact                                  |str                         |hotlineContact *Optional*                              |
|is_webex_teams_device                            |bool                        |isWebexTeamsDevice *Optional*                          |
|default_path_header                              |str                         |defaultPathHeader *Optional*                           |
</div>


## `SystemAccessDeviceAddRequest22V3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a system-level access device.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode: isWebexTeamsDevice
defaultPathHeader deviceExternalId

**Attributes:**

|Name                              |Type                        |Description                              |
|----------------------------------|----------------------------|-----------------------------------------|
|device_name                       |str                         |deviceName *Optional*                    |
|device_external_id                |str                         |deviceExternalId *Optional*              |
|device_type                       |str                         |deviceType                               |
|protocol                          |str                         |protocol *Optional*                      |
|net_address                       |str                         |netAddress *Optional*                    |
|port                              |int                         |port *Optional*                          |
|outbound_proxy_server_net_address |str                         |outboundProxyServerNetAddress *Optional* |
|stun_server_net_address           |str                         |stunServerNetAddress *Optional*          |
|mac_address                       |str                         |macAddress *Optional*                    |
|serial_number                     |str                         |serialNumber *Optional*                  |
|description                       |str                         |description *Optional*                   |
|physical_location                 |str                         |physicalLocation *Optional*              |
|transport_protocol                |str                         |transportProtocol *Optional*             |
|use_custom_user_name_password     |bool                        |useCustomUserNamePassword *Optional*     |
|access_device_credentials         |OCI.accessDeviceCredentials |accessDeviceCredentials *Optional*       |
|is_webex_teams_device             |bool                        |isWebexTeamsDevice *Optional*            |
|default_path_header               |str                         |defaultPathHeader *Optional*             |
</div>


## `SystemAccessDeviceCustomTagAddOrModifyListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add or modify a list of static configuration tag for a system access
device.

If the tag does not exist, it is added.  If the tag exists, its value is updated.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name        |Type          |Description|
|------------|--------------|-----------|
|device_name |str           |deviceName |
|tag         |List[OCI.tag] |tag        |
</div>


## `SystemAccessDeviceFileModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a specified system access device file.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

Replaced By: `SystemAccessDeviceFileModifyRequest14sp8()`

**Attributes:**

|Name        |Type           |Description           |
|------------|---------------|----------------------|
|device_name |str            |deviceName            |
|file_type   |str            |fileType              |
|file_source |str            |fileSource *Optional* |
|upload_file |OCI.uploadFile |uploadFile *Optional* |
</div>


## `SystemAccessDeviceFileModifyRequest14sp8`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a specified system access device file.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type           |Description                       |
|-------------------------|---------------|----------------------------------|
|device_name              |str            |deviceName                        |
|file_format              |str            |fileFormat                        |
|file_source              |str            |fileSource *Optional*             |
|upload_file              |OCI.uploadFile |uploadFile *Optional*             |
|extended_capture_enabled |bool           |extendedCaptureEnabled *Optional* |
</div>


## `SystemAccessDeviceLinkDeviceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to link one or more leaf devices to a system level tree device.

A tree device is a device associated with a device type that has the option
supportLinks set to "Support Links from Devices". Many leaf devices can be linked to
it.  A leaf device is a device associated with a device type that has the option
supportLinks set to "Support Link to Device". It can be linked to only one tree
device.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name            |Type                    |Description   |
|----------------|------------------------|--------------|
|device_name     |str                     |deviceName    |
|leaf_device_key |List[OCI.leafDeviceKey] |leafDeviceKey |
</div>


## `SystemAccessDeviceModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a specified system access device.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode: useHotline
hotlineContact isWebexTeamsDevice defaultPathHeader deviceExternalId

**Attributes:**

|Name                                             |Type                        |Description                                            |
|-------------------------------------------------|----------------------------|-------------------------------------------------------|
|device_name                                      |str                         |deviceName *Optional*                                  |
|device_external_id                               |str                         |deviceExternalId *Optional*                            |
|protocol                                         |str                         |protocol *Optional*                                    |
|net_address                                      |str                         |netAddress *Optional*                                  |
|port                                             |int                         |port *Optional*                                        |
|outbound_proxy_server_net_address                |str                         |outboundProxyServerNetAddress *Optional*               |
|stun_server_net_address                          |str                         |stunServerNetAddress *Optional*                        |
|mac_address                                      |str                         |macAddress *Optional*                                  |
|serial_number                                    |str                         |serialNumber *Optional*                                |
|description                                      |str                         |description *Optional*                                 |
|physical_location                                |str                         |physicalLocation *Optional*                            |
|transport_protocol                               |str                         |transportProtocol *Optional*                           |
|mobility_manager_provisioning_url                |str                         |mobilityManagerProvisioningURL *Optional*              |
|mobility_manager_provisioning_user_name          |str                         |mobilityManagerProvisioningUserName *Optional*         |
|mobility_manager_provisioning_password           |str                         |mobilityManagerProvisioningPassword *Optional*         |
|mobility_manager_default_originating_service_key |int                         |mobilityManagerDefaultOriginatingServiceKey *Optional* |
|mobility_manager_default_terminating_service_key |int                         |mobilityManagerDefaultTerminatingServiceKey *Optional* |
|use_custom_user_name_password                    |bool                        |useCustomUserNamePassword *Optional*                   |
|access_device_credentials                        |OCI.accessDeviceCredentials |accessDeviceCredentials *Optional*                     |
|use_hotline                                      |bool                        |useHotline *Optional*                                  |
|hotline_contact                                  |str                         |hotlineContact *Optional*                              |
|is_webex_teams_device                            |bool                        |isWebexTeamsDevice *Optional*                          |
|default_path_header                              |str                         |defaultPathHeader *Optional*                           |
</div>


## `SystemAccessDeviceModifyRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a specified system access device.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode: isWebexTeamsDevice
defaultPathHeader deviceExternalId

**Attributes:**

|Name                              |Type                        |Description                              |
|----------------------------------|----------------------------|-----------------------------------------|
|device_name                       |str                         |deviceName *Optional*                    |
|device_external_id                |str                         |deviceExternalId *Optional*              |
|protocol                          |str                         |protocol *Optional*                      |
|net_address                       |str                         |netAddress *Optional*                    |
|port                              |int                         |port *Optional*                          |
|outbound_proxy_server_net_address |str                         |outboundProxyServerNetAddress *Optional* |
|stun_server_net_address           |str                         |stunServerNetAddress *Optional*          |
|mac_address                       |str                         |macAddress *Optional*                    |
|serial_number                     |str                         |serialNumber *Optional*                  |
|description                       |str                         |description *Optional*                   |
|physical_location                 |str                         |physicalLocation *Optional*              |
|transport_protocol                |str                         |transportProtocol *Optional*             |
|use_custom_user_name_password     |bool                        |useCustomUserNamePassword *Optional*     |
|access_device_credentials         |OCI.accessDeviceCredentials |accessDeviceCredentials *Optional*       |
|is_webex_teams_device             |bool                        |isWebexTeamsDevice *Optional*            |
|default_path_header               |str                         |defaultPathHeader *Optional*             |
</div>


## `SystemAccessDeviceUnlinkDeviceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to unlink one or more leaf access devices from a tree device.

A leaf device is a device associated with a device type that has the option
supportLinks set to "Support Link to Device". It can be linked to only one tree
device.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name            |Type                    |Description   |
|----------------|------------------------|--------------|
|leaf_device_key |List[OCI.leafDeviceKey] |leafDeviceKey |
</div>


## `SystemAutomaticCollectCallPrefixDigitsAddListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a system automatic collect call prefix digits entry.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type                        |Description       |
|--------------------|----------------------------|------------------|
|prefix_digits_entry |List[OCI.prefixDigitsEntry] |prefixDigitsEntry |
</div>


## `SystemAutomaticCollectCallPrefixDigitsDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete an entry in system automatic collect call prefix table.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type                        |Description       |
|--------------------|----------------------------|------------------|
|prefix_digits_entry |List[OCI.prefixDigitsEntry] |prefixDigitsEntry |
</div>


## `SystemBroadWorksMobilityAddIMRNListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Adds BroadWorks Mobility IMRN numbers to the system.

It is possible to add either: a single number, a list of numbers, or a range of
numbers, or any combination thereof.

The response is either a `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name         |Type                  |Description            |
|-------------|----------------------|-----------------------|
|imrn_number  |List[str]             |imrnNumber *Optional*  |
|number_range |List[OCI.numberRange] |numberRange *Optional* |
</div>


## `SystemBroadWorksMobilityAddMobileNetworkIMRNListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Adds BroadWorks Mobility IMRN numbers to a Mobile Network.

It is possible to add either: a single number, a list of numbers, or a range of
numbers, or any combination thereof.

The response is either a `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type                  |Description            |
|--------------------|----------------------|-----------------------|
|mobile_network_name |str                   |mobileNetworkName      |
|imrn_number         |List[str]             |imrnNumber *Optional*  |
|number_range        |List[OCI.numberRange] |numberRange *Optional* |
</div>


## `SystemBroadWorksMobilityGeographicalPoolIMRNAddListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Adds BroadWorks Mobility IMRN numbers to a geographical pool.

It is possible to add either: a single number, a list of numbers, or a range of
numbers, or any combination thereof.

The response is either a `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                   |Type                  |Description            |
|-----------------------|----------------------|-----------------------|
|geographical_pool_name |str                   |geographicalPoolName   |
|imrn_number            |List[str]             |imrnNumber *Optional*  |
|number_range           |List[OCI.numberRange] |numberRange *Optional* |
</div>


## `SystemCallCenterEnhancedReportingBrandingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the system branding configuration.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                 |Type                   |Description                   |
|---------------------|-----------------------|------------------------------|
|branding_choice      |str                    |brandingChoice *Optional*     |
|custom_branding_file |OCI.customBrandingFile |customBrandingFile *Optional* |
</div>


## `SystemCallCenterEnhancedReportingReportTemplateAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a system level call center report template.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                    |Type             |Description                                    |
|----------------------------------------|-----------------|-----------------------------------------------|
|name                                    |str              |name                                           |
|description                             |str              |description *Optional*                         |
|data_template                           |str              |dataTemplate                                   |
|filter_number                           |int              |filterNumber *Optional*                        |
|xslt_template                           |OCI.xsltTemplate |xsltTemplate                                   |
|scope                                   |str              |scope                                          |
|is_enabled                              |bool             |isEnabled                                      |
|is_realtime_report                      |bool             |isRealtimeReport *Optional*                    |
|call_completion_threshold_param         |str              |callCompletionThresholdParam *Optional*        |
|short_duration_threshold_param          |str              |shortDurationThresholdParam *Optional*         |
|service_level_threshold_param           |str              |serviceLevelThresholdParam *Optional*          |
|service_level_inclusions_param          |str              |serviceLevelInclusionsParam *Optional*         |
|service_level_objective_threshold_param |str              |serviceLevelObjectiveThresholdParam *Optional* |
|abandoned_call_threshold_param          |str              |abandonedCallThresholdParam *Optional*         |
|service_level_threshold_param_number    |int              |serviceLevelThresholdParamNumber *Optional*    |
|abandoned_call_threshold_param_number   |int              |abandonedCallThresholdParamNumber *Optional*   |
|filter_value                            |List[str]        |filterValue *Optional*                         |
</div>


## `SystemCallCenterEnhancedReportingReportTemplateModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a system level call center report template.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name               |Type             |Description                 |
|-------------------|-----------------|----------------------------|
|name               |str              |name                        |
|new_name           |str              |newName *Optional*          |
|description        |str              |description *Optional*      |
|xslt_template      |OCI.xsltTemplate |xsltTemplate *Optional*     |
|scope              |str              |scope *Optional*            |
|is_enabled         |bool             |isEnabled *Optional*        |
|is_realtime_report |bool             |isRealtimeReport *Optional* |
|filter_number      |int              |filterNumber *Optional*     |
|filter_value       |OCI.filterValue  |filterValue *Optional*      |
</div>


## `SystemCallProcessingPolicyProfileModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call processing policy profile in system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by
`SystemCallProcessingPolicyProfileModifyRequest20()`.

**Attributes:**

|Name                          |Type                           |Description                           |
|------------------------------|-------------------------------|--------------------------------------|
|name                          |str                            |name                                  |
|new_name                      |str                            |newName *Optional*                    |
|description                   |str                            |description *Optional*                |
|assigned_subscriber_type_list |OCI.assignedSubscriberTypeList |assignedSubscriberTypeList *Optional* |
</div>


## `SystemCallProcessingPolicyProfileModifyRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call processing policy profile in system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                          |Type                           |Description                           |
|------------------------------|-------------------------------|--------------------------------------|
|name                          |str                            |name                                  |
|new_name                      |str                            |newName *Optional*                    |
|description                   |str                            |description *Optional*                |
|assigned_subscriber_type_list |OCI.assignedSubscriberTypeList |assignedSubscriberTypeList *Optional* |
</div>


## `SystemCallProcessingPolicyProfileModifyRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call processing policy profile in system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                          |Type                           |Description                           |
|------------------------------|-------------------------------|--------------------------------------|
|name                          |str                            |name                                  |
|new_name                      |str                            |newName *Optional*                    |
|description                   |str                            |description *Optional*                |
|assigned_subscriber_type_list |OCI.assignedSubscriberTypeList |assignedSubscriberTypeList *Optional* |
</div>


## `SystemCollaborateModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with collaborate services.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`SystemCollaborateModifyRequest20sp1()`

**Attributes:**

|Name                                               |Type                       |Description                                              |
|---------------------------------------------------|---------------------------|---------------------------------------------------------|
|collaborate_room_id_length                         |int                        |collaborateRoomIdLength *Optional*                       |
|instant_room_idle_timeout_seconds                  |int                        |instantRoomIdleTimeoutSeconds *Optional*                 |
|collaborate_room_maximum_duration_minutes          |int                        |collaborateRoomMaximumDurationMinutes *Optional*         |
|support_outdial                                    |bool                       |supportOutdial *Optional*                                |
|max_collaborate_room_participants                  |int                        |maxCollaborateRoomParticipants *Optional*                |
|collaborate_active_talker_refresh_interval_seconds |int                        |collaborateActiveTalkerRefreshIntervalSeconds *Optional* |
|terminate_collaborate_after_grace_period           |bool                       |terminateCollaborateAfterGracePeriod *Optional*          |
|collaborate_grace_period                           |OCI.collaborateGracePeriod |collaborateGracePeriod *Optional*                        |
|enable_active_collaborate_notification             |bool                       |enableActiveCollaborateNotification *Optional*           |
|collaborate_from_address                           |str                        |collaborateFromAddress *Optional*                        |
</div>


## `SystemCollaborateModifyRequest20sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with collaborate services.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by
SystemCollaborateModifyRequest20sp1V2

**Attributes:**

|Name                                               |Type                       |Description                                              |
|---------------------------------------------------|---------------------------|---------------------------------------------------------|
|collaborate_room_id_length                         |int                        |collaborateRoomIdLength *Optional*                       |
|instant_room_idle_timeout_seconds                  |int                        |instantRoomIdleTimeoutSeconds *Optional*                 |
|collaborate_room_maximum_duration_minutes          |int                        |collaborateRoomMaximumDurationMinutes *Optional*         |
|support_outdial                                    |bool                       |supportOutdial *Optional*                                |
|max_collaborate_room_participants                  |int                        |maxCollaborateRoomParticipants *Optional*                |
|collaborate_active_talker_refresh_interval_seconds |int                        |collaborateActiveTalkerRefreshIntervalSeconds *Optional* |
|terminate_collaborate_after_grace_period           |bool                       |terminateCollaborateAfterGracePeriod *Optional*          |
|collaborate_grace_period                           |OCI.collaborateGracePeriod |collaborateGracePeriod *Optional*                        |
|enable_active_collaborate_notification             |bool                       |enableActiveCollaborateNotification *Optional*           |
|collaborate_from_address                           |str                        |collaborateFromAddress *Optional*                        |
</div>


## `SystemCommunicationBarringCriteriaModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an existing Communication Barring Criteria.

The following elements are only used in AS data mode: matchNumberPortabilityStatus The
following elements are only used in XS data mode and ignored in AS data mode:
matchOtherGETS matchNotGETS matchGETSAN matchGETSNT matchGETSFC matchGETSFCAN
matchGETSFCNT

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                            |Type                             |Description                             |
|--------------------------------|---------------------------------|----------------------------------------|
|name                            |str                              |name                                    |
|new_name                        |str                              |newName *Optional*                      |
|description                     |str                              |description *Optional*                  |
|match_call_type                 |OCI.matchCallType                |matchCallType *Optional*                |
|match_alternate_call_indicator  |OCI.matchAlternateCallIndicator  |matchAlternateCallIndicator *Optional*  |
|match_virtual_on_net_call_type  |OCI.matchVirtualOnNetCallType    |matchVirtualOnNetCallType *Optional*    |
|match_public_network            |bool                             |matchPublicNetwork *Optional*           |
|match_private_network           |bool                             |matchPrivateNetwork *Optional*          |
|match_local_category            |bool                             |matchLocalCategory *Optional*           |
|match_national_category         |bool                             |matchNationalCategory *Optional*        |
|match_interlata_category        |bool                             |matchInterlataCategory *Optional*       |
|match_intralata_category        |bool                             |matchIntralataCategory *Optional*       |
|match_international_category    |bool                             |matchInternationalCategory *Optional*   |
|match_private_category          |bool                             |matchPrivateCategory *Optional*         |
|match_emergency_category        |bool                             |matchEmergencyCategory *Optional*       |
|match_other_category            |bool                             |matchOtherCategory *Optional*           |
|match_inter_network             |bool                             |matchInterNetwork *Optional*            |
|match_inter_hosting_ne          |bool                             |matchInterHostingNE *Optional*          |
|match_inter_as                  |bool                             |matchInterAS *Optional*                 |
|match_intra_as                  |bool                             |matchIntraAS *Optional*                 |
|match_charge_calls              |bool                             |matchChargeCalls *Optional*             |
|match_no_charge_calls           |bool                             |matchNoChargeCalls *Optional*           |
|match_group_calls               |bool                             |matchGroupCalls *Optional*              |
|match_enterprise_calls          |bool                             |matchEnterpriseCalls *Optional*         |
|match_network_calls             |bool                             |matchNetworkCalls *Optional*            |
|match_network_url_calls         |bool                             |matchNetworkURLCalls *Optional*         |
|match_repair_calls              |bool                             |matchRepairCalls *Optional*             |
|match_emergency_calls           |bool                             |matchEmergencyCalls *Optional*          |
|match_internal_calls            |bool                             |matchInternalCalls *Optional*           |
|match_other_gets_gets           |bool                             |matchOtherGETSGets *Optional*           |
|match_not_gets_gets             |bool                             |matchNotGETSGets *Optional*             |
|match_getsan_gets               |bool                             |matchGETSANGets *Optional*              |
|match_getsnt_gets               |bool                             |matchGETSNTGets *Optional*              |
|match_getsfc_gets               |bool                             |matchGETSFCGets *Optional*              |
|match_getsfcan_gets             |bool                             |matchGETSFCANGets *Optional*            |
|match_getsfcnt_gets             |bool                             |matchGETSFCNTGets *Optional*            |
|match_location                  |str                              |matchLocation *Optional*                |
|match_roaming                   |str                              |matchRoaming *Optional*                 |
|time_schedule                   |str                              |timeSchedule *Optional*                 |
|holiday_schedule                |str                              |holidaySchedule *Optional*              |
|match_number_portability_status |OCI.matchNumberPortabilityStatus |matchNumberPortabilityStatus *Optional* |
</div>


## `SystemCommunicationBarringIncomingCriteriaModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an existing Communication Barring Incoming Criteria.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                            |Type                             |Description                             |
|--------------------------------|---------------------------------|----------------------------------------|
|name                            |str                              |name                                    |
|new_name                        |str                              |newName *Optional*                      |
|description                     |str                              |description *Optional*                  |
|time_schedule                   |str                              |timeSchedule *Optional*                 |
|holiday_schedule                |str                              |holidaySchedule *Optional*              |
|match_number_portability_status |OCI.matchNumberPortabilityStatus |matchNumberPortabilityStatus *Optional* |
|call_tagged_as_spam             |bool                             |callTaggedAsSpam *Optional*             |
</div>


## `SystemCommunicationBarringProfileAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a new Communication Barring Profile.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                |Type                      |Description                                 |
|------------------------------------|--------------------------|--------------------------------------------|
|name                                |str                       |name                                        |
|description                         |str                       |description *Optional*                      |
|originating_default_action          |str                       |originatingDefaultAction                    |
|originating_default_treatment_id    |str                       |originatingDefaultTreatmentId *Optional*    |
|originating_default_transfer_number |str                       |originatingDefaultTransferNumber *Optional* |
|originating_default_call_timeout    |int                       |originatingDefaultCallTimeout *Optional*    |
|originating_rule                    |List[OCI.originatingRule] |originatingRule *Optional*                  |
|redirecting_default_action          |str                       |redirectingDefaultAction                    |
|redirecting_default_call_timeout    |int                       |redirectingDefaultCallTimeout *Optional*    |
|redirecting_rule                    |List[OCI.redirectingRule] |redirectingRule *Optional*                  |
</div>


## `SystemCommunicationBarringProfileAddRequest17sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a new Communication Barring Profile.

The priorities for IncomingRules are requantized to consecutive integers as part of
the add.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in XS data mode: incomingDefaultAction
incomingDefaultCallTimeout incomingRule

**Attributes:**

|Name                                |Type                      |Description                                 |
|------------------------------------|--------------------------|--------------------------------------------|
|name                                |str                       |name                                        |
|description                         |str                       |description *Optional*                      |
|originating_default_action          |str                       |originatingDefaultAction                    |
|originating_default_treatment_id    |str                       |originatingDefaultTreatmentId *Optional*    |
|originating_default_transfer_number |str                       |originatingDefaultTransferNumber *Optional* |
|originating_default_call_timeout    |int                       |originatingDefaultCallTimeout *Optional*    |
|originating_rule                    |List[OCI.originatingRule] |originatingRule *Optional*                  |
|redirecting_default_action          |str                       |redirectingDefaultAction                    |
|redirecting_default_call_timeout    |int                       |redirectingDefaultCallTimeout *Optional*    |
|redirecting_rule                    |List[OCI.redirectingRule] |redirectingRule *Optional*                  |
|incoming_default_action             |str                       |incomingDefaultAction                       |
|incoming_default_call_timeout       |int                       |incomingDefaultCallTimeout *Optional*       |
|incoming_rule                       |List[OCI.incomingRule]    |incomingRule *Optional*                     |
</div>


## `SystemCommunicationBarringProfileAddRequest17sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a new Communication Barring Profile.

The priorities for IncomingRules are requantized to consecutive integers as part of
the add.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode: callMeNowDefaultAction, use value "Block" in
XS data mode The following elements are only used in AS data mode and ignored in XS
data mode: callMeNowDefaultCallTimeout callMeNowRule Replaced by:
`SystemCommunicationBarringProfileAddRequest19sp1()` in AS data mode

**Attributes:**

|Name                                |Type                      |Description                                 |
|------------------------------------|--------------------------|--------------------------------------------|
|name                                |str                       |name                                        |
|description                         |str                       |description *Optional*                      |
|originating_default_action          |str                       |originatingDefaultAction                    |
|originating_default_treatment_id    |str                       |originatingDefaultTreatmentId *Optional*    |
|originating_default_transfer_number |str                       |originatingDefaultTransferNumber *Optional* |
|originating_default_call_timeout    |int                       |originatingDefaultCallTimeout *Optional*    |
|originating_rule                    |List[OCI.originatingRule] |originatingRule *Optional*                  |
|redirecting_default_action          |str                       |redirectingDefaultAction                    |
|redirecting_default_call_timeout    |int                       |redirectingDefaultCallTimeout *Optional*    |
|redirecting_rule                    |List[OCI.redirectingRule] |redirectingRule *Optional*                  |
|incoming_default_action             |str                       |incomingDefaultAction                       |
|incoming_default_call_timeout       |int                       |incomingDefaultCallTimeout *Optional*       |
|incoming_rule                       |List[OCI.incomingRule]    |incomingRule *Optional*                     |
|call_me_now_default_action          |str                       |callMeNowDefaultAction                      |
|call_me_now_default_call_timeout    |int                       |callMeNowDefaultCallTimeout *Optional*      |
|call_me_now_rule                    |List[OCI.callMeNowRule]   |callMeNowRule *Optional*                    |
</div>


## `SystemCommunicationBarringProfileAddRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a new Communication Barring Profile.

The priorities for IncomingRules are requantized to consecutive integers as part of
the add.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode: callMeNowDefaultAction, use value "Block" in
XS data mode callMeNowDefaultCallTimeout callMeNowRule applyToAttendedCallTransfers,
use value "false" in XS data mode

**Attributes:**

|Name                                |Type                      |Description                                 |
|------------------------------------|--------------------------|--------------------------------------------|
|name                                |str                       |name                                        |
|description                         |str                       |description *Optional*                      |
|originating_default_action          |str                       |originatingDefaultAction                    |
|originating_default_treatment_id    |str                       |originatingDefaultTreatmentId *Optional*    |
|originating_default_transfer_number |str                       |originatingDefaultTransferNumber *Optional* |
|originating_default_call_timeout    |int                       |originatingDefaultCallTimeout *Optional*    |
|originating_rule                    |List[OCI.originatingRule] |originatingRule *Optional*                  |
|redirecting_default_action          |str                       |redirectingDefaultAction                    |
|redirecting_default_call_timeout    |int                       |redirectingDefaultCallTimeout *Optional*    |
|redirecting_rule                    |List[OCI.redirectingRule] |redirectingRule *Optional*                  |
|incoming_default_action             |str                       |incomingDefaultAction                       |
|incoming_default_call_timeout       |int                       |incomingDefaultCallTimeout *Optional*       |
|incoming_rule                       |List[OCI.incomingRule]    |incomingRule *Optional*                     |
|call_me_now_default_action          |str                       |callMeNowDefaultAction                      |
|call_me_now_default_call_timeout    |int                       |callMeNowDefaultCallTimeout *Optional*      |
|call_me_now_rule                    |List[OCI.callMeNowRule]   |callMeNowRule *Optional*                    |
|apply_to_attended_call_transfers    |bool                      |applyToAttendedCallTransfers                |
</div>


## `SystemDeviceFamilyModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a device family.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type               |Description                    |
|-----------------------|-------------------|-------------------------------|
|device_family_name     |str                |deviceFamilyName               |
|new_device_family_name |str                |newDeviceFamilyName *Optional* |
|device_type_list       |OCI.deviceTypeList |deviceTypeList *Optional*      |
|tag_set_list           |OCI.tagSetList     |tagSetList *Optional*          |
</div>


## `SystemDeviceManagementAutoRebuildConfigModifyListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to enable or disable automatic trigger of DM events for OCI request prefixes,
regardless of the request's version.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                      |Type                             |Description            |
|--------------------------|---------------------------------|-----------------------|
|auto_rebuild_config_entry |List[OCI.autoRebuildConfigEntry] |autoRebuildConfigEntry |
</div>


## `SystemDeviceManagementTagSetImportDryRunRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to perform a dry run for the import of a Tag Set Archive File (TSAF) as a new
Tag Set.

The URL supports the HTTP and the FILE protocols.  When the optional element
resellerId is specified, the device type created is at reseller level.  When the
optional element tagSetOverride is set to true, an existing tag set on the destination
system will be overridden.  When the optional element tagSetRename is set, on import
the tag set name part of the TSAF will be changed to the desired name on the
destination system.

The response is either a `SystemDeviceManagementTagSetImportDryRunResponse()` or an
`ErrorResponse()`. The following data elements are only used in AS data mode and
ignored in XS data mode: resellerId

**Attributes:**

|Name             |Type             |Description               |
|-----------------|-----------------|--------------------------|
|file             |str              |file                      |
|reseller_id      |str              |resellerId *Optional*     |
|tag_set_override |bool             |tagSetOverride *Optional* |
|tag_set_rename   |OCI.tagSetRename |tagSetRename *Optional*   |
</div>


## `SystemDeviceManagementTagSetImportRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to import a Tag Set Archive File (TSAF) as a new Tag Set.

The URL supports the HTTP and the FILE protocols.  When the optional element
resellerId is specified, the device type created is at reseller level.  When the
optional element tagSetOverride is set to true, an existing tag set on the destination
system will be overridden.  When the optional element tagSetRename is set, on import
the tag set name part of the TSAF will be changed to the desired name on the
destination system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
data elements are only used in AS data mode and ignored in XS data mode: resellerId

**Attributes:**

|Name             |Type             |Description               |
|-----------------|-----------------|--------------------------|
|file             |str              |file                      |
|reseller_id      |str              |resellerId *Optional*     |
|tag_set_override |bool             |tagSetOverride *Optional* |
|tag_set_rename   |OCI.tagSetRename |tagSetRename *Optional*   |
</div>


## `SystemDeviceManagementTagSetRegionTagAddListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a tag override to a region of a static configuration tag set.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type          |Description|
|-------------|--------------|-----------|
|tag_set_name |str           |tagSetName |
|region_name  |str           |regionName |
|tag          |List[OCI.tag] |tag        |
</div>


## `SystemDeviceProfileAuthenticationLockoutClearRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to clear device profile authentication lockouts in the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name          |Type                   |Description  |
|--------------|-----------------------|-------------|
|access_device |List[OCI.accessDevice] |accessDevice |
</div>


## `SystemDeviceTypeImportDryRunRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to perform a dry run for the import of a Device Type Archive File (DTAF) as a
new Device Type.

The URL supports the HTTP and the FILE protocols.  When the optional element
resellerId is specified, the device type created is at reseller level.  When the
optional element deviceTypeRename is set, on import, the device type name part of the
DTAF will be changed to the desired name on the destination system.  When the optional
element deviceTypeFileUpdate is set, on import, the files that are matched based on
the file format are updated with the ones from the DTAF. The file format and the file
category are the only attributes that can't be updated.

The response is either a `SystemDeviceTypeImportDryRunResponse()` or an
`ErrorResponse()`. The following data elements are only used in AS data mode and
ignored in XS data mode: deviceTypeFileUpdate deviceTypeRename resellerId

**Attributes:**

|Name                    |Type                 |Description                     |
|------------------------|---------------------|--------------------------------|
|file                    |str                  |file                            |
|reseller_id             |str                  |resellerId *Optional*           |
|device_type_rename      |OCI.deviceTypeRename |deviceTypeRename *Optional*     |
|device_type_file_update |bool                 |deviceTypeFileUpdate *Optional* |
</div>


## `SystemDeviceTypeImportRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to import a Device Type Archive File (DTAF) as a new Device Type.

The URL supports the HTTP and the FILE protocols.  When the optional element
resellerId is specified, the device type created is at reseller level.  When the
optional element deviceTypeRename is set, on import, the device type name part of the
DTAF will be changed to the desired name on the destination system.  When the optional
element deviceTypeFileUpdate is set, on import, the files that are matched based on
the file format are updated with the ones from the DTAF. The file format and the file
category are the only attributes that can't be updated.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
data elements are only used in AS data mode and ignored in XS data mode:
deviceTypeFileUpdate deviceTypeRename resellerId

**Attributes:**

|Name                    |Type                 |Description                     |
|------------------------|---------------------|--------------------------------|
|file                    |str                  |file                            |
|reseller_id             |str                  |resellerId *Optional*           |
|device_type_rename      |OCI.deviceTypeRename |deviceTypeRename *Optional*     |
|device_type_file_update |bool                 |deviceTypeFileUpdate *Optional* |
</div>


## `SystemDialableCallerIDCriteriaModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a Dialable Caller ID Criteria.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                           |Type                            |Description                            |
|-------------------------------|--------------------------------|---------------------------------------|
|name                           |str                             |name                                   |
|new_name                       |str                             |newName *Optional*                     |
|description                    |str                             |description *Optional*                 |
|prefix_digits                  |str                             |prefixDigits *Optional*                |
|match_call_type                |OCI.matchCallType               |matchCallType *Optional*               |
|match_alternate_call_indicator |OCI.matchAlternateCallIndicator |matchAlternateCallIndicator *Optional* |
|match_local_category           |bool                            |matchLocalCategory *Optional*          |
|match_national_category        |bool                            |matchNationalCategory *Optional*       |
|match_interlata_category       |bool                            |matchInterlataCategory *Optional*      |
|match_intralata_category       |bool                            |matchIntralataCategory *Optional*      |
|match_international_category   |bool                            |matchInternationalCategory *Optional*  |
|match_private_category         |bool                            |matchPrivateCategory *Optional*        |
|match_emergency_category       |bool                            |matchEmergencyCategory *Optional*      |
|match_other_category           |bool                            |matchOtherCategory *Optional*          |
</div>


## `SystemDialableCallerIDModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level Dialable Caller ID criteria list.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                    |Type                            |Description                      |
|------------------------|--------------------------------|---------------------------------|
|criteria_priority_order |List[OCI.criteriaPriorityOrder] |criteriaPriorityOrder *Optional* |
</div>


## `SystemFeatureAccessCodeModifyListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify default Feature Access Codes.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`SystemFeatureAccessCodeModifyListRequest21()` in AS data mode

**Attributes:**

|Name                |Type                        |Description                  |
|--------------------|----------------------------|-----------------------------|
|feature_access_code |List[OCI.featureAccessCode] |featureAccessCode *Optional* |
</div>


## `SystemFeatureAccessCodeModifyListRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify default Feature Access Codes.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. In release 20
the "Call Recording" FAC name is changed to "Call Recording - Start". Replaced by:
`SystemFeatureAccessCodeModifyListRequest21()`

**Attributes:**

|Name                |Type                        |Description                  |
|--------------------|----------------------------|-----------------------------|
|feature_access_code |List[OCI.featureAccessCode] |featureAccessCode *Optional* |
</div>


## `SystemFeatureAccessCodeModifyListRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify default Feature Access Codes.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. In release 20
the "Call Recording" FAC name is changed to "Call Recording - Start".

**Attributes:**

|Name                |Type                        |Description                  |
|--------------------|----------------------------|-----------------------------|
|feature_access_code |List[OCI.featureAccessCode] |featureAccessCode *Optional* |
</div>


## `SystemFileRepositoryDeviceAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a new file repository.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by:
`SystemFileRepositoryDeviceAddRequest16()`

**Attributes:**

|Name             |Type               |Description               |
|-----------------|-------------------|--------------------------|
|name             |str                |name                      |
|root_directory   |str                |rootDirectory *Optional*  |
|port             |int                |port *Optional*           |
|protocol_web_dav |OCI.protocolWebDAV |protocolWebDAV *Optional* |
|protocol_ftp     |OCI.protocolFTP    |protocolFTP *Optional*    |
</div>


## `SystemFileRepositoryDeviceAddRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a new file repository.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by:
`SystemFileRepositoryDeviceAddRequest20()`

**Attributes:**

|Name             |Type               |Description               |
|-----------------|-------------------|--------------------------|
|name             |str                |name                      |
|root_directory   |str                |rootDirectory *Optional*  |
|port             |int                |port *Optional*           |
|protocol_web_dav |OCI.protocolWebDAV |protocolWebDAV *Optional* |
|protocol_ftp     |OCI.protocolFTP    |protocolFTP *Optional*    |
</div>


## `SystemFileRepositoryDeviceAddRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a new file repository.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name             |Type               |Description               |
|-----------------|-------------------|--------------------------|
|name             |str                |name                      |
|root_directory   |str                |rootDirectory *Optional*  |
|port             |int                |port *Optional*           |
|protocol_web_dav |OCI.protocolWebDAV |protocolWebDAV *Optional* |
|protocol_ftp     |OCI.protocolFTP    |protocolFTP *Optional*    |
|protocol_sftp    |OCI.protocolSFTP   |protocolSFTP *Optional*   |
|protocol_ftps    |OCI.protocolFTPS   |protocolFTPS *Optional*   |
</div>


## `SystemHolidayScheduleAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a system holiday schedule.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                  |Type          |Description          |
|----------------------|--------------|---------------------|
|holiday_schedule_name |str           |holidayScheduleName  |
|holiday01             |OCI.holiday01 |holiday01 *Optional* |
|holiday02             |OCI.holiday02 |holiday02 *Optional* |
|holiday03             |OCI.holiday03 |holiday03 *Optional* |
|holiday04             |OCI.holiday04 |holiday04 *Optional* |
|holiday05             |OCI.holiday05 |holiday05 *Optional* |
|holiday06             |OCI.holiday06 |holiday06 *Optional* |
|holiday07             |OCI.holiday07 |holiday07 *Optional* |
|holiday08             |OCI.holiday08 |holiday08 *Optional* |
|holiday09             |OCI.holiday09 |holiday09 *Optional* |
|holiday10             |OCI.holiday10 |holiday10 *Optional* |
|holiday11             |OCI.holiday11 |holiday11 *Optional* |
|holiday12             |OCI.holiday12 |holiday12 *Optional* |
|holiday13             |OCI.holiday13 |holiday13 *Optional* |
|holiday14             |OCI.holiday14 |holiday14 *Optional* |
|holiday15             |OCI.holiday15 |holiday15 *Optional* |
|holiday16             |OCI.holiday16 |holiday16 *Optional* |
|holiday17             |OCI.holiday17 |holiday17 *Optional* |
|holiday18             |OCI.holiday18 |holiday18 *Optional* |
|holiday19             |OCI.holiday19 |holiday19 *Optional* |
|holiday20             |OCI.holiday20 |holiday20 *Optional* |
</div>


## `SystemHolidayScheduleModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a system holiday schedule.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                      |Type          |Description                       |
|--------------------------|--------------|----------------------------------|
|holiday_schedule_name     |str           |holidayScheduleName               |
|new_holiday_schedule_name |str           |newHolidayScheduleName *Optional* |
|holiday01                 |OCI.holiday01 |holiday01 *Optional*              |
|holiday02                 |OCI.holiday02 |holiday02 *Optional*              |
|holiday03                 |OCI.holiday03 |holiday03 *Optional*              |
|holiday04                 |OCI.holiday04 |holiday04 *Optional*              |
|holiday05                 |OCI.holiday05 |holiday05 *Optional*              |
|holiday06                 |OCI.holiday06 |holiday06 *Optional*              |
|holiday07                 |OCI.holiday07 |holiday07 *Optional*              |
|holiday08                 |OCI.holiday08 |holiday08 *Optional*              |
|holiday09                 |OCI.holiday09 |holiday09 *Optional*              |
|holiday10                 |OCI.holiday10 |holiday10 *Optional*              |
|holiday11                 |OCI.holiday11 |holiday11 *Optional*              |
|holiday12                 |OCI.holiday12 |holiday12 *Optional*              |
|holiday13                 |OCI.holiday13 |holiday13 *Optional*              |
|holiday14                 |OCI.holiday14 |holiday14 *Optional*              |
|holiday15                 |OCI.holiday15 |holiday15 *Optional*              |
|holiday16                 |OCI.holiday16 |holiday16 *Optional*              |
|holiday17                 |OCI.holiday17 |holiday17 *Optional*              |
|holiday18                 |OCI.holiday18 |holiday18 *Optional*              |
|holiday19                 |OCI.holiday19 |holiday19 *Optional*              |
|holiday20                 |OCI.holiday20 |holiday20 *Optional*              |
</div>


## `SystemInterceptUserAddDnListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add an Intercept User number(s) to the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name              |Type                      |Description     |
|------------------|--------------------------|----------------|
|intercept_dn_list |List[OCI.interceptDNList] |interceptDNList |
</div>


## `SystemMediaSetModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a Media Set.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name            |Type              |Description              |
|----------------|------------------|-------------------------|
|set_name        |str               |setName                  |
|media_name_list |OCI.mediaNameList |mediaNameList *Optional* |
</div>


## `SystemMeetMeConferencingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system level data associated with Meet-Me Conferencing.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                              |Type                             |Description                                             |
|--------------------------------------------------|---------------------------------|--------------------------------------------------------|
|conference_id_length                              |int                              |conferenceIdLength *Optional*                           |
|moderator_pin_length                              |int                              |moderatorPinLength *Optional*                           |
|enable_conference_end_date_restriction            |bool                             |enableConferenceEndDateRestriction *Optional*           |
|conference_end_date_restriction_months            |int                              |conferenceEndDateRestrictionMonths *Optional*           |
|delete_expired_conferences_after_hold_period      |bool                             |deleteExpiredConferencesAfterHoldPeriod *Optional*      |
|expired_conference_hold_period_days               |int                              |expiredConferenceHoldPeriodDays *Optional*              |
|recording_web_app_url                             |str                              |recordingWebAppURL *Optional*                           |
|recording_file_format                             |str                              |recordingFileFormat *Optional*                          |
|terminate_after_grace_period                      |bool                             |terminateAfterGracePeriod *Optional*                    |
|conference_grace_period_minutes                   |OCI.conferenceGracePeriodMinutes |conferenceGracePeriodMinutes *Optional*                 |
|conference_participant_early_entry_minutes        |int                              |conferenceParticipantEarlyEntryMinutes *Optional*       |
|enable_conference_expiry_notification             |bool                             |enableConferenceExpiryNotification *Optional*           |
|enable_active_conference_notification             |bool                             |enableActiveConferenceNotification *Optional*           |
|conference_from_address                           |str                              |conferenceFromAddress *Optional*                        |
|conference_active_talker_refresh_interval_seconds |int                              |conferenceActiveTalkerRefreshIntervalSeconds *Optional* |
</div>


## `SystemNetworkClassOfServiceAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a new Network Class of Service.

The following elements are only used in AS data mode: callProcessingPolicyProfileName

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                |Type                             |Description                                |
|------------------------------------|---------------------------------|-------------------------------------------|
|name                                |str                              |name                                       |
|description                         |str                              |description *Optional*                     |
|communication_barring_profile0      |OCI.communicationBarringProfile0 |communicationBarringProfile0 *Optional*    |
|communication_barring_profile1      |OCI.communicationBarringProfile1 |communicationBarringProfile1 *Optional*    |
|communication_barring_profile2      |OCI.communicationBarringProfile2 |communicationBarringProfile2 *Optional*    |
|communication_barring_profile3      |OCI.communicationBarringProfile3 |communicationBarringProfile3 *Optional*    |
|communication_barring_profile4      |OCI.communicationBarringProfile4 |communicationBarringProfile4 *Optional*    |
|communication_barring_profile5      |OCI.communicationBarringProfile5 |communicationBarringProfile5 *Optional*    |
|communication_barring_profile6      |OCI.communicationBarringProfile6 |communicationBarringProfile6 *Optional*    |
|communication_barring_profile7      |OCI.communicationBarringProfile7 |communicationBarringProfile7 *Optional*    |
|communication_barring_profile8      |OCI.communicationBarringProfile8 |communicationBarringProfile8 *Optional*    |
|communication_barring_profile9      |OCI.communicationBarringProfile9 |communicationBarringProfile9 *Optional*    |
|network_translation_index           |str                              |networkTranslationIndex *Optional*         |
|call_processing_policy_profile_name |str                              |callProcessingPolicyProfileName *Optional* |
</div>


## `SystemNetworkClassOfServiceModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an existing Network Class of Service.

The following elements are only used in AS data mode: callProcessingPolicyProfileName

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                |Type                             |Description                                |
|------------------------------------|---------------------------------|-------------------------------------------|
|name                                |str                              |name                                       |
|new_name                            |str                              |newName *Optional*                         |
|description                         |str                              |description *Optional*                     |
|communication_barring_profile0      |OCI.communicationBarringProfile0 |communicationBarringProfile0 *Optional*    |
|communication_barring_profile1      |OCI.communicationBarringProfile1 |communicationBarringProfile1 *Optional*    |
|communication_barring_profile2      |OCI.communicationBarringProfile2 |communicationBarringProfile2 *Optional*    |
|communication_barring_profile3      |OCI.communicationBarringProfile3 |communicationBarringProfile3 *Optional*    |
|communication_barring_profile4      |OCI.communicationBarringProfile4 |communicationBarringProfile4 *Optional*    |
|communication_barring_profile5      |OCI.communicationBarringProfile5 |communicationBarringProfile5 *Optional*    |
|communication_barring_profile6      |OCI.communicationBarringProfile6 |communicationBarringProfile6 *Optional*    |
|communication_barring_profile7      |OCI.communicationBarringProfile7 |communicationBarringProfile7 *Optional*    |
|communication_barring_profile8      |OCI.communicationBarringProfile8 |communicationBarringProfile8 *Optional*    |
|communication_barring_profile9      |OCI.communicationBarringProfile9 |communicationBarringProfile9 *Optional*    |
|network_translation_index           |str                              |networkTranslationIndex *Optional*         |
|call_processing_policy_profile_name |str                              |callProcessingPolicyProfileName *Optional* |
</div>


## `SystemOfficeZoneModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an existing Office Zone.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                  |Type                    |Description                    |
|----------------------|------------------------|-------------------------------|
|office_zone_name      |str                     |officeZoneName                 |
|new_office_zone_name  |str                     |newOfficeZoneName *Optional*   |
|description           |str                     |description *Optional*         |
|replacement_zone_list |OCI.replacementZoneList |replacementZoneList *Optional* |
|primary_zone_name     |str                     |primaryZoneName *Optional*     |
</div>


## `SystemSIPAuthenticationEndpointLockoutClearRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to clear sip authentication endpoint lockouts in the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name              |Type                      |Description     |
|------------------|--------------------------|----------------|
|user_endpoint_key |List[OCI.userEndpointKey] |userEndpointKey |
</div>


## `SystemSIPAuthenticationTrunkGroupLockoutClearRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to clear sip authentication trunk group lockouts in the system.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name           |Type                    |Description   |
|---------------|------------------------|--------------|
|trunk_groupkey |List[OCI.trunkGroupkey] |trunkGroupkey |
</div>


## `SystemSIPDeviceTypeAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                          |Type                 |Description                  |
|------------------------------|---------------------|-----------------------------|
|device_type                   |str                  |deviceType                   |
|number_of_ports               |OCI.numberOfPorts    |numberOfPorts                |
|profile                       |str                  |profile                      |
|registration_capable          |bool                 |registrationCapable          |
|is_conference_device          |bool                 |isConferenceDevice           |
|is_music_on_hold_device       |bool                 |isMusicOnHoldDevice          |
|authentication_override       |bool                 |authenticationOverride       |
|rfc3264_hold                  |bool                 |RFC3264Hold                  |
|is_trusted                    |bool                 |isTrusted                    |
|e164_capable                  |bool                 |E164Capable                  |
|route_advance                 |bool                 |routeAdvance                 |
|forwarding_override           |bool                 |forwardingOverride           |
|wireless_integration          |bool                 |wirelessIntegration          |
|web_based_config_url          |str                  |webBasedConfigURL *Optional* |
|is_video_capable              |bool                 |isVideoCapable               |
|pbx_integration               |bool                 |PBXIntegration               |
|use_business_trunking_contact |bool                 |useBusinessTrunkingContact   |
|static_registration_capable   |bool                 |staticRegistrationCapable    |
|cpe_device_options            |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*  |
</div>


## `SystemSIPDeviceTypeAddRequest14sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`.

Replaced By: `SystemSIPDeviceTypeAddRequest14sp2()`

**Attributes:**

|Name                          |Type                 |Description                  |
|------------------------------|---------------------|-----------------------------|
|device_type                   |str                  |deviceType                   |
|number_of_ports               |OCI.numberOfPorts    |numberOfPorts                |
|profile                       |str                  |profile                      |
|registration_capable          |bool                 |registrationCapable          |
|is_conference_device          |bool                 |isConferenceDevice           |
|is_music_on_hold_device       |bool                 |isMusicOnHoldDevice          |
|authentication_override       |bool                 |authenticationOverride       |
|rfc3264_hold                  |bool                 |RFC3264Hold                  |
|is_trusted                    |bool                 |isTrusted                    |
|e164_capable                  |bool                 |E164Capable                  |
|route_advance                 |bool                 |routeAdvance                 |
|forwarding_override           |bool                 |forwardingOverride           |
|wireless_integration          |bool                 |wirelessIntegration          |
|web_based_config_url          |str                  |webBasedConfigURL *Optional* |
|is_video_capable              |bool                 |isVideoCapable               |
|pbx_integration               |bool                 |PBXIntegration               |
|use_business_trunking_contact |bool                 |useBusinessTrunkingContact   |
|static_registration_capable   |bool                 |staticRegistrationCapable    |
|cpe_device_options            |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*  |
|early_media_support           |str                  |earlyMediaSupport            |
</div>


## `SystemSIPDeviceTypeAddRequest14sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`.

Replaced By: `SystemSIPDeviceTypeAddRequest14sp3()`

**Attributes:**

|Name                          |Type                 |Description                  |
|------------------------------|---------------------|-----------------------------|
|device_type                   |str                  |deviceType                   |
|number_of_ports               |OCI.numberOfPorts    |numberOfPorts                |
|profile                       |str                  |profile                      |
|registration_capable          |bool                 |registrationCapable          |
|is_conference_device          |bool                 |isConferenceDevice           |
|is_music_on_hold_device       |bool                 |isMusicOnHoldDevice          |
|rfc3264_hold                  |bool                 |RFC3264Hold                  |
|is_trusted                    |bool                 |isTrusted                    |
|e164_capable                  |bool                 |E164Capable                  |
|route_advance                 |bool                 |routeAdvance                 |
|forwarding_override           |bool                 |forwardingOverride           |
|wireless_integration          |bool                 |wirelessIntegration          |
|web_based_config_url          |str                  |webBasedConfigURL *Optional* |
|is_video_capable              |bool                 |isVideoCapable               |
|pbx_integration               |bool                 |PBXIntegration               |
|use_business_trunking_contact |bool                 |useBusinessTrunkingContact   |
|static_registration_capable   |bool                 |staticRegistrationCapable    |
|cpe_device_options            |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*  |
|early_media_support           |str                  |earlyMediaSupport            |
|authenticate_refer            |bool                 |authenticateRefer            |
|auto_config_soft_client       |bool                 |autoConfigSoftClient         |
|authentication_mode           |str                  |authenticationMode           |
</div>


## `SystemSIPDeviceTypeAddRequest14sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by:
`SystemSIPDeviceTypeAddRequest14sp6()`

**Attributes:**

|Name                                       |Type                 |Description                          |
|-------------------------------------------|---------------------|-------------------------------------|
|device_type                                |str                  |deviceType                           |
|number_of_ports                            |OCI.numberOfPorts    |numberOfPorts                        |
|profile                                    |str                  |profile                              |
|registration_capable                       |bool                 |registrationCapable                  |
|is_conference_device                       |bool                 |isConferenceDevice                   |
|is_mobility_manager_device                 |bool                 |isMobilityManagerDevice              |
|is_music_on_hold_device                    |bool                 |isMusicOnHoldDevice                  |
|rfc3264_hold                               |bool                 |RFC3264Hold                          |
|is_trusted                                 |bool                 |isTrusted                            |
|e164_capable                               |bool                 |E164Capable                          |
|route_advance                              |bool                 |routeAdvance                         |
|forwarding_override                        |bool                 |forwardingOverride                   |
|wireless_integration                       |bool                 |wirelessIntegration                  |
|web_based_config_url                       |str                  |webBasedConfigURL *Optional*         |
|is_video_capable                           |bool                 |isVideoCapable                       |
|pbx_integration                            |bool                 |PBXIntegration                       |
|use_business_trunking_contact              |bool                 |useBusinessTrunkingContact           |
|static_registration_capable                |bool                 |staticRegistrationCapable            |
|cpe_device_options                         |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*          |
|early_media_support                        |str                  |earlyMediaSupport                    |
|authenticate_refer                         |bool                 |authenticateRefer                    |
|auto_config_soft_client                    |bool                 |autoConfigSoftClient                 |
|authentication_mode                        |str                  |authenticationMode                   |
|tdm_overlay                                |bool                 |tdmOverlay                           |
|supports_broad_works_info_for_call_waiting |bool                 |supportsBroadWorksINFOForCallWaiting |
</div>


## `SystemSIPDeviceTypeFileAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type file.

The response is either `SuccessResponse()` or `ErrorResponse()`.

Replaced By: `SystemSIPDeviceTypeFileAddRequest14sp8()`

**Attributes:**

|Name                                   |Type           |Description                         |
|---------------------------------------|---------------|------------------------------------|
|device_type                            |str            |deviceType                          |
|file_type                              |str            |fileType                            |
|file_format                            |str            |fileFormat                          |
|remote_file_format                     |str            |remoteFileFormat                    |
|file_category                          |str            |fileCategory                        |
|allow_file_customization               |bool           |allowFileCustomization              |
|file_source                            |str            |fileSource                          |
|upload_file                            |OCI.uploadFile |uploadFile *Optional*               |
|use_http_digest_authentication         |bool           |useHttpDigestAuthentication         |
|mac_based_file_authentication          |bool           |macBasedFileAuthentication          |
|user_name_password_file_authentication |bool           |userNamePasswordFileAuthentication  |
|mac_in_non_request_uri                 |bool           |macInNonRequestURI                  |
|mac_format_in_non_request_uri          |str            |macFormatInNonRequestURI *Optional* |
</div>


## `SystemSIPDeviceTypeFileAddRequest14sp8`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type file.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                   |Type           |Description                         |
|---------------------------------------|---------------|------------------------------------|
|device_type                            |str            |deviceType                          |
|file_format                            |str            |fileFormat                          |
|remote_file_format                     |str            |remoteFileFormat                    |
|file_category                          |str            |fileCategory                        |
|allow_file_customization               |bool           |allowFileCustomization              |
|file_source                            |str            |fileSource                          |
|upload_file                            |OCI.uploadFile |uploadFile *Optional*               |
|use_http_digest_authentication         |bool           |useHttpDigestAuthentication         |
|mac_based_file_authentication          |bool           |macBasedFileAuthentication          |
|user_name_password_file_authentication |bool           |userNamePasswordFileAuthentication  |
|mac_in_non_request_uri                 |bool           |macInNonRequestURI                  |
|mac_format_in_non_request_uri          |str            |macFormatInNonRequestURI *Optional* |
</div>


## `SystemSIPDeviceTypeFileAddRequest16sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Replaced By `SystemSIPDeviceTypeFileAddRequest18()`.

Request to add a sip device type file.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                   |Type           |Description                         |
|---------------------------------------|---------------|------------------------------------|
|device_type                            |str            |deviceType                          |
|file_format                            |str            |fileFormat                          |
|remote_file_format                     |str            |remoteFileFormat                    |
|file_category                          |str            |fileCategory                        |
|file_customization                     |str            |fileCustomization                   |
|file_source                            |str            |fileSource                          |
|upload_file                            |OCI.uploadFile |uploadFile *Optional*               |
|use_http_digest_authentication         |bool           |useHttpDigestAuthentication         |
|mac_based_file_authentication          |bool           |macBasedFileAuthentication          |
|user_name_password_file_authentication |bool           |userNamePasswordFileAuthentication  |
|mac_in_non_request_uri                 |bool           |macInNonRequestURI                  |
|mac_format_in_non_request_uri          |str            |macFormatInNonRequestURI *Optional* |
</div>


## `SystemSIPDeviceTypeFileAddRequest18`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type file.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                   |Type           |Description                         |
|---------------------------------------|---------------|------------------------------------|
|device_type                            |str            |deviceType                          |
|file_format                            |str            |fileFormat                          |
|remote_file_format                     |str            |remoteFileFormat                    |
|file_category                          |str            |fileCategory                        |
|file_customization                     |str            |fileCustomization                   |
|file_source                            |str            |fileSource                          |
|upload_file                            |OCI.uploadFile |uploadFile *Optional*               |
|use_http_digest_authentication         |bool           |useHttpDigestAuthentication         |
|mac_based_file_authentication          |bool           |macBasedFileAuthentication          |
|user_name_password_file_authentication |bool           |userNamePasswordFileAuthentication  |
|mac_in_non_request_uri                 |bool           |macInNonRequestURI                  |
|mac_format_in_non_request_uri          |str            |macFormatInNonRequestURI *Optional* |
|allow_http                             |bool           |allowHttp                           |
|allow_https                            |bool           |allowHttps                          |
|allow_tftp                             |bool           |allowTftp                           |
|enable_caching                         |bool           |enableCaching                       |
</div>


## `SystemSIPDeviceTypeFileAddRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type file.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by:
`SystemSIPDeviceTypeFileAddRequest20()`

**Attributes:**

|Name                                   |Type           |Description                         |
|---------------------------------------|---------------|------------------------------------|
|device_type                            |str            |deviceType                          |
|file_format                            |str            |fileFormat                          |
|remote_file_format                     |str            |remoteFileFormat                    |
|file_category                          |str            |fileCategory                        |
|file_customization                     |str            |fileCustomization                   |
|file_source                            |str            |fileSource                          |
|upload_file                            |OCI.uploadFile |uploadFile *Optional*               |
|use_http_digest_authentication         |bool           |useHttpDigestAuthentication         |
|mac_based_file_authentication          |bool           |macBasedFileAuthentication          |
|user_name_password_file_authentication |bool           |userNamePasswordFileAuthentication  |
|mac_in_non_request_uri                 |bool           |macInNonRequestURI                  |
|mac_format_in_non_request_uri          |str            |macFormatInNonRequestURI *Optional* |
|allow_http                             |bool           |allowHttp                           |
|allow_https                            |bool           |allowHttps                          |
|allow_tftp                             |bool           |allowTftp                           |
|enable_caching                         |bool           |enableCaching                       |
|allow_upload_from_device               |bool           |allowUploadFromDevice               |
</div>


## `SystemSIPDeviceTypeFileAddRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type file.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by:
SystemSIPDeviceTypeFileAddRequest20Sp1

**Attributes:**

|Name                                   |Type           |Description                               |
|---------------------------------------|---------------|------------------------------------------|
|device_type                            |str            |deviceType                                |
|file_format                            |str            |fileFormat                                |
|remote_file_format                     |str            |remoteFileFormat                          |
|file_category                          |str            |fileCategory                              |
|file_customization                     |str            |fileCustomization                         |
|file_source                            |str            |fileSource                                |
|upload_file                            |OCI.uploadFile |uploadFile *Optional*                     |
|use_http_digest_authentication         |bool           |useHttpDigestAuthentication               |
|mac_based_file_authentication          |bool           |macBasedFileAuthentication                |
|user_name_password_file_authentication |bool           |userNamePasswordFileAuthentication        |
|mac_in_non_request_uri                 |bool           |macInNonRequestURI                        |
|mac_format_in_non_request_uri          |str            |macFormatInNonRequestURI *Optional*       |
|allow_http                             |bool           |allowHttp                                 |
|allow_https                            |bool           |allowHttps                                |
|allow_tftp                             |bool           |allowTftp                                 |
|enable_caching                         |bool           |enableCaching                             |
|allow_upload_from_device               |bool           |allowUploadFromDevice                     |
|default_extended_file_capture_mode     |bool           |defaultExtendedFileCaptureMode *Optional* |
</div>


## `SystemSIPDeviceTypeFileAddRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type file.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following logic
applies to these elements: macInCert macInNonRequestURI The two elements are mutually
exclusive.  When both are set to true, the command fails.  Replaced by:
`SystemSIPDeviceTypeFileAddRequest22()` in AS data mode.

**Attributes:**

|Name                                   |Type           |Description                               |
|---------------------------------------|---------------|------------------------------------------|
|device_type                            |str            |deviceType                                |
|file_format                            |str            |fileFormat                                |
|remote_file_format                     |str            |remoteFileFormat                          |
|file_category                          |str            |fileCategory                              |
|file_customization                     |str            |fileCustomization                         |
|file_source                            |str            |fileSource                                |
|upload_file                            |OCI.uploadFile |uploadFile *Optional*                     |
|use_http_digest_authentication         |bool           |useHttpDigestAuthentication               |
|mac_based_file_authentication          |bool           |macBasedFileAuthentication                |
|user_name_password_file_authentication |bool           |userNamePasswordFileAuthentication        |
|mac_in_non_request_uri                 |bool           |macInNonRequestURI                        |
|mac_in_cert                            |bool           |macInCert                                 |
|mac_format_in_non_request_uri          |str            |macFormatInNonRequestURI *Optional*       |
|allow_http                             |bool           |allowHttp                                 |
|allow_https                            |bool           |allowHttps                                |
|allow_tftp                             |bool           |allowTftp                                 |
|enable_caching                         |bool           |enableCaching                             |
|allow_upload_from_device               |bool           |allowUploadFromDevice                     |
|default_extended_file_capture_mode     |bool           |defaultExtendedFileCaptureMode *Optional* |
</div>


## `SystemSIPDeviceTypeFileAddRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type file.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following logic
applies to these elements: macInCert macInNonRequestURI The two elements are mutually
exclusive.  When both are set to true, the command fails.

**Attributes:**

|Name                                   |Type           |Description                               |
|---------------------------------------|---------------|------------------------------------------|
|device_type                            |str            |deviceType                                |
|file_format                            |str            |fileFormat                                |
|remote_file_format                     |str            |remoteFileFormat                          |
|file_category                          |str            |fileCategory                              |
|file_customization                     |str            |fileCustomization                         |
|file_source                            |str            |fileSource                                |
|upload_file                            |OCI.uploadFile |uploadFile *Optional*                     |
|use_http_digest_authentication         |bool           |useHttpDigestAuthentication               |
|mac_based_file_authentication          |bool           |macBasedFileAuthentication                |
|user_name_password_file_authentication |bool           |userNamePasswordFileAuthentication        |
|mac_in_non_request_uri                 |bool           |macInNonRequestURI                        |
|mac_in_cert                            |bool           |macInCert                                 |
|mac_format_in_non_request_uri          |str            |macFormatInNonRequestURI *Optional*       |
|allow_http                             |bool           |allowHttp                                 |
|allow_https                            |bool           |allowHttps                                |
|allow_tftp                             |bool           |allowTftp                                 |
|enable_caching                         |bool           |enableCaching                             |
|allow_upload_from_device               |bool           |allowUploadFromDevice                     |
|default_extended_file_capture_mode     |bool           |defaultExtendedFileCaptureMode *Optional* |
</div>


## `SystemSIPDeviceTypeFileModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a sip device type file.

The response is either `SuccessResponse()` or `ErrorResponse()`.

Replaced By: `SystemSIPDeviceTypeFileModifyRequest14sp8()`

**Attributes:**

|Name                                   |Type           |Description                                   |
|---------------------------------------|---------------|----------------------------------------------|
|device_type                            |str            |deviceType                                    |
|file_type                              |str            |fileType                                      |
|allow_file_customization               |bool           |allowFileCustomization *Optional*             |
|file_source                            |str            |fileSource *Optional*                         |
|upload_file                            |OCI.uploadFile |uploadFile *Optional*                         |
|use_http_digest_authentication         |bool           |useHttpDigestAuthentication *Optional*        |
|mac_based_file_authentication          |bool           |macBasedFileAuthentication *Optional*         |
|user_name_password_file_authentication |bool           |userNamePasswordFileAuthentication *Optional* |
|mac_in_non_request_uri                 |bool           |macInNonRequestURI *Optional*                 |
|mac_format_in_non_request_uri          |str            |macFormatInNonRequestURI *Optional*           |
</div>


## `SystemSIPDeviceTypeFileModifyRequest14sp8`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a sip device type file.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                   |Type           |Description                                   |
|---------------------------------------|---------------|----------------------------------------------|
|device_type                            |str            |deviceType                                    |
|file_format                            |str            |fileFormat                                    |
|allow_file_customization               |bool           |allowFileCustomization *Optional*             |
|file_source                            |str            |fileSource *Optional*                         |
|upload_file                            |OCI.uploadFile |uploadFile *Optional*                         |
|use_http_digest_authentication         |bool           |useHttpDigestAuthentication *Optional*        |
|mac_based_file_authentication          |bool           |macBasedFileAuthentication *Optional*         |
|user_name_password_file_authentication |bool           |userNamePasswordFileAuthentication *Optional* |
|mac_in_non_request_uri                 |bool           |macInNonRequestURI *Optional*                 |
|mac_format_in_non_request_uri          |str            |macFormatInNonRequestURI *Optional*           |
</div>


## `SystemSIPDeviceTypeFileModifyRequest16sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a sip device type file.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following logic
applies to these elements: macInCert macInNonRequestURI The two elements are mutually
exclusive.  When both are set to true, the command fails.  When macInCert is set to
true, macInNonRequestURI will be reset to false.  When macInNonRequestURI is set to
true, macInCert will be reset to false.

**Attributes:**

|Name                                   |Type           |Description                                   |
|---------------------------------------|---------------|----------------------------------------------|
|device_type                            |str            |deviceType                                    |
|file_format                            |str            |fileFormat                                    |
|file_customization                     |str            |fileCustomization *Optional*                  |
|file_source                            |str            |fileSource *Optional*                         |
|upload_file                            |OCI.uploadFile |uploadFile *Optional*                         |
|use_http_digest_authentication         |bool           |useHttpDigestAuthentication *Optional*        |
|mac_based_file_authentication          |bool           |macBasedFileAuthentication *Optional*         |
|user_name_password_file_authentication |bool           |userNamePasswordFileAuthentication *Optional* |
|mac_in_non_request_uri                 |bool           |macInNonRequestURI *Optional*                 |
|mac_in_cert                            |bool           |macInCert *Optional*                          |
|mac_format_in_non_request_uri          |str            |macFormatInNonRequestURI *Optional*           |
|allow_http                             |bool           |allowHttp *Optional*                          |
|allow_https                            |bool           |allowHttps *Optional*                         |
|allow_tftp                             |bool           |allowTftp *Optional*                          |
|enable_caching                         |bool           |enableCaching *Optional*                      |
|allow_upload_from_device               |bool           |allowUploadFromDevice *Optional*              |
|default_extended_file_capture_mode     |bool           |defaultExtendedFileCaptureMode *Optional*     |
</div>


## `SystemSIPDeviceTypeLanguageMappingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the device language name that is mapped to a BroadWorks language
name.

The request can be used to map many languages.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name             |Type                      |Description                |
|-----------------|--------------------------|---------------------------|
|device_type      |str                       |deviceType                 |
|language_mapping |List[OCI.languageMapping] |languageMapping *Optional* |
</div>


## `SystemScheduleAddEventRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add an event to system schedule.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The startDate
element is adjusted to the first occurrence of the recurrent schedule that comes at or
after the startDate.  The endDate element is set to the sum of the adjusted starDate
element value and the event duration.

**Attributes:**

|Name          |Type            |Description            |
|--------------|----------------|-----------------------|
|schedule_key  |OCI.scheduleKey |scheduleKey            |
|event_name    |str             |eventName              |
|start_date    |str             |startDate              |
|all_day_event |bool            |allDayEvent *Optional* |
|start_time    |OCI.startTime   |startTime *Optional*   |
|end_time      |OCI.endTime     |endTime *Optional*     |
|end_date      |str             |endDate                |
|recurrence    |OCI.recurrence  |recurrence *Optional*  |
</div>


## `SystemScheduleDeleteEventListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a list of events from a system schedule.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type            |Description |
|-------------|----------------|------------|
|schedule_key |OCI.scheduleKey |scheduleKey |
|event_name   |List[str]       |eventName   |
</div>


## `SystemScheduleDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a list of system schedule.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type                  |Description |
|-------------|----------------------|------------|
|schedule_key |List[OCI.scheduleKey] |scheduleKey |
</div>


## `SystemScheduleGetEventListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of events of a system schedule.

The response is either a `SystemScheduleGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type            |Description |
|-------------|----------------|------------|
|schedule_key |OCI.scheduleKey |scheduleKey |
</div>


## `SystemScheduleGetEventRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get an event from a system schedule.

The response is either a `SystemScheduleGetEventResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type            |Description |
|-------------|----------------|------------|
|schedule_key |OCI.scheduleKey |scheduleKey |
|event_name   |str             |eventName   |
</div>


## `SystemScheduleModifyEventRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an event of a system schedule.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The startDate
element is adjusted to the first occurrence of the recurrent schedule that comes at or
after the startDate.  The endDate element is set to the sum of the adjusted starDate
element value and the event duration.

**Attributes:**

|Name           |Type            |Description             |
|---------------|----------------|------------------------|
|schedule_key   |OCI.scheduleKey |scheduleKey             |
|event_name     |str             |eventName               |
|new_event_name |str             |newEventName *Optional* |
|start_date     |str             |startDate *Optional*    |
|all_day_event  |bool            |allDayEvent *Optional*  |
|start_time     |OCI.startTime   |startTime *Optional*    |
|end_time       |OCI.endTime     |endTime *Optional*      |
|end_date       |str             |endDate *Optional*      |
|recurrence     |OCI.recurrence  |recurrence *Optional*   |
</div>


## `SystemScheduleModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a system schedule.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name              |Type            |Description                |
|------------------|----------------|---------------------------|
|schedule_key      |OCI.scheduleKey |scheduleKey                |
|new_schedule_name |str             |newScheduleName *Optional* |
</div>


## `SystemSecurityClassificationAddClassificationRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a new Security Classification The response is either a `SuccessResponse()` or an
`ErrorResponse()`.


**Attributes:**

|Name                         |Type          |Description                |
|-----------------------------|--------------|---------------------------|
|security_classification_name |str           |securityClassificationName |
|audio_file                   |OCI.audioFile |audioFile                  |
</div>


## `SystemSecurityClassificationModifyClassificationRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a Security Classification The response is either a `SuccessResponse()` or an
`ErrorResponse()`.


**Attributes:**

|Name                             |Type          |Description                              |
|---------------------------------|--------------|-----------------------------------------|
|security_classification_name     |str           |securityClassificationName               |
|new_security_classification_name |str           |newSecurityClassificationName *Optional* |
|audio_file                       |OCI.audioFile |audioFile *Optional*                     |
</div>


## `SystemServiceAttributeDefaultModifyListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a list of default attributes that are used when assigning the
feature.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                    |Type                            |Description           |
|------------------------|--------------------------------|----------------------|
|service_name            |str                             |serviceName           |
|service_attribute_entry |List[OCI.serviceAttributeEntry] |serviceAttributeEntry |
</div>


## `SystemSystemServiceDnAddListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Adds system service Dns.

It is possible to add either: a single DN, a list of DNs a range of DNs, or any
combination thereof.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name         |Type              |Description            |
|-------------|------------------|-----------------------|
|phone_number |List[str]         |phoneNumber *Optional* |
|dn_range     |List[OCI.dnRange] |dnRange *Optional*     |
</div>


## `SystemSystemServiceDnDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Deletes system service DNs.

It is possible to delete either: a single DN, a list of DNs, a range of DNs, or any
combination thereof.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name         |Type              |Description            |
|-------------|------------------|-----------------------|
|phone_number |List[str]         |phoneNumber *Optional* |
|dn_range     |List[OCI.dnRange] |dnRange *Optional*     |
</div>


## `SystemSystemVoicePortalAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a system voice portal instance.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in IMS mode: publicUserIdentity, ignored in standalone mode if
provided.  Replaced by: `SystemSystemVoicePortalAddRequest21sp1()`.

**Attributes:**

|Name                                                                |Type                           |Description                                               |
|--------------------------------------------------------------------|-------------------------------|----------------------------------------------------------|
|system_voice_portal_id                                              |str                            |systemVoicePortalId                                       |
|name                                                                |str                            |name                                                      |
|calling_line_id_name                                                |str                            |callingLineIdName                                         |
|language                                                            |str                            |language                                                  |
|time_zone                                                           |str                            |timeZone                                                  |
|phone_number                                                        |str                            |phoneNumber *Optional*                                    |
|public_user_identity                                                |str                            |publicUserIdentity *Optional*                             |
|network_voice_portal_number                                         |str                            |networkVoicePortalNumber *Optional*                       |
|allow_identification_by_phone_number_or_voice_mail_aliases_on_login |bool                           |allowIdentificationByPhoneNumberOrVoiceMailAliasesOnLogin |
|use_voice_portal_wizard                                             |bool                           |useVoicePortalWizard                                      |
|use_voice_portal_default_greeting                                   |bool                           |useVoicePortalDefaultGreeting                             |
|voice_portal_greeting_file                                          |OCI.voicePortalGreetingFile    |voicePortalGreetingFile *Optional*                        |
|use_voice_messaging_default_greeting                                |bool                           |useVoiceMessagingDefaultGreeting                          |
|voice_messaging_greeting_file                                       |OCI.voiceMessagingGreetingFile |voiceMessagingGreetingFile *Optional*                     |
</div>


## `SystemSystemVoicePortalAddRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a system voice portal instance.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in IMS mode: publicUserIdentity, ignored in standalone mode if
provided.  The following elements are only used in AS mode and ignored in XS data
mode: networkClassOfService

**Attributes:**

|Name                                                                |Type                           |Description                                               |
|--------------------------------------------------------------------|-------------------------------|----------------------------------------------------------|
|system_voice_portal_id                                              |str                            |systemVoicePortalId                                       |
|name                                                                |str                            |name                                                      |
|calling_line_id_name                                                |str                            |callingLineIdName                                         |
|language                                                            |str                            |language                                                  |
|time_zone                                                           |str                            |timeZone                                                  |
|phone_number                                                        |str                            |phoneNumber *Optional*                                    |
|public_user_identity                                                |str                            |publicUserIdentity *Optional*                             |
|network_voice_portal_number                                         |str                            |networkVoicePortalNumber *Optional*                       |
|allow_identification_by_phone_number_or_voice_mail_aliases_on_login |bool                           |allowIdentificationByPhoneNumberOrVoiceMailAliasesOnLogin |
|use_voice_portal_wizard                                             |bool                           |useVoicePortalWizard                                      |
|use_voice_portal_default_greeting                                   |bool                           |useVoicePortalDefaultGreeting                             |
|voice_portal_greeting_file                                          |OCI.voicePortalGreetingFile    |voicePortalGreetingFile *Optional*                        |
|use_voice_messaging_default_greeting                                |bool                           |useVoiceMessagingDefaultGreeting                          |
|voice_messaging_greeting_file                                       |OCI.voiceMessagingGreetingFile |voiceMessagingGreetingFile *Optional*                     |
|express_mode                                                        |bool                           |expressMode                                               |
|network_class_of_service                                            |str                            |networkClassOfService *Optional*                          |
</div>


## `SystemSystemVoicePortalModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to update a System Voice portal instance.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode:
networkClassOfService

**Attributes:**

|Name                                                                |Type                           |Description                                                          |
|--------------------------------------------------------------------|-------------------------------|---------------------------------------------------------------------|
|system_voice_portal_id                                              |str                            |systemVoicePortalId                                                  |
|new_system_voice_portal_id                                          |str                            |newSystemVoicePortalId *Optional*                                    |
|name                                                                |str                            |name *Optional*                                                      |
|calling_line_id_name                                                |str                            |callingLineIdName *Optional*                                         |
|language                                                            |str                            |language *Optional*                                                  |
|time_zone                                                           |str                            |timeZone *Optional*                                                  |
|phone_number                                                        |str                            |phoneNumber *Optional*                                               |
|public_user_identity                                                |str                            |publicUserIdentity *Optional*                                        |
|network_voice_portal_number                                         |str                            |networkVoicePortalNumber *Optional*                                  |
|allow_identification_by_phone_number_or_voice_mail_aliases_on_login |bool                           |allowIdentificationByPhoneNumberOrVoiceMailAliasesOnLogin *Optional* |
|use_voice_portal_wizard                                             |bool                           |useVoicePortalWizard *Optional*                                      |
|become_default_system_voice_portal                                  |bool                           |becomeDefaultSystemVoicePortal *Optional*                            |
|use_voice_portal_default_greeting                                   |bool                           |useVoicePortalDefaultGreeting *Optional*                             |
|voice_portal_greeting_file                                          |OCI.voicePortalGreetingFile    |voicePortalGreetingFile *Optional*                                   |
|use_voice_messaging_default_greeting                                |bool                           |useVoiceMessagingDefaultGreeting *Optional*                          |
|voice_messaging_greeting_file                                       |OCI.voiceMessagingGreetingFile |voiceMessagingGreetingFile *Optional*                                |
|express_mode                                                        |bool                           |expressMode *Optional*                                               |
|network_class_of_service                                            |str                            |networkClassOfService *Optional*                                     |
</div>


## `SystemTimeScheduleAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a system time schedule.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name               |Type               |Description               |
|-------------------|-------------------|--------------------------|
|time_schedule_name |str                |timeScheduleName          |
|time_interval01    |OCI.timeInterval01 |timeInterval01 *Optional* |
|time_interval02    |OCI.timeInterval02 |timeInterval02 *Optional* |
|time_interval03    |OCI.timeInterval03 |timeInterval03 *Optional* |
|time_interval04    |OCI.timeInterval04 |timeInterval04 *Optional* |
|time_interval05    |OCI.timeInterval05 |timeInterval05 *Optional* |
|time_interval06    |OCI.timeInterval06 |timeInterval06 *Optional* |
|time_interval07    |OCI.timeInterval07 |timeInterval07 *Optional* |
|time_interval08    |OCI.timeInterval08 |timeInterval08 *Optional* |
|time_interval09    |OCI.timeInterval09 |timeInterval09 *Optional* |
|time_interval10    |OCI.timeInterval10 |timeInterval10 *Optional* |
|time_interval11    |OCI.timeInterval11 |timeInterval11 *Optional* |
|time_interval12    |OCI.timeInterval12 |timeInterval12 *Optional* |
|time_interval13    |OCI.timeInterval13 |timeInterval13 *Optional* |
|time_interval14    |OCI.timeInterval14 |timeInterval14 *Optional* |
|time_interval15    |OCI.timeInterval15 |timeInterval15 *Optional* |
|time_interval16    |OCI.timeInterval16 |timeInterval16 *Optional* |
|time_interval17    |OCI.timeInterval17 |timeInterval17 *Optional* |
|time_interval18    |OCI.timeInterval18 |timeInterval18 *Optional* |
|time_interval19    |OCI.timeInterval19 |timeInterval19 *Optional* |
|time_interval20    |OCI.timeInterval20 |timeInterval20 *Optional* |
</div>


## `SystemTimeScheduleModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a specified system time schedule.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type               |Description                    |
|-----------------------|-------------------|-------------------------------|
|time_schedule_name     |str                |timeScheduleName               |
|new_time_schedule_name |str                |newTimeScheduleName *Optional* |
|time_interval01        |OCI.timeInterval01 |timeInterval01 *Optional*      |
|time_interval02        |OCI.timeInterval02 |timeInterval02 *Optional*      |
|time_interval03        |OCI.timeInterval03 |timeInterval03 *Optional*      |
|time_interval04        |OCI.timeInterval04 |timeInterval04 *Optional*      |
|time_interval05        |OCI.timeInterval05 |timeInterval05 *Optional*      |
|time_interval06        |OCI.timeInterval06 |timeInterval06 *Optional*      |
|time_interval07        |OCI.timeInterval07 |timeInterval07 *Optional*      |
|time_interval08        |OCI.timeInterval08 |timeInterval08 *Optional*      |
|time_interval09        |OCI.timeInterval09 |timeInterval09 *Optional*      |
|time_interval10        |OCI.timeInterval10 |timeInterval10 *Optional*      |
|time_interval11        |OCI.timeInterval11 |timeInterval11 *Optional*      |
|time_interval12        |OCI.timeInterval12 |timeInterval12 *Optional*      |
|time_interval13        |OCI.timeInterval13 |timeInterval13 *Optional*      |
|time_interval14        |OCI.timeInterval14 |timeInterval14 *Optional*      |
|time_interval15        |OCI.timeInterval15 |timeInterval15 *Optional*      |
|time_interval16        |OCI.timeInterval16 |timeInterval16 *Optional*      |
|time_interval17        |OCI.timeInterval17 |timeInterval17 *Optional*      |
|time_interval18        |OCI.timeInterval18 |timeInterval18 *Optional*      |
|time_interval19        |OCI.timeInterval19 |timeInterval19 *Optional*      |
|time_interval20        |OCI.timeInterval20 |timeInterval20 *Optional*      |
</div>


## `SystemXsiApplicationIdAddListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add the system Xsi application Id entries.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type                            |Description           |
|-------------------------|--------------------------------|----------------------|
|xsi_application_id_entry |List[OCI.xsiApplicationIdEntry] |xsiApplicationIdEntry |
</div>


## `SystemXsiPolicyProfileDeleteRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete an entry from system Xsi application Id list.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name               |Type                 |Description      |
|-------------------|---------------------|-----------------|
|xsi_policy_profile |OCI.xsiPolicyProfile |xsiPolicyProfile |
</div>


## `SystemXsiPolicyProfileGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get an existing Xsi policy profile.

The response is either a `SystemXsiPolicyProfileGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name               |Type                 |Description      |
|-------------------|---------------------|-----------------|
|xsi_policy_profile |OCI.xsiPolicyProfile |xsiPolicyProfile |
</div>


## `SystemXsiPolicyProfileModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the system Xsi policy profile entry.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                        |Type                 |Description                        |
|----------------------------|---------------------|-----------------------------------|
|xsi_policy_profile          |OCI.xsiPolicyProfile |xsiPolicyProfile                   |
|new_xsi_policy_profile_name |str                  |newXsiPolicyProfileName *Optional* |
|description                 |str                  |description *Optional*             |
|max_target_subscription     |int                  |maxTargetSubscription *Optional*   |
</div>


## `SystemZoneAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Zone and optional Net Addresses and Physical Locations.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                             |Type                      |Description                              |
|---------------------------------|--------------------------|-----------------------------------------|
|zone_name                        |str                       |zoneName                                 |
|net_address                      |List[str]                 |netAddress *Optional*                    |
|net_address_range                |List[OCI.netAddressRange] |netAddressRange *Optional*               |
|location_based_physical_location |List[str]                 |locationBasedPhysicalLocation *Optional* |
|calling_zone_physical_location   |str                       |callingZonePhysicalLocation *Optional*   |
</div>


## `SystemZoneCallingRestrictionsNetAddressAddListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Adds a list of IP addresses to a zone The response is `SuccessResponse()` or an
`ErrorResponse()`.

Replaced by: `SystemZoneNetAddressAddListRequest()`

**Attributes:**

|Name              |Type                      |Description                |
|------------------|--------------------------|---------------------------|
|zone_name         |str                       |zoneName                   |
|net_address       |List[str]                 |netAddress *Optional*      |
|net_address_range |List[OCI.netAddressRange] |netAddressRange *Optional* |
</div>


## `SystemZoneCallingRestrictionsNetAddressDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Deletes a list of IP addresses from a zone The response is `SuccessResponse()` or an
`ErrorResponse()`.

Replaced by: `SystemZoneNetAddressDeleteListRequest()`

**Attributes:**

|Name              |Type                      |Description                |
|------------------|--------------------------|---------------------------|
|zone_name         |str                       |zoneName                   |
|net_address       |List[str]                 |netAddress *Optional*      |
|net_address_range |List[OCI.netAddressRange] |netAddressRange *Optional* |
</div>


## `SystemZoneNetAddressAddListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Adds a list of IP addresses to a zone The response is `SuccessResponse()` or an
`ErrorResponse()`.


**Attributes:**

|Name              |Type                      |Description                |
|------------------|--------------------------|---------------------------|
|zone_name         |str                       |zoneName                   |
|net_address       |List[str]                 |netAddress *Optional*      |
|net_address_range |List[OCI.netAddressRange] |netAddressRange *Optional* |
</div>


## `SystemZoneNetAddressDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Deletes a list of IP addresses from a zone The response is `SuccessResponse()` or an
`ErrorResponse()`.


**Attributes:**

|Name              |Type                      |Description                |
|------------------|--------------------------|---------------------------|
|zone_name         |str                       |zoneName                   |
|net_address       |List[str]                 |netAddress *Optional*      |
|net_address_range |List[OCI.netAddressRange] |netAddressRange *Optional* |
</div>


## `UserAccessDeviceFileGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of Device Management user modifiable files.

The response is either `UserAccessDeviceFileGetListResponse()` or `ErrorResponse()`.

**Attributes:**

|Name          |Type             |Description  |
|--------------|-----------------|-------------|
|user_id       |str              |userId       |
|access_device |OCI.accessDevice |accessDevice |
</div>


## `UserAccessDeviceFileGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a user modifiable file.

The response is either `UserAccessDeviceFileGetResponse()` or `ErrorResponse()`.

**Attributes:**

|Name          |Type             |Description  |
|--------------|-----------------|-------------|
|user_id       |str              |userId       |
|access_device |OCI.accessDevice |accessDevice |
|file_format   |str              |fileFormat   |
</div>


## `UserAccessDeviceFileModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a user modifiable access device file.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name          |Type             |Description  |
|--------------|-----------------|-------------|
|user_id       |str              |userId       |
|access_device |OCI.accessDevice |accessDevice |
|file_format   |str              |fileFormat   |
|upload_file   |OCI.uploadFile   |uploadFile   |
</div>


## `UserAccessDeviceResetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Reset a specific user SIP device that supports the reset operation.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name          |Type             |Description  |
|--------------|-----------------|-------------|
|user_id       |str              |userId       |
|access_device |OCI.accessDevice |accessDevice |
</div>


## `UserAccessDeviceTagsGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the device tag names and values for a specific device.

The resolved tags are returned only if the device is the main device for this user.

The response is either a `UserAccessDeviceTagsGetResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name          |Type             |Description  |
|--------------|-----------------|-------------|
|user_id       |str              |userId       |
|access_device |OCI.accessDevice |accessDevice |
</div>


## `UserAlternateNumbersModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Alternate Numbers.

The following element in AlternateNumberEntry21 datatype is only used in AS mode:
description

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name              |Type                 |Description                 |
|------------------|---------------------|----------------------------|
|user_id           |str                  |userId                      |
|distinctive_ring  |bool                 |distinctiveRing *Optional*  |
|alternate_entry01 |OCI.alternateEntry01 |alternateEntry01 *Optional* |
|alternate_entry02 |OCI.alternateEntry02 |alternateEntry02 *Optional* |
|alternate_entry03 |OCI.alternateEntry03 |alternateEntry03 *Optional* |
|alternate_entry04 |OCI.alternateEntry04 |alternateEntry04 *Optional* |
|alternate_entry05 |OCI.alternateEntry05 |alternateEntry05 *Optional* |
|alternate_entry06 |OCI.alternateEntry06 |alternateEntry06 *Optional* |
|alternate_entry07 |OCI.alternateEntry07 |alternateEntry07 *Optional* |
|alternate_entry08 |OCI.alternateEntry08 |alternateEntry08 *Optional* |
|alternate_entry09 |OCI.alternateEntry09 |alternateEntry09 *Optional* |
|alternate_entry10 |OCI.alternateEntry10 |alternateEntry10 *Optional* |
</div>


## `UserAnnouncementFileAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add an announcement to the user announcement repository The following elements are
only used in AS data mode and ignored in XS data mode: announcementFileExternalId The
response is either a `SuccessResponse()` or an `ErrorResponse()`.


**Attributes:**

|Name                          |Type                 |Description                           |
|------------------------------|---------------------|--------------------------------------|
|user_id                       |str                  |userId                                |
|announcement_file_name        |str                  |announcementFileName *Optional*       |
|announcement_file_external_id |str                  |announcementFileExternalId *Optional* |
|announcement_file             |OCI.announcementFile |announcementFile                      |
</div>


## `UserAnnouncementFileDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete one or more announcements from the user announcement repository The following
elements are only used in AS data mode and ignored in XS data mode:
announcementFileExternalId The response is either a `SuccessResponse()` or an
`ErrorResponse()`.


**Attributes:**

|Name                          |Type                          |Description                           |
|------------------------------|------------------------------|--------------------------------------|
|user_id                       |str                           |userId                                |
|announcement_file_key         |List[OCI.announcementFileKey] |announcementFileKey *Optional*        |
|announcement_file_external_id |List[str]                     |announcementFileExternalId *Optional* |
</div>


## `UserAnnouncementFileGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the announcement repository file information.

The response is either `UserAnnouncementFileGetResponse()` or `ErrorResponse()`.
Replaced by: `UserAnnouncementFileGetRequest22()`.

**Attributes:**

|Name                  |Type                    |Description         |
|----------------------|------------------------|--------------------|
|user_id               |str                     |userId              |
|announcement_file_key |OCI.announcementFileKey |announcementFileKey |
</div>


## `UserAnnouncementFileGetRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the announcement repository file information.

The following elements are only used in AS data mode and ignored in XS data mode:
announcementFileExternalId

The response is either `UserAnnouncementFileGetResponse22()` or `ErrorResponse()`.

**Attributes:**

|Name                          |Type                    |Description                           |
|------------------------------|------------------------|--------------------------------------|
|user_id                       |str                     |userId *Optional*                     |
|announcement_file_key         |OCI.announcementFileKey |announcementFileKey *Optional*        |
|announcement_file_external_id |str                     |announcementFileExternalId *Optional* |
</div>


## `UserAnnouncementFileModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
This command is used to change the name of the file or upload a new announcement file
for an existing announcement in the user repository.

When modifying the file type the command will fail if the media type of the new file
changes the announcement from audio to video (or vice versa). The following elements
are only used in AS data mode and ignored in XS data mode: announcementFileExternalId

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                          |Type                    |Description                           |
|------------------------------|------------------------|--------------------------------------|
|user_id                       |str                     |userId *Optional*                     |
|announcement_file_key         |OCI.announcementFileKey |announcementFileKey *Optional*        |
|announcement_file_external_id |str                     |announcementFileExternalId *Optional* |
|new_announcement_file_name    |str                     |newAnnouncementFileName *Optional*    |
|announcement_file             |OCI.announcementFile    |announcementFile *Optional*           |
</div>


## `UserBroadWorksAnywhereAddSelectiveCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a criteria to the user's BroadWorks Anywhere phone number.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name             |Type               |Description             |
|-----------------|-------------------|------------------------|
|user_id          |str                |userId                  |
|phone_number     |str                |phoneNumber             |
|criteria_name    |str                |criteriaName            |
|time_schedule    |OCI.timeSchedule   |timeSchedule *Optional* |
|from_dn_criteria |OCI.fromDnCriteria |fromDnCriteria          |
</div>


## `UserBroadWorksAnywhereAddSelectiveCriteriaRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a criteria to the user's BroadWorks Anywhere phone number.

The following elements are only used in AS data mode: callToNumber For the
callToNumber, the extension element is not used and the number element is only used
when the type is BroadWorks Mobility.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name             |Type                   |Description                |
|-----------------|-----------------------|---------------------------|
|user_id          |str                    |userId                     |
|phone_number     |str                    |phoneNumber                |
|criteria_name    |str                    |criteriaName               |
|time_schedule    |OCI.timeSchedule       |timeSchedule *Optional*    |
|holiday_schedule |OCI.holidaySchedule    |holidaySchedule *Optional* |
|blacklisted      |bool                   |blacklisted                |
|from_dn_criteria |OCI.fromDnCriteria     |fromDnCriteria             |
|call_to_number   |List[OCI.callToNumber] |callToNumber *Optional*    |
</div>


## `UserBroadWorksAnywhereModifyPhoneNumberRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a BroadWorks Anywhere phone number The response is either a `SuccessResponse()`
or an `ErrorResponse()`.


**Attributes:**

|Name                         |Type                         |Description                           |
|-----------------------------|-----------------------------|--------------------------------------|
|user_id                      |str                          |userId                                |
|phone_number                 |str                          |phoneNumber                           |
|new_phone_number             |str                          |newPhoneNumber *Optional*             |
|description                  |str                          |description *Optional*                |
|is_active                    |bool                         |isActive *Optional*                   |
|outbound_alternate_number    |str                          |outboundAlternateNumber *Optional*    |
|broadworks_call_control      |bool                         |broadworksCallControl *Optional*      |
|use_diversion_inhibitor      |bool                         |useDiversionInhibitor *Optional*      |
|answer_confirmation_required |bool                         |answerConfirmationRequired *Optional* |
|criteria_activation          |List[OCI.criteriaActivation] |criteriaActivation *Optional*         |
</div>


## `UserBroadWorksMobilityModifyRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's BroadWorks Mobility service settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The isActive,
useMobileIdentityCallAnchoring, and preventCallsToOwnMobiles parameters can be
modified by users with Group Authorization Level and above.  The mobileIdentity,
profileIdentityDevicesToRing, rofileIdentityIncludeSharedCallAppearance,
profileIdentityIncludeBroadworksAnywhere mobileIdentity and
profileIdentityMobilityNumbersAlerted parameters can be modified by users with User
Authorization Level and above when the BroadWorks Mobility service is turned on.

**Attributes:**

|Name                                            |Type                                      |Description                                           |
|------------------------------------------------|------------------------------------------|------------------------------------------------------|
|user_id                                         |str                                       |userId                                                |
|is_active                                       |bool                                      |isActive *Optional*                                   |
|use_mobile_identity_call_anchoring              |bool                                      |useMobileIdentityCallAnchoring *Optional*             |
|prevent_calls_to_own_mobiles                    |bool                                      |preventCallsToOwnMobiles *Optional*                   |
|mobile_identity                                 |List[OCI.mobileIdentity]                  |mobileIdentity *Optional*                             |
|profile_identity_devices_to_ring                |str                                       |profileIdentityDevicesToRing *Optional*               |
|profile_identity_include_shared_call_appearance |bool                                      |profileIdentityIncludeSharedCallAppearance *Optional* |
|profile_identity_include_broadworks_anywhere    |bool                                      |profileIdentityIncludeBroadworksAnywhere *Optional*   |
|profile_identity_include_executive_assistant    |bool                                      |profileIdentityIncludeExecutiveAssistant *Optional*   |
|profile_identity_mobility_numbers_alerted       |OCI.profileIdentityMobilityNumbersAlerted |profileIdentityMobilityNumbersAlerted *Optional*      |
</div>


## `UserBroadWorksReceptionistEnterpriseModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Replace the BroadWorks Receptionist - Enterprise monitored user list.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type                    |Description                    |
|-----------------------|------------------------|-------------------------------|
|user_id                |str                     |userId                         |
|monitored_user_id_list |OCI.monitoredUserIdList |monitoredUserIdList *Optional* |
</div>


## `UserBroadWorksReceptionistEnterpriseNoteGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the Receptionist notes for the specified Receptionist and Contact User IDs.

The response is either a `UserBroadWorksReceptionistEnterpriseNoteGetResponse()` or an
`ErrorResponse()`. If the user sending the request is the not the owner of the
Receptionist Note, then an `ErrorResponse()` will be returned.

**Attributes:**

|Name                 |Type        |Description              |
|---------------------|------------|-------------------------|
|receptionist_user_id |str         |receptionistUserId       |
|contact_user_id      |str         |contactUserId *Optional* |
|von_user             |OCI.vonUser |vonUser *Optional*       |
</div>


## `UserBroadWorksReceptionistOfficeModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Replace the Receptionist Office monitored user list.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type                    |Description                    |
|-----------------------|------------------------|-------------------------------|
|user_id                |str                     |userId                         |
|monitored_user_id_list |OCI.monitoredUserIdList |monitoredUserIdList *Optional* |
</div>


## `UserBroadWorksReceptionistSmallBusinessModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Replace the Receptionist Small Business monitored user list.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type                    |Description                    |
|-----------------------|------------------------|-------------------------------|
|user_id                |str                     |userId                         |
|monitored_user_id_list |OCI.monitoredUserIdList |monitoredUserIdList *Optional* |
</div>


## `UserBusyLampFieldModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the settings for the busy lamp field service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                          |Type                    |Description                           |
|------------------------------|------------------------|--------------------------------------|
|user_id                       |str                     |userId                                |
|list_uri                      |str                     |listURI *Optional*                    |
|monitored_user_id_list        |OCI.monitoredUserIdList |monitoredUserIdList *Optional*        |
|enable_call_park_notification |bool                    |enableCallParkNotification *Optional* |
</div>


## `UserCallCenterEnhancedReportingReportTemplateParamInfoGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the input parameter info for a call center report template.

The response is either a
`UserCallCenterEnhancedReportingReportTemplateParamInfoGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name            |Type               |Description    |
|----------------|-------------------|---------------|
|report_template |OCI.reportTemplate |reportTemplate |
</div>


## `UserCallCenterModifyAvailabilityListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request for an agent to login or logout of one or more Call Centers.

Contains a list specifing the desired login status of one or more call centers.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

Replaced By: `UserCallCenterModifyRequest17sp4()`

**Attributes:**

|Name                     |Type                             |Description                       |
|-------------------------|---------------------------------|----------------------------------|
|user_id                  |str                              |userId                            |
|call_center_availability |List[OCI.callCenterAvailability] |callCenterAvailability *Optional* |
</div>


## `UserCallCenterModifyCallCenterListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the call center list for an agent.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                 |Type                  |Description                  |
|---------------------|----------------------|-----------------------------|
|agent_user_id        |str                   |agentUserId                  |
|service_user_id_list |OCI.serviceUserIdList |serviceUserIdList *Optional* |
</div>


## `UserCallCenterModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the agents call center settings and the availability for an agent in one or
more Call Centers.

Contains a list specifying the desired availability status of one or more call
centers.  A default unavailable code will be used if the parameter
agentUnavailableCode is not active, included or is invalid.  Changing the
agentACDState from unavailable to any other state will automatically clear the
unavailable code.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by
`UserCallCenterModifyRequest17sp4()`.

**Attributes:**

|Name                                                        |Type                             |Description                                                     |
|------------------------------------------------------------|---------------------------------|----------------------------------------------------------------|
|user_id                                                     |str                              |userId                                                          |
|agent_acd_state                                             |str                              |agentACDState *Optional*                                        |
|agent_unavailable_code                                      |str                              |agentUnavailableCode *Optional*                                 |
|use_default_guard_timer                                     |bool                             |useDefaultGuardTimer *Optional*                                 |
|enable_guard_timer                                          |bool                             |enableGuardTimer *Optional*                                     |
|guard_timer_seconds                                         |int                              |guardTimerSeconds *Optional*                                    |
|use_system_default_unavailable_settings                     |bool                             |useSystemDefaultUnavailableSettings *Optional*                  |
|force_agent_unavailable_on_dnd_activation                   |bool                             |forceAgentUnavailableOnDNDActivation *Optional*                 |
|force_unavailable_on_personal_calls                         |bool                             |forceUnavailableOnPersonalCalls *Optional*                      |
|force_agent_unavailable_on_bounced_call_limit               |bool                             |forceAgentUnavailableOnBouncedCallLimit *Optional*              |
|number_consecutive_bounced_calls_to_force_agent_unavailable |int                              |numberConsecutiveBouncedCallsToForceAgentUnavailable *Optional* |
|make_outgoing_calls_as_call_center                          |bool                             |makeOutgoingCallsAsCallCenter *Optional*                        |
|outgoing_call_dnis                                          |OCI.outgoingCallDNIS             |outgoingCallDNIS *Optional*                                     |
|call_center_availability                                    |List[OCI.callCenterAvailability] |callCenterAvailability *Optional*                               |
</div>


## `UserCallCenterModifyRequest17sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the agents call center settings and the availability for an agent in one or
more Call Centers.

Contains a list specifying the desired availability status of one or more call
centers.  A default unavailable code will be used if the parameter
agentUnavailableCode is not active, included or is invalid.  Changing the
agentACDState from unavailable to any other state will automatically clear the
unavailable code.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by
`UserCallCenterModifyRequest19()`.

**Attributes:**

|Name                                                        |Type                             |Description                                                     |
|------------------------------------------------------------|---------------------------------|----------------------------------------------------------------|
|user_id                                                     |str                              |userId                                                          |
|agent_acd_state                                             |str                              |agentACDState *Optional*                                        |
|agent_threshold_profile_name                                |str                              |agentThresholdProfileName *Optional*                            |
|agent_unavailable_code                                      |str                              |agentUnavailableCode *Optional*                                 |
|use_default_guard_timer                                     |bool                             |useDefaultGuardTimer *Optional*                                 |
|enable_guard_timer                                          |bool                             |enableGuardTimer *Optional*                                     |
|guard_timer_seconds                                         |int                              |guardTimerSeconds *Optional*                                    |
|use_system_default_unavailable_settings                     |bool                             |useSystemDefaultUnavailableSettings *Optional*                  |
|force_agent_unavailable_on_dnd_activation                   |bool                             |forceAgentUnavailableOnDNDActivation *Optional*                 |
|force_agent_unavailable_on_personal_calls                   |bool                             |forceAgentUnavailableOnPersonalCalls *Optional*                 |
|force_agent_unavailable_on_bounced_call_limit               |bool                             |forceAgentUnavailableOnBouncedCallLimit *Optional*              |
|number_consecutive_bounced_calls_to_force_agent_unavailable |int                              |numberConsecutiveBouncedCallsToForceAgentUnavailable *Optional* |
|force_agent_unavailable_on_not_reachable                    |bool                             |forceAgentUnavailableOnNotReachable *Optional*                  |
|make_outgoing_calls_as_call_center                          |bool                             |makeOutgoingCallsAsCallCenter *Optional*                        |
|outgoing_call_dnis                                          |OCI.outgoingCallDNIS             |outgoingCallDNIS *Optional*                                     |
|call_center_availability                                    |List[OCI.callCenterAvailability] |callCenterAvailability *Optional*                               |
</div>


## `UserCallCenterModifyRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the agents call center settings and the availability for an agent in one or
more Call Centers.

Contains a list specifying the desired availability status of one or more call
centers.  A default unavailable code will be used if the parameter
agentUnavailableCode is not active, included or is invalid.  Changing the
agentACDState from unavailable to any other state will automatically clear the
unavailable code.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode: agentACDState
agentThresholdProfileName agentUnavailableCode useSystemDefaultUnavailableSettings
forceAgentUnavailableOnDNDActivation forceAgentUnavailableOnPersonalCalls
forceAgentUnavailableOnBouncedCallLimit
numberConsecutiveBouncedCallsToForceAgentUnavailable
forceAgentUnavailableOnNotReachable makeOutgoingCallsAsCallCenter outgoingCallDNIS
useSystemDefaultWrapUpDestination wrapUpDestination

**Attributes:**

|Name                                                        |Type                              |Description                                                     |
|------------------------------------------------------------|----------------------------------|----------------------------------------------------------------|
|user_id                                                     |str                               |userId                                                          |
|agent_acd_state                                             |str                               |agentACDState *Optional*                                        |
|agent_threshold_profile_name                                |str                               |agentThresholdProfileName *Optional*                            |
|agent_unavailable_code                                      |str                               |agentUnavailableCode *Optional*                                 |
|use_default_guard_timer                                     |bool                              |useDefaultGuardTimer *Optional*                                 |
|enable_guard_timer                                          |bool                              |enableGuardTimer *Optional*                                     |
|guard_timer_seconds                                         |int                               |guardTimerSeconds *Optional*                                    |
|use_system_default_unavailable_settings                     |bool                              |useSystemDefaultUnavailableSettings *Optional*                  |
|force_agent_unavailable_on_dnd_activation                   |bool                              |forceAgentUnavailableOnDNDActivation *Optional*                 |
|force_agent_unavailable_on_personal_calls                   |bool                              |forceAgentUnavailableOnPersonalCalls *Optional*                 |
|force_agent_unavailable_on_bounced_call_limit               |bool                              |forceAgentUnavailableOnBouncedCallLimit *Optional*              |
|number_consecutive_bounced_calls_to_force_agent_unavailable |int                               |numberConsecutiveBouncedCallsToForceAgentUnavailable *Optional* |
|force_agent_unavailable_on_not_reachable                    |bool                              |forceAgentUnavailableOnNotReachable *Optional*                  |
|make_outgoing_calls_as_call_center                          |bool                              |makeOutgoingCallsAsCallCenter *Optional*                        |
|outgoing_call_dnis                                          |OCI.outgoingCallDNIS              |outgoingCallDNIS *Optional*                                     |
|call_center_agent_settings                                  |List[OCI.callCenterAgentSettings] |callCenterAgentSettings *Optional*                              |
|use_system_default_wrap_up_destination                      |bool                              |useSystemDefaultWrapUpDestination *Optional*                    |
|wrap_up_destination                                         |str                               |wrapUpDestination *Optional*                                    |
</div>


## `UserCallCenterModifySupervisedAgentListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies a list of users to be supervised by a supervisor on a call center.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name               |Type                |Description                |
|-------------------|--------------------|---------------------------|
|supervisor_user_id |str                 |supervisorUserId           |
|service_user_id    |str                 |serviceUserId              |
|agent_user_id_list |OCI.agentUserIdList |agentUserIdList *Optional* |
</div>


## `UserCallForwardingSelectiveAddCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a criteria to the user's call forwarding selective service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                        |Type               |Description                     |
|----------------------------|-------------------|--------------------------------|
|user_id                     |str                |userId                          |
|criteria_name               |str                |criteriaName                    |
|time_schedule               |OCI.timeSchedule   |timeSchedule *Optional*         |
|forward_to_number_selection |str                |forwardToNumberSelection        |
|forward_to_phone_number     |str                |forwardToPhoneNumber *Optional* |
|from_dn_criteria            |OCI.fromDnCriteria |fromDnCriteria                  |
</div>


## `UserCallForwardingSelectiveAddCriteriaRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a criteria to the user's call forwarding selective service.

The following elements are only used in AS data mode: callToNumber For the
callToNumber, the extension element is not used and the number element is only used
when the type is BroadWorks Mobility.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                        |Type                   |Description                         |
|----------------------------|-----------------------|------------------------------------|
|user_id                     |str                    |userId                              |
|criteria_name               |str                    |criteriaName                        |
|time_schedule               |OCI.timeSchedule       |timeSchedule *Optional*             |
|holiday_schedule            |OCI.holidaySchedule    |holidaySchedule *Optional*          |
|forward_to_number_selection |str                    |forwardToNumberSelection *Optional* |
|forward_to_phone_number     |str                    |forwardToPhoneNumber *Optional*     |
|from_dn_criteria            |OCI.fromDnCriteria     |fromDnCriteria                      |
|call_to_number              |List[OCI.callToNumber] |callToNumber *Optional*             |
</div>


## `UserCallForwardingSelectiveModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's call forwarding selective service setting.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                            |Type                         |Description                            |
|--------------------------------|-----------------------------|---------------------------------------|
|user_id                         |str                          |userId                                 |
|is_active                       |bool                         |isActive *Optional*                    |
|default_forward_to_phone_number |str                          |defaultForwardToPhoneNumber *Optional* |
|play_ring_reminder              |bool                         |playRingReminder *Optional*            |
|criteria_activation             |List[OCI.criteriaActivation] |criteriaActivation *Optional*          |
</div>


## `UserCallMeNowAddCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a criterion to the user's call me now service.

The criterion added is automatically active.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name             |Type                |Description                |
|-----------------|--------------------|---------------------------|
|user_id          |str                 |userId                     |
|criteria_name    |str                 |criteriaName               |
|time_schedule    |OCI.timeSchedule    |timeSchedule *Optional*    |
|holiday_schedule |OCI.holidaySchedule |holidaySchedule *Optional* |
|reject_call      |bool                |rejectCall                 |
|to_dn_criteria   |OCI.toDnCriteria    |toDnCriteria               |
</div>


## `UserCallMeNowModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's call me now service setting.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type                         |Description                   |
|--------------------|-----------------------------|------------------------------|
|user_id             |str                          |userId                        |
|is_active           |bool                         |isActive *Optional*           |
|answer_confirmation |str                          |answerConfirmation *Optional* |
|criteria_activation |List[OCI.criteriaActivation] |criteriaActivation *Optional* |
</div>


## `UserCallNotifyAddCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a criteria to the user's call notify service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name             |Type               |Description             |
|-----------------|-------------------|------------------------|
|user_id          |str                |userId                  |
|criteria_name    |str                |criteriaName            |
|time_schedule    |OCI.timeSchedule   |timeSchedule *Optional* |
|from_dn_criteria |OCI.fromDnCriteria |fromDnCriteria          |
</div>


## `UserCallNotifyAddCriteriaRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a criteria to the user's call notify service.

The following elements are only used in AS data mode: callToNumber For the
callToNumber, the extension element is not used and the number element is only used
when the type is BroadWorks Mobility.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name             |Type                   |Description                |
|-----------------|-----------------------|---------------------------|
|user_id          |str                    |userId                     |
|criteria_name    |str                    |criteriaName               |
|time_schedule    |OCI.timeSchedule       |timeSchedule *Optional*    |
|holiday_schedule |OCI.holidaySchedule    |holidaySchedule *Optional* |
|blacklisted      |bool                   |blacklisted                |
|from_dn_criteria |OCI.fromDnCriteria     |fromDnCriteria             |
|call_to_number   |List[OCI.callToNumber] |callToNumber *Optional*    |
</div>


## `UserCallNotifyModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's call notify service setting.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                      |Type                         |Description                       |
|--------------------------|-----------------------------|----------------------------------|
|user_id                   |str                          |userId                            |
|call_notify_email_address |str                          |callNotifyEmailAddress *Optional* |
|criteria_activation       |List[OCI.criteriaActivation] |criteriaActivation *Optional*     |
</div>


## `UserCollaborateProjectRoomAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add collaborate project room.

The response is either a `UserCollaborateProjectRoomAddResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                       |Type             |Description                          |
|-------------------------------------------|-----------------|-------------------------------------|
|user_id                                    |str              |userId                               |
|room_name                                  |str              |roomName                             |
|attendee_notification                      |str              |attendeeNotification                 |
|end_collaborate_room_session_on_owner_exit |bool             |endCollaborateRoomSessionOnOwnerExit |
|owner_required                             |bool             |ownerRequired                        |
|room_schedule                              |OCI.roomSchedule |roomSchedule                         |
</div>


## `UserCollaborateProjectRoomModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify collaborate room settings for a project room.

The request fails when modifying collaborate room settings for instant rooms or My
Room.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                       |Type             |Description                                     |
|-------------------------------------------|-----------------|------------------------------------------------|
|user_id                                    |str              |userId                                          |
|room_id                                    |str              |roomId                                          |
|room_name                                  |str              |roomName *Optional*                             |
|attendee_notification                      |str              |attendeeNotification *Optional*                 |
|end_collaborate_room_session_on_owner_exit |bool             |endCollaborateRoomSessionOnOwnerExit *Optional* |
|owner_required                             |bool             |ownerRequired *Optional*                        |
|room_schedule                              |OCI.roomSchedule |roomSchedule *Optional*                         |
</div>


## `UserCollaborateRoomModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify room settings for a specific Project Room or My Room.

Request to modify room settings for a specific Instant Room is responded with an
`ErrorResponse()`. The roomSchedule parameter is applicable for Project Room only.  If
the roomSchedule parameter is specified in the request to modify My Room, the request
will be failed.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                       |Type             |Description                                     |
|-------------------------------------------|-----------------|------------------------------------------------|
|user_id                                    |str              |userId                                          |
|room_id                                    |str              |roomId                                          |
|room_name                                  |str              |roomName *Optional*                             |
|attendee_notification                      |str              |attendeeNotification *Optional*                 |
|end_collaborate_room_session_on_owner_exit |bool             |endCollaborateRoomSessionOnOwnerExit *Optional* |
|owner_required                             |bool             |ownerRequired *Optional*                        |
|room_schedule                              |OCI.roomSchedule |roomSchedule *Optional*                         |
</div>


## `UserCommunicationBarringAuthorizationCodeAddListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a list of Communication Barring Authorization codes to a user.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type           |Description|
|--------|---------------|-----------|
|user_id |str            |userId     |
|code    |List[OCI.code] |code       |
</div>


## `UserCustomRingbackUserModifyActiveCriteriaListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's custom ringback service criteria's active setting.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type                         |Description                   |
|--------------------|-----------------------------|------------------------------|
|user_id             |str                          |userId                        |
|criteria_activation |List[OCI.criteriaActivation] |criteriaActivation *Optional* |
</div>


## `UserDirectRouteModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the direct route setting and the list of DTGs/Trunk Identities assigned to a
user.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                           |Type                        |Description                            |
|-------------------------------|----------------------------|---------------------------------------|
|user_id                        |str                         |userId                                 |
|outgoing_dtg_policy            |str                         |outgoingDTGPolicy *Optional*           |
|outgoing_trunk_identity_policy |str                         |outgoingTrunkIdentityPolicy *Optional* |
|direct_route_identity_list     |OCI.directRouteIdentityList |directRouteIdentityList *Optional*     |
</div>


## `UserEnhancedCallLogsGetListRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request user's call logs.

If the callLogType is not specified, all types of calls logs (placed, received,
missed) are returned.  It is possible to restrict the number of rows returned using
responsePagingControl.

The response is either a `UserEnhancedCallLogsGetListResponse16()` or an
`ErrorResponse()`. Replaced by `UserEnhancedCallLogsGetListRequest17sp4()`

**Attributes:**

|Name                    |Type                      |Description                      |
|------------------------|--------------------------|---------------------------------|
|user_id                 |str                       |userId                           |
|call_log_type           |str                       |callLogType *Optional*           |
|response_paging_control |OCI.responsePagingControl |responsePagingControl *Optional* |
</div>


## `UserExecutiveAddFilteringSelectiveCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a filtering criteria to an executive user.

Both executive and the executive assistant can run this command.  For the
callToNumber, the extension element is not used and the number element is only used
when the type is BroadWorks Mobility.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name             |Type                   |Description                |
|-----------------|-----------------------|---------------------------|
|user_id          |str                    |userId                     |
|criteria_name    |str                    |criteriaName               |
|time_schedule    |OCI.timeSchedule       |timeSchedule *Optional*    |
|holiday_schedule |OCI.holidaySchedule    |holidaySchedule *Optional* |
|filter           |bool                   |filter                     |
|from_dn_criteria |OCI.fromDnCriteria     |fromDnCriteria             |
|call_to_number   |List[OCI.callToNumber] |callToNumber *Optional*    |
</div>


## `UserExecutiveAssistantModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the setting for executive assistant.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                   |Type                  |Description                    |
|-----------------------|----------------------|-------------------------------|
|user_id                |str                   |userId                         |
|enable_divert          |bool                  |enableDivert *Optional*        |
|divert_to_phone_number |str                   |divertToPhoneNumber *Optional* |
|opt_in_status          |List[OCI.optInStatus] |optInStatus *Optional*         |
</div>


## `UserExecutiveModifyAssistantRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the assistant setting and the list of assistants assigned to an
executive user.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                   |Type                    |Description                    |
|-----------------------|------------------------|-------------------------------|
|user_id                |str                     |userId                         |
|allow_opt_in_out       |bool                    |allowOptInOut *Optional*       |
|assistant_user_id_list |OCI.assistantUserIdList |assistantUserIdList *Optional* |
</div>


## `UserExecutiveModifyFilteringRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the filtering setting for an executive user.

Both executive and the executive assistant can run this command.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type                         |Description                   |
|--------------------|-----------------------------|------------------------------|
|user_id             |str                          |userId                        |
|enable_filtering    |bool                         |enableFiltering *Optional*    |
|filtering_mode      |str                          |filteringMode *Optional*      |
|simple_filter_type  |str                          |simpleFilterType *Optional*   |
|criteria_activation |List[OCI.criteriaActivation] |criteriaActivation *Optional* |
</div>


## `UserFaxMessagingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Fax Messaging.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name           |Type             |Description             |
|---------------|-----------------|------------------------|
|user_id        |str              |userId                  |
|is_active      |bool             |isActive *Optional*     |
|phone_number   |str              |phoneNumber *Optional*  |
|extension      |str              |extension *Optional*    |
|sip_alias_list |OCI.sipAliasList |sipAliasList *Optional* |
</div>


## `UserFeatureAccessCodeModifyListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Enable or disable a list of feature access codes for a user.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type                        |Description                  |
|--------------------|----------------------------|-----------------------------|
|user_id             |str                         |userId                       |
|feature_access_code |List[OCI.featureAccessCode] |featureAccessCode *Optional* |
</div>


## `UserHolidayScheduleAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a holiday schedule to a user.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                  |Type          |Description          |
|----------------------|--------------|---------------------|
|user_id               |str           |userId               |
|holiday_schedule_name |str           |holidayScheduleName  |
|holiday01             |OCI.holiday01 |holiday01 *Optional* |
|holiday02             |OCI.holiday02 |holiday02 *Optional* |
|holiday03             |OCI.holiday03 |holiday03 *Optional* |
|holiday04             |OCI.holiday04 |holiday04 *Optional* |
|holiday05             |OCI.holiday05 |holiday05 *Optional* |
|holiday06             |OCI.holiday06 |holiday06 *Optional* |
|holiday07             |OCI.holiday07 |holiday07 *Optional* |
|holiday08             |OCI.holiday08 |holiday08 *Optional* |
|holiday09             |OCI.holiday09 |holiday09 *Optional* |
|holiday10             |OCI.holiday10 |holiday10 *Optional* |
|holiday11             |OCI.holiday11 |holiday11 *Optional* |
|holiday12             |OCI.holiday12 |holiday12 *Optional* |
|holiday13             |OCI.holiday13 |holiday13 *Optional* |
|holiday14             |OCI.holiday14 |holiday14 *Optional* |
|holiday15             |OCI.holiday15 |holiday15 *Optional* |
|holiday16             |OCI.holiday16 |holiday16 *Optional* |
|holiday17             |OCI.holiday17 |holiday17 *Optional* |
|holiday18             |OCI.holiday18 |holiday18 *Optional* |
|holiday19             |OCI.holiday19 |holiday19 *Optional* |
|holiday20             |OCI.holiday20 |holiday20 *Optional* |
</div>


## `UserHolidayScheduleModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a holiday schedule for a user.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                      |Type          |Description                       |
|--------------------------|--------------|----------------------------------|
|user_id                   |str           |userId                            |
|holiday_schedule_name     |str           |holidayScheduleName               |
|new_holiday_schedule_name |str           |newHolidayScheduleName *Optional* |
|holiday01                 |OCI.holiday01 |holiday01 *Optional*              |
|holiday02                 |OCI.holiday02 |holiday02 *Optional*              |
|holiday03                 |OCI.holiday03 |holiday03 *Optional*              |
|holiday04                 |OCI.holiday04 |holiday04 *Optional*              |
|holiday05                 |OCI.holiday05 |holiday05 *Optional*              |
|holiday06                 |OCI.holiday06 |holiday06 *Optional*              |
|holiday07                 |OCI.holiday07 |holiday07 *Optional*              |
|holiday08                 |OCI.holiday08 |holiday08 *Optional*              |
|holiday09                 |OCI.holiday09 |holiday09 *Optional*              |
|holiday10                 |OCI.holiday10 |holiday10 *Optional*              |
|holiday11                 |OCI.holiday11 |holiday11 *Optional*              |
|holiday12                 |OCI.holiday12 |holiday12 *Optional*              |
|holiday13                 |OCI.holiday13 |holiday13 *Optional*              |
|holiday14                 |OCI.holiday14 |holiday14 *Optional*              |
|holiday15                 |OCI.holiday15 |holiday15 *Optional*              |
|holiday16                 |OCI.holiday16 |holiday16 *Optional*              |
|holiday17                 |OCI.holiday17 |holiday17 *Optional*              |
|holiday18                 |OCI.holiday18 |holiday18 *Optional*              |
|holiday19                 |OCI.holiday19 |holiday19 *Optional*              |
|holiday20                 |OCI.holiday20 |holiday20 *Optional*              |
</div>


## `UserInterceptUserModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's intercept user service settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

Replaced By: `UserInterceptUserModifyRequest16()`

**Attributes:**

|Name                             |Type          |Description                            |
|---------------------------------|--------------|---------------------------------------|
|user_id                          |str           |userId                                 |
|is_active                        |bool          |isActive *Optional*                    |
|announcement_selection           |str           |announcementSelection *Optional*       |
|audio_file                       |OCI.audioFile |audioFile *Optional*                   |
|video_file                       |OCI.videoFile |videoFile *Optional*                   |
|play_new_phone_number            |bool          |playNewPhoneNumber *Optional*          |
|new_phone_number                 |str           |newPhoneNumber *Optional*              |
|transfer_on_zero_to_phone_number |bool          |transferOnZeroToPhoneNumber *Optional* |
|transfer_phone_number            |str           |transferPhoneNumber *Optional*         |
</div>


## `UserInterceptUserModifyRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's intercept user service settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`UserInterceptUserModifyResponse21sp1()` in AS data mode

**Attributes:**

|Name                             |Type          |Description                              |
|---------------------------------|--------------|-----------------------------------------|
|user_id                          |str           |userId                                   |
|is_active                        |bool          |isActive *Optional*                      |
|announcement_selection           |str           |announcementSelection *Optional*         |
|audio_file                       |OCI.audioFile |audioFile *Optional*                     |
|video_file                       |OCI.videoFile |videoFile *Optional*                     |
|play_new_phone_number            |bool          |playNewPhoneNumber *Optional*            |
|new_phone_number                 |str           |newPhoneNumber *Optional*                |
|transfer_on_zero_to_phone_number |bool          |transferOnZeroToPhoneNumber *Optional*   |
|transfer_phone_number            |str           |transferPhoneNumber *Optional*           |
|reroute_outbound_calls           |bool          |rerouteOutboundCalls *Optional*          |
|outbound_reroute_phone_number    |str           |outboundReroutePhoneNumber *Optional*    |
|allow_outbound_local_calls       |bool          |allowOutboundLocalCalls *Optional*       |
|inbound_call_mode                |str           |inboundCallMode *Optional*               |
|alternate_blocking_announcement  |bool          |alternateBlockingAnnouncement *Optional* |
|route_to_voice_mail              |bool          |routeToVoiceMail *Optional*              |
</div>


## `UserInterceptUserModifyRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's intercept user service settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode:
exemptInboundMobilityCalls exemptOutboundMobilityCalls
disableParallelRingingToNetworkLocations

**Attributes:**

|Name                                          |Type          |Description                                         |
|----------------------------------------------|--------------|----------------------------------------------------|
|user_id                                       |str           |userId                                              |
|is_active                                     |bool          |isActive *Optional*                                 |
|announcement_selection                        |str           |announcementSelection *Optional*                    |
|audio_file                                    |OCI.audioFile |audioFile *Optional*                                |
|video_file                                    |OCI.videoFile |videoFile *Optional*                                |
|inbound_call_mode                             |str           |inboundCallMode *Optional*                          |
|alternate_blocking_announcement               |bool          |alternateBlockingAnnouncement *Optional*            |
|exempt_inbound_mobility_calls                 |bool          |exemptInboundMobilityCalls *Optional*               |
|disable_parallel_ringing_to_network_locations |bool          |disableParallelRingingToNetworkLocations *Optional* |
|route_to_voice_mail                           |bool          |routeToVoiceMail *Optional*                         |
|play_new_phone_number                         |bool          |playNewPhoneNumber *Optional*                       |
|new_phone_number                              |str           |newPhoneNumber *Optional*                           |
|transfer_on_zero_to_phone_number              |bool          |transferOnZeroToPhoneNumber *Optional*              |
|transfer_phone_number                         |str           |transferPhoneNumber *Optional*                      |
|outbound_call_mode                            |str           |outboundCallMode *Optional*                         |
|exempt_outbound_mobility_calls                |bool          |exemptOutboundMobilityCalls *Optional*              |
|reroute_outbound_calls                        |bool          |rerouteOutboundCalls *Optional*                     |
|outbound_reroute_phone_number                 |str           |outboundReroutePhoneNumber *Optional*               |
</div>


## `UserMaliciousCallTraceModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Malicious Call Trace.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                  |Type                |Description                   |
|----------------------|--------------------|------------------------------|
|user_id               |str                 |userId                        |
|is_active             |bool                |isActive *Optional*           |
|trace_type_selection  |str                 |traceTypeSelection *Optional* |
|trace_for_time_period |bool                |traceForTimePeriod *Optional* |
|trace_time_period     |OCI.traceTimePeriod |traceTimePeriod *Optional*    |
</div>


## `UserMeetMeConferencingAddConferenceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Meet-Me conference.

The response is either `UserMeetMeConferencingAddConferenceResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                             |Type                   |Description                      |
|---------------------------------|-----------------------|---------------------------------|
|user_id                          |str                    |userId                           |
|bridge_id                        |str                    |bridgeId                         |
|title                            |str                    |title                            |
|estimated_participants           |int                    |estimatedParticipants *Optional* |
|restrict_participants            |bool                   |restrictParticipants *Optional*  |
|max_participants                 |int                    |maxParticipants *Optional*       |
|account_code                     |str                    |accountCode *Optional*           |
|mute_all_attendees_on_entry      |bool                   |muteAllAttendeesOnEntry          |
|end_conference_on_moderator_exit |bool                   |endConferenceOnModeratorExit     |
|moderator_required               |bool                   |moderatorRequired                |
|attendee_notification            |str                    |attendeeNotification             |
|conference_schedule              |OCI.conferenceSchedule |conferenceSchedule               |
</div>


## `UserMeetMeConferencingAddConferenceRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Meet-Me conference.

The response is either `UserMeetMeConferencingAddConferenceResponse19()` or
`ErrorResponse()`. The startTime element is adjusted to the first occurrence of the
recurrent schedule that comes at or after the startTime.  The startTime, endTime and
recurrence information for a conferenceSchedule element will be adjusted to the user
Host time zone.  Replaced by: `UserMeetMeConferencingAddConferenceRequest23()`

**Attributes:**

|Name                             |Type                   |Description                      |
|---------------------------------|-----------------------|---------------------------------|
|user_id                          |str                    |userId                           |
|bridge_id                        |str                    |bridgeId                         |
|title                            |str                    |title                            |
|estimated_participants           |int                    |estimatedParticipants *Optional* |
|restrict_participants            |bool                   |restrictParticipants *Optional*  |
|max_participants                 |int                    |maxParticipants *Optional*       |
|account_code                     |str                    |accountCode *Optional*           |
|mute_all_attendees_on_entry      |bool                   |muteAllAttendeesOnEntry          |
|end_conference_on_moderator_exit |bool                   |endConferenceOnModeratorExit     |
|moderator_required               |bool                   |moderatorRequired                |
|require_security_pin             |bool                   |requireSecurityPin               |
|allow_unique_identifier          |bool                   |allowUniqueIdentifier            |
|attendee_notification            |str                    |attendeeNotification             |
|conference_schedule              |OCI.conferenceSchedule |conferenceSchedule               |
</div>


## `UserMeetMeConferencingAddConferenceRequest23`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Meet-Me conference.

The response is either `UserMeetMeConferencingAddConferenceResponse23()` or
`ErrorResponse()`. The startTime element is adjusted to the first occurrence of the
recurrent schedule that comes at or after the startTime.  The startTime, endTime and
recurrence information for a conferenceSchedule element will be adjusted to the user
Host time zone.

**Attributes:**

|Name                                          |Type                   |Description                             |
|----------------------------------------------|-----------------------|----------------------------------------|
|user_id                                       |str                    |userId                                  |
|bridge_id                                     |str                    |bridgeId                                |
|title                                         |str                    |title                                   |
|estimated_participants                        |int                    |estimatedParticipants *Optional*        |
|restrict_participants                         |bool                   |restrictParticipants *Optional*         |
|max_participants                              |int                    |maxParticipants *Optional*              |
|account_code                                  |str                    |accountCode *Optional*                  |
|mute_all_attendees_on_entry                   |bool                   |muteAllAttendeesOnEntry                 |
|end_conference_on_moderator_exit              |bool                   |endConferenceOnModeratorExit            |
|moderator_required                            |bool                   |moderatorRequired                       |
|require_security_pin                          |bool                   |requireSecurityPin                      |
|allow_unique_identifier                       |bool                   |allowUniqueIdentifier                   |
|attendee_notification                         |str                    |attendeeNotification                    |
|conference_schedule                           |OCI.conferenceSchedule |conferenceSchedule                      |
|allow_participant_unmute_in_auto_lecture_mode |bool                   |allowParticipantUnmuteInAutoLectureMode |
</div>


## `UserMeetMeConferencingDeleteConferenceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete one or more conferences which are owned by the user.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name           |Type                    |Description   |
|---------------|------------------------|--------------|
|user_id        |str                     |userId        |
|conference_key |List[OCI.conferenceKey] |conferenceKey |
</div>


## `UserMeetMeConferencingDeleteConferenceRecordingListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete one or more conference recordings owned by the user.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name          |Type                   |Description  |
|--------------|-----------------------|-------------|
|user_id       |str                    |userId       |
|recording_key |List[OCI.recordingKey] |recordingKey |
</div>


## `UserMeetMeConferencingGetConferenceDelegateListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the conference delegates for this conference.

The response is either `UserMeetMeConferencingGetConferenceDelegateListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name           |Type              |Description   |
|---------------|------------------|--------------|
|user_id        |str               |userId        |
|conference_key |OCI.conferenceKey |conferenceKey |
</div>


## `UserMeetMeConferencingGetConferenceGreetingRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the information of a conference custom greeting.

The response is either `UserMeetMeConferencingGetConferenceGreetingResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name           |Type              |Description   |
|---------------|------------------|--------------|
|user_id        |str               |userId        |
|conference_key |OCI.conferenceKey |conferenceKey |
</div>


## `UserMeetMeConferencingGetConferenceGreetingRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the information of a conference custom greeting.

The response is either `UserMeetMeConferencingGetConferenceGreetingResponse20()` or
`ErrorResponse()`.

**Attributes:**

|Name           |Type              |Description   |
|---------------|------------------|--------------|
|user_id        |str               |userId        |
|conference_key |OCI.conferenceKey |conferenceKey |
</div>


## `UserMeetMeConferencingGetConferenceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the information of a conference owned by the user.

The response is either `UserMeetMeConferencingGetConferenceResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name           |Type              |Description   |
|---------------|------------------|--------------|
|user_id        |str               |userId        |
|conference_key |OCI.conferenceKey |conferenceKey |
</div>


## `UserMeetMeConferencingGetConferenceRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the information of a conference owned by the user.

The response is either `UserMeetMeConferencingGetConferenceResponse19()` or
`ErrorResponse()`.

**Attributes:**

|Name           |Type              |Description   |
|---------------|------------------|--------------|
|user_id        |str               |userId        |
|conference_key |OCI.conferenceKey |conferenceKey |
</div>


## `UserMeetMeConferencingGetConferenceRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the information of a conference owned by the user.

The response is either `UserMeetMeConferencingGetConferenceResponse20()` or
`ErrorResponse()`. Replaced by: `UserMeetMeConferencingGetConferenceRequest23()`

**Attributes:**

|Name           |Type              |Description   |
|---------------|------------------|--------------|
|user_id        |str               |userId        |
|conference_key |OCI.conferenceKey |conferenceKey |
</div>


## `UserMeetMeConferencingGetConferenceRequest23`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the information of a conference owned by the user.

The response is either `UserMeetMeConferencingGetConferenceResponse23()` or
`ErrorResponse()`.

**Attributes:**

|Name           |Type              |Description   |
|---------------|------------------|--------------|
|user_id        |str               |userId        |
|conference_key |OCI.conferenceKey |conferenceKey |
</div>


## `UserMeetMeConferencingModifyConferenceDelegateListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the existing conference delegates list.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                          |Type                           |Description                           |
|------------------------------|-------------------------------|--------------------------------------|
|user_id                       |str                            |userId                                |
|conference_key                |OCI.conferenceKey              |conferenceKey                         |
|conference_delegate_user_list |OCI.conferenceDelegateUserList |conferenceDelegateUserList *Optional* |
</div>


## `UserMeetMeConferencingModifyConferenceGreetingRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an existing custom greeting audio file.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                   |Type                     |Description                     |
|-----------------------|-------------------------|--------------------------------|
|user_id                |str                      |userId                          |
|conference_key         |OCI.conferenceKey        |conferenceKey                   |
|play_entrance_greeting |bool                     |playEntranceGreeting *Optional* |
|entrance_greeting_file |OCI.entranceGreetingFile |entranceGreetingFile *Optional* |
</div>


## `UserMeetMeConferencingModifyConferenceGreetingRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an existing custom greeting audio file.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                   |Type                     |Description                     |
|-----------------------|-------------------------|--------------------------------|
|user_id                |str                      |userId                          |
|conference_key         |OCI.conferenceKey        |conferenceKey                   |
|play_entrance_greeting |bool                     |playEntranceGreeting *Optional* |
|entrance_greeting_file |OCI.entranceGreetingFile |entranceGreetingFile *Optional* |
</div>


## `UserMeetMeConferencingModifyConferenceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an existing conference.

The response is either `SuccessResponse()` or `ErrorResponse()`. The startTime element
is adjusted to the first occurrence of the recurrent schedule that comes at or after
the startTime.  The startTime, endTime and recurrence information for a
conferenceSchedule element will be adjusted to the user Host time zone.

**Attributes:**

|Name                                          |Type                   |Description                                        |
|----------------------------------------------|-----------------------|---------------------------------------------------|
|user_id                                       |str                    |userId                                             |
|conference_key                                |OCI.conferenceKey      |conferenceKey                                      |
|title                                         |str                    |title *Optional*                                   |
|estimated_participants                        |int                    |estimatedParticipants *Optional*                   |
|restrict_participants                         |bool                   |restrictParticipants *Optional*                    |
|max_participants                              |int                    |maxParticipants *Optional*                         |
|account_code                                  |str                    |accountCode *Optional*                             |
|mute_all_attendees_on_entry                   |bool                   |muteAllAttendeesOnEntry *Optional*                 |
|end_conference_on_moderator_exit              |bool                   |endConferenceOnModeratorExit *Optional*            |
|moderator_required                            |bool                   |moderatorRequired *Optional*                       |
|require_security_pin                          |bool                   |requireSecurityPin *Optional*                      |
|allow_unique_identifier                       |bool                   |allowUniqueIdentifier *Optional*                   |
|attendee_notification                         |str                    |attendeeNotification *Optional*                    |
|conference_schedule                           |OCI.conferenceSchedule |conferenceSchedule *Optional*                      |
|allow_participant_unmute_in_auto_lecture_mode |bool                   |allowParticipantUnmuteInAutoLectureMode *Optional* |
</div>


## `UserModifyRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a user.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                         |Type             |Description                         |
|-----------------------------|-----------------|------------------------------------|
|user_id                      |str              |userId                              |
|last_name                    |str              |lastName *Optional*                 |
|first_name                   |str              |firstName *Optional*                |
|calling_line_id_last_name    |str              |callingLineIdLastName *Optional*    |
|calling_line_id_first_name   |str              |callingLineIdFirstName *Optional*   |
|hiragana_last_name           |str              |hiraganaLastName *Optional*         |
|hiragana_first_name          |str              |hiraganaFirstName *Optional*        |
|phone_number                 |str              |phoneNumber *Optional*              |
|extension                    |str              |extension *Optional*                |
|calling_line_id_phone_number |str              |callingLineIdPhoneNumber *Optional* |
|old_password                 |str              |oldPassword *Optional*              |
|new_password                 |str              |newPassword *Optional*              |
|department                   |OCI.department   |department *Optional*               |
|language                     |str              |language *Optional*                 |
|time_zone                    |str              |timeZone *Optional*                 |
|sip_alias_list               |OCI.sipAliasList |sipAliasList *Optional*             |
|endpoint                     |OCI.endpoint     |endpoint *Optional*                 |
|title                        |str              |title *Optional*                    |
|pager_phone_number           |str              |pagerPhoneNumber *Optional*         |
|mobile_phone_number          |str              |mobilePhoneNumber *Optional*        |
|email_address                |str              |emailAddress *Optional*             |
|yahoo_id                     |str              |yahooId *Optional*                  |
|address_location             |str              |addressLocation *Optional*          |
|address                      |OCI.address      |address *Optional*                  |
</div>


## `UserModifyRequest14sp9`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a user.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by:
`UserModifyRequest16()`

**Attributes:**

|Name                         |Type             |Description                         |
|-----------------------------|-----------------|------------------------------------|
|user_id                      |str              |userId                              |
|last_name                    |str              |lastName *Optional*                 |
|first_name                   |str              |firstName *Optional*                |
|calling_line_id_last_name    |str              |callingLineIdLastName *Optional*    |
|calling_line_id_first_name   |str              |callingLineIdFirstName *Optional*   |
|hiragana_last_name           |str              |hiraganaLastName *Optional*         |
|hiragana_first_name          |str              |hiraganaFirstName *Optional*        |
|phone_number                 |str              |phoneNumber *Optional*              |
|extension                    |str              |extension *Optional*                |
|calling_line_id_phone_number |str              |callingLineIdPhoneNumber *Optional* |
|old_password                 |str              |oldPassword *Optional*              |
|new_password                 |str              |newPassword *Optional*              |
|department                   |OCI.department   |department *Optional*               |
|language                     |str              |language *Optional*                 |
|time_zone                    |str              |timeZone *Optional*                 |
|sip_alias_list               |OCI.sipAliasList |sipAliasList *Optional*             |
|endpoint                     |OCI.endpoint     |endpoint *Optional*                 |
|title                        |str              |title *Optional*                    |
|pager_phone_number           |str              |pagerPhoneNumber *Optional*         |
|mobile_phone_number          |str              |mobilePhoneNumber *Optional*        |
|email_address                |str              |emailAddress *Optional*             |
|yahoo_id                     |str              |yahooId *Optional*                  |
|address_location             |str              |addressLocation *Optional*          |
|address                      |OCI.address      |address *Optional*                  |
|network_class_of_service     |str              |networkClassOfService *Optional*    |
</div>


## `UserModifyRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Replaced By `UserModifyRequest17sp4()` Request to modify a user.

When oldPassword is specified, all password rule applies.  If oldPassword in not
specified, any password rule related to old password does not apply.  The request will
fail if officeZoneName or primaryZoneName is present but the Location-Based Calling
Restrictions service is not assigned to the user.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                         |Type             |Description                         |
|-----------------------------|-----------------|------------------------------------|
|user_id                      |str              |userId                              |
|last_name                    |str              |lastName *Optional*                 |
|first_name                   |str              |firstName *Optional*                |
|calling_line_id_last_name    |str              |callingLineIdLastName *Optional*    |
|calling_line_id_first_name   |str              |callingLineIdFirstName *Optional*   |
|hiragana_last_name           |str              |hiraganaLastName *Optional*         |
|hiragana_first_name          |str              |hiraganaFirstName *Optional*        |
|phone_number                 |str              |phoneNumber *Optional*              |
|extension                    |str              |extension *Optional*                |
|calling_line_id_phone_number |str              |callingLineIdPhoneNumber *Optional* |
|old_password                 |str              |oldPassword *Optional*              |
|new_password                 |str              |newPassword *Optional*              |
|department                   |OCI.department   |department *Optional*               |
|language                     |str              |language *Optional*                 |
|time_zone                    |str              |timeZone *Optional*                 |
|sip_alias_list               |OCI.sipAliasList |sipAliasList *Optional*             |
|endpoint                     |OCI.endpoint     |endpoint *Optional*                 |
|title                        |str              |title *Optional*                    |
|pager_phone_number           |str              |pagerPhoneNumber *Optional*         |
|mobile_phone_number          |str              |mobilePhoneNumber *Optional*        |
|email_address                |str              |emailAddress *Optional*             |
|yahoo_id                     |str              |yahooId *Optional*                  |
|address_location             |str              |addressLocation *Optional*          |
|address                      |OCI.address      |address *Optional*                  |
|network_class_of_service     |str              |networkClassOfService *Optional*    |
|office_zone_name             |str              |officeZoneName *Optional*           |
|primary_zone_name            |str              |primaryZoneName *Optional*          |
</div>


## `UserMusicOnHoldUserModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify data for Music On Hold User.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

Replaced By: `UserMusicOnHoldUserModifyRequest16()`

**Attributes:**

|Name                                    |Type               |Description                                   |
|----------------------------------------|-------------------|----------------------------------------------|
|user_id                                 |str                |userId                                        |
|source                                  |OCI.source         |source *Optional*                             |
|use_alternate_source_for_internal_calls |bool               |useAlternateSourceForInternalCalls *Optional* |
|internal_source                         |OCI.internalSource |internalSource *Optional*                     |
</div>


## `UserMusicOnHoldUserModifyRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify data for Music On Hold User.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`UserMusicOnHoldUserModifyRequest20()` in AS data mode

**Attributes:**

|Name                                    |Type               |Description                                   |
|----------------------------------------|-------------------|----------------------------------------------|
|user_id                                 |str                |userId                                        |
|source                                  |OCI.source         |source *Optional*                             |
|use_alternate_source_for_internal_calls |bool               |useAlternateSourceForInternalCalls *Optional* |
|internal_source                         |OCI.internalSource |internalSource *Optional*                     |
</div>


## `UserMusicOnHoldUserModifyRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify data for Music On Hold User.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                    |Type               |Description                                   |
|----------------------------------------|-------------------|----------------------------------------------|
|user_id                                 |str                |userId                                        |
|source                                  |OCI.source         |source *Optional*                             |
|use_alternate_source_for_internal_calls |bool               |useAlternateSourceForInternalCalls *Optional* |
|internal_source                         |OCI.internalSource |internalSource *Optional*                     |
</div>


## `UserOCICallControlApplicationModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify which OCI Call Control Applications are enabled on a user The response is
either `SuccessResponse()` or `ErrorResponse()`.


**Attributes:**

|Name                |Type                  |Description                  |
|--------------------|----------------------|-----------------------------|
|user_id             |str                   |userId                       |
|application_id_list |OCI.applicationIdList |applicationIdList *Optional* |
</div>


## `UserOutgoingCallingPlanAuthorizationCodeAddListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a list of authorization codes to a user.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name       |Type                |Description|
|-----------|--------------------|-----------|
|user_id    |str                 |userId     |
|code_entry |List[OCI.codeEntry] |codeEntry  |
</div>


## `UserOutgoingCallingPlanCallMeNowModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Call Me Now call permissions for a user.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type                |Description                  |
|--------------------|--------------------|-----------------------------|
|user_id             |str                 |userId                       |
|use_custom_settings |bool                |useCustomSettings *Optional* |
|user_permissions    |OCI.userPermissions |userPermissions *Optional*   |
</div>


## `UserOutgoingCallingPlanOriginatingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the originating permissions for a user.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type                |Description                  |
|--------------------|--------------------|-----------------------------|
|user_id             |str                 |userId                       |
|use_custom_settings |bool                |useCustomSettings *Optional* |
|user_permissions    |OCI.userPermissions |userPermissions *Optional*   |
</div>


## `UserOutgoingCallingPlanRedirectedModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the call forwarded/transferred permissions for a user.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type                |Description                  |
|--------------------|--------------------|-----------------------------|
|user_id             |str                 |userId                       |
|use_custom_settings |bool                |useCustomSettings *Optional* |
|user_permissions    |OCI.userPermissions |userPermissions *Optional*   |
</div>


## `UserOutgoingCallingPlanRedirectingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the initiating call forwards/transfer permissions for a user.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type                |Description                  |
|--------------------|--------------------|-----------------------------|
|user_id             |str                 |userId                       |
|use_custom_settings |bool                |useCustomSettings *Optional* |
|user_permissions    |OCI.userPermissions |userPermissions *Optional*   |
</div>


## `UserOutgoingCallingPlanTransferNumbersModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the transfer numbers for a user.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type            |Description                  |
|--------------------|----------------|-----------------------------|
|user_id             |str             |userId                       |
|use_custom_settings |bool            |useCustomSettings *Optional* |
|user_numbers        |OCI.userNumbers |userNumbers *Optional*       |
</div>


## `UserPersonalPhoneListAddListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add one or more entries to a user's personal phone list.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name    |Type            |Description|
|--------|----------------|-----------|
|user_id |str             |userId     |
|entry   |List[OCI.entry] |entry      |
</div>


## `UserPolycomPhoneServicesGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the user's Polycom Phone Services attributes.

The response is either a `UserPolycomPhoneServicesGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name          |Type             |Description  |
|--------------|-----------------|-------------|
|user_id       |str              |userId       |
|access_device |OCI.accessDevice |accessDevice |
</div>


## `UserPolycomPhoneServicesModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's Polycom Phone Services attributes.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                                |Type             |Description                                              |
|----------------------------------------------------|-----------------|---------------------------------------------------------|
|user_id                                             |str              |userId                                                   |
|access_device                                       |OCI.accessDevice |accessDevice                                             |
|integrate_phone_directory_with_broad_works          |bool             |integratePhoneDirectoryWithBroadWorks *Optional*         |
|include_user_personal_phone_list_in_directory       |bool             |includeUserPersonalPhoneListInDirectory *Optional*       |
|include_group_custom_contact_directory_in_directory |bool             |includeGroupCustomContactDirectoryInDirectory *Optional* |
|group_custom_contact_directory                      |str              |groupCustomContactDirectory *Optional*                   |
</div>


## `UserPreAlertingAnnouncementAddCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a criteria to the user's pre-alerting service.

The following elements are only used in AS data mode: callToNumber For the
callToNumber, the extension element is not used and the number element is only used
when the type is BroadWorks Mobility.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name             |Type                   |Description                |
|-----------------|-----------------------|---------------------------|
|user_id          |str                    |userId                     |
|criteria_name    |str                    |criteriaName               |
|time_schedule    |OCI.timeSchedule       |timeSchedule *Optional*    |
|holiday_schedule |OCI.holidaySchedule    |holidaySchedule *Optional* |
|blacklisted      |bool                   |blacklisted                |
|from_dn_criteria |OCI.fromDnCriteria     |fromDnCriteria             |
|call_to_number   |List[OCI.callToNumber] |callToNumber *Optional*    |
</div>


## `UserPreferredCarrierUserModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the currently configured preferred carriers for a user.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                  |Type                     |Description                     |
|----------------------|-------------------------|--------------------------------|
|user_id               |str                      |userId                          |
|intra_lata_carrier    |OCI.intraLataCarrier     |intraLataCarrier *Optional*     |
|inter_lata_carrier    |OCI.interLataCarrier     |interLataCarrier *Optional*     |
|international_carrier |OCI.internationalCarrier |internationalCarrier *Optional* |
</div>


## `UserPriorityAlertAddCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a criteria to the user's priority alert service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name             |Type               |Description             |
|-----------------|-------------------|------------------------|
|user_id          |str                |userId                  |
|criteria_name    |str                |criteriaName            |
|time_schedule    |OCI.timeSchedule   |timeSchedule *Optional* |
|from_dn_criteria |OCI.fromDnCriteria |fromDnCriteria          |
</div>


## `UserPriorityAlertAddCriteriaRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a criteria to the user's priority alert service.

The following elements are only used in AS data mode: callToNumber For the
callToNumber, the extension element is not used and the number element is only used
when the type is BroadWorks Mobility.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name             |Type                   |Description                |
|-----------------|-----------------------|---------------------------|
|user_id          |str                    |userId                     |
|criteria_name    |str                    |criteriaName               |
|time_schedule    |OCI.timeSchedule       |timeSchedule *Optional*    |
|holiday_schedule |OCI.holidaySchedule    |holidaySchedule *Optional* |
|blacklisted      |bool                   |blacklisted                |
|from_dn_criteria |OCI.fromDnCriteria     |fromDnCriteria             |
|call_to_number   |List[OCI.callToNumber] |callToNumber *Optional*    |
</div>


## `UserPriorityAlertModifyActiveCriteriaListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Activate the user's priority alert criteria list.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type                         |Description                   |
|--------------------|-----------------------------|------------------------------|
|user_id             |str                          |userId                        |
|criteria_activation |List[OCI.criteriaActivation] |criteriaActivation *Optional* |
</div>


## `UserPrivacyModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with Privacy.

This command is supported for regular users only.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                            |Type                           |Description                                           |
|------------------------------------------------|-------------------------------|------------------------------------------------------|
|user_id                                         |str                            |userId                                                |
|enable_directory_privacy                        |bool                           |enableDirectoryPrivacy *Optional*                     |
|enable_auto_attendant_extension_dialing_privacy |bool                           |enableAutoAttendantExtensionDialingPrivacy *Optional* |
|enable_auto_attendant_name_dialing_privacy      |bool                           |enableAutoAttendantNameDialingPrivacy *Optional*      |
|enable_phone_status_privacy                     |bool                           |enablePhoneStatusPrivacy *Optional*                   |
|permitted_monitor_user_id_list                  |OCI.permittedMonitorUserIdList |permittedMonitorUserIdList *Optional*                 |
</div>


## `UserPushToTalkModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Change the push to talk service settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                          |Type                   |Description                            |
|------------------------------|-----------------------|---------------------------------------|
|user_id                       |str                    |userId                                 |
|allow_auto_answer             |bool                   |allowAutoAnswer *Optional*             |
|outgoing_connection_selection |str                    |outgoingConnectionSelection *Optional* |
|access_list_selection         |str                    |accessListSelection *Optional*         |
|selected_user_id_list         |OCI.selectedUserIdList |selectedUserIdList *Optional*          |
</div>


## `UserRouteListModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the route list setting and the list of number ranges and number prefixes
assigned to a user.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                                |Type                             |Description                                              |
|----------------------------------------------------|---------------------------------|---------------------------------------------------------|
|user_id                                             |str                              |userId                                                   |
|treat_originations_and_pbx_redirections_as_screened |bool                             |treatOriginationsAndPBXRedirectionsAsScreened *Optional* |
|use_route_list_identity_for_non_emergency_calls     |bool                             |useRouteListIdentityForNonEmergencyCalls *Optional*      |
|use_route_list_identity_for_emergency_calls         |bool                             |useRouteListIdentityForEmergencyCalls *Optional*         |
|assigned_number_range_start_list                    |OCI.assignedNumberRangeStartList |assignedNumberRangeStartList *Optional*                  |
|assigned_number_prefix_list                         |OCI.assignedNumberPrefixList     |assignedNumberPrefixList *Optional*                      |
</div>


## `UserRoutePointSupervisorModifyListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the Route Point supervisor list for a user.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                    |Type                     |Description                     |
|------------------------|-------------------------|--------------------------------|
|user_id                 |str                      |userId                          |
|supervisor_user_id_list |OCI.supervisorUserIdList |supervisorUserIdList *Optional* |
</div>


## `UserScheduleAddEventRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add an event to user schedule.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The startDate
element is adjusted to the first occurrence of the recurrent schedule that comes at or
after the startDate.  The endDate element is set to the sum of the adjusted starDate
element value and the event duration.

**Attributes:**

|Name          |Type            |Description            |
|--------------|----------------|-----------------------|
|user_id       |str             |userId                 |
|schedule_key  |OCI.scheduleKey |scheduleKey            |
|event_name    |str             |eventName              |
|start_date    |str             |startDate              |
|all_day_event |bool            |allDayEvent *Optional* |
|start_time    |OCI.startTime   |startTime *Optional*   |
|end_time      |OCI.endTime     |endTime *Optional*     |
|end_date      |str             |endDate                |
|recurrence    |OCI.recurrence  |recurrence *Optional*  |
</div>


## `UserScheduleDeleteEventListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a list of events from a user schedule.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type            |Description |
|-------------|----------------|------------|
|user_id      |str             |userId      |
|schedule_key |OCI.scheduleKey |scheduleKey |
|event_name   |List[str]       |eventName   |
</div>


## `UserScheduleDeleteListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Delete a list of user schedule.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type                  |Description |
|-------------|----------------------|------------|
|user_id      |str                   |userId      |
|schedule_key |List[OCI.scheduleKey] |scheduleKey |
</div>


## `UserScheduleGetEventListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of events of a user schedule.

The response is either a `UserScheduleGetEventListResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type            |Description |
|-------------|----------------|------------|
|user_id      |str             |userId      |
|schedule_key |OCI.scheduleKey |scheduleKey |
</div>


## `UserScheduleGetEventRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get an event from a user schedule.

The response is either a `UserScheduleGetEventResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name         |Type            |Description |
|-------------|----------------|------------|
|user_id      |str             |userId      |
|schedule_key |OCI.scheduleKey |scheduleKey |
|event_name   |str             |eventName   |
</div>


## `UserScheduleModifyEventRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an event of a user schedule.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The startDate
element is adjusted to the first occurrence of the recurrent schedule that comes at or
after the startDate.  The endDate element is set to the sum of the adjusted starDate
element value and the event duration.

**Attributes:**

|Name           |Type            |Description             |
|---------------|----------------|------------------------|
|user_id        |str             |userId                  |
|schedule_key   |OCI.scheduleKey |scheduleKey             |
|event_name     |str             |eventName               |
|new_event_name |str             |newEventName *Optional* |
|start_date     |str             |startDate *Optional*    |
|all_day_event  |bool            |allDayEvent *Optional*  |
|start_time     |OCI.startTime   |startTime *Optional*    |
|end_time       |OCI.endTime     |endTime *Optional*      |
|end_date       |str             |endDate *Optional*      |
|recurrence     |OCI.recurrence  |recurrence *Optional*   |
</div>


## `UserScheduleModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a user schedule.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name              |Type            |Description                |
|------------------|----------------|---------------------------|
|user_id           |str             |userId                     |
|schedule_key      |OCI.scheduleKey |scheduleKey                |
|new_schedule_name |str             |newScheduleName *Optional* |
</div>


## `UserSelectiveCallAcceptanceAddCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a criteria to the user's selective call acceptance service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name             |Type               |Description             |
|-----------------|-------------------|------------------------|
|user_id          |str                |userId                  |
|criteria_name    |str                |criteriaName            |
|time_schedule    |OCI.timeSchedule   |timeSchedule *Optional* |
|from_dn_criteria |OCI.fromDnCriteria |fromDnCriteria          |
</div>


## `UserSelectiveCallAcceptanceAddCriteriaRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a criteria to the user's selective call acceptance service.

The following elements are only used in AS data mode: callToNumber For the
callToNumber, the extension element is not used and the number element is only used
when the type is BroadWorks Mobility.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name             |Type                   |Description                |
|-----------------|-----------------------|---------------------------|
|user_id          |str                    |userId                     |
|criteria_name    |str                    |criteriaName               |
|time_schedule    |OCI.timeSchedule       |timeSchedule *Optional*    |
|holiday_schedule |OCI.holidaySchedule    |holidaySchedule *Optional* |
|blacklisted      |bool                   |blacklisted                |
|from_dn_criteria |OCI.fromDnCriteria     |fromDnCriteria             |
|call_to_number   |List[OCI.callToNumber] |callToNumber *Optional*    |
</div>


## `UserSelectiveCallAcceptanceModifyActiveCriteriaListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Activate the user's selective call acceptance criteria list.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type                         |Description                   |
|--------------------|-----------------------------|------------------------------|
|user_id             |str                          |userId                        |
|criteria_activation |List[OCI.criteriaActivation] |criteriaActivation *Optional* |
</div>


## `UserSelectiveCallRejectionAddCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a criteria to the user's selective call rejection service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name             |Type               |Description             |
|-----------------|-------------------|------------------------|
|user_id          |str                |userId                  |
|criteria_name    |str                |criteriaName            |
|time_schedule    |OCI.timeSchedule   |timeSchedule *Optional* |
|from_dn_criteria |OCI.fromDnCriteria |fromDnCriteria          |
</div>


## `UserSelectiveCallRejectionAddCriteriaRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a criteria to the user's selective call rejection service.

The following elements are only used in AS data mode: callToNumber For the
callToNumber, the extension element is not used and the number element is only used
when the type is BroadWorks Mobility.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name             |Type                   |Description                |
|-----------------|-----------------------|---------------------------|
|user_id          |str                    |userId                     |
|criteria_name    |str                    |criteriaName               |
|time_schedule    |OCI.timeSchedule       |timeSchedule *Optional*    |
|from_dn_criteria |OCI.fromDnCriteria     |fromDnCriteria             |
|holiday_schedule |OCI.holidaySchedule    |holidaySchedule *Optional* |
|blacklisted      |bool                   |blacklisted                |
|call_to_number   |List[OCI.callToNumber] |callToNumber *Optional*    |
</div>


## `UserSelectiveCallRejectionModifyActiveCriteriaListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Activate the user's selective call rejection criteria list.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type                         |Description                   |
|--------------------|-----------------------------|------------------------------|
|user_id             |str                          |userId                        |
|criteria_activation |List[OCI.criteriaActivation] |criteriaActivation *Optional* |
</div>


## `UserSequentialRingAddCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a criteria to the user's sequential ring service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name             |Type               |Description             |
|-----------------|-------------------|------------------------|
|user_id          |str                |userId                  |
|criteria_name    |str                |criteriaName            |
|time_schedule    |OCI.timeSchedule   |timeSchedule *Optional* |
|from_dn_criteria |OCI.fromDnCriteria |fromDnCriteria          |
</div>


## `UserSequentialRingAddCriteriaRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a criteria to the user's sequential ring service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name             |Type                |Description                |
|-----------------|--------------------|---------------------------|
|user_id          |str                 |userId                     |
|criteria_name    |str                 |criteriaName               |
|time_schedule    |OCI.timeSchedule    |timeSchedule *Optional*    |
|holiday_schedule |OCI.holidaySchedule |holidaySchedule *Optional* |
|blacklisted      |bool                |blacklisted                |
|from_dn_criteria |OCI.fromDnCriteria  |fromDnCriteria             |
</div>


## `UserSequentialRingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's sequential ring service setting.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                              |Type                         |Description                             |
|----------------------------------|-----------------------------|----------------------------------------|
|user_id                           |str                          |userId                                  |
|ring_base_location_first          |bool                         |ringBaseLocationFirst *Optional*        |
|base_location_number_of_rings     |int                          |baseLocationNumberOfRings *Optional*    |
|continue_if_base_location_is_busy |bool                         |continueIfBaseLocationIsBusy *Optional* |
|caller_may_stop_search            |bool                         |callerMayStopSearch *Optional*          |
|location01                        |OCI.Location01               |Location01 *Optional*                   |
|location02                        |OCI.Location02               |Location02 *Optional*                   |
|location03                        |OCI.Location03               |Location03 *Optional*                   |
|location04                        |OCI.Location04               |Location04 *Optional*                   |
|location05                        |OCI.Location05               |Location05 *Optional*                   |
|criteria_activation               |List[OCI.criteriaActivation] |criteriaActivation *Optional*           |
</div>


## `UserShInterfaceGetPublicIdDataRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Returns the Sh non-transparent data stored against a Public User Identity (a SIP URI
or TEL URI).

The response is either a `UserShInterfaceGetPublicIdDataResponse()` or an
`ErrorResponse()`. Replaced by: `UserShInterfaceGetPublicIdDataRequest21sp1()`.

**Attributes:**

|Name                 |Type                   |Description        |
|---------------------|-----------------------|-------------------|
|public_user_identity |OCI.publicUserIdentity |publicUserIdentity |
</div>


## `UserShInterfaceGetPublicIdDataRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Returns the Sh non-transparent data stored against a Public User Identity (a SIP URI
or TEL URI).

The response is either a `UserShInterfaceGetPublicIdDataResponse21sp1()` or an
`ErrorResponse()`.

**Attributes:**

|Name                 |Type                   |Description        |
|---------------------|-----------------------|-------------------|
|public_user_identity |OCI.publicUserIdentity |publicUserIdentity |
</div>


## `UserShInterfaceModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the Sh Interface non-transparent data associated with a Public User Identity.

The response is a `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                 |Type                   |Description             |
|---------------------|-----------------------|------------------------|
|public_user_identity |OCI.publicUserIdentity |publicUserIdentity      |
|scscf_name           |str                    |SCSCFName *Optional*    |
|ims_user_state       |str                    |IMSUserState *Optional* |
</div>


## `UserShInterfacePublicIdentityRefreshTaskStartRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Dispatches a Public Identity refresh task on the local Application Server node for the
specified public identity.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                 |Type                   |Description        |
|---------------------|-----------------------|-------------------|
|public_user_identity |OCI.publicUserIdentity |publicUserIdentity |
</div>


## `UserSimultaneousRingFamilyAddCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a criteria to the user's simultaneous ring family service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name             |Type                |Description                |
|-----------------|--------------------|---------------------------|
|user_id          |str                 |userId                     |
|criteria_name    |str                 |criteriaName               |
|time_schedule    |OCI.timeSchedule    |timeSchedule *Optional*    |
|holiday_schedule |OCI.holidaySchedule |holidaySchedule *Optional* |
|blacklisted      |bool                |blacklisted                |
|from_dn_criteria |OCI.fromDnCriteria  |fromDnCriteria             |
</div>


## `UserSimultaneousRingFamilyModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's simultaneous ring family service setting.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

Replaced By: `UserSimultaneousRingFamilyModifyRequest14sp4()`

**Attributes:**

|Name                       |Type                       |Description                       |
|---------------------------|---------------------------|----------------------------------|
|user_id                    |str                        |userId                            |
|is_active                  |bool                       |isActive *Optional*               |
|incoming_calls             |str                        |incomingCalls *Optional*          |
|sim_ring_phone_number_list |OCI.simRingPhoneNumberList |simRingPhoneNumberList *Optional* |
</div>


## `UserSimultaneousRingPersonalAddCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a criteria to the user's simultaneous ring personal service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name             |Type                |Description                |
|-----------------|--------------------|---------------------------|
|user_id          |str                 |userId                     |
|criteria_name    |str                 |criteriaName               |
|time_schedule    |OCI.timeSchedule    |timeSchedule *Optional*    |
|holiday_schedule |OCI.holidaySchedule |holidaySchedule *Optional* |
|blacklisted      |bool                |blacklisted                |
|from_dn_criteria |OCI.fromDnCriteria  |fromDnCriteria             |
</div>


## `UserSimultaneousRingPersonalModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's simultaneous ring personal service setting.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

Replaced By: `UserSimultaneousRingPersonalModifyRequest14sp4()`

**Attributes:**

|Name                       |Type                       |Description                       |
|---------------------------|---------------------------|----------------------------------|
|user_id                    |str                        |userId                            |
|is_active                  |bool                       |isActive *Optional*               |
|incoming_calls             |str                        |incomingCalls *Optional*          |
|sim_ring_phone_number_list |OCI.simRingPhoneNumberList |simRingPhoneNumberList *Optional* |
</div>


## `UserSpeedDial100AddListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add one or more speed dial 100 settings for a user.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name             |Type                     |Description    |
|-----------------|-------------------------|---------------|
|user_id          |str                      |userId         |
|speed_dial_entry |List[OCI.speedDialEntry] |speedDialEntry |
</div>


## `UserSpeedDial100ModifyListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the speed dial 100 settings for a user.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Engineering
Note: This command is used internally by Call Processing.

**Attributes:**

|Name             |Type                     |Description               |
|-----------------|-------------------------|--------------------------|
|user_id          |str                      |userId                    |
|speed_dial_entry |List[OCI.speedDialEntry] |speedDialEntry *Optional* |
</div>


## `UserSpeedDial8ModifyListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the speed dial 8 settings for a user.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Engineering
Note: This command is used internally by Call Processing.

**Attributes:**

|Name             |Type                     |Description               |
|-----------------|-------------------------|--------------------------|
|user_id          |str                      |userId                    |
|speed_dial_entry |List[OCI.speedDialEntry] |speedDialEntry *Optional* |
</div>


## `UserTimeScheduleAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a time schedule for a user.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name               |Type               |Description               |
|-------------------|-------------------|--------------------------|
|user_id            |str                |userId                    |
|time_schedule_name |str                |timeScheduleName          |
|time_interval01    |OCI.timeInterval01 |timeInterval01 *Optional* |
|time_interval02    |OCI.timeInterval02 |timeInterval02 *Optional* |
|time_interval03    |OCI.timeInterval03 |timeInterval03 *Optional* |
|time_interval04    |OCI.timeInterval04 |timeInterval04 *Optional* |
|time_interval05    |OCI.timeInterval05 |timeInterval05 *Optional* |
|time_interval06    |OCI.timeInterval06 |timeInterval06 *Optional* |
|time_interval07    |OCI.timeInterval07 |timeInterval07 *Optional* |
|time_interval08    |OCI.timeInterval08 |timeInterval08 *Optional* |
|time_interval09    |OCI.timeInterval09 |timeInterval09 *Optional* |
|time_interval10    |OCI.timeInterval10 |timeInterval10 *Optional* |
|time_interval11    |OCI.timeInterval11 |timeInterval11 *Optional* |
|time_interval12    |OCI.timeInterval12 |timeInterval12 *Optional* |
|time_interval13    |OCI.timeInterval13 |timeInterval13 *Optional* |
|time_interval14    |OCI.timeInterval14 |timeInterval14 *Optional* |
|time_interval15    |OCI.timeInterval15 |timeInterval15 *Optional* |
|time_interval16    |OCI.timeInterval16 |timeInterval16 *Optional* |
|time_interval17    |OCI.timeInterval17 |timeInterval17 *Optional* |
|time_interval18    |OCI.timeInterval18 |timeInterval18 *Optional* |
|time_interval19    |OCI.timeInterval19 |timeInterval19 *Optional* |
|time_interval20    |OCI.timeInterval20 |timeInterval20 *Optional* |
</div>


## `UserTimeScheduleModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a user time schedule.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type               |Description                    |
|-----------------------|-------------------|-------------------------------|
|user_id                |str                |userId                         |
|time_schedule_name     |str                |timeScheduleName               |
|new_time_schedule_name |str                |newTimeScheduleName *Optional* |
|time_interval01        |OCI.timeInterval01 |timeInterval01 *Optional*      |
|time_interval02        |OCI.timeInterval02 |timeInterval02 *Optional*      |
|time_interval03        |OCI.timeInterval03 |timeInterval03 *Optional*      |
|time_interval04        |OCI.timeInterval04 |timeInterval04 *Optional*      |
|time_interval05        |OCI.timeInterval05 |timeInterval05 *Optional*      |
|time_interval06        |OCI.timeInterval06 |timeInterval06 *Optional*      |
|time_interval07        |OCI.timeInterval07 |timeInterval07 *Optional*      |
|time_interval08        |OCI.timeInterval08 |timeInterval08 *Optional*      |
|time_interval09        |OCI.timeInterval09 |timeInterval09 *Optional*      |
|time_interval10        |OCI.timeInterval10 |timeInterval10 *Optional*      |
|time_interval11        |OCI.timeInterval11 |timeInterval11 *Optional*      |
|time_interval12        |OCI.timeInterval12 |timeInterval12 *Optional*      |
|time_interval13        |OCI.timeInterval13 |timeInterval13 *Optional*      |
|time_interval14        |OCI.timeInterval14 |timeInterval14 *Optional*      |
|time_interval15        |OCI.timeInterval15 |timeInterval15 *Optional*      |
|time_interval16        |OCI.timeInterval16 |timeInterval16 *Optional*      |
|time_interval17        |OCI.timeInterval17 |timeInterval17 *Optional*      |
|time_interval18        |OCI.timeInterval18 |timeInterval18 *Optional*      |
|time_interval19        |OCI.timeInterval19 |timeInterval19 *Optional*      |
|time_interval20        |OCI.timeInterval20 |timeInterval20 *Optional*      |
</div>


## `UserVoiceMessagingUserModifyDistributionListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a voice mail distribution list for a users voice message.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name              |Type                |Description                |
|------------------|--------------------|---------------------------|
|user_id           |str                 |userId                     |
|list_id           |int                 |listId                     |
|description       |str                 |description *Optional*     |
|phone_number_list |OCI.phoneNumberList |phoneNumberList *Optional* |
</div>


## `UserVoiceMessagingUserModifyOutgoingSMDIMWIRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's voice messaging outgoing message waiting indicator service setting.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                               |Type                               |Description                               |
|-----------------------------------|-----------------------------------|------------------------------------------|
|user_id                            |str                                |userId                                    |
|is_active                          |bool                               |isActive *Optional*                       |
|outgoing_smdimwi_phone_number_list |OCI.outgoingSMDIMWIPhoneNumberList |outgoingSMDIMWIPhoneNumberList *Optional* |
</div>


## `UserVoiceMessagingUserModifyVoicePortalRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's voice messaging voice portal settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Engineering
Note: This command is used internally by Call Processing.

Replaced By: `UserVoiceMessagingUserModifyVoicePortalRequest16()`

**Attributes:**

|Name                         |Type                          |Description                          |
|-----------------------------|------------------------------|-------------------------------------|
|user_id                      |str                           |userId                               |
|use_personalized_name        |bool                          |usePersonalizedName *Optional*       |
|voice_portal_auto_login      |bool                          |voicePortalAutoLogin *Optional*      |
|personalized_name_audio_file |OCI.personalizedNameAudioFile |personalizedNameAudioFile *Optional* |
</div>


## `UserVoiceMessagingUserModifyVoicePortalRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's voice messaging voice portal settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Engineering
Note: This command is used internally by Call Processing.

**Attributes:**

|Name                         |Type                          |Description                          |
|-----------------------------|------------------------------|-------------------------------------|
|user_id                      |str                           |userId                               |
|use_personalized_name        |bool                          |usePersonalizedName *Optional*       |
|voice_portal_auto_login      |bool                          |voicePortalAutoLogin *Optional*      |
|personalized_name_audio_file |OCI.personalizedNameAudioFile |personalizedNameAudioFile *Optional* |
</div>


## `UserVoiceMessagingUserModifyVoicePortalRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's voice messaging voice portal settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Engineering
Note: This command is used internally by Call Processing.

**Attributes:**

|Name                         |Type                          |Description                          |
|-----------------------------|------------------------------|-------------------------------------|
|user_id                      |str                           |userId                               |
|use_personalized_name        |bool                          |usePersonalizedName *Optional*       |
|voice_portal_auto_login      |bool                          |voicePortalAutoLogin *Optional*      |
|personalized_name_audio_file |OCI.personalizedNameAudioFile |personalizedNameAudioFile *Optional* |
</div>


## `UserXsiPolicyProfileModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modifies the default Xsi policy profile for a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name               |Type                 |Description                 |
|-------------------|---------------------|----------------------------|
|user_id            |str                  |userId                      |
|xsi_policy_profile |OCI.xsiPolicyProfile |xsiPolicyProfile *Optional* |
</div>


## `EnterpriseBroadWorksMobilityMobileSubscriberDirectoryNumberGetAssignmentListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a summary table of all Mobile Subscriber Directory Numbers in an enterprise.

The response is either
`EnterpriseBroadWorksMobilityMobileSubscriberDirectoryNumberGetAssignmentListResponse()`
or `ErrorResponse()`.

**Attributes:**

|Name                                               |Type                                                    |Description                                              |
|---------------------------------------------------|--------------------------------------------------------|---------------------------------------------------------|
|service_provider_id                                |str                                                     |serviceProviderId                                        |
|response_size_limit                                |int                                                     |responseSizeLimit *Optional*                             |
|search_criteria_mobile_subscriber_directory_number |List[OCI.searchCriteriaMobileSubscriberDirectoryNumber] |searchCriteriaMobileSubscriberDirectoryNumber *Optional* |
|search_criteria_exact_user_group                   |OCI.searchCriteriaExactUserGroup                        |searchCriteriaExactUserGroup *Optional*                  |
|search_criteria_user_id                            |List[OCI.searchCriteriaUserId]                          |searchCriteriaUserId *Optional*                          |
|search_criteria_user_last_name                     |List[OCI.searchCriteriaUserLastName]                    |searchCriteriaUserLastName *Optional*                    |
|search_criteria_user_first_name                    |List[OCI.searchCriteriaUserFirstName]                   |searchCriteriaUserFirstName *Optional*                   |
|search_criteria_dn                                 |List[OCI.searchCriteriaDn]                              |searchCriteriaDn *Optional*                              |
|search_criteria_extension                          |List[OCI.searchCriteriaExtension]                       |searchCriteriaExtension *Optional*                       |
|search_criteria_exact_user_department              |OCI.searchCriteriaExactUserDepartment                   |searchCriteriaExactUserDepartment *Optional*             |
|search_criteria_exact_mobile_network               |OCI.searchCriteriaExactMobileNetwork                    |searchCriteriaExactMobileNetwork *Optional*              |
</div>


## `EnterpriseBroadWorksMobilityMobileSubscriberDirectoryNumberGetAvailablePagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a list of available Mobile Subscriber Directory Numbers not yet assigned to
any user.

If the responsePagingControl element is not provided, the paging startIndex will be
set to 1 by default, and the responsePageSize will be set to the maximum
ResponsePageSize by default.  If no sortOrder is included the response is sorted by
Mobile Number ascending by default.  Multiple search criteria are logically ANDed
together unless the searchCriteriaModeOr option is included.  Then the search criteria
are logically ORed together.

The response is either
`EnterpriseBroadWorksMobilityMobileSubscriberDirectoryNumberGetAvailablePagedSortedListResponse()`
or `ErrorResponse()`. Replaced by:
`EnterpriseBroadWorksMobilityMobileSubscriberDirectoryNumberGetAvailablePagedSortedListRequest22()`

**Attributes:**

|Name                                               |Type                                                    |Description                                              |
|---------------------------------------------------|--------------------------------------------------------|---------------------------------------------------------|
|service_provider_id                                |str                                                     |serviceProviderId                                        |
|response_paging_control                            |OCI.responsePagingControl                               |responsePagingControl *Optional*                         |
|sort_by_mobile_directory_number                    |OCI.sortByMobileDirectoryNumber                         |sortByMobileDirectoryNumber *Optional*                   |
|search_criteria_mobile_subscriber_directory_number |List[OCI.searchCriteriaMobileSubscriberDirectoryNumber] |searchCriteriaMobileSubscriberDirectoryNumber *Optional* |
|search_criteria_mode_or                            |bool                                                    |searchCriteriaModeOr *Optional*                          |
</div>


## `EnterpriseBroadWorksMobilityMobileSubscriberDirectoryNumberGetAvailablePagedSortedListRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a list of available Mobile Subscriber Directory Numbers not yet assigned to
any user.

If the responsePagingControl element is not provided, the paging startIndex will be
set to 1 by default, and the responsePageSize will be set to the maximum
ResponsePageSize by default.  If no sortOrder is included the response is sorted by
Mobile Number ascending by default.  Multiple search criteria are logically ANDed
together unless the searchCriteriaModeOr option is included.  Then the search criteria
are logically ORed together.

The response is either
`EnterpriseBroadWorksMobilityMobileSubscriberDirectoryNumberGetAvailablePagedSortedListResponse22()`
or `ErrorResponse()`.

**Attributes:**

|Name                                               |Type                                                    |Description                                              |
|---------------------------------------------------|--------------------------------------------------------|---------------------------------------------------------|
|service_provider_id                                |str                                                     |serviceProviderId                                        |
|include_total_number_of_rows                       |bool                                                    |includeTotalNumberOfRows *Optional*                      |
|response_paging_control                            |OCI.responsePagingControl                               |responsePagingControl *Optional*                         |
|sort_by_mobile_directory_number                    |OCI.sortByMobileDirectoryNumber                         |sortByMobileDirectoryNumber *Optional*                   |
|search_criteria_mobile_subscriber_directory_number |List[OCI.searchCriteriaMobileSubscriberDirectoryNumber] |searchCriteriaMobileSubscriberDirectoryNumber *Optional* |
|search_criteria_mode_or                            |bool                                                    |searchCriteriaModeOr *Optional*                          |
</div>


## `EnterpriseCallCenterAgentThresholdDefaultProfileGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Gets an existing default Call Center Agent Threshold Profile in an Enterprise.

If includeAgentsTable is set to true, a table with the list of agents assigned to the
profile is included in the response.  The search criteria is used to filter the list
of agents to be included in the table.

The response is either a
`EnterpriseCallCenterAgentThresholdDefaultProfileGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|service_provider_id                   |str                                   |serviceProviderId                            |
|include_agents_table                  |bool                                  |includeAgentsTable                           |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_exact_user_group      |OCI.searchCriteriaExactUserGroup      |searchCriteriaExactUserGroup *Optional*      |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*              |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                  |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*           |
</div>


## `EnterpriseCallCenterAgentThresholdProfileGetAvailableAgentListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of all Agents in the Enterprise that can be assigned to a given Call
Center Agent Threshold Profile in an Enterprise.

An agent is available to be assigned to a given Agent Threshold Profile if it is a
Call Center Standard or Call Center Premium agent and the agent is not yet assigned to
the profile.  The available agent list for a new Call Center Agent Threshold profile
can be obtained by not setting the excludeAgentsAssignedToProfileName.  When the
excludeAgentsAssignedToProfileName is specified, all agents already assigned to the
specified profile are not included in the response, even if the search criterion
element searchCriteriaAgentThresholdProfile is specified using the same profile name.

The response is either a
`EnterpriseCallCenterAgentThresholdProfileGetAvailableAgentListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                    |Type                                          |Description                                    |
|----------------------------------------|----------------------------------------------|-----------------------------------------------|
|service_provider_id                     |str                                           |serviceProviderId                              |
|exclude_agents_assigned_to_profile_name |str                                           |excludeAgentsAssignedToProfileName *Optional*  |
|response_size_limit                     |int                                           |responseSizeLimit *Optional*                   |
|search_criteria_user_last_name          |List[OCI.searchCriteriaUserLastName]          |searchCriteriaUserLastName *Optional*          |
|search_criteria_user_first_name         |List[OCI.searchCriteriaUserFirstName]         |searchCriteriaUserFirstName *Optional*         |
|search_criteria_exact_user_department   |OCI.searchCriteriaExactUserDepartment         |searchCriteriaExactUserDepartment *Optional*   |
|search_criteria_exact_user_group        |OCI.searchCriteriaExactUserGroup              |searchCriteriaExactUserGroup *Optional*        |
|search_criteria_user_id                 |List[OCI.searchCriteriaUserId]                |searchCriteriaUserId *Optional*                |
|search_criteria_dn                      |List[OCI.searchCriteriaDn]                    |searchCriteriaDn *Optional*                    |
|search_criteria_extension               |List[OCI.searchCriteriaExtension]             |searchCriteriaExtension *Optional*             |
|search_criteria_agent_threshold_profile |List[OCI.searchCriteriaAgentThresholdProfile] |searchCriteriaAgentThresholdProfile *Optional* |
</div>


## `EnterpriseCallCenterCurrentAndPastAgentGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to all the current and past agents in the enterprise.

The searchCriteriaExactUserGroup does not apply to past agents.

The response is either `EnterpriseCallCenterCurrentAndPastAgentGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                             |Type                                  |Description                             |
|---------------------------------|--------------------------------------|----------------------------------------|
|service_provider_id              |str                                   |serviceProviderId                       |
|response_size_limit              |int                                   |responseSizeLimit *Optional*            |
|search_criteria_user_last_name   |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*   |
|search_criteria_user_first_name  |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*  |
|search_criteria_exact_user_group |OCI.searchCriteriaExactUserGroup      |searchCriteriaExactUserGroup *Optional* |
|search_criteria_user_id          |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*         |
|search_criteria_dn               |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*             |
|search_criteria_extension        |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*      |
</div>


## `EnterpriseCallCenterCurrentAndPastCallCenterGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the current and past call centers for the enterprise.

The searchCriteriaExactUserGroup does not apply to past call centers.

The response is either `EnterpriseCallCenterCurrentAndPastCallCenterGetListResponse()`
or `ErrorResponse()`.

**Attributes:**

|Name                             |Type                             |Description                             |
|---------------------------------|---------------------------------|----------------------------------------|
|service_provider_id              |str                              |serviceProviderId                       |
|is_premium_only                  |bool                             |isPremiumOnly *Optional*                |
|response_size_limit              |int                              |responseSizeLimit *Optional*            |
|search_criteria_exact_user_group |OCI.searchCriteriaExactUserGroup |searchCriteriaExactUserGroup *Optional* |
|search_criteria_call_center_name |OCI.searchCriteriaCallCenterName |searchCriteriaCallCenterName *Optional* |
</div>


## `EnterpriseCallCenterEnhancedReportingScheduledReportGetActiveListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a list of active enterprise level call center reporting scheduled
reports.

The response is either an
`EnterpriseCallCenterEnhancedReportingScheduledReportGetActiveListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                                                     |Type                                                                |Description                                                                |
|-------------------------------------------------------------------------|--------------------------------------------------------------------|---------------------------------------------------------------------------|
|service_provider_id                                                      |str                                                                 |serviceProviderId                                                          |
|response_size_limit                                                      |int                                                                 |responseSizeLimit *Optional*                                               |
|search_criteria_call_center_scheduled_report_name                        |List[OCI.searchCriteriaCallCenterScheduledReportName]               |searchCriteriaCallCenterScheduledReportName *Optional*                     |
|search_criteria_exact_call_center_scheduled_report_created_by_supervisor |OCI.searchCriteriaExactCallCenterScheduledReportCreatedBySupervisor |searchCriteriaExactCallCenterScheduledReportCreatedBySupervisor *Optional* |
|search_criteria_exact_call_center_report_template_key                    |OCI.searchCriteriaExactCallCenterReportTemplateKey                  |searchCriteriaExactCallCenterReportTemplateKey *Optional*                  |
</div>


## `EnterpriseCallCenterEnhancedReportingScheduledReportGetCompletedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a list of completed enterprise level call center reporting scheduled
reports.

The response is either an
`EnterpriseCallCenterEnhancedReportingScheduledReportGetCompletedListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                                                     |Type                                                                |Description                                                                |
|-------------------------------------------------------------------------|--------------------------------------------------------------------|---------------------------------------------------------------------------|
|service_provider_id                                                      |str                                                                 |serviceProviderId                                                          |
|response_size_limit                                                      |int                                                                 |responseSizeLimit *Optional*                                               |
|search_criteria_call_center_scheduled_report_name                        |List[OCI.searchCriteriaCallCenterScheduledReportName]               |searchCriteriaCallCenterScheduledReportName *Optional*                     |
|search_criteria_exact_call_center_scheduled_report_created_by_supervisor |OCI.searchCriteriaExactCallCenterScheduledReportCreatedBySupervisor |searchCriteriaExactCallCenterScheduledReportCreatedBySupervisor *Optional* |
|search_criteria_exact_call_center_report_template_key                    |OCI.searchCriteriaExactCallCenterReportTemplateKey                  |searchCriteriaExactCallCenterReportTemplateKey *Optional*                  |
</div>


## `EnterpriseCallCenterEnhancedReportingScheduledReportGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a list of enterprise level call center reporting scheduled reports.

The response is either an
`EnterpriseCallCenterEnhancedReportingScheduledReportGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                                                     |Type                                                                |Description                                                                |
|-------------------------------------------------------------------------|--------------------------------------------------------------------|---------------------------------------------------------------------------|
|service_provider_id                                                      |str                                                                 |serviceProviderId                                                          |
|response_size_limit                                                      |int                                                                 |responseSizeLimit *Optional*                                               |
|search_criteria_call_center_scheduled_report_name                        |List[OCI.searchCriteriaCallCenterScheduledReportName]               |searchCriteriaCallCenterScheduledReportName *Optional*                     |
|search_criteria_exact_call_center_scheduled_report_created_by_supervisor |OCI.searchCriteriaExactCallCenterScheduledReportCreatedBySupervisor |searchCriteriaExactCallCenterScheduledReportCreatedBySupervisor *Optional* |
|search_criteria_exact_call_center_report_template_key                    |OCI.searchCriteriaExactCallCenterReportTemplateKey                  |searchCriteriaExactCallCenterReportTemplateKey *Optional*                  |
</div>


## `EnterpriseCommonPhoneListGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get an enterprise's common phone list.

The response is either a `EnterpriseCommonPhoneListGetListResponse()` or an
`ErrorResponse()`. The search can be done using multiple criterion.  If the
searchCriteriaModeOr is present, any result matching any one criteria is included in
the results.  Otherwise, only results matching all the search criterion are included
in the results.  If no search criteria is specified, all results are returned.
Specifying searchCriteriaModeOr without any search criteria results in an
`ErrorResponse()`. In all cases, if a responseSizeLimit is specified and the number of
matching results is more than this limit, then an `ErrorResponse()` is returned.

**Attributes:**

|Name                                                |Type                                                    |Description                                              |
|----------------------------------------------------|--------------------------------------------------------|---------------------------------------------------------|
|service_provider_id                                 |str                                                     |serviceProviderId                                        |
|response_size_limit                                 |int                                                     |responseSizeLimit *Optional*                             |
|search_criteria_mode_or                             |bool                                                    |searchCriteriaModeOr *Optional*                          |
|search_criteria_enterprise_common_phone_list_name   |List[OCI.searchCriteriaEnterpriseCommonPhoneListName]   |searchCriteriaEnterpriseCommonPhoneListName *Optional*   |
|search_criteria_enterprise_common_phone_list_number |List[OCI.searchCriteriaEnterpriseCommonPhoneListNumber] |searchCriteriaEnterpriseCommonPhoneListNumber *Optional* |
</div>


## `EnterpriseCommunicationBarringAuthorizationCodeGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of Communication Barring Authorization Codes in an enterprise.

The response is either
`EnterpriseCommunicationBarringAuthorizationCodeGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                                                                 |Type                                                                     |Description                                                               |
|---------------------------------------------------------------------|-------------------------------------------------------------------------|--------------------------------------------------------------------------|
|service_provider_id                                                  |str                                                                      |serviceProviderId                                                         |
|response_size_limit                                                  |int                                                                      |responseSizeLimit *Optional*                                              |
|search_criteria_communication_barring_authorization_code             |List[OCI.searchCriteriaCommunicationBarringAuthorizationCode]            |searchCriteriaCommunicationBarringAuthorizationCode *Optional*            |
|search_criteria_communication_barring_authorization_code_description |List[OCI.searchCriteriaCommunicationBarringAuthorizationCodeDescription] |searchCriteriaCommunicationBarringAuthorizationCodeDescription *Optional* |
|search_criteria_network_class_of_service_name                        |List[OCI.searchCriteriaNetworkClassOfServiceName]                        |searchCriteriaNetworkClassOfServiceName *Optional*                        |
</div>


## `EnterpriseDepartmentAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a department to enterprise.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                  |Type                    |Description                    |
|----------------------|------------------------|-------------------------------|
|enterprise_id         |str                     |enterpriseId                   |
|department_name       |str                     |departmentName                 |
|parent_department_key |OCI.parentDepartmentKey |parentDepartmentKey *Optional* |
</div>


## `EnterpriseDepartmentModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a department of an enterprise.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                      |Type                       |Description                       |
|--------------------------|---------------------------|----------------------------------|
|enterprise_id             |str                        |enterpriseId                      |
|department_name           |str                        |departmentName                    |
|new_department_name       |str                        |newDepartmentName *Optional*      |
|new_parent_department_key |OCI.newParentDepartmentKey |newParentDepartmentKey *Optional* |
</div>


## `EnterpriseEnterpriseTrunkGetAvailableTrunkGroupListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of all available trunk groups defined in an enterprise.

It is possible to search by various criteria to restrict the number of rows returned.
Multiple search criteria are logically ANDed together.

The response is either a
`EnterpriseEnterpriseTrunkGetAvailableTrunkGroupListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                             |Type                                   |Description                             |
|---------------------------------|---------------------------------------|----------------------------------------|
|service_provider_id              |str                                    |serviceProviderId                       |
|response_size_limit              |int                                    |responseSizeLimit *Optional*            |
|search_criteria_trunk_group_name |List[OCI.searchCriteriaTrunkGroupName] |searchCriteriaTrunkGroupName *Optional* |
|search_criteria_group_id         |List[OCI.searchCriteriaGroupId]        |searchCriteriaGroupId *Optional*        |
</div>


## `EnterpriseEnterpriseTrunkGetAvailableUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the list of users that are available to be added to an enterprise trunk.

This list contains users in the enterprise that are trunk users and not already
assigned to an enterprise trunk.  It is possible to search by various criteria to
restrict the number of rows returned.  Multiple search criteria are logically ANDed
together.

The response is either an `EnterpriseEnterpriseTrunkGetAvailableUserListResponse()` or
an `ErrorResponse()`.

**Attributes:**

|Name                                            |Type                                                 |Description                                           |
|------------------------------------------------|-----------------------------------------------------|------------------------------------------------------|
|service_provider_id                             |str                                                  |serviceProviderId                                     |
|response_size_limit                             |int                                                  |responseSizeLimit *Optional*                          |
|search_criteria_user_last_name                  |List[OCI.searchCriteriaUserLastName]                 |searchCriteriaUserLastName *Optional*                 |
|search_criteria_user_first_name                 |List[OCI.searchCriteriaUserFirstName]                |searchCriteriaUserFirstName *Optional*                |
|search_criteria_dn                              |List[OCI.searchCriteriaDn]                           |searchCriteriaDn *Optional*                           |
|search_criteria_user_id                         |List[OCI.searchCriteriaUserId]                       |searchCriteriaUserId *Optional*                       |
|search_criteria_group_id                        |List[OCI.searchCriteriaGroupId]                      |searchCriteriaGroupId *Optional*                      |
|search_criteria_alternate_trunk_identity        |List[OCI.searchCriteriaAlternateTrunkIdentity]       |searchCriteriaAlternateTrunkIdentity *Optional*       |
|search_criteria_alternate_trunk_identity_domain |List[OCI.searchCriteriaAlternateTrunkIdentityDomain] |searchCriteriaAlternateTrunkIdentityDomain *Optional* |
|search_criteria_extension                       |List[OCI.searchCriteriaExtension]                    |searchCriteriaExtension *Optional*                    |
|search_criteria_exact_user_department           |OCI.searchCriteriaExactUserDepartment                |searchCriteriaExactUserDepartment *Optional*          |
</div>


## `EnterpriseEnterpriseTrunkGetUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the list of users in an enterprise trunk.

It is possible to search by various criteria to restrict the number of rows returned.
Multiple search criteria are logically ANDed together.

The response is either a `EnterpriseEnterpriseTrunkGetUserListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                            |Type                                                 |Description                                           |
|------------------------------------------------|-----------------------------------------------------|------------------------------------------------------|
|service_provider_id                             |str                                                  |serviceProviderId                                     |
|enterprise_trunk_name                           |str                                                  |enterpriseTrunkName                                   |
|response_size_limit                             |int                                                  |responseSizeLimit *Optional*                          |
|search_criteria_user_last_name                  |List[OCI.searchCriteriaUserLastName]                 |searchCriteriaUserLastName *Optional*                 |
|search_criteria_user_first_name                 |List[OCI.searchCriteriaUserFirstName]                |searchCriteriaUserFirstName *Optional*                |
|search_criteria_dn                              |List[OCI.searchCriteriaDn]                           |searchCriteriaDn *Optional*                           |
|search_criteria_user_id                         |List[OCI.searchCriteriaUserId]                       |searchCriteriaUserId *Optional*                       |
|search_criteria_group_id                        |List[OCI.searchCriteriaGroupId]                      |searchCriteriaGroupId *Optional*                      |
|search_criteria_alternate_trunk_identity        |List[OCI.searchCriteriaAlternateTrunkIdentity]       |searchCriteriaAlternateTrunkIdentity *Optional*       |
|search_criteria_alternate_trunk_identity_domain |List[OCI.searchCriteriaAlternateTrunkIdentityDomain] |searchCriteriaAlternateTrunkIdentityDomain *Optional* |
|search_criteria_extension                       |List[OCI.searchCriteriaExtension]                    |searchCriteriaExtension *Optional*                    |
|search_criteria_exact_user_department           |OCI.searchCriteriaExactUserDepartment                |searchCriteriaExactUserDepartment *Optional*          |
|search_criteria_exact_user_route_list_assigned  |OCI.searchCriteriaExactUserRouteListAssigned         |searchCriteriaExactUserRouteListAssigned *Optional*   |
</div>


## `EnterpriseLocalGatewayGetPagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of local gateways defined within an enterprise.

Only the local gateways having device associated are returned.  If the
responsePagingControl element is not provided, the paging startIndex will be set to 1
by default, and the responsePageSize will be set to the maximum ResponsePageSize by
default.  If no sortOrder is included the response is sorted by Trunk group name
ascending by default.  Multiple search criteria are logically ANDed together unless
the searchCriteriaModeOr option is included.  Then the search criteria are logically
ORed together.

The response is either a `EnterpriseLocalGatewayGetPagedSortedListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                             |Type                                   |Description                             |
|---------------------------------|---------------------------------------|----------------------------------------|
|service_provider_id              |str                                    |serviceProviderId                       |
|response_paging_control          |OCI.responsePagingControl              |responsePagingControl *Optional*        |
|sort_by_trunk_group_name         |OCI.sortByTrunkGroupName               |sortByTrunkGroupName *Optional*         |
|search_criteria_trunk_group_name |List[OCI.searchCriteriaTrunkGroupName] |searchCriteriaTrunkGroupName *Optional* |
|search_criteria_mode_or          |bool                                   |searchCriteriaModeOr *Optional*         |
</div>


## `EnterprisePhoneDirectoryGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a table containing the phone directory for an enterprise.

The directory includes all users in the enterprise and all entries in the enterprise
common phone list.  It is possible to search by various criteria to restrict the
number of rows returned.  Multiple search criteria are logically ANDed together.

The response is either `EnterprisePhoneDirectoryGetListResponse()` or
`ErrorResponse()`. Replace by: `EnterprisePhoneDirectoryGetListRequest17()`

**Attributes:**

|Name                                  |Type                                      |Description                                  |
|--------------------------------------|------------------------------------------|---------------------------------------------|
|enterprise_id                         |str                                       |enterpriseId                                 |
|is_extended_info_requested            |bool                                      |isExtendedInfoRequested                      |
|response_size_limit                   |int                                       |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]      |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName]     |searchCriteriaUserFirstName *Optional*       |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]                |searchCriteriaDn *Optional*                  |
|search_criteria_group_location_code   |List[OCI.searchCriteriaGroupLocationCode] |searchCriteriaGroupLocationCode *Optional*   |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]         |searchCriteriaExtension *Optional*           |
|search_criteria_mobile_phone_number   |List[OCI.searchCriteriaMobilePhoneNumber] |searchCriteriaMobilePhoneNumber *Optional*   |
|search_criteria_email_address         |List[OCI.searchCriteriaEmailAddress]      |searchCriteriaEmailAddress *Optional*        |
|search_criteria_yahoo_id              |List[OCI.searchCriteriaYahooId]           |searchCriteriaYahooId *Optional*             |
|search_criteria_exact_user_group      |OCI.searchCriteriaExactUserGroup          |searchCriteriaExactUserGroup *Optional*      |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment     |searchCriteriaExactUserDepartment *Optional* |
</div>


## `EnterprisePhoneDirectoryGetListRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a table containing the phone directory for an enterprise.

The directory includes all users in the enterprise and all entries in the enterprise
common phone list.  It is possible to search by various criteria to restrict the
number of rows returned.  Multiple search criteria are logically ANDed together.

The response is either `EnterprisePhoneDirectoryGetListResponse17()` or
`ErrorResponse()`. Replaced by: `EnterprisePhoneDirectoryGetListRequest18()`

**Attributes:**

|Name                                  |Type                                      |Description                                  |
|--------------------------------------|------------------------------------------|---------------------------------------------|
|enterprise_id                         |str                                       |enterpriseId                                 |
|is_extended_info_requested            |bool                                      |isExtendedInfoRequested                      |
|response_size_limit                   |int                                       |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]      |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName]     |searchCriteriaUserFirstName *Optional*       |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]                |searchCriteriaDn *Optional*                  |
|search_criteria_group_location_code   |List[OCI.searchCriteriaGroupLocationCode] |searchCriteriaGroupLocationCode *Optional*   |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]         |searchCriteriaExtension *Optional*           |
|search_criteria_mobile_phone_number   |List[OCI.searchCriteriaMobilePhoneNumber] |searchCriteriaMobilePhoneNumber *Optional*   |
|search_criteria_email_address         |List[OCI.searchCriteriaEmailAddress]      |searchCriteriaEmailAddress *Optional*        |
|search_criteria_yahoo_id              |List[OCI.searchCriteriaYahooId]           |searchCriteriaYahooId *Optional*             |
|search_criteria_exact_user_group      |OCI.searchCriteriaExactUserGroup          |searchCriteriaExactUserGroup *Optional*      |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment     |searchCriteriaExactUserDepartment *Optional* |
</div>


## `EnterprisePhoneDirectoryGetListRequest17sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a table containing the phone directory for an enterprise.

The directory includes all users in the enterprise and all entries in the enterprise
common phone list.  It is possible to search by various criteria to restrict the
number of rows returned.  Multiple search criteria are logically ANDed together.

The response is either `EnterprisePhoneDirectoryGetListResponse17sp3()` or
`ErrorResponse()`. Replaced by: `EnterprisePhoneDirectoryGetListRequest18()`

**Attributes:**

|Name                                  |Type                                      |Description                                  |
|--------------------------------------|------------------------------------------|---------------------------------------------|
|enterprise_id                         |str                                       |enterpriseId                                 |
|is_extended_info_requested            |bool                                      |isExtendedInfoRequested                      |
|response_size_limit                   |int                                       |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]      |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName]     |searchCriteriaUserFirstName *Optional*       |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]                |searchCriteriaDn *Optional*                  |
|search_criteria_group_location_code   |List[OCI.searchCriteriaGroupLocationCode] |searchCriteriaGroupLocationCode *Optional*   |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]         |searchCriteriaExtension *Optional*           |
|search_criteria_mobile_phone_number   |List[OCI.searchCriteriaMobilePhoneNumber] |searchCriteriaMobilePhoneNumber *Optional*   |
|search_criteria_email_address         |List[OCI.searchCriteriaEmailAddress]      |searchCriteriaEmailAddress *Optional*        |
|search_criteria_yahoo_id              |List[OCI.searchCriteriaYahooId]           |searchCriteriaYahooId *Optional*             |
|search_criteria_exact_user_group      |OCI.searchCriteriaExactUserGroup          |searchCriteriaExactUserGroup *Optional*      |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment     |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_imp_id                |List[OCI.searchCriteriaImpId]             |searchCriteriaImpId *Optional*               |
</div>


## `EnterprisePhoneDirectoryGetListRequest18`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a table containing the phone directory for an enterprise.

The directory includes all users in the enterprise and all entries in the enterprise
common phone list.  It is possible to search by various criteria to restrict the
number of rows returned.  Multiple search criteria are logically ANDed together.

The response is either `EnterprisePhoneDirectoryGetListResponse18()` or
`ErrorResponse()`.

Replaced By: `EnterprisePhoneDirectoryGetPagedSortedListRequest()`

**Attributes:**

|Name                                  |Type                                      |Description                                  |
|--------------------------------------|------------------------------------------|---------------------------------------------|
|enterprise_id                         |str                                       |enterpriseId                                 |
|is_extended_info_requested            |bool                                      |isExtendedInfoRequested                      |
|response_size_limit                   |int                                       |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]      |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName]     |searchCriteriaUserFirstName *Optional*       |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]                |searchCriteriaDn *Optional*                  |
|search_criteria_group_location_code   |List[OCI.searchCriteriaGroupLocationCode] |searchCriteriaGroupLocationCode *Optional*   |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]         |searchCriteriaExtension *Optional*           |
|search_criteria_mobile_phone_number   |List[OCI.searchCriteriaMobilePhoneNumber] |searchCriteriaMobilePhoneNumber *Optional*   |
|search_criteria_email_address         |List[OCI.searchCriteriaEmailAddress]      |searchCriteriaEmailAddress *Optional*        |
|search_criteria_yahoo_id              |List[OCI.searchCriteriaYahooId]           |searchCriteriaYahooId *Optional*             |
|search_criteria_exact_user_group      |OCI.searchCriteriaExactUserGroup          |searchCriteriaExactUserGroup *Optional*      |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment     |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]            |searchCriteriaUserId *Optional*              |
|search_criteria_imp_id                |List[OCI.searchCriteriaImpId]             |searchCriteriaImpId *Optional*               |
</div>


## `EnterprisePhoneDirectoryGetPagedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a table containing the phone directory for an enterprise.

The directory includes all users in the enterprise and all entries in the enterprise
common phone list.  It is possible to search by various criteria to restrict the
number of rows returned.  Multiple search criteria are logically ANDed together.

The response is either `EnterprisePhoneDirectoryGetPagedListResponse()` or
`ErrorResponse()`.

Replaced By: `EnterprisePhoneDirectoryGetPagedSortedListRequest()`

**Attributes:**

|Name                                  |Type                                      |Description                                  |
|--------------------------------------|------------------------------------------|---------------------------------------------|
|enterprise_id                         |str                                       |enterpriseId                                 |
|is_extended_info_requested            |bool                                      |isExtendedInfoRequested                      |
|response_paging_control               |OCI.responsePagingControl                 |responsePagingControl                        |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]      |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName]     |searchCriteriaUserFirstName *Optional*       |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]                |searchCriteriaDn *Optional*                  |
|search_criteria_group_location_code   |List[OCI.searchCriteriaGroupLocationCode] |searchCriteriaGroupLocationCode *Optional*   |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]         |searchCriteriaExtension *Optional*           |
|search_criteria_mobile_phone_number   |List[OCI.searchCriteriaMobilePhoneNumber] |searchCriteriaMobilePhoneNumber *Optional*   |
|search_criteria_email_address         |List[OCI.searchCriteriaEmailAddress]      |searchCriteriaEmailAddress *Optional*        |
|search_criteria_yahoo_id              |List[OCI.searchCriteriaYahooId]           |searchCriteriaYahooId *Optional*             |
|search_criteria_exact_user_group      |OCI.searchCriteriaExactUserGroup          |searchCriteriaExactUserGroup *Optional*      |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment     |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]            |searchCriteriaUserId *Optional*              |
|search_criteria_imp_id                |List[OCI.searchCriteriaImpId]             |searchCriteriaImpId *Optional*               |
</div>


## `EnterprisePreAlertingAnnouncementModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the enterprise level pre-alerting service settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                        |Type          |Description                          |
|----------------------------|--------------|-------------------------------------|
|service_provider_id         |str           |serviceProviderId                    |
|announcement_interruption   |str           |announcementInterruption *Optional*  |
|interruption_digit_sequence |str           |interruptionDigitSequence *Optional* |
|audio_selection             |str           |audioSelection *Optional*            |
|audio_file                  |OCI.audioFile |audioFile *Optional*                 |
|video_selection             |str           |videoSelection *Optional*            |
|video_file                  |OCI.videoFile |videoFile *Optional*                 |
</div>


## `EnterpriseSessionAdmissionControlGetAvailableDeviceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of devices can be assigned to session admission control group
for the enterprise.

The response is either an
`EnterpriseSessionAdmissionControlGetAvailableDeviceListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                               |Type                                     |Description                               |
|-----------------------------------|-----------------------------------------|------------------------------------------|
|service_provider_id                |str                                      |serviceProviderId                         |
|response_size_limit                |int                                      |responseSizeLimit *Optional*              |
|search_criteria_device_name        |List[OCI.searchCriteriaDeviceName]       |searchCriteriaDeviceName *Optional*       |
|search_criteria_device_mac_address |List[OCI.searchCriteriaDeviceMACAddress] |searchCriteriaDeviceMACAddress *Optional* |
|search_criteria_device_net_address |List[OCI.searchCriteriaDeviceNetAddress] |searchCriteriaDeviceNetAddress *Optional* |
|search_criteria_group_id           |List[OCI.searchCriteriaGroupId]          |searchCriteriaGroupId *Optional*          |
|search_criteria_exact_device_type  |OCI.searchCriteriaExactDeviceType        |searchCriteriaExactDeviceType *Optional*  |
|search_criteria_exact_device_level |OCI.searchCriteriaExactDeviceLevel       |searchCriteriaExactDeviceLevel *Optional* |
</div>


## `EnterpriseSessionAdmissionControlGroupAddDeviceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add one or more devices to an enterprise level session admission control
group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type              |Description       |
|--------------------|------------------|------------------|
|service_provider_id |str               |serviceProviderId |
|name                |str               |name              |
|devices             |List[OCI.devices] |devices           |
</div>


## `EnterpriseSessionAdmissionControlGroupAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a session admission control group for the enterprise.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                               |Type              |Description                                |
|-----------------------------------|------------------|-------------------------------------------|
|service_provider_id                |str               |serviceProviderId                          |
|name                               |str               |name                                       |
|max_session                        |int               |maxSession                                 |
|max_user_originating_sessions      |int               |maxUserOriginatingSessions *Optional*      |
|max_user_terminating_sessions      |int               |maxUserTerminatingSessions *Optional*      |
|reserved_session                   |int               |reservedSession                            |
|reserved_user_originating_sessions |int               |reservedUserOriginatingSessions *Optional* |
|reserved_user_terminating_sessions |int               |reservedUserTerminatingSessions *Optional* |
|become_default_group               |bool              |becomeDefaultGroup                         |
|count_intra_sac_group_sessions     |bool              |countIntraSACGroupSessions                 |
|devices                            |List[OCI.devices] |devices *Optional*                         |
</div>


## `EnterpriseSessionAdmissionControlGroupAddRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a session admission control group for the enterprise.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Note that to
provision the accessInfoPattern element, the captureAccessInfoInPaniHeader system
parameter needs to be set to "true".

**Attributes:**

|Name                                               |Type              |Description                                |
|---------------------------------------------------|------------------|-------------------------------------------|
|service_provider_id                                |str               |serviceProviderId                          |
|name                                               |str               |name                                       |
|max_session                                        |int               |maxSession                                 |
|max_user_originating_sessions                      |int               |maxUserOriginatingSessions *Optional*      |
|max_user_terminating_sessions                      |int               |maxUserTerminatingSessions *Optional*      |
|reserved_session                                   |int               |reservedSession                            |
|reserved_user_originating_sessions                 |int               |reservedUserOriginatingSessions *Optional* |
|reserved_user_terminating_sessions                 |int               |reservedUserTerminatingSessions *Optional* |
|become_default_group                               |bool              |becomeDefaultGroup                         |
|count_intra_sac_group_sessions                     |bool              |countIntraSACGroupSessions                 |
|devices                                            |List[OCI.devices] |devices *Optional*                         |
|block_emergency_and_repair_calls_due_to_sac_limits |bool              |blockEmergencyAndRepairCallsDueToSACLimits |
|media_group_name                                   |str               |mediaGroupName *Optional*                  |
|access_info_pattern                                |str               |accessInfoPattern *Optional*               |
</div>


## `EnterpriseSessionAdmissionControlGroupDeleteDeviceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to delete one or more devices from an enterprise level session admission
control group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type              |Description       |
|--------------------|------------------|------------------|
|service_provider_id |str               |serviceProviderId |
|name                |str               |name              |
|devices             |List[OCI.devices] |devices           |
</div>


## `EnterpriseUserCallForwardingSettingsGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of users and the service settings for a Call Forwarding service.

The response is either `EnterpriseUserCallForwardingSettingsGetListResponse()` or
`ErrorResponse()`. By default, virtual users and non-virtual users that match the
selected search criteria are included in the response when "includeVirtualUsers" is
present; otherwise, if "includeVirtualUsers" is absent, then only non-virtual users
are returned.  The search can be performed using multiple criteria.  If search
criteria is specified, only the users matching all of the specified search criteria
are included in the response.  If no search criteria is specified, all results are
returned.

**Attributes:**

|Name                                      |Type                                      |Description                                    |
|------------------------------------------|------------------------------------------|-----------------------------------------------|
|service_provider_id                       |str                                       |serviceProviderId                              |
|call_forwarding_service                   |str                                       |callForwardingService                          |
|response_paging_control                   |OCI.responsePagingControl                 |responsePagingControl                          |
|sort_by_user_last_name                    |OCI.sortByUserLastName                    |sortByUserLastName *Optional*                  |
|sort_by_user_first_name                   |OCI.sortByUserFirstName                   |sortByUserFirstName *Optional*                 |
|sort_by_user_department                   |OCI.sortByUserDepartment                  |sortByUserDepartment *Optional*                |
|sort_by_dn                                |OCI.sortByDn                              |sortByDn *Optional*                            |
|sort_by_extension                         |OCI.sortByExtension                       |sortByExtension *Optional*                     |
|sort_by_group_id                          |OCI.sortByGroupId                         |sortByGroupId *Optional*                       |
|sort_by_forwarded_to_number               |OCI.sortByForwardedToNumber               |sortByForwardedToNumber *Optional*             |
|include_virtual_users                     |bool                                      |includeVirtualUsers *Optional*                 |
|search_criteria_user_last_name            |List[OCI.searchCriteriaUserLastName]      |searchCriteriaUserLastName *Optional*          |
|search_criteria_user_first_name           |List[OCI.searchCriteriaUserFirstName]     |searchCriteriaUserFirstName *Optional*         |
|search_criteria_user_id                   |List[OCI.searchCriteriaUserId]            |searchCriteriaUserId *Optional*                |
|search_criteria_dn                        |List[OCI.searchCriteriaDn]                |searchCriteriaDn *Optional*                    |
|search_criteria_extension                 |List[OCI.searchCriteriaExtension]         |searchCriteriaExtension *Optional*             |
|search_criteria_email_address             |List[OCI.searchCriteriaEmailAddress]      |searchCriteriaEmailAddress *Optional*          |
|search_criteria_exact_user_department     |OCI.searchCriteriaExactUserDepartment     |searchCriteriaExactUserDepartment *Optional*   |
|search_criteria_exact_user_in_trunk_group |OCI.searchCriteriaExactUserInTrunkGroup   |searchCriteriaExactUserInTrunkGroup *Optional* |
|search_criteria_forwarded_to_number       |List[OCI.searchCriteriaForwardedToNumber] |searchCriteriaForwardedToNumber *Optional*     |
</div>


## `EnterpriseUserCallWaitingSettingsGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of users and the Call Waiting service status (active or not active).

The response is either `EnterpriseUserCallWaitingSettingsGetListResponse()` or
`ErrorResponse()`. By default, virtual users and non-virtual users that match the
selected search criteria are included in the response when "includeVirtualUsers" is
present; otherwise, if "includeVirtualUsers" is absent, then only non-virtual users
are returned.  The search can be performed using multiple criteria.  If search
criteria is specified, only the users matching all of the specified search criteria
are included in the response.  If no search criteria is specified, all results are
returned.

**Attributes:**

|Name                                      |Type                                    |Description                                    |
|------------------------------------------|----------------------------------------|-----------------------------------------------|
|service_provider_id                       |str                                     |serviceProviderId                              |
|response_paging_control                   |OCI.responsePagingControl               |responsePagingControl                          |
|sort_by_user_last_name                    |OCI.sortByUserLastName                  |sortByUserLastName *Optional*                  |
|sort_by_user_first_name                   |OCI.sortByUserFirstName                 |sortByUserFirstName *Optional*                 |
|sort_by_user_department                   |OCI.sortByUserDepartment                |sortByUserDepartment *Optional*                |
|sort_by_dn                                |OCI.sortByDn                            |sortByDn *Optional*                            |
|sort_by_extension                         |OCI.sortByExtension                     |sortByExtension *Optional*                     |
|sort_by_service_status                    |OCI.sortByServiceStatus                 |sortByServiceStatus *Optional*                 |
|sort_by_group_id                          |OCI.sortByGroupId                       |sortByGroupId *Optional*                       |
|include_virtual_users                     |bool                                    |includeVirtualUsers *Optional*                 |
|search_criteria_user_last_name            |List[OCI.searchCriteriaUserLastName]    |searchCriteriaUserLastName *Optional*          |
|search_criteria_user_first_name           |List[OCI.searchCriteriaUserFirstName]   |searchCriteriaUserFirstName *Optional*         |
|search_criteria_user_id                   |List[OCI.searchCriteriaUserId]          |searchCriteriaUserId *Optional*                |
|search_criteria_dn                        |List[OCI.searchCriteriaDn]              |searchCriteriaDn *Optional*                    |
|search_criteria_extension                 |List[OCI.searchCriteriaExtension]       |searchCriteriaExtension *Optional*             |
|search_criteria_email_address             |List[OCI.searchCriteriaEmailAddress]    |searchCriteriaEmailAddress *Optional*          |
|search_criteria_exact_user_department     |OCI.searchCriteriaExactUserDepartment   |searchCriteriaExactUserDepartment *Optional*   |
|search_criteria_exact_user_in_trunk_group |OCI.searchCriteriaExactUserInTrunkGroup |searchCriteriaExactUserInTrunkGroup *Optional* |
|search_criteria_service_status            |OCI.searchCriteriaServiceStatus         |searchCriteriaServiceStatus *Optional*         |
</div>


## `EnterpriseUserCallingPlanSettingsGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of users and the default or custom calling plan setting.

The response is either `EnterpriseUserCallingPlanSettingsGetListResponse()` or
`ErrorResponse()`. By default, virtual users and non-virtual users that match the
selected search criteria are included in the response when "includeVirtualUsers" is
present; otherwise, if "includeVirtualUsers" is absent, then only non-virtual users
are returned.  The search can be performed using multiple criteria.  If search
criteria is specified, only the users matching all of the specified search criteria
are included in the response.  If no search criteria is specified, all results are
returned.

**Attributes:**

|Name                                      |Type                                    |Description                                    |
|------------------------------------------|----------------------------------------|-----------------------------------------------|
|service_provider_id                       |str                                     |serviceProviderId                              |
|calling_plan_service                      |str                                     |callingPlanService                             |
|response_paging_control                   |OCI.responsePagingControl               |responsePagingControl                          |
|sort_by_user_last_name                    |OCI.sortByUserLastName                  |sortByUserLastName *Optional*                  |
|sort_by_user_first_name                   |OCI.sortByUserFirstName                 |sortByUserFirstName *Optional*                 |
|sort_by_user_department                   |OCI.sortByUserDepartment                |sortByUserDepartment *Optional*                |
|sort_by_dn                                |OCI.sortByDn                            |sortByDn *Optional*                            |
|sort_by_extension                         |OCI.sortByExtension                     |sortByExtension *Optional*                     |
|sort_by_group_id                          |OCI.sortByGroupId                       |sortByGroupId *Optional*                       |
|include_virtual_users                     |bool                                    |includeVirtualUsers *Optional*                 |
|search_criteria_user_last_name            |List[OCI.searchCriteriaUserLastName]    |searchCriteriaUserLastName *Optional*          |
|search_criteria_user_first_name           |List[OCI.searchCriteriaUserFirstName]   |searchCriteriaUserFirstName *Optional*         |
|search_criteria_user_id                   |List[OCI.searchCriteriaUserId]          |searchCriteriaUserId *Optional*                |
|search_criteria_dn                        |List[OCI.searchCriteriaDn]              |searchCriteriaDn *Optional*                    |
|search_criteria_extension                 |List[OCI.searchCriteriaExtension]       |searchCriteriaExtension *Optional*             |
|search_criteria_email_address             |List[OCI.searchCriteriaEmailAddress]    |searchCriteriaEmailAddress *Optional*          |
|search_criteria_exact_user_department     |OCI.searchCriteriaExactUserDepartment   |searchCriteriaExactUserDepartment *Optional*   |
|search_criteria_exact_user_in_trunk_group |OCI.searchCriteriaExactUserInTrunkGroup |searchCriteriaExactUserInTrunkGroup *Optional* |
</div>


## `EnterpriseUserHotelingGuestSettingsGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of users and their Hoteling Guest service status (active or not active).

The response is either `EnterpriseUserHotelingGuestSettingsGetListResponse()` or
`ErrorResponse()`. By default, virtual users and non-virtual users that match the
selected search criteria are included in the response when "includeVirtualUsers" is
present; otherwise, if "includeVirtualUsers" is absent, then only non-virtual users
are returned.  The search can be performed using multiple criteria.  If search
criteria is specified, only the users matching all of the specified search criteria
are included in the response.  If no search criteria is specified, all results are
returned.

**Attributes:**

|Name                                      |Type                                    |Description                                    |
|------------------------------------------|----------------------------------------|-----------------------------------------------|
|service_provider_id                       |str                                     |serviceProviderId                              |
|response_paging_control                   |OCI.responsePagingControl               |responsePagingControl                          |
|sort_by_user_last_name                    |OCI.sortByUserLastName                  |sortByUserLastName *Optional*                  |
|sort_by_user_first_name                   |OCI.sortByUserFirstName                 |sortByUserFirstName *Optional*                 |
|sort_by_user_department                   |OCI.sortByUserDepartment                |sortByUserDepartment *Optional*                |
|sort_by_dn                                |OCI.sortByDn                            |sortByDn *Optional*                            |
|sort_by_extension                         |OCI.sortByExtension                     |sortByExtension *Optional*                     |
|sort_by_service_status                    |OCI.sortByServiceStatus                 |sortByServiceStatus *Optional*                 |
|sort_by_group_id                          |OCI.sortByGroupId                       |sortByGroupId *Optional*                       |
|include_virtual_users                     |bool                                    |includeVirtualUsers *Optional*                 |
|search_criteria_user_last_name            |List[OCI.searchCriteriaUserLastName]    |searchCriteriaUserLastName *Optional*          |
|search_criteria_user_first_name           |List[OCI.searchCriteriaUserFirstName]   |searchCriteriaUserFirstName *Optional*         |
|search_criteria_user_id                   |List[OCI.searchCriteriaUserId]          |searchCriteriaUserId *Optional*                |
|search_criteria_dn                        |List[OCI.searchCriteriaDn]              |searchCriteriaDn *Optional*                    |
|search_criteria_extension                 |List[OCI.searchCriteriaExtension]       |searchCriteriaExtension *Optional*             |
|search_criteria_email_address             |List[OCI.searchCriteriaEmailAddress]    |searchCriteriaEmailAddress *Optional*          |
|search_criteria_exact_user_department     |OCI.searchCriteriaExactUserDepartment   |searchCriteriaExactUserDepartment *Optional*   |
|search_criteria_exact_user_in_trunk_group |OCI.searchCriteriaExactUserInTrunkGroup |searchCriteriaExactUserInTrunkGroup *Optional* |
</div>


## `EnterpriseVirtualOnNetEnterpriseExtensionsGetUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the list of Virtual On-Net users in an Enterprise.

It is possible to search by various criteria to restrict the number of rows returned.
Multiple search criteria are logically ANDed together.

The response is either a
`EnterpriseVirtualOnNetEnterpriseExtensionsGetUserListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                                |Type                                            |Description                                            |
|----------------------------------------------------|------------------------------------------------|-------------------------------------------------------|
|service_provider_id                                 |str                                             |serviceProviderId                                      |
|response_size_limit                                 |int                                             |responseSizeLimit *Optional*                           |
|search_criteria_user_last_name                      |List[OCI.searchCriteriaUserLastName]            |searchCriteriaUserLastName *Optional*                  |
|search_criteria_user_first_name                     |List[OCI.searchCriteriaUserFirstName]           |searchCriteriaUserFirstName *Optional*                 |
|search_criteria_dn                                  |List[OCI.searchCriteriaDn]                      |searchCriteriaDn *Optional*                            |
|search_criteria_group_location_code                 |List[OCI.searchCriteriaGroupLocationCode]       |searchCriteriaGroupLocationCode *Optional*             |
|search_criteria_extension                           |List[OCI.searchCriteriaExtension]               |searchCriteriaExtension *Optional*                     |
|search_criteria_exact_virtual_on_net_call_type_name |OCI.searchCriteriaExactVirtualOnNetCallTypeName |searchCriteriaExactVirtualOnNetCallTypeName *Optional* |
</div>


## `EnterpriseVoiceVPNGetPolicyListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the list of Voice VPN locations.

It is possible to search by various criteria to restrict the number of rows returned.
Multiple search criteria are logically ANDed together.

The response is either a `EnterpriseVoiceVPNGetPolicyListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                   |Type                                      |Description                                   |
|---------------------------------------|------------------------------------------|----------------------------------------------|
|service_provider_id                    |str                                       |serviceProviderId                             |
|response_size_limit                    |int                                       |responseSizeLimit *Optional*                  |
|search_criteria_group_location_code    |List[OCI.searchCriteriaGroupLocationCode] |searchCriteriaGroupLocationCode *Optional*    |
|search_criteria_exact_policy_selection |OCI.searchCriteriaExactPolicySelection    |searchCriteriaExactPolicySelection *Optional* |
</div>


## `GroupAccessDeviceGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of access devices in a group.

The following elements are only used in AS data mode and ignored in XS data mode:
groupExternalId

The response is either `GroupAccessDeviceGetListResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                        |Description                                  |
|--------------------------------------|--------------------------------------------|---------------------------------------------|
|service_provider_id                   |str                                         |serviceProviderId *Optional*                 |
|group_id                              |str                                         |groupId *Optional*                           |
|group_external_id                     |str                                         |groupExternalId *Optional*                   |
|response_size_limit                   |int                                         |responseSizeLimit *Optional*                 |
|search_criteria_device_name           |List[OCI.searchCriteriaDeviceName]          |searchCriteriaDeviceName *Optional*          |
|search_criteria_device_mac_address    |List[OCI.searchCriteriaDeviceMACAddress]    |searchCriteriaDeviceMACAddress *Optional*    |
|search_criteria_device_net_address    |List[OCI.searchCriteriaDeviceNetAddress]    |searchCriteriaDeviceNetAddress *Optional*    |
|search_criteria_exact_device_type     |OCI.searchCriteriaExactDeviceType           |searchCriteriaExactDeviceType *Optional*     |
|search_criteria_access_device_version |List[OCI.searchCriteriaAccessDeviceVersion] |searchCriteriaAccessDeviceVersion *Optional* |
</div>


## `GroupAccessDeviceGetPagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of access devices in a group.

The response is either `GroupAccessDeviceGetPagedSortedListResponse()` or
`ErrorResponse()`. If no sortOrder is included, the response is sorted by Device Name
ascending by default.  If the responsePagingControl element is not provided, the
paging startIndex will be set to 1 by default, and the responsePageSize will be set to
the maximum responsePageSize by default.  Multiple search criteria are logically ANDed
together unless the searchCriteriaModeOr option is included.  Then the search criteria
are logically ORed together.  The getVisualDeviceManagementAPIDevicesOnly element can
only be set when CloudPBX is licenced.  If the getVisualDeviceManagementAPIDevicesOnly
element is not set, all devices are returned with Visual Device Management API flag
set to empty.  If the getVisualDeviceManagementAPIDevicesOnly element is set to true,
only SIP devices supporting Visual Device Management API are returned.  If the
getVisualDeviceManagementAPIDevicesOnly element is set to false, all SIP devices are
returned with their current Visual Device Management API flag value.  Replaced by
`GroupAccessDeviceGetPagedSortedListRequest22()`.

**Attributes:**

|Name                                          |Type                                        |Description                                        |
|----------------------------------------------|--------------------------------------------|---------------------------------------------------|
|service_provider_id                           |str                                         |serviceProviderId                                  |
|group_id                                      |str                                         |groupId                                            |
|response_paging_control                       |OCI.responsePagingControl                   |responsePagingControl *Optional*                   |
|sort_by_device_name                           |OCI.sortByDeviceName                        |sortByDeviceName *Optional*                        |
|sort_by_device_type                           |OCI.sortByDeviceType                        |sortByDeviceType *Optional*                        |
|sort_by_device_net_address                    |OCI.sortByDeviceNetAddress                  |sortByDeviceNetAddress *Optional*                  |
|sort_by_device_mac_address                    |OCI.sortByDeviceMACAddress                  |sortByDeviceMACAddress *Optional*                  |
|search_criteria_device_name                   |List[OCI.searchCriteriaDeviceName]          |searchCriteriaDeviceName *Optional*                |
|search_criteria_device_mac_address            |List[OCI.searchCriteriaDeviceMACAddress]    |searchCriteriaDeviceMACAddress *Optional*          |
|search_criteria_device_net_address            |List[OCI.searchCriteriaDeviceNetAddress]    |searchCriteriaDeviceNetAddress *Optional*          |
|search_criteria_exact_device_type             |List[OCI.searchCriteriaExactDeviceType]     |searchCriteriaExactDeviceType *Optional*           |
|search_criteria_access_device_version         |List[OCI.searchCriteriaAccessDeviceVersion] |searchCriteriaAccessDeviceVersion *Optional*       |
|search_criteria_mode_or                       |bool                                        |searchCriteriaModeOr *Optional*                    |
|get_visual_device_management_api_devices_only |bool                                        |getVisualDeviceManagementAPIDevicesOnly *Optional* |
</div>


## `GroupAccessDeviceGetUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the configuration of a specified group access device.

The response is either `GroupAccessDeviceGetUserListResponse()` or `ErrorResponse()`.
The following elements are only used in XS data mode and ignored in AS data mode:
searchCriteriaAccessDeviceEndpointPrivateIdentity Replaced by:
`GroupAccessDeviceGetUserListRequest21sp1()` in AS data mode.

**Attributes:**

|Name                                                    |Type                                                        |Description                                                  |
|--------------------------------------------------------|------------------------------------------------------------|-------------------------------------------------------------|
|service_provider_id                                     |str                                                         |serviceProviderId                                            |
|group_id                                                |str                                                         |groupId                                                      |
|device_name                                             |str                                                         |deviceName                                                   |
|response_size_limit                                     |int                                                         |responseSizeLimit *Optional*                                 |
|search_criteria_line_port_user_part                     |List[OCI.searchCriteriaLinePortUserPart]                    |searchCriteriaLinePortUserPart *Optional*                    |
|search_criteria_line_port_domain                        |List[OCI.searchCriteriaLinePortDomain]                      |searchCriteriaLinePortDomain *Optional*                      |
|search_criteria_user_last_name                          |List[OCI.searchCriteriaUserLastName]                        |searchCriteriaUserLastName *Optional*                        |
|search_criteria_user_first_name                         |List[OCI.searchCriteriaUserFirstName]                       |searchCriteriaUserFirstName *Optional*                       |
|search_criteria_dn                                      |List[OCI.searchCriteriaDn]                                  |searchCriteriaDn *Optional*                                  |
|search_criteria_user_id                                 |List[OCI.searchCriteriaUserId]                              |searchCriteriaUserId *Optional*                              |
|search_criteria_exact_endpoint_type                     |OCI.searchCriteriaExactEndpointType                         |searchCriteriaExactEndpointType *Optional*                   |
|search_criteria_exact_user_type                         |OCI.searchCriteriaExactUserType                             |searchCriteriaExactUserType *Optional*                       |
|search_criteria_extension                               |List[OCI.searchCriteriaExtension]                           |searchCriteriaExtension *Optional*                           |
|search_criteria_exact_user_department                   |OCI.searchCriteriaExactUserDepartment                       |searchCriteriaExactUserDepartment *Optional*                 |
|search_criteria_exact_port_number                       |OCI.searchCriteriaExactPortNumber                           |searchCriteriaExactPortNumber *Optional*                     |
|search_criteria_access_device_endpoint_private_identity |List[OCI.searchCriteriaAccessDeviceEndpointPrivateIdentity] |searchCriteriaAccessDeviceEndpointPrivateIdentity *Optional* |
</div>


## `GroupAccessDeviceGetUserListRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the configuration of a specified group access device.

The response is either `GroupAccessDeviceGetUserListResponse21sp1()` or
`ErrorResponse()`. The following elements are only used in XS data mode and ignored in
AS data mode: searchCriteriaAccessDeviceEndpointPrivateIdentity

**Attributes:**

|Name                                                    |Type                                                        |Description                                                  |
|--------------------------------------------------------|------------------------------------------------------------|-------------------------------------------------------------|
|service_provider_id                                     |str                                                         |serviceProviderId                                            |
|group_id                                                |str                                                         |groupId                                                      |
|device_name                                             |str                                                         |deviceName                                                   |
|response_size_limit                                     |int                                                         |responseSizeLimit *Optional*                                 |
|search_criteria_line_port_user_part                     |List[OCI.searchCriteriaLinePortUserPart]                    |searchCriteriaLinePortUserPart *Optional*                    |
|search_criteria_line_port_domain                        |List[OCI.searchCriteriaLinePortDomain]                      |searchCriteriaLinePortDomain *Optional*                      |
|search_criteria_user_last_name                          |List[OCI.searchCriteriaUserLastName]                        |searchCriteriaUserLastName *Optional*                        |
|search_criteria_user_first_name                         |List[OCI.searchCriteriaUserFirstName]                       |searchCriteriaUserFirstName *Optional*                       |
|search_criteria_dn                                      |List[OCI.searchCriteriaDn]                                  |searchCriteriaDn *Optional*                                  |
|search_criteria_user_id                                 |List[OCI.searchCriteriaUserId]                              |searchCriteriaUserId *Optional*                              |
|search_criteria_exact_endpoint_type                     |OCI.searchCriteriaExactEndpointType                         |searchCriteriaExactEndpointType *Optional*                   |
|search_criteria_exact_user_type                         |OCI.searchCriteriaExactUserType                             |searchCriteriaExactUserType *Optional*                       |
|search_criteria_extension                               |List[OCI.searchCriteriaExtension]                           |searchCriteriaExtension *Optional*                           |
|search_criteria_exact_user_department                   |OCI.searchCriteriaExactUserDepartment                       |searchCriteriaExactUserDepartment *Optional*                 |
|search_criteria_exact_port_number                       |OCI.searchCriteriaExactPortNumber                           |searchCriteriaExactPortNumber *Optional*                     |
|search_criteria_access_device_endpoint_private_identity |List[OCI.searchCriteriaAccessDeviceEndpointPrivateIdentity] |searchCriteriaAccessDeviceEndpointPrivateIdentity *Optional* |
|search_criteria_user_hotline_contact                    |List[OCI.searchCriteriaUserHotlineContact]                  |searchCriteriaUserHotlineContact *Optional*                  |
</div>


## `GroupAccountAuthorizationCodesGetAvailableUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of non restricted users for the account/authorization codes service.

The response is either `GroupAccountAuthorizationCodesGetAvailableUserListResponse()`
or `ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|service_provider_id                   |str                                   |serviceProviderId                            |
|group_id                              |str                                   |groupId                                      |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*              |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                  |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*           |
</div>


## `GroupAnnouncementFileGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of available announcement files for a Group.

The following elements are only used in AS data mode and ignored in XS data mode:
groupExternalId

The response is either a `GroupAnnouncementFileGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                   |Type                                         |Description                                   |
|---------------------------------------|---------------------------------------------|----------------------------------------------|
|service_provider_id                    |str                                          |serviceProviderId *Optional*                  |
|group_id                               |str                                          |groupId *Optional*                            |
|group_external_id                      |str                                          |groupExternalId *Optional*                    |
|announcement_file_type                 |str                                          |announcementFileType *Optional*               |
|include_announcement_table             |bool                                         |includeAnnouncementTable                      |
|response_size_limit                    |int                                          |responseSizeLimit *Optional*                  |
|search_criteria_announcement_file_name |List[OCI.searchCriteriaAnnouncementFileName] |searchCriteriaAnnouncementFileName *Optional* |
</div>


## `GroupAnnouncementFileGetPagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of available announcement files for a Group.

If the responsePagingControl element is not provided, the paging startIndex will be
set to 1 by default, and the responsePageSize will be set to the maximum
responsePageSize by default.  If no sortOrder is included, the response is sorted by
Name ascending by default.  Multiple search criteria are logically ANDed together
unless the searchCriteriaModeOr option is included.  Then the search criteria are
logically ORed together.  The following elements are only used in AS data mode and
ignored in XS data mode: groupExternalId

The response is either a `GroupAnnouncementFileGetPagedSortedListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                         |Type                                         |Description                                        |
|---------------------------------------------|---------------------------------------------|---------------------------------------------------|
|service_provider_id                          |str                                          |serviceProviderId *Optional*                       |
|group_id                                     |str                                          |groupId *Optional*                                 |
|group_external_id                            |str                                          |groupExternalId *Optional*                         |
|response_paging_control                      |OCI.responsePagingControl                    |responsePagingControl *Optional*                   |
|sort_by_announcement_file_name               |OCI.sortByAnnouncementFileName               |sortByAnnouncementFileName *Optional*              |
|sort_by_announcement_file_size               |OCI.sortByAnnouncementFileSize               |sortByAnnouncementFileSize *Optional*              |
|search_criteria_announcement_file_name       |List[OCI.searchCriteriaAnnouncementFileName] |searchCriteriaAnnouncementFileName *Optional*      |
|search_criteria_exact_announcement_file_type |OCI.searchCriteriaExactAnnouncementFileType  |searchCriteriaExactAnnouncementFileType *Optional* |
|search_criteria_exact_media_file_type        |List[OCI.searchCriteriaExactMediaFileType]   |searchCriteriaExactMediaFileType *Optional*        |
|search_criteria_mode_or                      |bool                                         |searchCriteriaModeOr *Optional*                    |
</div>


## `GroupBroadWorksAnywhereAddInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a BroadWorks Anywhere instance to a group.

The domain is required in the serviceUserId.  The following elements are only used in
AS data mode: networkClassOfService

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                       |Type                       |Description                      |
|---------------------------|---------------------------|---------------------------------|
|service_provider_id        |str                        |serviceProviderId                |
|group_id                   |str                        |groupId                          |
|service_user_id            |str                        |serviceUserId                    |
|service_instance_profile   |OCI.serviceInstanceProfile |serviceInstanceProfile           |
|broad_works_anywhere_scope |str                        |broadWorksAnywhereScope          |
|prompt_for_clid            |str                        |promptForCLID                    |
|silent_prompt_mode         |bool                       |silentPromptMode                 |
|prompt_for_passcode        |bool                       |promptForPasscode                |
|network_class_of_service   |str                        |networkClassOfService *Optional* |
</div>


## `GroupBroadWorksAnywhereModifyInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a BroadWorks Anywhere instance.

The following elements are only used in AS data mode: networkClassOfService

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                       |Type                       |Description                        |
|---------------------------|---------------------------|-----------------------------------|
|service_user_id            |str                        |serviceUserId                      |
|service_instance_profile   |OCI.serviceInstanceProfile |serviceInstanceProfile *Optional*  |
|broad_works_anywhere_scope |str                        |broadWorksAnywhereScope *Optional* |
|prompt_for_clid            |str                        |promptForCLID *Optional*           |
|silent_prompt_mode         |bool                       |silentPromptMode *Optional*        |
|prompt_for_passcode        |bool                       |promptForPasscode *Optional*       |
|network_class_of_service   |str                        |networkClassOfService *Optional*   |
</div>


## `GroupBroadWorksMobilityMobileSubscriberDirectoryNumberGetAssignmentListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of assigned and unassigned Mobile Subscriber Directory Numbers in a
group.

Each DN can be assigned to a user.  . This command is applicable only for group in a
service provider and will fail for a group in an enterprise.

The response is either a
`GroupBroadWorksMobilityMobileSubscriberDirectoryNumberGetAssignmentListResponse()` or
an `ErrorResponse()`.

**Attributes:**

|Name                                               |Type                                                    |Description                                              |
|---------------------------------------------------|--------------------------------------------------------|---------------------------------------------------------|
|service_provider_id                                |str                                                     |serviceProviderId                                        |
|group_id                                           |str                                                     |groupId                                                  |
|response_size_limit                                |int                                                     |responseSizeLimit *Optional*                             |
|search_criteria_mobile_subscriber_directory_number |List[OCI.searchCriteriaMobileSubscriberDirectoryNumber] |searchCriteriaMobileSubscriberDirectoryNumber *Optional* |
|search_criteria_user_id                            |List[OCI.searchCriteriaUserId]                          |searchCriteriaUserId *Optional*                          |
|search_criteria_user_last_name                     |List[OCI.searchCriteriaUserLastName]                    |searchCriteriaUserLastName *Optional*                    |
|search_criteria_user_first_name                    |List[OCI.searchCriteriaUserFirstName]                   |searchCriteriaUserFirstName *Optional*                   |
|search_criteria_dn                                 |List[OCI.searchCriteriaDn]                              |searchCriteriaDn *Optional*                              |
|search_criteria_exact_user_department              |OCI.searchCriteriaExactUserDepartment                   |searchCriteriaExactUserDepartment *Optional*             |
|search_criteria_extension                          |List[OCI.searchCriteriaExtension]                       |searchCriteriaExtension *Optional*                       |
</div>


## `GroupCallCapacityManagementGetAvailableUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of users that can be assigned to a Call Capacity Management group.

The available user list for a new Call Capacity Management group can be obtained by
not setting the name.

The response is either `GroupCallCapacityManagementGetAvailableUserListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|service_provider_id                   |str                                   |serviceProviderId                            |
|group_id                              |str                                   |groupId                                      |
|name                                  |str                                   |name *Optional*                              |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*              |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                  |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*           |
</div>


## `GroupCallCenterAddInstanceRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Call Center instance to a group.

The domain is required in the serviceUserId.

The response is either `SuccessResponse()` or `ErrorResponse()`.

Replaced By: `GroupCallCenterAddInstanceRequest14sp3()`

**Attributes:**

|Name                                  |Type                       |Description                       |
|--------------------------------------|---------------------------|----------------------------------|
|service_provider_id                   |str                        |serviceProviderId                 |
|group_id                              |str                        |groupId                           |
|service_user_id                       |str                        |serviceUserId                     |
|service_instance_profile              |OCI.serviceInstanceProfile |serviceInstanceProfile            |
|policy                                |str                        |policy                            |
|hunt_after_no_answer                  |bool                       |huntAfterNoAnswer                 |
|no_answer_number_of_rings             |int                        |noAnswerNumberOfRings             |
|forward_after_timeout                 |bool                       |forwardAfterTimeout               |
|forward_timeout_seconds               |int                        |forwardTimeoutSeconds             |
|forward_to_phone_number               |str                        |forwardToPhoneNumber *Optional*   |
|enable_video                          |bool                       |enableVideo                       |
|queue_length                          |int                        |queueLength                       |
|allow_agent_logoff                    |bool                       |allowAgentLogoff                  |
|play_music_on_hold                    |bool                       |playMusicOnHold                   |
|play_comfort_message                  |bool                       |playComfortMessage                |
|time_between_comfort_messages_seconds |int                        |timeBetweenComfortMessagesSeconds |
|enable_guard_timer                    |bool                       |enableGuardTimer                  |
|guard_timer_seconds                   |int                        |guardTimerSeconds                 |
|agent_user_id                         |List[str]                  |agentUserId *Optional*            |
|allow_call_waiting_for_agents         |bool                       |allowCallWaitingForAgents         |
</div>


## `GroupCallCenterAddInstanceRequest14sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Call Center instance to a group.

The domain is required in the serviceUserId.

The response is either `SuccessResponse()` or `ErrorResponse()`.

Replaced By: `GroupCallCenterAddInstanceRequest14sp9()`

**Attributes:**

|Name                                       |Type                       |Description                          |
|-------------------------------------------|---------------------------|-------------------------------------|
|service_provider_id                        |str                        |serviceProviderId                    |
|group_id                                   |str                        |groupId                              |
|service_user_id                            |str                        |serviceUserId                        |
|service_instance_profile                   |OCI.serviceInstanceProfile |serviceInstanceProfile               |
|policy                                     |str                        |policy                               |
|hunt_after_no_answer                       |bool                       |huntAfterNoAnswer                    |
|no_answer_number_of_rings                  |int                        |noAnswerNumberOfRings                |
|forward_after_timeout                      |bool                       |forwardAfterTimeout                  |
|forward_timeout_seconds                    |int                        |forwardTimeoutSeconds                |
|forward_to_phone_number                    |str                        |forwardToPhoneNumber *Optional*      |
|enable_video                               |bool                       |enableVideo                          |
|queue_length                               |int                        |queueLength                          |
|allow_agent_logoff                         |bool                       |allowAgentLogoff                     |
|play_music_on_hold                         |bool                       |playMusicOnHold                      |
|play_comfort_message                       |bool                       |playComfortMessage                   |
|time_between_comfort_messages_seconds      |int                        |timeBetweenComfortMessagesSeconds    |
|enable_guard_timer                         |bool                       |enableGuardTimer                     |
|guard_timer_seconds                        |int                        |guardTimerSeconds                    |
|agent_user_id                              |List[str]                  |agentUserId *Optional*               |
|allow_call_waiting_for_agents              |bool                       |allowCallWaitingForAgents            |
|allow_calls_to_agents_in_wrap_up           |bool                       |allowCallsToAgentsInWrapUp           |
|enable_call_queue_when_no_agents_available |bool                       |enableCallQueueWhenNoAgentsAvailable |
</div>


## `GroupCallCenterAddInstanceRequest14sp9`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Call Center instance to a group.

The domain is required in the serviceUserId.

The response is either `SuccessResponse()` or `ErrorResponse()`.

Replaced By: `GroupCallCenterAddInstanceRequest16()`,
`GroupCallCenterAddAgentListRequest()`, `GroupCallCenterModifyPolicyRequest()`,
`GroupCallCenterModifyAnnouncementRequest16()`

**Attributes:**

|Name                                       |Type                       |Description                          |
|-------------------------------------------|---------------------------|-------------------------------------|
|service_provider_id                        |str                        |serviceProviderId                    |
|group_id                                   |str                        |groupId                              |
|service_user_id                            |str                        |serviceUserId                        |
|service_instance_profile                   |OCI.serviceInstanceProfile |serviceInstanceProfile               |
|policy                                     |str                        |policy                               |
|hunt_after_no_answer                       |bool                       |huntAfterNoAnswer                    |
|no_answer_number_of_rings                  |int                        |noAnswerNumberOfRings                |
|forward_after_timeout                      |bool                       |forwardAfterTimeout                  |
|forward_timeout_seconds                    |int                        |forwardTimeoutSeconds                |
|forward_to_phone_number                    |str                        |forwardToPhoneNumber *Optional*      |
|enable_video                               |bool                       |enableVideo                          |
|queue_length                               |int                        |queueLength                          |
|allow_agent_logoff                         |bool                       |allowAgentLogoff                     |
|play_music_on_hold                         |bool                       |playMusicOnHold                      |
|play_comfort_message                       |bool                       |playComfortMessage                   |
|time_between_comfort_messages_seconds      |int                        |timeBetweenComfortMessagesSeconds    |
|enable_guard_timer                         |bool                       |enableGuardTimer                     |
|guard_timer_seconds                        |int                        |guardTimerSeconds                    |
|agent_user_id                              |List[str]                  |agentUserId *Optional*               |
|allow_call_waiting_for_agents              |bool                       |allowCallWaitingForAgents            |
|allow_calls_to_agents_in_wrap_up           |bool                       |allowCallsToAgentsInWrapUp           |
|enable_call_queue_when_no_agents_available |bool                       |enableCallQueueWhenNoAgentsAvailable |
|statistics_source                          |str                        |statisticsSource                     |
</div>


## `GroupCallCenterAddInstanceRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Call Center instance to a group.

The domain is required in the serviceUserId.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by:
`GroupCallCenterAddInstanceRequest17()`

**Attributes:**

|Name                                      |Type                       |Description                                    |
|------------------------------------------|---------------------------|-----------------------------------------------|
|service_provider_id                       |str                        |serviceProviderId                              |
|group_id                                  |str                        |groupId                                        |
|service_user_id                           |str                        |serviceUserId                                  |
|service_instance_profile                  |OCI.serviceInstanceProfile |serviceInstanceProfile                         |
|type                                      |str                        |type                                           |
|policy                                    |str                        |policy                                         |
|enable_video                              |bool                       |enableVideo                                    |
|queue_length                              |int                        |queueLength                                    |
|reporting_server_name                     |str                        |reportingServerName *Optional*                 |
|allow_caller_to_dial_escape_digit         |bool                       |allowCallerToDialEscapeDigit                   |
|escape_digit                              |str                        |escapeDigit                                    |
|reset_call_statistics_upon_entry_in_queue |bool                       |resetCallStatisticsUponEntryInQueue *Optional* |
|allow_agent_logoff                        |bool                       |allowAgentLogoff                               |
|allow_call_waiting_for_agents             |bool                       |allowCallWaitingForAgents                      |
|allow_calls_to_agents_in_wrap_up          |bool                       |allowCallsToAgentsInWrapUp *Optional*          |
|override_agent_wrap_up_time               |bool                       |overrideAgentWrapUpTime *Optional*             |
|wrap_up_seconds                           |int                        |wrapUpSeconds *Optional*                       |
|force_delivery_of_calls                   |bool                       |forceDeliveryOfCalls *Optional*                |
|force_delivery_wait_time_seconds          |int                        |forceDeliveryWaitTimeSeconds *Optional*        |
|external_preferred_audio_codec            |str                        |externalPreferredAudioCodec                    |
|internal_preferred_audio_codec            |str                        |internalPreferredAudioCodec                    |
|play_ringing_when_offering_call           |bool                       |playRingingWhenOfferingCall                    |
</div>


## `GroupCallCenterAddInstanceRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Call Center instance to a group.

The domain is required in the serviceUserId.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                      |Type                       |Description                                    |
|------------------------------------------|---------------------------|-----------------------------------------------|
|service_provider_id                       |str                        |serviceProviderId                              |
|group_id                                  |str                        |groupId                                        |
|service_user_id                           |str                        |serviceUserId                                  |
|service_instance_profile                  |OCI.serviceInstanceProfile |serviceInstanceProfile                         |
|type                                      |str                        |type                                           |
|policy                                    |str                        |policy                                         |
|enable_video                              |bool                       |enableVideo                                    |
|queue_length                              |int                        |queueLength                                    |
|reporting_server_name                     |str                        |reportingServerName *Optional*                 |
|allow_caller_to_dial_escape_digit         |bool                       |allowCallerToDialEscapeDigit                   |
|escape_digit                              |str                        |escapeDigit                                    |
|reset_call_statistics_upon_entry_in_queue |bool                       |resetCallStatisticsUponEntryInQueue *Optional* |
|allow_agent_logoff                        |bool                       |allowAgentLogoff                               |
|allow_call_waiting_for_agents             |bool                       |allowCallWaitingForAgents                      |
|allow_calls_to_agents_in_wrap_up          |bool                       |allowCallsToAgentsInWrapUp *Optional*          |
|override_agent_wrap_up_time               |bool                       |overrideAgentWrapUpTime *Optional*             |
|wrap_up_seconds                           |int                        |wrapUpSeconds *Optional*                       |
|force_delivery_of_calls                   |bool                       |forceDeliveryOfCalls *Optional*                |
|force_delivery_wait_time_seconds          |int                        |forceDeliveryWaitTimeSeconds *Optional*        |
|enable_automatic_state_change_for_agents  |bool                       |enableAutomaticStateChangeForAgents *Optional* |
|agent_state_after_call                    |str                        |agentStateAfterCall *Optional*                 |
|agent_unavailable_code                    |str                        |agentUnavailableCode *Optional*                |
|external_preferred_audio_codec            |str                        |externalPreferredAudioCodec                    |
|internal_preferred_audio_codec            |str                        |internalPreferredAudioCodec                    |
|play_ringing_when_offering_call           |bool                       |playRingingWhenOfferingCall                    |
</div>


## `GroupCallCenterAddInstanceRequest17sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Call Center instance to a group.

The domain is required in the serviceUserId.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by:
`GroupCallCenterAddInstanceRequest17sp3()`

**Attributes:**

|Name                                      |Type                       |Description                                    |
|------------------------------------------|---------------------------|-----------------------------------------------|
|service_provider_id                       |str                        |serviceProviderId                              |
|group_id                                  |str                        |groupId                                        |
|service_user_id                           |str                        |serviceUserId                                  |
|service_instance_profile                  |OCI.serviceInstanceProfile |serviceInstanceProfile                         |
|type                                      |str                        |type                                           |
|policy                                    |str                        |policy                                         |
|enable_video                              |bool                       |enableVideo                                    |
|queue_length                              |int                        |queueLength                                    |
|enable_reporting                          |bool                       |enableReporting *Optional*                     |
|reporting_server_name                     |str                        |reportingServerName *Optional*                 |
|allow_caller_to_dial_escape_digit         |bool                       |allowCallerToDialEscapeDigit                   |
|escape_digit                              |str                        |escapeDigit                                    |
|reset_call_statistics_upon_entry_in_queue |bool                       |resetCallStatisticsUponEntryInQueue *Optional* |
|allow_agent_logoff                        |bool                       |allowAgentLogoff                               |
|allow_call_waiting_for_agents             |bool                       |allowCallWaitingForAgents                      |
|allow_calls_to_agents_in_wrap_up          |bool                       |allowCallsToAgentsInWrapUp *Optional*          |
|override_agent_wrap_up_time               |bool                       |overrideAgentWrapUpTime *Optional*             |
|wrap_up_seconds                           |int                        |wrapUpSeconds *Optional*                       |
|force_delivery_of_calls                   |bool                       |forceDeliveryOfCalls *Optional*                |
|force_delivery_wait_time_seconds          |int                        |forceDeliveryWaitTimeSeconds *Optional*        |
|enable_automatic_state_change_for_agents  |bool                       |enableAutomaticStateChangeForAgents *Optional* |
|agent_state_after_call                    |str                        |agentStateAfterCall *Optional*                 |
|agent_unavailable_code                    |str                        |agentUnavailableCode *Optional*                |
|external_preferred_audio_codec            |str                        |externalPreferredAudioCodec                    |
|internal_preferred_audio_codec            |str                        |internalPreferredAudioCodec                    |
|play_ringing_when_offering_call           |bool                       |playRingingWhenOfferingCall                    |
</div>


## `GroupCallCenterAddInstanceRequest17sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Call Center instance to a group.

The domain is required in the serviceUserId.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by
`GroupCallCenterAddInstanceRequest19()`

**Attributes:**

|Name                                      |Type                       |Description                                    |
|------------------------------------------|---------------------------|-----------------------------------------------|
|service_provider_id                       |str                        |serviceProviderId                              |
|group_id                                  |str                        |groupId                                        |
|service_user_id                           |str                        |serviceUserId                                  |
|service_instance_profile                  |OCI.serviceInstanceProfile |serviceInstanceProfile                         |
|type                                      |str                        |type                                           |
|policy                                    |str                        |policy                                         |
|enable_video                              |bool                       |enableVideo                                    |
|queue_length                              |int                        |queueLength                                    |
|enable_reporting                          |bool                       |enableReporting *Optional*                     |
|reporting_server_name                     |str                        |reportingServerName *Optional*                 |
|allow_caller_to_dial_escape_digit         |bool                       |allowCallerToDialEscapeDigit                   |
|escape_digit                              |str                        |escapeDigit                                    |
|reset_call_statistics_upon_entry_in_queue |bool                       |resetCallStatisticsUponEntryInQueue            |
|allow_agent_logoff                        |bool                       |allowAgentLogoff                               |
|allow_call_waiting_for_agents             |bool                       |allowCallWaitingForAgents                      |
|allow_calls_to_agents_in_wrap_up          |bool                       |allowCallsToAgentsInWrapUp *Optional*          |
|override_agent_wrap_up_time               |bool                       |overrideAgentWrapUpTime *Optional*             |
|wrap_up_seconds                           |int                        |wrapUpSeconds *Optional*                       |
|force_delivery_of_calls                   |bool                       |forceDeliveryOfCalls *Optional*                |
|force_delivery_wait_time_seconds          |int                        |forceDeliveryWaitTimeSeconds *Optional*        |
|enable_automatic_state_change_for_agents  |bool                       |enableAutomaticStateChangeForAgents *Optional* |
|agent_state_after_call                    |str                        |agentStateAfterCall *Optional*                 |
|agent_unavailable_code                    |str                        |agentUnavailableCode *Optional*                |
|external_preferred_audio_codec            |str                        |externalPreferredAudioCodec                    |
|internal_preferred_audio_codec            |str                        |internalPreferredAudioCodec                    |
|play_ringing_when_offering_call           |bool                       |playRingingWhenOfferingCall                    |
</div>


## `GroupCallCenterAddInstanceRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Call Center instance to a group.

The domain is required in the serviceUserId.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by
`GroupCallCenterAddInstanceRequest22()`

**Attributes:**

|Name                                      |Type                       |Description                                    |
|------------------------------------------|---------------------------|-----------------------------------------------|
|service_provider_id                       |str                        |serviceProviderId                              |
|group_id                                  |str                        |groupId                                        |
|service_user_id                           |str                        |serviceUserId                                  |
|service_instance_profile                  |OCI.serviceInstanceProfile |serviceInstanceProfile                         |
|type                                      |str                        |type                                           |
|routing_type                              |str                        |routingType *Optional*                         |
|policy                                    |str                        |policy                                         |
|enable_video                              |bool                       |enableVideo                                    |
|queue_length                              |int                        |queueLength                                    |
|enable_reporting                          |bool                       |enableReporting *Optional*                     |
|allow_caller_to_dial_escape_digit         |bool                       |allowCallerToDialEscapeDigit                   |
|escape_digit                              |str                        |escapeDigit                                    |
|reset_call_statistics_upon_entry_in_queue |bool                       |resetCallStatisticsUponEntryInQueue            |
|allow_agent_logoff                        |bool                       |allowAgentLogoff                               |
|allow_call_waiting_for_agents             |bool                       |allowCallWaitingForAgents                      |
|allow_calls_to_agents_in_wrap_up          |bool                       |allowCallsToAgentsInWrapUp *Optional*          |
|override_agent_wrap_up_time               |bool                       |overrideAgentWrapUpTime *Optional*             |
|wrap_up_seconds                           |int                        |wrapUpSeconds *Optional*                       |
|force_delivery_of_calls                   |bool                       |forceDeliveryOfCalls *Optional*                |
|force_delivery_wait_time_seconds          |int                        |forceDeliveryWaitTimeSeconds *Optional*        |
|enable_automatic_state_change_for_agents  |bool                       |enableAutomaticStateChangeForAgents *Optional* |
|agent_state_after_call                    |str                        |agentStateAfterCall *Optional*                 |
|agent_unavailable_code                    |str                        |agentUnavailableCode *Optional*                |
|external_preferred_audio_codec            |str                        |externalPreferredAudioCodec                    |
|internal_preferred_audio_codec            |str                        |internalPreferredAudioCodec                    |
|play_ringing_when_offering_call           |bool                       |playRingingWhenOfferingCall                    |
|network_class_of_service                  |str                        |networkClassOfService *Optional*               |
</div>


## `GroupCallCenterAddInstanceRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Call Center instance to a group.

The domain is required in the serviceUserId.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode: routingType
enableReporting allowCallsToAgentsInWrapUp overrideAgentWrapUpTime wrapUpSeconds
forceDeliveryOfCalls forceDeliveryWaitTimeSeconds enableAutomaticStateChangeForAgents
agentStateAfterCall agentUnavailableCode networkClassOfService

**Attributes:**

|Name                                      |Type                       |Description                                    |
|------------------------------------------|---------------------------|-----------------------------------------------|
|service_provider_id                       |str                        |serviceProviderId                              |
|group_id                                  |str                        |groupId                                        |
|service_user_id                           |str                        |serviceUserId                                  |
|service_instance_profile                  |OCI.serviceInstanceProfile |serviceInstanceProfile                         |
|type                                      |str                        |type                                           |
|routing_type                              |str                        |routingType *Optional*                         |
|policy                                    |str                        |policy                                         |
|enable_video                              |bool                       |enableVideo                                    |
|queue_length                              |int                        |queueLength                                    |
|enable_reporting                          |bool                       |enableReporting *Optional*                     |
|allow_caller_to_dial_escape_digit         |bool                       |allowCallerToDialEscapeDigit                   |
|escape_digit                              |str                        |escapeDigit                                    |
|reset_call_statistics_upon_entry_in_queue |bool                       |resetCallStatisticsUponEntryInQueue            |
|allow_agent_logoff                        |bool                       |allowAgentLogoff                               |
|allow_call_waiting_for_agents             |bool                       |allowCallWaitingForAgents                      |
|allow_calls_to_agents_in_wrap_up          |bool                       |allowCallsToAgentsInWrapUp *Optional*          |
|override_agent_wrap_up_time               |bool                       |overrideAgentWrapUpTime *Optional*             |
|wrap_up_seconds                           |int                        |wrapUpSeconds *Optional*                       |
|force_delivery_of_calls                   |bool                       |forceDeliveryOfCalls *Optional*                |
|force_delivery_wait_time_seconds          |int                        |forceDeliveryWaitTimeSeconds *Optional*        |
|enable_automatic_state_change_for_agents  |bool                       |enableAutomaticStateChangeForAgents *Optional* |
|agent_state_after_call                    |str                        |agentStateAfterCall *Optional*                 |
|agent_unavailable_code                    |str                        |agentUnavailableCode *Optional*                |
|external_preferred_audio_codec            |str                        |externalPreferredAudioCodec                    |
|internal_preferred_audio_codec            |str                        |internalPreferredAudioCodec                    |
|play_ringing_when_offering_call           |bool                       |playRingingWhenOfferingCall                    |
|network_class_of_service                  |str                        |networkClassOfService *Optional*               |
</div>


## `GroupCallCenterAgentThresholdDefaultProfileGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Gets an existing default Call Center Agent Threshold Profile in a Group.

If includeAgentsTable is set to true, a table with the list of agents assigned to the
profile is included in the response.  The search criteria is used to filter the list
of agents to be included in the table.

The response is either a `GroupCallCenterAgentThresholdDefaultProfileGetResponse()` or
an `ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|service_provider_id                   |str                                   |serviceProviderId                            |
|group_id                              |str                                   |groupId                                      |
|include_agents_table                  |bool                                  |includeAgentsTable                           |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*              |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                  |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*           |
</div>


## `GroupCallCenterAgentThresholdProfileGetAvailableAgentListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of all Agents in the Group that can be assigned to a given Call Center
Agent Threshold Profile in a Group.

An agent is available to be assigned to a given Agent Threshold Profile if it is a
Call Center Standard or Call Center Premium agent and the agent is not yet assigned to
the profile.  The available agent list for a new Call Center Agent Threshold profile
can be obtained by not setting the excludeAgentsAssignedToProfileName.  When the
excludeAgentsAssignedToProfileName is specified, all agents already assigned to the
specified profile are not included in the response, even if the search criterion
element searchCriteriaAgentThresholdProfile is specified using the same profile name.

The response is either a
`GroupCallCenterAgentThresholdProfileGetAvailableAgentListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                    |Type                                          |Description                                    |
|----------------------------------------|----------------------------------------------|-----------------------------------------------|
|service_provider_id                     |str                                           |serviceProviderId                              |
|group_id                                |str                                           |groupId                                        |
|exclude_agents_assigned_to_profile_name |str                                           |excludeAgentsAssignedToProfileName *Optional*  |
|response_size_limit                     |int                                           |responseSizeLimit *Optional*                   |
|search_criteria_user_last_name          |List[OCI.searchCriteriaUserLastName]          |searchCriteriaUserLastName *Optional*          |
|search_criteria_user_first_name         |List[OCI.searchCriteriaUserFirstName]         |searchCriteriaUserFirstName *Optional*         |
|search_criteria_exact_user_department   |OCI.searchCriteriaExactUserDepartment         |searchCriteriaExactUserDepartment *Optional*   |
|search_criteria_user_id                 |List[OCI.searchCriteriaUserId]                |searchCriteriaUserId *Optional*                |
|search_criteria_dn                      |List[OCI.searchCriteriaDn]                    |searchCriteriaDn *Optional*                    |
|search_criteria_extension               |List[OCI.searchCriteriaExtension]             |searchCriteriaExtension *Optional*             |
|search_criteria_agent_threshold_profile |List[OCI.searchCriteriaAgentThresholdProfile] |searchCriteriaAgentThresholdProfile *Optional* |
</div>


## `GroupCallCenterComfortMessageBypassModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call center's comfort message bypass settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                          |Type          |Description                                         |
|----------------------------------------------|--------------|----------------------------------------------------|
|service_user_id                               |str           |serviceUserId                                       |
|is_active                                     |bool          |isActive *Optional*                                 |
|call_waiting_age_threshold_seconds            |int           |callWaitingAgeThresholdSeconds *Optional*           |
|play_announcement_after_ringing               |bool          |playAnnouncementAfterRinging *Optional*             |
|ring_time_before_playing_announcement_seconds |int           |ringTimeBeforePlayingAnnouncementSeconds *Optional* |
|audio_message_selection                       |str           |audioMessageSelection *Optional*                    |
|audio_file                                    |OCI.audioFile |audioFile *Optional*                                |
|video_message_selection                       |str           |videoMessageSelection *Optional*                    |
|video_file                                    |OCI.videoFile |videoFile *Optional*                                |
</div>


## `GroupCallCenterComfortMessageBypassModifyRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call center's comfort message bypass settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                          |Type              |Description                                         |
|----------------------------------------------|------------------|----------------------------------------------------|
|service_user_id                               |str               |serviceUserId                                       |
|is_active                                     |bool              |isActive *Optional*                                 |
|call_waiting_age_threshold_seconds            |int               |callWaitingAgeThresholdSeconds *Optional*           |
|play_announcement_after_ringing               |bool              |playAnnouncementAfterRinging *Optional*             |
|ring_time_before_playing_announcement_seconds |int               |ringTimeBeforePlayingAnnouncementSeconds *Optional* |
|audio_message_selection                       |str               |audioMessageSelection *Optional*                    |
|audio_url_list                                |OCI.audioUrlList  |audioUrlList *Optional*                             |
|audio_file_list                               |OCI.audioFileList |audioFileList *Optional*                            |
|video_message_selection                       |str               |videoMessageSelection *Optional*                    |
|video_url_list                                |OCI.videoUrlList  |videoUrlList *Optional*                             |
|video_file_list                               |OCI.videoFileList |videoFileList *Optional*                            |
</div>


## `GroupCallCenterComfortMessageBypassModifyRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call center's comfort message bypass settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                          |Type              |Description                                         |
|----------------------------------------------|------------------|----------------------------------------------------|
|service_user_id                               |str               |serviceUserId                                       |
|is_active                                     |bool              |isActive *Optional*                                 |
|call_waiting_age_threshold_seconds            |int               |callWaitingAgeThresholdSeconds *Optional*           |
|play_announcement_after_ringing               |bool              |playAnnouncementAfterRinging *Optional*             |
|ring_time_before_playing_announcement_seconds |int               |ringTimeBeforePlayingAnnouncementSeconds *Optional* |
|audio_message_selection                       |str               |audioMessageSelection *Optional*                    |
|audio_url_list                                |OCI.audioUrlList  |audioUrlList *Optional*                             |
|audio_file_list                               |OCI.audioFileList |audioFileList *Optional*                            |
|video_message_selection                       |str               |videoMessageSelection *Optional*                    |
|video_url_list                                |OCI.videoUrlList  |videoUrlList *Optional*                             |
|video_file_list                               |OCI.videoFileList |videoFileList *Optional*                            |
</div>


## `GroupCallCenterCurrentAndPastAgentGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the current and past agents for the group.

The response is either `GroupCallCenterCurrentAndPastAgentGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                            |Type                                  |Description                            |
|--------------------------------|--------------------------------------|---------------------------------------|
|service_provider_id             |str                                   |serviceProviderId                      |
|group_id                        |str                                   |groupId                                |
|response_size_limit             |int                                   |responseSizeLimit *Optional*           |
|search_criteria_user_last_name  |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*  |
|search_criteria_user_first_name |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional* |
|search_criteria_user_id         |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*        |
|search_criteria_dn              |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*            |
|search_criteria_extension       |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*     |
</div>


## `GroupCallCenterCurrentAndPastCallCenterGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all the current and past call centers for the group.

The response is either `GroupCallCenterCurrentAndPastCallCenterGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                             |Type                             |Description                             |
|---------------------------------|---------------------------------|----------------------------------------|
|service_provider_id              |str                              |serviceProviderId                       |
|is_premium_only                  |bool                             |isPremiumOnly *Optional*                |
|group_id                         |str                              |groupId                                 |
|response_size_limit              |int                              |responseSizeLimit *Optional*            |
|search_criteria_call_center_name |OCI.searchCriteriaCallCenterName |searchCriteriaCallCenterName *Optional* |
</div>


## `GroupCallCenterEnhancedReportingScheduledReportGetActiveListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a list of active group level call center reporting scheduled reports.

The response is either a
`GroupCallCenterEnhancedReportingScheduledReportGetActiveListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                                                     |Type                                                                |Description                                                                |
|-------------------------------------------------------------------------|--------------------------------------------------------------------|---------------------------------------------------------------------------|
|service_provider_id                                                      |str                                                                 |serviceProviderId                                                          |
|group_id                                                                 |str                                                                 |groupId                                                                    |
|response_size_limit                                                      |int                                                                 |responseSizeLimit *Optional*                                               |
|search_criteria_call_center_scheduled_report_name                        |List[OCI.searchCriteriaCallCenterScheduledReportName]               |searchCriteriaCallCenterScheduledReportName *Optional*                     |
|search_criteria_exact_call_center_scheduled_report_created_by_supervisor |OCI.searchCriteriaExactCallCenterScheduledReportCreatedBySupervisor |searchCriteriaExactCallCenterScheduledReportCreatedBySupervisor *Optional* |
|search_criteria_exact_call_center_report_template_key                    |OCI.searchCriteriaExactCallCenterReportTemplateKey                  |searchCriteriaExactCallCenterReportTemplateKey *Optional*                  |
</div>


## `GroupCallCenterEnhancedReportingScheduledReportGetCompletedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a list of completed group level call center reporting scheduled
reports.

The response is either a
`GroupCallCenterEnhancedReportingScheduledReportGetCompletedListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                                                     |Type                                                                |Description                                                                |
|-------------------------------------------------------------------------|--------------------------------------------------------------------|---------------------------------------------------------------------------|
|service_provider_id                                                      |str                                                                 |serviceProviderId                                                          |
|group_id                                                                 |str                                                                 |groupId                                                                    |
|response_size_limit                                                      |int                                                                 |responseSizeLimit *Optional*                                               |
|search_criteria_call_center_scheduled_report_name                        |List[OCI.searchCriteriaCallCenterScheduledReportName]               |searchCriteriaCallCenterScheduledReportName *Optional*                     |
|search_criteria_exact_call_center_scheduled_report_created_by_supervisor |OCI.searchCriteriaExactCallCenterScheduledReportCreatedBySupervisor |searchCriteriaExactCallCenterScheduledReportCreatedBySupervisor *Optional* |
|search_criteria_exact_call_center_report_template_key                    |OCI.searchCriteriaExactCallCenterReportTemplateKey                  |searchCriteriaExactCallCenterReportTemplateKey *Optional*                  |
</div>


## `GroupCallCenterEnhancedReportingScheduledReportGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a list of group level call center reporting scheduled reports.

The response is either a
`GroupCallCenterEnhancedReportingScheduledReportGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                                                     |Type                                                                |Description                                                                |
|-------------------------------------------------------------------------|--------------------------------------------------------------------|---------------------------------------------------------------------------|
|service_provider_id                                                      |str                                                                 |serviceProviderId                                                          |
|group_id                                                                 |str                                                                 |groupId                                                                    |
|response_size_limit                                                      |int                                                                 |responseSizeLimit *Optional*                                               |
|search_criteria_call_center_scheduled_report_name                        |List[OCI.searchCriteriaCallCenterScheduledReportName]               |searchCriteriaCallCenterScheduledReportName *Optional*                     |
|search_criteria_exact_call_center_scheduled_report_created_by_supervisor |OCI.searchCriteriaExactCallCenterScheduledReportCreatedBySupervisor |searchCriteriaExactCallCenterScheduledReportCreatedBySupervisor *Optional* |
|search_criteria_exact_call_center_report_template_key                    |OCI.searchCriteriaExactCallCenterReportTemplateKey                  |searchCriteriaExactCallCenterReportTemplateKey *Optional*                  |
</div>


## `GroupCallCenterForcedForwardingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call center's forced forwarding settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                |Type          |Description                                 |
|------------------------------------|--------------|--------------------------------------------|
|service_user_id                     |str           |serviceUserId                               |
|is_active                           |bool          |isActive *Optional*                         |
|forward_to_phone_number             |str           |forwardToPhoneNumber *Optional*             |
|allow_enable_via_fac                |bool          |allowEnableViaFAC *Optional*                |
|play_announcement_before_forwarding |bool          |playAnnouncementBeforeForwarding *Optional* |
|audio_message_selection             |str           |audioMessageSelection *Optional*            |
|audio_file                          |OCI.audioFile |audioFile *Optional*                        |
|video_message_selection             |str           |videoMessageSelection *Optional*            |
|video_file                          |OCI.videoFile |videoFile *Optional*                        |
</div>


## `GroupCallCenterForcedForwardingModifyRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call center's forced forwarding settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                |Type              |Description                                 |
|------------------------------------|------------------|--------------------------------------------|
|service_user_id                     |str               |serviceUserId                               |
|is_active                           |bool              |isActive *Optional*                         |
|forward_to_phone_number             |str               |forwardToPhoneNumber *Optional*             |
|allow_enable_via_fac                |bool              |allowEnableViaFAC *Optional*                |
|play_announcement_before_forwarding |bool              |playAnnouncementBeforeForwarding *Optional* |
|audio_message_selection             |str               |audioMessageSelection *Optional*            |
|audio_url_list                      |OCI.audioUrlList  |audioUrlList *Optional*                     |
|audio_file_list                     |OCI.audioFileList |audioFileList *Optional*                    |
|video_message_selection             |str               |videoMessageSelection *Optional*            |
|video_url_list                      |OCI.videoUrlList  |videoUrlList *Optional*                     |
|video_file_list                     |OCI.videoFileList |videoFileList *Optional*                    |
</div>


## `GroupCallCenterForcedForwardingModifyRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call center's forced forwarding settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                |Type              |Description                                 |
|------------------------------------|------------------|--------------------------------------------|
|service_user_id                     |str               |serviceUserId                               |
|is_active                           |bool              |isActive *Optional*                         |
|forward_to_phone_number             |str               |forwardToPhoneNumber *Optional*             |
|allow_enable_via_fac                |bool              |allowEnableViaFAC *Optional*                |
|play_announcement_before_forwarding |bool              |playAnnouncementBeforeForwarding *Optional* |
|audio_message_selection             |str               |audioMessageSelection *Optional*            |
|audio_url_list                      |OCI.audioUrlList  |audioUrlList *Optional*                     |
|audio_file_list                     |OCI.audioFileList |audioFileList *Optional*                    |
|video_message_selection             |str               |videoMessageSelection *Optional*            |
|video_url_list                      |OCI.videoUrlList  |videoUrlList *Optional*                     |
|video_file_list                     |OCI.videoFileList |videoFileList *Optional*                    |
</div>


## `GroupCallCenterGetAgentListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of agents assigned to a call center.

The response is either a `GroupCallCenterGetAgentListResponse()` or an
`ErrorResponse()`. The following element is only used in AS data mode and ignored in
XS data mode: searchCriteriaExactSkillLevel

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|service_user_id                       |str                                   |serviceUserId                                |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_exact_user_group      |OCI.searchCriteriaExactUserGroup      |searchCriteriaExactUserGroup *Optional*      |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*              |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                  |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*           |
|search_criteria_exact_skill_level     |OCI.searchCriteriaExactSkillLevel     |searchCriteriaExactSkillLevel *Optional*     |
</div>


## `GroupCallCenterGetAgentPagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of agents assigned to a call center.

If the responsePagingControl element is not provided, the paging startIndex will be
set to 1 by default, and the responsePageSize will be set to the maximum
ResponsePageSize by default.  It is possible to search by various criteria to restrict
the number of rows returned.  Multiple search criteria are logically ANDed together
unless the searchCriteriaModeOr option is included.  Then the search criteria are
logically ORed together.  `ErrorResponse()` is returned if
searchCriteriaExactUserGroup or searchCriteriaExactSkillLevel have multiple entries
and searchCriteriaModeOr is not included.  Sorting is done on either a priority basis
or a skill basis depending on the type of call center.

The response is either a `GroupCallCenterGetAgentPagedSortedListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                              |Type                                    |Description                              |
|----------------------------------|----------------------------------------|-----------------------------------------|
|service_user_id                   |str                                     |serviceUserId                            |
|response_paging_control           |OCI.responsePagingControl               |responsePagingControl *Optional*         |
|search_criteria_user_id           |List[OCI.searchCriteriaUserId]          |searchCriteriaUserId *Optional*          |
|search_criteria_user_last_name    |List[OCI.searchCriteriaUserLastName]    |searchCriteriaUserLastName *Optional*    |
|search_criteria_user_first_name   |List[OCI.searchCriteriaUserFirstName]   |searchCriteriaUserFirstName *Optional*   |
|search_criteria_dn                |List[OCI.searchCriteriaDn]              |searchCriteriaDn *Optional*              |
|search_criteria_extension         |List[OCI.searchCriteriaExtension]       |searchCriteriaExtension *Optional*       |
|search_criteria_department_name   |List[OCI.searchCriteriaDepartmentName]  |searchCriteriaDepartmentName *Optional*  |
|search_criteria_email_address     |List[OCI.searchCriteriaEmailAddress]    |searchCriteriaEmailAddress *Optional*    |
|search_criteria_exact_skill_level |List[OCI.searchCriteriaExactSkillLevel] |searchCriteriaExactSkillLevel *Optional* |
|search_criteria_exact_user_group  |List[OCI.searchCriteriaExactUserGroup]  |searchCriteriaExactUserGroup *Optional*  |
|search_criteria_mode_or           |bool                                    |searchCriteriaModeOr *Optional*          |
</div>


## `GroupCallCenterGetAvailableAgentListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of users that can be assigned as agents to a given type of Call Center.

Searching for users by group only makes sense when the call center is part of an
Enterprise.

The response is either `GroupCallCenterGetAvailableAgentListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|service_provider_id                   |str                                   |serviceProviderId                            |
|group_id                              |str                                   |groupId                                      |
|call_center_type                      |str                                   |callCenterType                               |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_exact_user_group      |OCI.searchCriteriaExactUserGroup      |searchCriteriaExactUserGroup *Optional*      |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*              |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                  |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*           |
</div>


## `GroupCallCenterGetAvailableSupervisorListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of users that can be assigned as supervisors to a Call Center.

Searching for users by group only makes sense when the call center is part of an
Enterprise.

The response is either `GroupCallCenterGetAvailableSupervisorListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|service_provider_id                   |str                                   |serviceProviderId                            |
|group_id                              |str                                   |groupId                                      |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_exact_user_group      |OCI.searchCriteriaExactUserGroup      |searchCriteriaExactUserGroup *Optional*      |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*              |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                  |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*           |
</div>


## `GroupCallCenterGetAvailableUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of users that can be assigned to a Call Center group.

Searching for users by group only makes sense when the call center is part of an
Enterprise.

The response is either `GroupCallCenterGetAvailableUserListResponse()` or
`ErrorResponse()`.

Replaced By: `GroupCallCenterGetAvailableAgentListRequest()` and
`GroupCallCenterGetAvailableSupervisorListRequest()`

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|service_provider_id                   |str                                   |serviceProviderId                            |
|group_id                              |str                                   |groupId                                      |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_exact_user_group      |OCI.searchCriteriaExactUserGroup      |searchCriteriaExactUserGroup *Optional*      |
</div>


## `GroupCallCenterHolidayServiceModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call center's holiday service settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                            |Type          |Description                             |
|--------------------------------|--------------|----------------------------------------|
|service_user_id                 |str           |serviceUserId                           |
|action                          |str           |action *Optional*                       |
|holiday_schedule                |str           |holidaySchedule *Optional*              |
|transfer_phone_number           |str           |transferPhoneNumber *Optional*          |
|play_announcement_before_action |bool          |playAnnouncementBeforeAction *Optional* |
|audio_message_selection         |str           |audioMessageSelection *Optional*        |
|audio_file                      |OCI.audioFile |audioFile *Optional*                    |
|video_message_selection         |str           |videoMessageSelection *Optional*        |
|video_file                      |OCI.videoFile |videoFile *Optional*                    |
</div>


## `GroupCallCenterHolidayServiceModifyRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call center's holiday service settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                            |Type              |Description                             |
|--------------------------------|------------------|----------------------------------------|
|service_user_id                 |str               |serviceUserId                           |
|action                          |str               |action *Optional*                       |
|holiday_schedule                |str               |holidaySchedule *Optional*              |
|transfer_phone_number           |str               |transferPhoneNumber *Optional*          |
|play_announcement_before_action |bool              |playAnnouncementBeforeAction *Optional* |
|audio_message_selection         |str               |audioMessageSelection *Optional*        |
|audio_url_list                  |OCI.audioUrlList  |audioUrlList *Optional*                 |
|audio_file_list                 |OCI.audioFileList |audioFileList *Optional*                |
|video_message_selection         |str               |videoMessageSelection *Optional*        |
|video_url_list                  |OCI.videoUrlList  |videoUrlList *Optional*                 |
|video_file_list                 |OCI.videoFileList |videoFileList *Optional*                |
</div>


## `GroupCallCenterHolidayServiceModifyRequest17sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call center's holiday service settings.

Only Group and Enterprise level schedules are accepted.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                            |Type                |Description                             |
|--------------------------------|--------------------|----------------------------------------|
|service_user_id                 |str                 |serviceUserId                           |
|action                          |str                 |action *Optional*                       |
|holiday_schedule                |OCI.holidaySchedule |holidaySchedule *Optional*              |
|transfer_phone_number           |str                 |transferPhoneNumber *Optional*          |
|play_announcement_before_action |bool                |playAnnouncementBeforeAction *Optional* |
|audio_message_selection         |str                 |audioMessageSelection *Optional*        |
|audio_url_list                  |OCI.audioUrlList    |audioUrlList *Optional*                 |
|audio_file_list                 |OCI.audioFileList   |audioFileList *Optional*                |
|video_message_selection         |str                 |videoMessageSelection *Optional*        |
|video_url_list                  |OCI.videoUrlList    |videoUrlList *Optional*                 |
|video_file_list                 |OCI.videoFileList   |videoFileList *Optional*                |
</div>


## `GroupCallCenterHolidayServiceModifyRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call center's holiday service settings.

Only Group and Enterprise level schedules are accepted.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                            |Type                |Description                             |
|--------------------------------|--------------------|----------------------------------------|
|service_user_id                 |str                 |serviceUserId                           |
|action                          |str                 |action *Optional*                       |
|holiday_schedule                |OCI.holidaySchedule |holidaySchedule *Optional*              |
|transfer_phone_number           |str                 |transferPhoneNumber *Optional*          |
|play_announcement_before_action |bool                |playAnnouncementBeforeAction *Optional* |
|audio_message_selection         |str                 |audioMessageSelection *Optional*        |
|audio_url_list                  |OCI.audioUrlList    |audioUrlList *Optional*                 |
|audio_file_list                 |OCI.audioFileList   |audioFileList *Optional*                |
|video_message_selection         |str                 |videoMessageSelection *Optional*        |
|video_url_list                  |OCI.videoUrlList    |videoUrlList *Optional*                 |
|video_file_list                 |OCI.videoFileList   |videoFileList *Optional*                |
</div>


## `GroupCallCenterModifyAgentListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the agent list for a call center.

The response is either `SuccessResponse()` or `ErrorResponse()`. If the
agentUserIdList is used for Skill Based Premium call centers, the agents will be set
to skill level 1. The following element is only used in AS data mode and ignored in XS
data mode: skilledAgentUserIdList

**Attributes:**

|Name                       |Type                             |Description                       |
|---------------------------|---------------------------------|----------------------------------|
|service_user_id            |str                              |serviceUserId                     |
|agent_user_id_list         |OCI.agentUserIdList              |agentUserIdList *Optional*        |
|skilled_agent_user_id_list |List[OCI.skilledAgentUserIdList] |skilledAgentUserIdList *Optional* |
</div>


## `GroupCallCenterModifyInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a Call Center instance.

The response is either `SuccessResponse()` or `ErrorResponse()`.

Replaced By: `GroupCallCenterModifyInstanceRequest16()`

**Attributes:**

|Name                                       |Type                       |Description                                     |
|-------------------------------------------|---------------------------|------------------------------------------------|
|service_user_id                            |str                        |serviceUserId                                   |
|service_instance_profile                   |OCI.serviceInstanceProfile |serviceInstanceProfile *Optional*               |
|policy                                     |str                        |policy *Optional*                               |
|hunt_after_no_answer                       |bool                       |huntAfterNoAnswer *Optional*                    |
|no_answer_number_of_rings                  |int                        |noAnswerNumberOfRings *Optional*                |
|forward_after_timeout                      |bool                       |forwardAfterTimeout *Optional*                  |
|forward_timeout_seconds                    |int                        |forwardTimeoutSeconds *Optional*                |
|forward_to_phone_number                    |str                        |forwardToPhoneNumber *Optional*                 |
|enable_video                               |bool                       |enableVideo *Optional*                          |
|queue_length                               |int                        |queueLength *Optional*                          |
|allow_agent_logoff                         |bool                       |allowAgentLogoff *Optional*                     |
|play_music_on_hold                         |bool                       |playMusicOnHold *Optional*                      |
|play_comfort_message                       |bool                       |playComfortMessage *Optional*                   |
|time_between_comfort_messages_seconds      |int                        |timeBetweenComfortMessagesSeconds *Optional*    |
|enable_guard_timer                         |bool                       |enableGuardTimer *Optional*                     |
|guard_timer_seconds                        |int                        |guardTimerSeconds *Optional*                    |
|agent_user_id_list                         |OCI.agentUserIdList        |agentUserIdList *Optional*                      |
|allow_call_waiting_for_agents              |bool                       |allowCallWaitingForAgents *Optional*            |
|allow_calls_to_agents_in_wrap_up           |bool                       |allowCallsToAgentsInWrapUp *Optional*           |
|enable_call_queue_when_no_agents_available |bool                       |enableCallQueueWhenNoAgentsAvailable *Optional* |
|statistics_source                          |str                        |statisticsSource *Optional*                     |
</div>


## `GroupCallCenterModifyInstanceRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a Call Center instance.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                      |Type                       |Description                                    |
|------------------------------------------|---------------------------|-----------------------------------------------|
|service_user_id                           |str                        |serviceUserId                                  |
|service_instance_profile                  |OCI.serviceInstanceProfile |serviceInstanceProfile *Optional*              |
|type                                      |str                        |type *Optional*                                |
|policy                                    |str                        |policy *Optional*                              |
|enable_video                              |bool                       |enableVideo *Optional*                         |
|queue_length                              |int                        |queueLength *Optional*                         |
|reporting_server_name                     |str                        |reportingServerName *Optional*                 |
|allow_caller_to_dial_escape_digit         |bool                       |allowCallerToDialEscapeDigit *Optional*        |
|escape_digit                              |str                        |escapeDigit *Optional*                         |
|reset_call_statistics_upon_entry_in_queue |bool                       |resetCallStatisticsUponEntryInQueue *Optional* |
|allow_agent_logoff                        |bool                       |allowAgentLogoff *Optional*                    |
|allow_call_waiting_for_agents             |bool                       |allowCallWaitingForAgents *Optional*           |
|allow_calls_to_agents_in_wrap_up          |bool                       |allowCallsToAgentsInWrapUp *Optional*          |
|override_agent_wrap_up_time               |bool                       |overrideAgentWrapUpTime *Optional*             |
|wrap_up_seconds                           |int                        |wrapUpSeconds *Optional*                       |
|force_delivery_of_calls                   |bool                       |forceDeliveryOfCalls *Optional*                |
|force_delivery_wait_time_seconds          |int                        |forceDeliveryWaitTimeSeconds *Optional*        |
|enable_automatic_state_change_for_agents  |bool                       |enableAutomaticStateChangeForAgents *Optional* |
|agent_state_after_call                    |str                        |agentStateAfterCall *Optional*                 |
|agent_unavailable_code                    |str                        |agentUnavailableCode *Optional*                |
|external_preferred_audio_codec            |str                        |externalPreferredAudioCodec *Optional*         |
|internal_preferred_audio_codec            |str                        |internalPreferredAudioCodec *Optional*         |
|play_ringing_when_offering_call           |bool                       |playRingingWhenOfferingCall *Optional*         |
</div>


## `GroupCallCenterModifyInstanceRequest17sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a Call Center instance.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by:
`GroupCallCenterModifyInstanceRequest19()`

**Attributes:**

|Name                                      |Type                       |Description                                    |
|------------------------------------------|---------------------------|-----------------------------------------------|
|service_user_id                           |str                        |serviceUserId                                  |
|service_instance_profile                  |OCI.serviceInstanceProfile |serviceInstanceProfile *Optional*              |
|type                                      |str                        |type *Optional*                                |
|policy                                    |str                        |policy *Optional*                              |
|enable_video                              |bool                       |enableVideo *Optional*                         |
|queue_length                              |int                        |queueLength *Optional*                         |
|enable_reporting                          |bool                       |enableReporting *Optional*                     |
|reporting_server_name                     |str                        |reportingServerName *Optional*                 |
|allow_caller_to_dial_escape_digit         |bool                       |allowCallerToDialEscapeDigit *Optional*        |
|escape_digit                              |str                        |escapeDigit *Optional*                         |
|reset_call_statistics_upon_entry_in_queue |bool                       |resetCallStatisticsUponEntryInQueue *Optional* |
|allow_agent_logoff                        |bool                       |allowAgentLogoff *Optional*                    |
|allow_call_waiting_for_agents             |bool                       |allowCallWaitingForAgents *Optional*           |
|allow_calls_to_agents_in_wrap_up          |bool                       |allowCallsToAgentsInWrapUp *Optional*          |
|override_agent_wrap_up_time               |bool                       |overrideAgentWrapUpTime *Optional*             |
|wrap_up_seconds                           |int                        |wrapUpSeconds *Optional*                       |
|force_delivery_of_calls                   |bool                       |forceDeliveryOfCalls *Optional*                |
|force_delivery_wait_time_seconds          |int                        |forceDeliveryWaitTimeSeconds *Optional*        |
|enable_automatic_state_change_for_agents  |bool                       |enableAutomaticStateChangeForAgents *Optional* |
|agent_state_after_call                    |str                        |agentStateAfterCall *Optional*                 |
|agent_unavailable_code                    |str                        |agentUnavailableCode *Optional*                |
|external_preferred_audio_codec            |str                        |externalPreferredAudioCodec *Optional*         |
|internal_preferred_audio_codec            |str                        |internalPreferredAudioCodec *Optional*         |
|play_ringing_when_offering_call           |bool                       |playRingingWhenOfferingCall *Optional*         |
</div>


## `GroupCallCenterModifyInstanceRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a Call Center instance.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                      |Type                       |Description                                    |
|------------------------------------------|---------------------------|-----------------------------------------------|
|service_user_id                           |str                        |serviceUserId                                  |
|service_instance_profile                  |OCI.serviceInstanceProfile |serviceInstanceProfile *Optional*              |
|type                                      |str                        |type *Optional*                                |
|routing_type                              |str                        |routingType *Optional*                         |
|policy                                    |str                        |policy *Optional*                              |
|enable_video                              |bool                       |enableVideo *Optional*                         |
|queue_length                              |int                        |queueLength *Optional*                         |
|enable_reporting                          |bool                       |enableReporting *Optional*                     |
|allow_caller_to_dial_escape_digit         |bool                       |allowCallerToDialEscapeDigit *Optional*        |
|escape_digit                              |str                        |escapeDigit *Optional*                         |
|reset_call_statistics_upon_entry_in_queue |bool                       |resetCallStatisticsUponEntryInQueue *Optional* |
|allow_agent_logoff                        |bool                       |allowAgentLogoff *Optional*                    |
|allow_call_waiting_for_agents             |bool                       |allowCallWaitingForAgents *Optional*           |
|allow_calls_to_agents_in_wrap_up          |bool                       |allowCallsToAgentsInWrapUp *Optional*          |
|override_agent_wrap_up_time               |bool                       |overrideAgentWrapUpTime *Optional*             |
|wrap_up_seconds                           |int                        |wrapUpSeconds *Optional*                       |
|force_delivery_of_calls                   |bool                       |forceDeliveryOfCalls *Optional*                |
|force_delivery_wait_time_seconds          |int                        |forceDeliveryWaitTimeSeconds *Optional*        |
|enable_automatic_state_change_for_agents  |bool                       |enableAutomaticStateChangeForAgents *Optional* |
|agent_state_after_call                    |str                        |agentStateAfterCall *Optional*                 |
|agent_unavailable_code                    |str                        |agentUnavailableCode *Optional*                |
|external_preferred_audio_codec            |str                        |externalPreferredAudioCodec *Optional*         |
|internal_preferred_audio_codec            |str                        |internalPreferredAudioCodec *Optional*         |
|play_ringing_when_offering_call           |bool                       |playRingingWhenOfferingCall *Optional*         |
|network_class_of_service                  |str                        |networkClassOfService *Optional*               |
</div>


## `GroupCallCenterModifyInstanceRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a Call Center instance.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode: routingType
enableReporting allowCallsToAgentsInWrapUp overrideAgentWrapUpTime wrapUpSeconds
forceDeliveryOfCalls forceDeliveryWaitTimeSeconds enableAutomaticStateChangeForAgents
agentStateAfterCall agentUnavailableCode callCenterQueueThresholdsIsActive
networkClassOfService

**Attributes:**

|Name                                      |Type                       |Description                                    |
|------------------------------------------|---------------------------|-----------------------------------------------|
|service_user_id                           |str                        |serviceUserId                                  |
|service_instance_profile                  |OCI.serviceInstanceProfile |serviceInstanceProfile *Optional*              |
|type                                      |str                        |type *Optional*                                |
|routing_type                              |str                        |routingType *Optional*                         |
|policy                                    |str                        |policy *Optional*                              |
|enable_video                              |bool                       |enableVideo *Optional*                         |
|queue_length                              |int                        |queueLength *Optional*                         |
|enable_reporting                          |bool                       |enableReporting *Optional*                     |
|allow_caller_to_dial_escape_digit         |bool                       |allowCallerToDialEscapeDigit *Optional*        |
|escape_digit                              |str                        |escapeDigit *Optional*                         |
|reset_call_statistics_upon_entry_in_queue |bool                       |resetCallStatisticsUponEntryInQueue *Optional* |
|allow_agent_logoff                        |bool                       |allowAgentLogoff *Optional*                    |
|allow_call_waiting_for_agents             |bool                       |allowCallWaitingForAgents *Optional*           |
|allow_calls_to_agents_in_wrap_up          |bool                       |allowCallsToAgentsInWrapUp *Optional*          |
|override_agent_wrap_up_time               |bool                       |overrideAgentWrapUpTime *Optional*             |
|wrap_up_seconds                           |int                        |wrapUpSeconds *Optional*                       |
|force_delivery_of_calls                   |bool                       |forceDeliveryOfCalls *Optional*                |
|force_delivery_wait_time_seconds          |int                        |forceDeliveryWaitTimeSeconds *Optional*        |
|enable_automatic_state_change_for_agents  |bool                       |enableAutomaticStateChangeForAgents *Optional* |
|agent_state_after_call                    |str                        |agentStateAfterCall *Optional*                 |
|agent_unavailable_code                    |str                        |agentUnavailableCode *Optional*                |
|external_preferred_audio_codec            |str                        |externalPreferredAudioCodec *Optional*         |
|internal_preferred_audio_codec            |str                        |internalPreferredAudioCodec *Optional*         |
|play_ringing_when_offering_call           |bool                       |playRingingWhenOfferingCall *Optional*         |
|network_class_of_service                  |str                        |networkClassOfService *Optional*               |
</div>


## `GroupCallCenterNightServiceModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call center's night service settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                            |Type                |Description                             |
|--------------------------------|--------------------|----------------------------------------|
|service_user_id                 |str                 |serviceUserId                           |
|action                          |str                 |action *Optional*                       |
|business_hours                  |str                 |businessHours *Optional*                |
|force_night_service             |bool                |forceNightService *Optional*            |
|allow_manual_override_via_fac   |bool                |allowManualOverrideViaFAC *Optional*    |
|transfer_phone_number           |str                 |transferPhoneNumber *Optional*          |
|play_announcement_before_action |bool                |playAnnouncementBeforeAction *Optional* |
|audio_message_selection         |str                 |audioMessageSelection *Optional*        |
|audio_file                      |OCI.audioFile       |audioFile *Optional*                    |
|video_message_selection         |str                 |videoMessageSelection *Optional*        |
|video_file                      |OCI.videoFile       |videoFile *Optional*                    |
|manual_announcement_mode        |str                 |manualAnnouncementMode *Optional*       |
|manual_audio_message_selection  |str                 |manualAudioMessageSelection *Optional*  |
|manual_audio_file               |OCI.manualAudioFile |manualAudioFile *Optional*              |
|manual_video_message_selection  |str                 |manualVideoMessageSelection *Optional*  |
|manual_video_file               |OCI.manualVideoFile |manualVideoFile *Optional*              |
</div>


## `GroupCallCenterNightServiceModifyRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call center's night service settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                            |Type                    |Description                             |
|--------------------------------|------------------------|----------------------------------------|
|service_user_id                 |str                     |serviceUserId                           |
|action                          |str                     |action *Optional*                       |
|business_hours                  |str                     |businessHours *Optional*                |
|force_night_service             |bool                    |forceNightService *Optional*            |
|allow_manual_override_via_fac   |bool                    |allowManualOverrideViaFAC *Optional*    |
|transfer_phone_number           |str                     |transferPhoneNumber *Optional*          |
|play_announcement_before_action |bool                    |playAnnouncementBeforeAction *Optional* |
|audio_message_selection         |str                     |audioMessageSelection *Optional*        |
|audio_url_list                  |OCI.audioUrlList        |audioUrlList *Optional*                 |
|audio_file_list                 |OCI.audioFileList       |audioFileList *Optional*                |
|video_message_selection         |str                     |videoMessageSelection *Optional*        |
|video_url_list                  |OCI.videoUrlList        |videoUrlList *Optional*                 |
|video_file_list                 |OCI.videoFileList       |videoFileList *Optional*                |
|manual_announcement_mode        |str                     |manualAnnouncementMode *Optional*       |
|manual_audio_message_selection  |str                     |manualAudioMessageSelection *Optional*  |
|manual_audio_url_list           |OCI.manualAudioUrlList  |manualAudioUrlList *Optional*           |
|manual_audio_file_list          |OCI.manualAudioFileList |manualAudioFileList *Optional*          |
|manual_video_message_selection  |str                     |manualVideoMessageSelection *Optional*  |
|manual_video_url_list           |OCI.manualVideoUrlList  |manualVideoUrlList *Optional*           |
|manual_video_file_list          |OCI.manualVideoFileList |manualVideoFileList *Optional*          |
</div>


## `GroupCallCenterNightServiceModifyRequest17sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call center's night service settings.

Only Group and Enterprise level schedules are accepted.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                            |Type                    |Description                             |
|--------------------------------|------------------------|----------------------------------------|
|service_user_id                 |str                     |serviceUserId                           |
|action                          |str                     |action *Optional*                       |
|business_hours                  |OCI.businessHours       |businessHours *Optional*                |
|force_night_service             |bool                    |forceNightService *Optional*            |
|allow_manual_override_via_fac   |bool                    |allowManualOverrideViaFAC *Optional*    |
|transfer_phone_number           |str                     |transferPhoneNumber *Optional*          |
|play_announcement_before_action |bool                    |playAnnouncementBeforeAction *Optional* |
|audio_message_selection         |str                     |audioMessageSelection *Optional*        |
|audio_url_list                  |OCI.audioUrlList        |audioUrlList *Optional*                 |
|audio_file_list                 |OCI.audioFileList       |audioFileList *Optional*                |
|video_message_selection         |str                     |videoMessageSelection *Optional*        |
|video_url_list                  |OCI.videoUrlList        |videoUrlList *Optional*                 |
|video_file_list                 |OCI.videoFileList       |videoFileList *Optional*                |
|manual_announcement_mode        |str                     |manualAnnouncementMode *Optional*       |
|manual_audio_message_selection  |str                     |manualAudioMessageSelection *Optional*  |
|manual_audio_url_list           |OCI.manualAudioUrlList  |manualAudioUrlList *Optional*           |
|manual_audio_file_list          |OCI.manualAudioFileList |manualAudioFileList *Optional*          |
|manual_video_message_selection  |str                     |manualVideoMessageSelection *Optional*  |
|manual_video_url_list           |OCI.manualVideoUrlList  |manualVideoUrlList *Optional*           |
|manual_video_file_list          |OCI.manualVideoFileList |manualVideoFileList *Optional*          |
</div>


## `GroupCallCenterNightServiceModifyRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call center's night service settings.

Only Group and Enterprise level schedules are accepted.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                            |Type                    |Description                             |
|--------------------------------|------------------------|----------------------------------------|
|service_user_id                 |str                     |serviceUserId                           |
|action                          |str                     |action *Optional*                       |
|business_hours                  |OCI.businessHours       |businessHours *Optional*                |
|force_night_service             |bool                    |forceNightService *Optional*            |
|allow_manual_override_via_fac   |bool                    |allowManualOverrideViaFAC *Optional*    |
|transfer_phone_number           |str                     |transferPhoneNumber *Optional*          |
|play_announcement_before_action |bool                    |playAnnouncementBeforeAction *Optional* |
|audio_message_selection         |str                     |audioMessageSelection *Optional*        |
|audio_url_list                  |OCI.audioUrlList        |audioUrlList *Optional*                 |
|audio_file_list                 |OCI.audioFileList       |audioFileList *Optional*                |
|video_message_selection         |str                     |videoMessageSelection *Optional*        |
|video_url_list                  |OCI.videoUrlList        |videoUrlList *Optional*                 |
|video_file_list                 |OCI.videoFileList       |videoFileList *Optional*                |
|manual_announcement_mode        |str                     |manualAnnouncementMode *Optional*       |
|manual_audio_message_selection  |str                     |manualAudioMessageSelection *Optional*  |
|manual_audio_url_list           |OCI.manualAudioUrlList  |manualAudioUrlList *Optional*           |
|manual_audio_file_list          |OCI.manualAudioFileList |manualAudioFileList *Optional*          |
|manual_video_message_selection  |str                     |manualVideoMessageSelection *Optional*  |
|manual_video_url_list           |OCI.manualVideoUrlList  |manualVideoUrlList *Optional*           |
|manual_video_file_list          |OCI.manualVideoFileList |manualVideoFileList *Optional*          |
</div>


## `GroupCallCenterOverflowModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call center's overflow settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                         |Type          |Description                                         |
|---------------------------------------------|--------------|----------------------------------------------------|
|service_user_id                              |str           |serviceUserId                                       |
|action                                       |str           |action *Optional*                                   |
|transfer_phone_number                        |str           |transferPhoneNumber *Optional*                      |
|overflow_after_timeout                       |bool          |overflowAfterTimeout *Optional*                     |
|timeout_seconds                              |int           |timeoutSeconds *Optional*                           |
|play_announcement_before_overflow_processing |bool          |playAnnouncementBeforeOverflowProcessing *Optional* |
|audio_message_selection                      |str           |audioMessageSelection *Optional*                    |
|audio_file                                   |OCI.audioFile |audioFile *Optional*                                |
|video_message_selection                      |str           |videoMessageSelection *Optional*                    |
|video_file                                   |OCI.videoFile |videoFile *Optional*                                |
</div>


## `GroupCallCenterOverflowModifyRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call center's overflow settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                         |Type              |Description                                         |
|---------------------------------------------|------------------|----------------------------------------------------|
|service_user_id                              |str               |serviceUserId                                       |
|action                                       |str               |action *Optional*                                   |
|transfer_phone_number                        |str               |transferPhoneNumber *Optional*                      |
|overflow_after_timeout                       |bool              |overflowAfterTimeout *Optional*                     |
|timeout_seconds                              |int               |timeoutSeconds *Optional*                           |
|play_announcement_before_overflow_processing |bool              |playAnnouncementBeforeOverflowProcessing *Optional* |
|audio_message_selection                      |str               |audioMessageSelection *Optional*                    |
|audio_url_list                               |OCI.audioUrlList  |audioUrlList *Optional*                             |
|audio_file_list                              |OCI.audioFileList |audioFileList *Optional*                            |
|video_message_selection                      |str               |videoMessageSelection *Optional*                    |
|video_url_list                               |OCI.videoUrlList  |videoUrlList *Optional*                             |
|video_file_list                              |OCI.videoFileList |videoFileList *Optional*                            |
</div>


## `GroupCallCenterOverflowModifyRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call center's overflow settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                         |Type              |Description                                         |
|---------------------------------------------|------------------|----------------------------------------------------|
|service_user_id                              |str               |serviceUserId                                       |
|action                                       |str               |action *Optional*                                   |
|transfer_phone_number                        |str               |transferPhoneNumber *Optional*                      |
|overflow_after_timeout                       |bool              |overflowAfterTimeout *Optional*                     |
|timeout_seconds                              |int               |timeoutSeconds *Optional*                           |
|play_announcement_before_overflow_processing |bool              |playAnnouncementBeforeOverflowProcessing *Optional* |
|audio_message_selection                      |str               |audioMessageSelection *Optional*                    |
|audio_url_list                               |OCI.audioUrlList  |audioUrlList *Optional*                             |
|audio_file_list                              |OCI.audioFileList |audioFileList *Optional*                            |
|video_message_selection                      |str               |videoMessageSelection *Optional*                    |
|video_url_list                               |OCI.videoUrlList  |videoUrlList *Optional*                             |
|video_file_list                              |OCI.videoFileList |videoFileList *Optional*                            |
</div>


## `GroupCallCenterStrandedCallModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call center's stranded call settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                    |Type          |Description                      |
|------------------------|--------------|---------------------------------|
|service_user_id         |str           |serviceUserId                    |
|action                  |str           |action *Optional*                |
|transfer_phone_number   |str           |transferPhoneNumber *Optional*   |
|audio_message_selection |str           |audioMessageSelection *Optional* |
|audio_file              |OCI.audioFile |audioFile *Optional*             |
|video_message_selection |str           |videoMessageSelection *Optional* |
|video_file              |OCI.videoFile |videoFile *Optional*             |
</div>


## `GroupCallCenterStrandedCallModifyRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call center's stranded call settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                    |Type              |Description                      |
|------------------------|------------------|---------------------------------|
|service_user_id         |str               |serviceUserId                    |
|action                  |str               |action *Optional*                |
|transfer_phone_number   |str               |transferPhoneNumber *Optional*   |
|audio_message_selection |str               |audioMessageSelection *Optional* |
|audio_url_list          |OCI.audioUrlList  |audioUrlList *Optional*          |
|audio_file_list         |OCI.audioFileList |audioFileList *Optional*         |
|video_message_selection |str               |videoMessageSelection *Optional* |
|video_url_list          |OCI.videoUrlList  |videoUrlList *Optional*          |
|video_file_list         |OCI.videoFileList |videoFileList *Optional*         |
</div>


## `GroupCallCenterStrandedCallModifyRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call center's stranded call settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                    |Type              |Description                      |
|------------------------|------------------|---------------------------------|
|service_user_id         |str               |serviceUserId                    |
|action                  |str               |action *Optional*                |
|transfer_phone_number   |str               |transferPhoneNumber *Optional*   |
|audio_message_selection |str               |audioMessageSelection *Optional* |
|audio_url_list          |OCI.audioUrlList  |audioUrlList *Optional*          |
|audio_file_list         |OCI.audioFileList |audioFileList *Optional*         |
|video_message_selection |str               |videoMessageSelection *Optional* |
|video_url_list          |OCI.videoUrlList  |videoUrlList *Optional*          |
|video_file_list         |OCI.videoFileList |videoFileList *Optional*         |
</div>


## `GroupCallCenterStrandedCallUnavailableModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call center's stranded calls - unavailable settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                                                 |Type              |Description                                                            |
|---------------------------------------------------------------------|------------------|-----------------------------------------------------------------------|
|service_user_id                                                      |str               |serviceUserId                                                          |
|condition_policy_on_number_of_agents_with_specified_unavailable_code |bool              |conditionPolicyOnNumberOfAgentsWithSpecifiedUnavailableCode *Optional* |
|number_of_agents_with_specified_unavailable_code                     |int               |numberOfAgentsWithSpecifiedUnavailableCode *Optional*                  |
|agents_unavailable_code                                              |str               |agentsUnavailableCode *Optional*                                       |
|action                                                               |str               |action *Optional*                                                      |
|transfer_phone_number                                                |str               |transferPhoneNumber *Optional*                                         |
|audio_message_selection                                              |str               |audioMessageSelection *Optional*                                       |
|audio_url_list                                                       |OCI.audioUrlList  |audioUrlList *Optional*                                                |
|audio_file_list                                                      |OCI.audioFileList |audioFileList *Optional*                                               |
|video_message_selection                                              |str               |videoMessageSelection *Optional*                                       |
|video_url_list                                                       |OCI.videoUrlList  |videoUrlList *Optional*                                                |
|video_file_list                                                      |OCI.videoFileList |videoFileList *Optional*                                               |
</div>


## `GroupCallCenterStrandedCallUnavailableModifyRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call center's stranded calls - unavailable settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                                                 |Type              |Description                                                            |
|---------------------------------------------------------------------|------------------|-----------------------------------------------------------------------|
|service_user_id                                                      |str               |serviceUserId                                                          |
|condition_policy_on_number_of_agents_with_specified_unavailable_code |bool              |conditionPolicyOnNumberOfAgentsWithSpecifiedUnavailableCode *Optional* |
|number_of_agents_with_specified_unavailable_code                     |int               |numberOfAgentsWithSpecifiedUnavailableCode *Optional*                  |
|agents_unavailable_code                                              |str               |agentsUnavailableCode *Optional*                                       |
|action                                                               |str               |action *Optional*                                                      |
|transfer_phone_number                                                |str               |transferPhoneNumber *Optional*                                         |
|audio_message_selection                                              |str               |audioMessageSelection *Optional*                                       |
|audio_url_list                                                       |OCI.audioUrlList  |audioUrlList *Optional*                                                |
|audio_file_list                                                      |OCI.audioFileList |audioFileList *Optional*                                               |
|video_message_selection                                              |str               |videoMessageSelection *Optional*                                       |
|video_url_list                                                       |OCI.videoUrlList  |videoUrlList *Optional*                                                |
|video_file_list                                                      |OCI.videoFileList |videoFileList *Optional*                                               |
</div>


## `GroupCallParkGetAvailableAlternateRecallUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of hunt groups that are available to select as an alternate recall user.

The response is either `GroupCallParkGetAvailableAlternateRecallUserListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|service_provider_id                   |str                                   |serviceProviderId                            |
|group_id                              |str                                   |groupId                                      |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
</div>


## `GroupCallParkGetAvailableUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of users that can be assigned to a Call Park group.

The available user list for a new Call Park group can be obtained by not setting the
name.

The response is either `GroupCallParkGetAvailableUserListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|service_provider_id                   |str                                   |serviceProviderId                            |
|group_id                              |str                                   |groupId                                      |
|name                                  |str                                   |name *Optional*                              |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*              |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                  |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*           |
</div>


## `GroupCallParkGetInstancePagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a list of Call Park group instances within a group.

If the responsePagingControl element is not provided, the paging startIndex will be
set to 1 by default, and the responsePageSize will be set to the maximum
ResponsePageSize by default.  It is possible to search by various criteria to restrict
the number of rows returned.  Multiple search criteria are logically ANDed together
unless the searchCriteriaModeOr option is included.  Then the search criteria are
logically ORed together.

The response is either `GroupCallParkGetInstancePagedSortedListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                           |Type                                 |Description                           |
|-------------------------------|-------------------------------------|--------------------------------------|
|service_provider_id            |str                                  |serviceProviderId                     |
|group_id                       |str                                  |groupId                               |
|response_paging_control        |OCI.responsePagingControl            |responsePagingControl *Optional*      |
|sort_by_call_park_name         |OCI.sortByCallParkName               |sortByCallParkName *Optional*         |
|search_criteria_call_park_name |List[OCI.searchCriteriaCallParkName] |searchCriteriaCallParkName *Optional* |
|search_criteria_mode_or        |bool                                 |searchCriteriaModeOr *Optional*       |
</div>


## `GroupCallParkGetInstancePagedSortedRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Gets a Call Park group.

If the responsePagingControl element is not provided, the paging startIndex will be
set to 1 by default, and the responsePageSize will be set to the maximum
ResponsePageSize by default.  It is possible to search by various criteria to restrict
the number of rows returned.  The sort order is based on the user order provided when
creating or modifying the call park instance.  Multiple search criteria are logically
ANDed together unless the searchCriteriaModeOr option is included.  Then the search
criteria are logically ORed together.

The response is either `GroupCallParkGetInstancePagedSortedResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                            |Type                                   |Description                             |
|--------------------------------|---------------------------------------|----------------------------------------|
|service_provider_id             |str                                    |serviceProviderId                       |
|group_id                        |str                                    |groupId                                 |
|name                            |str                                    |name                                    |
|response_paging_control         |OCI.responsePagingControl              |responsePagingControl *Optional*        |
|search_criteria_user_id         |List[OCI.searchCriteriaUserId]         |searchCriteriaUserId *Optional*         |
|search_criteria_user_last_name  |List[OCI.searchCriteriaUserLastName]   |searchCriteriaUserLastName *Optional*   |
|search_criteria_user_first_name |List[OCI.searchCriteriaUserFirstName]  |searchCriteriaUserFirstName *Optional*  |
|search_criteria_dn              |List[OCI.searchCriteriaDn]             |searchCriteriaDn *Optional*             |
|search_criteria_extension       |List[OCI.searchCriteriaExtension]      |searchCriteriaExtension *Optional*      |
|search_criteria_department_name |List[OCI.searchCriteriaDepartmentName] |searchCriteriaDepartmentName *Optional* |
|search_criteria_email_address   |List[OCI.searchCriteriaEmailAddress]   |searchCriteriaEmailAddress *Optional*   |
|search_criteria_mode_or         |bool                                   |searchCriteriaModeOr *Optional*         |
</div>


## `GroupCallPickupGetAvailableUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of users that can be assigned to a Call Pickup group.

The available user list for a new Call Pickup group can be obtained by not setting the
name.

The response is either `GroupCallPickupGetAvailableUserListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|service_provider_id                   |str                                   |serviceProviderId                            |
|group_id                              |str                                   |groupId                                      |
|name                                  |str                                   |name *Optional*                              |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*              |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                  |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*           |
</div>


## `GroupCallPickupGetInstancePagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a list of Call Pickup instances within a group.

If the responsePagingControl element is not provided, the paging startIndex will be
set to 1 by default, and the responsePageSize will be set to the maximum
ResponsePageSize by default.  It is possible to search by various criteria to restrict
the number of rows returned.  Multiple search criteria are logically ANDed together
unless the searchCriteriaModeOr option is included.  Then the search criteria are
logically ORed together.

The response is either `GroupCallPickupGetInstancePagedSortedListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                             |Type                                   |Description                             |
|---------------------------------|---------------------------------------|----------------------------------------|
|service_provider_id              |str                                    |serviceProviderId                       |
|group_id                         |str                                    |groupId                                 |
|response_paging_control          |OCI.responsePagingControl              |responsePagingControl *Optional*        |
|sort_by_call_pickup_name         |OCI.sortByCallPickupName               |sortByCallPickupName *Optional*         |
|search_criteria_call_pickup_name |List[OCI.searchCriteriaCallPickupName] |searchCriteriaCallPickupName *Optional* |
|search_criteria_mode_or          |bool                                   |searchCriteriaModeOr *Optional*         |
</div>


## `GroupCollaborateBridgeAddInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a collaborate bridge to a group.

The domain is required in the serviceUserId.  The request fails when supportOutdial is
enabled and the system-level collaborate supportOutdial setting is disabled.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by
`GroupCollaborateBridgeAddInstanceRequest20sp1()`

**Attributes:**

|Name                              |Type                          |Description                       |
|----------------------------------|------------------------------|----------------------------------|
|service_provider_id               |str                           |serviceProviderId                 |
|group_id                          |str                           |groupId                           |
|service_user_id                   |str                           |serviceUserId                     |
|service_instance_profile          |OCI.serviceInstanceProfile    |serviceInstanceProfile            |
|maximum_bridge_participants       |OCI.maximumBridgeParticipants |maximumBridgeParticipants         |
|network_class_of_service          |str                           |networkClassOfService *Optional*  |
|max_collaborate_room_participants |int                           |maxCollaborateRoomParticipants    |
|support_outdial                   |bool                          |supportOutdial                    |
|collaborate_owner_user_id         |List[str]                     |collaborateOwnerUserId *Optional* |
</div>


## `GroupCollaborateBridgeAddInstanceRequest20sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a collaborate bridge to a group.

The domain is required in the serviceUserId.  The request fails when supportOutdial is
enabled and the system-level collaborate supportOutdial setting is disabled.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                              |Type                          |Description                       |
|----------------------------------|------------------------------|----------------------------------|
|service_provider_id               |str                           |serviceProviderId                 |
|group_id                          |str                           |groupId                           |
|service_user_id                   |str                           |serviceUserId                     |
|service_instance_profile          |OCI.serviceInstanceProfile    |serviceInstanceProfile            |
|maximum_bridge_participants       |OCI.maximumBridgeParticipants |maximumBridgeParticipants         |
|network_class_of_service          |str                           |networkClassOfService *Optional*  |
|max_collaborate_room_participants |int                           |maxCollaborateRoomParticipants    |
|support_outdial                   |bool                          |supportOutdial                    |
|collaborate_owner_user_id         |List[str]                     |collaborateOwnerUserId *Optional* |
</div>


## `GroupCollaborateBridgeConsolidatedAddInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a collaborate bridge to a group.

The domain is required in the serviceUserId.  The request fails when supportOutdial is
enabled and the system-level collaborate supportOutdial setting is disabled.  If the
phoneNumber has not been assigned to the group and addPhoneNumberToGroup is set to
true, it will be added to group if the command is executed by a service provider
administrator or above and the number is already assigned to the service provider.
The command will fail otherwise.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                              |Type                          |Description                       |
|----------------------------------|------------------------------|----------------------------------|
|service_provider_id               |str                           |serviceProviderId                 |
|group_id                          |str                           |groupId                           |
|service_user_id                   |str                           |serviceUserId                     |
|add_phone_number_to_group         |bool                          |addPhoneNumberToGroup *Optional*  |
|service_instance_profile          |OCI.serviceInstanceProfile    |serviceInstanceProfile            |
|maximum_bridge_participants       |OCI.maximumBridgeParticipants |maximumBridgeParticipants         |
|network_class_of_service          |str                           |networkClassOfService *Optional*  |
|max_collaborate_room_participants |int                           |maxCollaborateRoomParticipants    |
|support_outdial                   |bool                          |supportOutdial                    |
|collaborate_owner_user_id         |List[str]                     |collaborateOwnerUserId *Optional* |
|service                           |List[OCI.service]             |service *Optional*                |
</div>


## `GroupCollaborateBridgeGetAvailableUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of users with the Collaborate – Audio service assigned that can be assigned
to a collaborate bridge.

For an Enterprise Group this will include all users in the group’s enterprise.  The
SearchCriteriaExactUserGroup parameter is only applicable for enterprise groups.

The response is either `GroupCollaborateBridgeGetAvailableUserListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|service_provider_id                   |str                                   |serviceProviderId                            |
|group_id                              |str                                   |groupId                                      |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*              |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_exact_user_group      |OCI.searchCriteriaExactUserGroup      |searchCriteriaExactUserGroup *Optional*      |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                  |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*           |
</div>


## `GroupCollaborateBridgeModifyInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a Collaborate bridge.

The request fails when the collaborateOwnerUserIdList is included in the request for
the default collaborate bridge.  The request fails when the supportOutdial is included
in the request and the system-level collaborate supportOutdial setting is disabled.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by:
`GroupCollaborateBridgeModifyInstanceRequest20sp1()`

**Attributes:**

|Name                              |Type                           |Description                               |
|----------------------------------|-------------------------------|------------------------------------------|
|service_user_id                   |str                            |serviceUserId                             |
|service_instance_profile          |OCI.serviceInstanceProfile     |serviceInstanceProfile *Optional*         |
|maximum_bridge_participants       |OCI.maximumBridgeParticipants  |maximumBridgeParticipants *Optional*      |
|network_class_of_service          |str                            |networkClassOfService *Optional*          |
|max_collaborate_room_participants |int                            |maxCollaborateRoomParticipants *Optional* |
|support_outdial                   |bool                           |supportOutdial *Optional*                 |
|collaborate_owner_user_id_list    |OCI.collaborateOwnerUserIdList |collaborateOwnerUserIdList *Optional*     |
</div>


## `GroupCollaborateBridgeModifyInstanceRequest20sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a Collaborate bridge.

The request fails when the collaborateOwnerUserIdList is included in the request for
the default collaborate bridge.  The request fails when the supportOutdial is included
in the request and the system-level collaborate supportOutdial setting is disabled.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                              |Type                           |Description                               |
|----------------------------------|-------------------------------|------------------------------------------|
|service_user_id                   |str                            |serviceUserId                             |
|service_instance_profile          |OCI.serviceInstanceProfile     |serviceInstanceProfile *Optional*         |
|maximum_bridge_participants       |OCI.maximumBridgeParticipants  |maximumBridgeParticipants *Optional*      |
|network_class_of_service          |str                            |networkClassOfService *Optional*          |
|max_collaborate_room_participants |int                            |maxCollaborateRoomParticipants *Optional* |
|support_outdial                   |bool                           |supportOutdial *Optional*                 |
|collaborate_owner_user_id_list    |OCI.collaborateOwnerUserIdList |collaborateOwnerUserIdList *Optional*     |
</div>


## `GroupCommonPhoneListGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a group's common phone list.

The response is either a `GroupCommonPhoneListGetListResponse()` or an
`ErrorResponse()`. The search can be done using multiple criterion.  If the
searchCriteriaModeOr is present, any result matching any one criteria is included in
the results.  Otherwise, only results matching all the search criterion are included
in the results.  If no search criteria is specified, all results are returned.
Specifying searchCriteriaModeOr without any search criteria results in an
`ErrorResponse()`. In all cases, if a responseSizeLimit is specified and the number of
matching results is more than this limit, then an `ErrorResponse()` is returned.

**Attributes:**

|Name                                           |Type                                               |Description                                         |
|-----------------------------------------------|---------------------------------------------------|----------------------------------------------------|
|service_provider_id                            |str                                                |serviceProviderId                                   |
|group_id                                       |str                                                |groupId                                             |
|response_size_limit                            |int                                                |responseSizeLimit *Optional*                        |
|search_criteria_mode_or                        |bool                                               |searchCriteriaModeOr *Optional*                     |
|search_criteria_group_common_phone_list_name   |List[OCI.searchCriteriaGroupCommonPhoneListName]   |searchCriteriaGroupCommonPhoneListName *Optional*   |
|search_criteria_group_common_phone_list_number |List[OCI.searchCriteriaGroupCommonPhoneListNumber] |searchCriteriaGroupCommonPhoneListNumber *Optional* |
</div>


## `GroupCommunicationBarringAuthorizationCodeGetListRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of Communication Barring Authorization Codes for a group.

The response is either
`GroupCommunicationBarringAuthorizationCodeGetListResponse21sp1()` or
`ErrorResponse()`.

**Attributes:**

|Name                                                                 |Type                                                                     |Description                                                               |
|---------------------------------------------------------------------|-------------------------------------------------------------------------|--------------------------------------------------------------------------|
|service_provider_id                                                  |str                                                                      |serviceProviderId                                                         |
|group_id                                                             |str                                                                      |groupId                                                                   |
|response_size_limit                                                  |int                                                                      |responseSizeLimit *Optional*                                              |
|search_criteria_communication_barring_authorization_code             |List[OCI.searchCriteriaCommunicationBarringAuthorizationCode]            |searchCriteriaCommunicationBarringAuthorizationCode *Optional*            |
|search_criteria_communication_barring_authorization_code_description |List[OCI.searchCriteriaCommunicationBarringAuthorizationCodeDescription] |searchCriteriaCommunicationBarringAuthorizationCodeDescription *Optional* |
|search_criteria_network_class_of_service_name                        |List[OCI.searchCriteriaNetworkClassOfServiceName]                        |searchCriteriaNetworkClassOfServiceName *Optional*                        |
</div>


## `GroupConsolidatedAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode:
serviceProviderExternalId groupExternalId The following elements are only used in
Amplify data mode and ignored in AS and XS data mode: servicePolicy,
callProcessingSliceId, provisioningSliceId, subscriberPartition.  When the
callProcessingSliceId or provisioningSliceId is not specified in the AmplifyDataMode,
the default slice Id is assigned to the Group.  Only Provisioning admin and above can
change the callProcessingSliceId, provisioningSliceId, and subscriberPartition.  The
following elements are only used in Amplify and XS data mode and ignored in AS mode:
preferredDataCenter.  Only Provisioning admin and above can change the
preferredDataCenter.  The following elements are only used in XS data mode and ignored
in Amplify and AS data mode: defaultUserCallingLineIdPhoneNumber.  The following
elements are optional for the group.  If the elements are included, they will be
either added, authorized, or modified on the group.  Should any of the following
elements be rejected to due existing system or service provider settings, the group
will not be added and the response will be an `ErrorResponse()`: domain admin
minExtensionLength maxExtensionLength defaultExtensionLength servicePackAuthorization
groupServiceAuthorizationAndAssignment userServiceAuthorization servicePack
activatablePhoneNumber activatableDNRange routingProfile trunkGroupMaxActiveCalls
trunkGroupBurstingMaxActiveCalls meetMeConferencingAllocatedPorts When a group or user
service is included that is not activated, is not licensed, or not authorized to the
service provider, the response will be an `ErrorResponse()`. If the group service
authorized quantity is not included it will default to Unlimited.  If
activatablePhoneNumber and activatableDNRange elements are included, when activate
element is present, this value overrides the system group default activatable
settings.

**Attributes:**

|Name                                       |Type                                             |Description                                       |
|-------------------------------------------|-------------------------------------------------|--------------------------------------------------|
|service_provider_id                        |str                                              |serviceProviderId *Optional*                      |
|service_provider_external_id               |str                                              |serviceProviderExternalId *Optional*              |
|group_id                                   |str                                              |groupId *Optional*                                |
|group_external_id                          |str                                              |groupExternalId *Optional*                        |
|default_domain                             |str                                              |defaultDomain                                     |
|user_limit                                 |int                                              |userLimit                                         |
|group_name                                 |str                                              |groupName *Optional*                              |
|calling_line_id_name                       |str                                              |callingLineIdName *Optional*                      |
|time_zone                                  |str                                              |timeZone *Optional*                               |
|location_dialing_code                      |str                                              |locationDialingCode *Optional*                    |
|contact                                    |OCI.contact                                      |contact *Optional*                                |
|address                                    |OCI.address                                      |address *Optional*                                |
|service_policy                             |str                                              |servicePolicy *Optional*                          |
|call_processing_slice_id                   |str                                              |callProcessingSliceId *Optional*                  |
|provisioning_slice_id                      |str                                              |provisioningSliceId *Optional*                    |
|subscriber_partition                       |str                                              |subscriberPartition *Optional*                    |
|preferred_data_center                      |str                                              |preferredDataCenter *Optional*                    |
|default_user_calling_line_id_phone_number  |str                                              |defaultUserCallingLineIdPhoneNumber *Optional*    |
|domain                                     |List[str]                                        |domain *Optional*                                 |
|admin                                      |List[OCI.admin]                                  |admin *Optional*                                  |
|min_extension_length                       |int                                              |minExtensionLength *Optional*                     |
|max_extension_length                       |int                                              |maxExtensionLength *Optional*                     |
|default_extension_length                   |int                                              |defaultExtensionLength *Optional*                 |
|group_service_authorization_and_assignment |List[OCI.groupServiceAuthorizationAndAssignment] |groupServiceAuthorizationAndAssignment *Optional* |
|user_service_authorization                 |List[OCI.userServiceAuthorization]               |userServiceAuthorization *Optional*               |
|service_pack_authorization                 |List[OCI.servicePackAuthorization]               |servicePackAuthorization *Optional*               |
|activatable_phone_number                   |List[OCI.activatablePhoneNumber]                 |activatablePhoneNumber *Optional*                 |
|activatable_dn_range                       |List[OCI.activatableDNRange]                     |activatableDNRange *Optional*                     |
|routing_profile                            |str                                              |routingProfile *Optional*                         |
|meet_me_conferencing_allocated_ports       |OCI.meetMeConferencingAllocatedPorts             |meetMeConferencingAllocatedPorts *Optional*       |
|trunk_group_max_active_calls               |int                                              |trunkGroupMaxActiveCalls *Optional*               |
|trunk_group_bursting_max_active_calls      |OCI.trunkGroupBurstingMaxActiveCalls             |trunkGroupBurstingMaxActiveCalls *Optional*       |
</div>


## `GroupConsolidatedAddRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a group.

The following elements are only used in AS data mode and ignored in XS data mode:
serviceProviderExternalId groupExternalId The following elements are only used in
Amplify data mode and ignored in AS and XS data mode: servicePolicy,
callProcessingSliceId, provisioningSliceId, subscriberPartition.  When the
callProcessingSliceId or provisioningSliceId is not specified in the AmplifyDataMode,
the default slice Id is assigned to the Group.  Only Provisioning admin and above can
change the callProcessingSliceId, provisioningSliceId, and subscriberPartition.  The
following elements are only used in Amplify and XS data mode and ignored in AS mode:
preferredDataCenter.  Only Provisioning admin and above can change the
preferredDataCenter.  The following elements are only used in XS data mode and ignored
in Amplify and AS data mode: defaultUserCallingLineIdPhoneNumber.  The following
elements are optional for the group.  If the elements are included, they will be
either added, authorized, or modified on the group.  Should any of the following
elements be rejected to due existing system or service provider settings, the group
will not be added and the response will be an `ErrorResponse()`: domain admin
minExtensionLength maxExtensionLength defaultExtensionLength servicePackAuthorization
groupServiceAuthorizationAndAssignment userServiceAuthorization servicePack
activatablePhoneNumber activatableDNRange routingProfile trunkGroupMaxActiveCalls
trunkGroupBurstingMaxActiveCalls meetMeConferencingAllocatedPorts When a group or user
service is included that is not activated, is not licensed, or not authorized to the
service provider, the response will be an `ErrorResponse()`. If the group service
authorized quantity is not included it will default to Unlimited.  If
activatablePhoneNumber and activatableDNRange elements are included, when activate
element is present, this value overrides the system group default activatable
settings.  If the activatablePhoneNumber and activatableDNRange element are included,
the phone numbers are added to the service provider if they are available to be
assigned to the group and not currently added to the service provider.

The response returned is a - `SuccessResponse()` if all the data is successfully
added.  - `ErrorResponse()` if any data other than the DN validation/assignment fails.
- `GroupConsolidatedAddResponse22()` if any of the activatablePhoneNumber or
activatableDNRange fails validation.

**Attributes:**

|Name                                       |Type                                             |Description                                       |
|-------------------------------------------|-------------------------------------------------|--------------------------------------------------|
|service_provider_id                        |str                                              |serviceProviderId *Optional*                      |
|service_provider_external_id               |str                                              |serviceProviderExternalId *Optional*              |
|group_id                                   |str                                              |groupId *Optional*                                |
|group_external_id                          |str                                              |groupExternalId *Optional*                        |
|default_domain                             |str                                              |defaultDomain                                     |
|user_limit                                 |int                                              |userLimit                                         |
|group_name                                 |str                                              |groupName *Optional*                              |
|calling_line_id_name                       |str                                              |callingLineIdName *Optional*                      |
|time_zone                                  |str                                              |timeZone *Optional*                               |
|location_dialing_code                      |str                                              |locationDialingCode *Optional*                    |
|contact                                    |OCI.contact                                      |contact *Optional*                                |
|address                                    |OCI.address                                      |address *Optional*                                |
|service_policy                             |str                                              |servicePolicy *Optional*                          |
|call_processing_slice_id                   |str                                              |callProcessingSliceId *Optional*                  |
|provisioning_slice_id                      |str                                              |provisioningSliceId *Optional*                    |
|subscriber_partition                       |str                                              |subscriberPartition *Optional*                    |
|preferred_data_center                      |str                                              |preferredDataCenter *Optional*                    |
|default_user_calling_line_id_phone_number  |str                                              |defaultUserCallingLineIdPhoneNumber *Optional*    |
|domain                                     |List[str]                                        |domain *Optional*                                 |
|admin                                      |List[OCI.admin]                                  |admin *Optional*                                  |
|min_extension_length                       |int                                              |minExtensionLength *Optional*                     |
|max_extension_length                       |int                                              |maxExtensionLength *Optional*                     |
|default_extension_length                   |int                                              |defaultExtensionLength *Optional*                 |
|group_service_authorization_and_assignment |List[OCI.groupServiceAuthorizationAndAssignment] |groupServiceAuthorizationAndAssignment *Optional* |
|user_service_authorization                 |List[OCI.userServiceAuthorization]               |userServiceAuthorization *Optional*               |
|service_pack_authorization                 |List[OCI.servicePackAuthorization]               |servicePackAuthorization *Optional*               |
|activatable_phone_number                   |List[OCI.activatablePhoneNumber]                 |activatablePhoneNumber *Optional*                 |
|activatable_dn_range                       |List[OCI.activatableDNRange]                     |activatableDNRange *Optional*                     |
|routing_profile                            |str                                              |routingProfile *Optional*                         |
|meet_me_conferencing_allocated_ports       |OCI.meetMeConferencingAllocatedPorts             |meetMeConferencingAllocatedPorts *Optional*       |
|trunk_group_max_active_calls               |int                                              |trunkGroupMaxActiveCalls *Optional*               |
|trunk_group_bursting_max_active_calls      |OCI.trunkGroupBurstingMaxActiveCalls             |trunkGroupBurstingMaxActiveCalls *Optional*       |
</div>


## `GroupCustomContactDirectoryGetAvailableUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of users that can be part of a custom contact directory.

The response is either `GroupCustomContactDirectoryGetAvailableUserListResponse()` or
`ErrorResponse()`. Replace by:
`GroupCustomContactDirectoryGetAvailableUserListRequest17()`

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|service_provider_id                   |str                                   |serviceProviderId                            |
|group_id                              |str                                   |groupId                                      |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_exact_user_group      |OCI.searchCriteriaExactUserGroup      |searchCriteriaExactUserGroup *Optional*      |
</div>


## `GroupCustomContactDirectoryGetAvailableUserListRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of users that can be part of a custom contact directory.

The response is either `GroupCustomContactDirectoryGetAvailableUserListResponse17()`
or `ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|service_provider_id                   |str                                   |serviceProviderId                            |
|group_id                              |str                                   |groupId                                      |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_exact_user_group      |OCI.searchCriteriaExactUserGroup      |searchCriteriaExactUserGroup *Optional*      |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*              |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                  |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*           |
</div>


## `GroupCustomContactDirectoryGetRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Gets a Custom Contact Directory in a group.

The response is either `GroupCustomContactDirectoryGetResponse17()` or
`ErrorResponse()`. The search can be done using multiple criterion.  If the
searchCriteriaModeOr is present, any result matching any one criteria is included in
the results.  Otherwise, only results matching all the search criterion are included
in the results.  If no search criteria is specified, all results are returned.
Specifying searchCriteriaModeOr without any search criteria results in an
`ErrorResponse()`. In all cases, if a responseSizeLimit is specified and the number of
matching results is more than this limit, then an `ErrorResponse()` is returned.  The
Receptionist Note column is only populated in AS mode; and populated only if the user
sending the request is a the owner of this Receptionist Note and a Note exists.

**Attributes:**

|Name                                  |Type                                      |Description                                  |
|--------------------------------------|------------------------------------------|---------------------------------------------|
|service_provider_id                   |str                                       |serviceProviderId                            |
|group_id                              |str                                       |groupId                                      |
|name                                  |str                                       |name                                         |
|response_size_limit                   |int                                       |responseSizeLimit *Optional*                 |
|search_criteria_mode_or               |bool                                      |searchCriteriaModeOr *Optional*              |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]      |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName]     |searchCriteriaUserFirstName *Optional*       |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]                |searchCriteriaDn *Optional*                  |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]         |searchCriteriaExtension *Optional*           |
|search_criteria_mobile_phone_number   |List[OCI.searchCriteriaMobilePhoneNumber] |searchCriteriaMobilePhoneNumber *Optional*   |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]            |searchCriteriaUserId *Optional*              |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment     |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_imp_id                |List[OCI.searchCriteriaImpId]             |searchCriteriaImpId *Optional*               |
|search_criteria_title                 |List[OCI.searchCriteriaTitle]             |searchCriteriaTitle *Optional*               |
|search_criteria_receptionist_note     |List[OCI.searchCriteriaReceptionistNote]  |searchCriteriaReceptionistNote *Optional*    |
</div>


## `GroupCustomContactDirectoryModifyRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Adds a Custom Contact Directory to a group.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type          |Description          |
|--------------------|--------------|---------------------|
|service_provider_id |str           |serviceProviderId    |
|group_id            |str           |groupId              |
|name                |str           |name                 |
|new_name            |str           |newName *Optional*   |
|entry_list          |OCI.entryList |entryList *Optional* |
</div>


## `GroupCustomRingbackGroupModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the group's custom ring back service settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

Replaced By: `GroupCustomRingbackGroupModifyRequest16()`

**Attributes:**

|Name                |Type          |Description               |
|--------------------|--------------|--------------------------|
|service_provider_id |str           |serviceProviderId         |
|group_id            |str           |groupId                   |
|is_active           |bool          |isActive *Optional*       |
|audio_selection     |str           |audioSelection *Optional* |
|audio_file          |OCI.audioFile |audioFile *Optional*      |
|video_selection     |str           |videoSelection *Optional* |
|video_file          |OCI.videoFile |videoFile *Optional*      |
</div>


## `GroupCustomRingbackGroupModifyRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the group's custom ring back service settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`GroupCustomRingbackGroupModifyRequest20()` in AS data mode

**Attributes:**

|Name                |Type          |Description               |
|--------------------|--------------|--------------------------|
|service_provider_id |str           |serviceProviderId         |
|group_id            |str           |groupId                   |
|is_active           |bool          |isActive *Optional*       |
|audio_selection     |str           |audioSelection *Optional* |
|audio_file          |OCI.audioFile |audioFile *Optional*      |
|video_selection     |str           |videoSelection *Optional* |
|video_file          |OCI.videoFile |videoFile *Optional*      |
</div>


## `GroupCustomRingbackGroupModifyRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the group's custom ring back service settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type          |Description               |
|--------------------|--------------|--------------------------|
|service_provider_id |str           |serviceProviderId         |
|group_id            |str           |groupId                   |
|is_active           |bool          |isActive *Optional*       |
|audio_selection     |str           |audioSelection *Optional* |
|audio_file          |OCI.audioFile |audioFile *Optional*      |
|video_selection     |str           |videoSelection *Optional* |
|video_file          |OCI.videoFile |videoFile *Optional*      |
</div>


## `GroupDepartmentAdminAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a department administrator to a group department.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name           |Type              |Description          |
|---------------|------------------|---------------------|
|department_key |OCI.departmentKey |departmentKey        |
|user_id        |str               |userId               |
|first_name     |str               |firstName *Optional* |
|last_name      |str               |lastName *Optional*  |
|password       |str               |password *Optional*  |
|language       |str               |language *Optional*  |
</div>


## `GroupDepartmentAdminGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of department administrators for the department.

The response is either a `GroupDepartmentAdminGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name           |Type              |Description   |
|---------------|------------------|--------------|
|department_key |OCI.departmentKey |departmentKey |
</div>


## `GroupDeviceManagementEventGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request device management's events for a specific queue.

It is possible to restrict the number of rows returned using responseSizeLimit.  If
eventQueueType is not specified, the events from all the event queues are returned.

The response is either a `GroupDeviceManagementEventGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                                                        |Type                                                                  |Description                                                                  |
|----------------------------------------------------------------------------|----------------------------------------------------------------------|-----------------------------------------------------------------------------|
|service_provider_id                                                         |str                                                                   |serviceProviderId                                                            |
|group_id                                                                    |str                                                                   |groupId                                                                      |
|event_queue_type                                                            |str                                                                   |eventQueueType *Optional*                                                    |
|response_size_limit                                                         |int                                                                   |responseSizeLimit *Optional*                                                 |
|search_criteria_exact_device_management_event_status_in_progress_or_pending |OCI.searchCriteriaExactDeviceManagementEventStatusInProgressOrPending |searchCriteriaExactDeviceManagementEventStatusInProgressOrPending *Optional* |
|search_criteria_exact_device_management_event_status_completed              |OCI.searchCriteriaExactDeviceManagementEventStatusCompleted           |searchCriteriaExactDeviceManagementEventStatusCompleted *Optional*           |
|search_criteria_exact_device_management_event_action                        |OCI.searchCriteriaExactDeviceManagementEventAction                    |searchCriteriaExactDeviceManagementEventAction *Optional*                    |
|search_criteria_exact_device_management_event_level                         |OCI.searchCriteriaExactDeviceManagementEventLevel                     |searchCriteriaExactDeviceManagementEventLevel *Optional*                     |
|search_criteria_exact_device_management_event_type                          |OCI.searchCriteriaExactDeviceManagementEventType                      |searchCriteriaExactDeviceManagementEventType *Optional*                      |
|search_criteria_device_management_event_additional_info                     |List[OCI.searchCriteriaDeviceManagementEventAdditionalInfo]           |searchCriteriaDeviceManagementEventAdditionalInfo *Optional*                 |
|search_criteria_device_management_event_login_id                            |List[OCI.searchCriteriaDeviceManagementEventLoginId]                  |searchCriteriaDeviceManagementEventLoginId *Optional*                        |
</div>


## `GroupDeviceManagementEventGetListRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request device management's events for a specific queue.

It is possible to restrict the number of rows returned using responseSizeLimit.  If
eventQueueType is not specified, the events from all the event queues are returned.

The response is either a `GroupDeviceManagementEventGetListResponse22()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                                                        |Type                                                                  |Description                                                                  |
|----------------------------------------------------------------------------|----------------------------------------------------------------------|-----------------------------------------------------------------------------|
|service_provider_id                                                         |str                                                                   |serviceProviderId                                                            |
|group_id                                                                    |str                                                                   |groupId                                                                      |
|event_queue_type                                                            |str                                                                   |eventQueueType *Optional*                                                    |
|response_size_limit                                                         |int                                                                   |responseSizeLimit *Optional*                                                 |
|search_criteria_exact_device_management_event_status_in_progress_or_pending |OCI.searchCriteriaExactDeviceManagementEventStatusInProgressOrPending |searchCriteriaExactDeviceManagementEventStatusInProgressOrPending *Optional* |
|search_criteria_exact_device_management_event_status_completed              |OCI.searchCriteriaExactDeviceManagementEventStatusCompleted           |searchCriteriaExactDeviceManagementEventStatusCompleted *Optional*           |
|search_criteria_exact_device_management_event_action                        |OCI.searchCriteriaExactDeviceManagementEventAction                    |searchCriteriaExactDeviceManagementEventAction *Optional*                    |
|search_criteria_exact_device_management_event_level                         |OCI.searchCriteriaExactDeviceManagementEventLevel                     |searchCriteriaExactDeviceManagementEventLevel *Optional*                     |
|search_criteria_exact_device_management_event_type                          |OCI.searchCriteriaExactDeviceManagementEventType                      |searchCriteriaExactDeviceManagementEventType *Optional*                      |
|search_criteria_device_management_event_additional_info                     |List[OCI.searchCriteriaDeviceManagementEventAdditionalInfo]           |searchCriteriaDeviceManagementEventAdditionalInfo *Optional*                 |
|search_criteria_device_management_event_login_id                            |List[OCI.searchCriteriaDeviceManagementEventLoginId]                  |searchCriteriaDeviceManagementEventLoginId *Optional*                        |
</div>


## `GroupDnGetAssignmentListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of assigned and unassigned DNs in a group.

Each DN can be assigned to a user and/or department.  Ranges of DNs with identical
assignment and activation properties are coalesced to a single table row entry.

The response is either a `GroupDnGetAssignmentListResponse()` or an `ErrorResponse()`.
Replaced by: `GroupDnGetAssignmentListRequest18()`

**Attributes:**

|Name                                |Type                                  |Description                                |
|------------------------------------|--------------------------------------|-------------------------------------------|
|service_provider_id                 |str                                   |serviceProviderId                          |
|group_id                            |str                                   |groupId                                    |
|response_size_limit                 |int                                   |responseSizeLimit *Optional*               |
|search_criteria_dn                  |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                |
|search_criteria_user_first_name     |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*     |
|search_criteria_user_last_name      |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*      |
|search_criteria_exact_dn_department |OCI.searchCriteriaExactDnDepartment   |searchCriteriaExactDnDepartment *Optional* |
|search_criteria_exact_dn_activation |OCI.searchCriteriaExactDnActivation   |searchCriteriaExactDnActivation *Optional* |
</div>


## `GroupDnGetAssignmentListRequest18`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of assigned and unassigned DNs in a group.

Each DN can be assigned to a user and/or department.  Ranges of DNs with identical
assignment and activation properties are coalesced to a single table row entry.  Dns
assigned to the IMRN pool are not listed in the response.

The response is either a `GroupDnGetAssignmentListResponse18()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                |Type                                  |Description                                |
|------------------------------------|--------------------------------------|-------------------------------------------|
|service_provider_id                 |str                                   |serviceProviderId                          |
|group_id                            |str                                   |groupId                                    |
|response_size_limit                 |int                                   |responseSizeLimit *Optional*               |
|search_criteria_dn                  |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                |
|search_criteria_user_first_name     |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*     |
|search_criteria_user_last_name      |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*      |
|search_criteria_exact_dn_department |OCI.searchCriteriaExactDnDepartment   |searchCriteriaExactDnDepartment *Optional* |
|search_criteria_exact_dn_activation |OCI.searchCriteriaExactDnActivation   |searchCriteriaExactDnActivation *Optional* |
|search_criteria_user_id             |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*            |
|search_criteria_extension           |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*         |
</div>


## `GroupDomainGetAssignedUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a list of users within in a group that have a given domain assigned.

The response is either `GroupDomainGetAssignedUserListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|service_provider_id                   |str                                   |serviceProviderId                            |
|group_id                              |str                                   |groupId                                      |
|domain                                |str                                   |domain                                       |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                  |
|search_criteria_email_address         |List[OCI.searchCriteriaEmailAddress]  |searchCriteriaEmailAddress *Optional*        |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*              |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*           |
</div>


## `GroupEndpointGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to search endpoints in the group.

The response is either `GroupEndpointGetListResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                     |Description                                  |
|--------------------------------------|-----------------------------------------|---------------------------------------------|
|service_provider_id                   |str                                      |serviceProviderId                            |
|group_id                              |str                                      |groupId                                      |
|response_size_limit                   |int                                      |responseSizeLimit *Optional*                 |
|search_criteria_line_port_user_part   |List[OCI.searchCriteriaLinePortUserPart] |searchCriteriaLinePortUserPart *Optional*    |
|search_criteria_line_port_domain      |List[OCI.searchCriteriaLinePortDomain]   |searchCriteriaLinePortDomain *Optional*      |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]     |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName]    |searchCriteriaUserFirstName *Optional*       |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]           |searchCriteriaUserId *Optional*              |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]               |searchCriteriaDn *Optional*                  |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]        |searchCriteriaExtension *Optional*           |
|search_criteria_device_type           |List[OCI.searchCriteriaDeviceType]       |searchCriteriaDeviceType *Optional*          |
|search_criteria_device_name           |List[OCI.searchCriteriaDeviceName]       |searchCriteriaDeviceName *Optional*          |
|search_criteria_device_mac_address    |List[OCI.searchCriteriaDeviceMACAddress] |searchCriteriaDeviceMACAddress *Optional*    |
|search_criteria_device_net_address    |List[OCI.searchCriteriaDeviceNetAddress] |searchCriteriaDeviceNetAddress *Optional*    |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment    |searchCriteriaExactUserDepartment *Optional* |
</div>


## `GroupEnterpriseTrunkGetAvailableTrunkGroupListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of all available trunk groups defined in a group.

It is possible to search by various criteria to restrict the number of rows returned.
Multiple search criteria are logically ANDed together.

The response is either a `GroupEnterpriseTrunkGetAvailableTrunkGroupListResponse()` or
an `ErrorResponse()`.

**Attributes:**

|Name                             |Type                                   |Description                             |
|---------------------------------|---------------------------------------|----------------------------------------|
|service_provider_id              |str                                    |serviceProviderId                       |
|group_id                         |str                                    |groupId                                 |
|response_size_limit              |int                                    |responseSizeLimit *Optional*            |
|search_criteria_trunk_group_name |List[OCI.searchCriteriaTrunkGroupName] |searchCriteriaTrunkGroupName *Optional* |
</div>


## `GroupEnterpriseTrunkGetAvailableUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the list of users that are available to be added to an enterprise trunk.

This list contains users in the group that are trunk users and not already assigned to
an enterprise trunk.  It is possible to search by various criteria to restrict the
number of rows returned.  Multiple search criteria are logically ANDed together.

The response is either a `GroupEnterpriseTrunkGetAvailableUserListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                            |Type                                                 |Description                                           |
|------------------------------------------------|-----------------------------------------------------|------------------------------------------------------|
|service_provider_id                             |str                                                  |serviceProviderId                                     |
|group_id                                        |str                                                  |groupId                                               |
|response_size_limit                             |int                                                  |responseSizeLimit *Optional*                          |
|search_criteria_user_last_name                  |List[OCI.searchCriteriaUserLastName]                 |searchCriteriaUserLastName *Optional*                 |
|search_criteria_user_first_name                 |List[OCI.searchCriteriaUserFirstName]                |searchCriteriaUserFirstName *Optional*                |
|search_criteria_dn                              |List[OCI.searchCriteriaDn]                           |searchCriteriaDn *Optional*                           |
|search_criteria_user_id                         |List[OCI.searchCriteriaUserId]                       |searchCriteriaUserId *Optional*                       |
|search_criteria_alternate_trunk_identity        |List[OCI.searchCriteriaAlternateTrunkIdentity]       |searchCriteriaAlternateTrunkIdentity *Optional*       |
|search_criteria_alternate_trunk_identity_domain |List[OCI.searchCriteriaAlternateTrunkIdentityDomain] |searchCriteriaAlternateTrunkIdentityDomain *Optional* |
|search_criteria_extension                       |List[OCI.searchCriteriaExtension]                    |searchCriteriaExtension *Optional*                    |
|search_criteria_exact_user_department           |OCI.searchCriteriaExactUserDepartment                |searchCriteriaExactUserDepartment *Optional*          |
</div>


## `GroupEnterpriseTrunkGetUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the list of users in an enterprise trunk.

It is possible to search by various criteria to restrict the number of rows returned.
Multiple search criteria are logically ANDed together.

The response is either a `GroupEnterpriseTrunkGetUserListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                            |Type                                                 |Description                                           |
|------------------------------------------------|-----------------------------------------------------|------------------------------------------------------|
|service_provider_id                             |str                                                  |serviceProviderId                                     |
|group_id                                        |str                                                  |groupId                                               |
|enterprise_trunk_name                           |str                                                  |enterpriseTrunkName                                   |
|response_size_limit                             |int                                                  |responseSizeLimit *Optional*                          |
|search_criteria_user_last_name                  |List[OCI.searchCriteriaUserLastName]                 |searchCriteriaUserLastName *Optional*                 |
|search_criteria_user_first_name                 |List[OCI.searchCriteriaUserFirstName]                |searchCriteriaUserFirstName *Optional*                |
|search_criteria_dn                              |List[OCI.searchCriteriaDn]                           |searchCriteriaDn *Optional*                           |
|search_criteria_user_id                         |List[OCI.searchCriteriaUserId]                       |searchCriteriaUserId *Optional*                       |
|search_criteria_group_id                        |List[OCI.searchCriteriaGroupId]                      |searchCriteriaGroupId *Optional*                      |
|search_criteria_alternate_trunk_identity        |List[OCI.searchCriteriaAlternateTrunkIdentity]       |searchCriteriaAlternateTrunkIdentity *Optional*       |
|search_criteria_alternate_trunk_identity_domain |List[OCI.searchCriteriaAlternateTrunkIdentityDomain] |searchCriteriaAlternateTrunkIdentityDomain *Optional* |
|search_criteria_extension                       |List[OCI.searchCriteriaExtension]                    |searchCriteriaExtension *Optional*                    |
|search_criteria_exact_user_department           |OCI.searchCriteriaExactUserDepartment                |searchCriteriaExactUserDepartment *Optional*          |
|search_criteria_exact_user_route_list_assigned  |OCI.searchCriteriaExactUserRouteListAssigned         |searchCriteriaExactUserRouteListAssigned *Optional*   |
</div>


## `GroupFindMeFollowMeAddInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Find-me/Follow-me instance to a group.

The domain is required in the serviceUserId.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                     |Type                       |Description                      |
|-------------------------|---------------------------|---------------------------------|
|service_provider_id      |str                        |serviceProviderId                |
|group_id                 |str                        |groupId                          |
|service_user_id          |str                        |serviceUserId                    |
|service_instance_profile |OCI.serviceInstanceProfile |serviceInstanceProfile           |
|network_class_of_service |str                        |networkClassOfService *Optional* |
</div>


## `GroupFindMeFollowMeAlertingGroupGetAvailableUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of users that can be assigned to a Find-me/Follow-me alerting group.

The response is either
`GroupFindMeFollowMeAlertingGroupGetAvailableUserListResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|service_provider_id                   |str                                   |serviceProviderId                            |
|group_id                              |str                                   |groupId                                      |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*              |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                  |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*           |
</div>


## `GroupFindMeFollowMeModifyAlertingGroupSelectiveCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a Find-me/Follow-me alerting group criteria.

For the callToNumbers in the callToNumberList, the extension and number elements are
not used and the only types accepted for each number are Primary and Alternates.  If
other type is specified the command fails.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type                 |Description                 |
|--------------------|---------------------|----------------------------|
|service_user_id     |str                  |serviceUserId               |
|alerting_group_name |str                  |alertingGroupName           |
|criteria_name       |str                  |criteriaName                |
|new_criteria_name   |str                  |newCriteriaName *Optional*  |
|time_schedule       |OCI.timeSchedule     |timeSchedule *Optional*     |
|from_dn_criteria    |OCI.fromDnCriteria   |fromDnCriteria *Optional*   |
|holiday_schedule    |OCI.holidaySchedule  |holidaySchedule *Optional*  |
|blacklisted         |bool                 |blacklisted *Optional*      |
|call_to_number_list |OCI.callToNumberList |callToNumberList *Optional* |
</div>


## `GroupFindMeFollowMeModifyInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a Find-me/Follow-me instance.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                     |Type                       |Description                       |
|-------------------------|---------------------------|----------------------------------|
|service_user_id          |str                        |serviceUserId                     |
|service_instance_profile |OCI.serviceInstanceProfile |serviceInstanceProfile *Optional* |
|network_class_of_service |str                        |networkClassOfService *Optional*  |
</div>


## `GroupFlexibleSeatingHostAddInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a flexible seating host instance to a group.

The domain is required in the serviceUserId.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by:
`GroupFlexibleSeatingHostAddInstanceRequest22()`.

**Attributes:**

|Name                     |Type                       |Description                      |
|-------------------------|---------------------------|---------------------------------|
|service_provider_id      |str                        |serviceProviderId                |
|group_id                 |str                        |groupId                          |
|service_user_id          |str                        |serviceUserId                    |
|service_instance_profile |OCI.serviceInstanceProfile |serviceInstanceProfile           |
|access_device_endpoint   |OCI.accessDeviceEndpoint   |accessDeviceEndpoint *Optional*  |
|network_class_of_service |str                        |networkClassOfService *Optional* |
</div>


## `GroupFlexibleSeatingHostAddInstanceRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a flexible seating host instance to a group.

The domain is required in the serviceUserId.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                     |Type                       |Description                      |
|-------------------------|---------------------------|---------------------------------|
|service_provider_id      |str                        |serviceProviderId                |
|group_id                 |str                        |groupId                          |
|service_user_id          |str                        |serviceUserId                    |
|service_instance_profile |OCI.serviceInstanceProfile |serviceInstanceProfile           |
|access_device_endpoint   |OCI.accessDeviceEndpoint   |accessDeviceEndpoint *Optional*  |
|network_class_of_service |str                        |networkClassOfService *Optional* |
</div>


## `GroupFlexibleSeatingHostGetInstanceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of flexible seating host instances within a group.

The response is either `GroupFlexibleSeatingHostGetInstanceListResponse()` or
`ErrorResponse()`. It is possible to get the instances within a specified department.

**Attributes:**

|Name                                  |Type                                        |Description                                  |
|--------------------------------------|--------------------------------------------|---------------------------------------------|
|service_provider_id                   |str                                         |serviceProviderId                            |
|group_id                              |str                                         |groupId                                      |
|group_department_name                 |str                                         |groupDepartmentName *Optional*               |
|response_size_limit                   |int                                         |responseSizeLimit *Optional*                 |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment       |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_service_instance_name |List[OCI.searchCriteriaServiceInstanceName] |searchCriteriaServiceInstanceName *Optional* |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]              |searchCriteriaUserId *Optional*              |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]                  |searchCriteriaDn *Optional*                  |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]           |searchCriteriaExtension *Optional*           |
</div>


## `GroupFlexibleSeatingHostModifyInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a flexible seating host instance.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by:
`GroupFlexibleSeatingHostModifyInstanceRequest22()`.

**Attributes:**

|Name                     |Type                       |Description                       |
|-------------------------|---------------------------|----------------------------------|
|service_user_id          |str                        |serviceUserId                     |
|service_instance_profile |OCI.serviceInstanceProfile |serviceInstanceProfile *Optional* |
|access_device_endpoint   |OCI.accessDeviceEndpoint   |accessDeviceEndpoint *Optional*   |
|network_class_of_service |str                        |networkClassOfService *Optional*  |
</div>


## `GroupGetListInServiceProviderRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the list of groups in a service provider or enterprise.

It is possible to search by various criteria to restrict the number of rows returned.
Multiple search criteria are logically ANDed together.

The response is either a `GroupGetListInServiceProviderResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                       |Type                              |Description                        |
|---------------------------|----------------------------------|-----------------------------------|
|service_provider_id        |str                               |serviceProviderId                  |
|response_size_limit        |int                               |responseSizeLimit *Optional*       |
|search_criteria_group_id   |List[OCI.searchCriteriaGroupId]   |searchCriteriaGroupId *Optional*   |
|search_criteria_group_name |List[OCI.searchCriteriaGroupName] |searchCriteriaGroupName *Optional* |
</div>


## `GroupGetListInSystemRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the list of groups in the system.

It is possible to search by various criteria to restrict the number of rows returned.
Multiple search criteria are logically ANDed together.  If reseller administrator
sends the request, searchCriteriaResellerId is ignored.  All the groups in the
administrator's reseller meeting the search criteria are returned.

The response is either a `GroupGetListInSystemResponse()` or an `ErrorResponse()`. The
following data elements are only used in AS data mode: searchCriteriaResellerId

**Attributes:**

|Name                                   |Type                                      |Description                                   |
|---------------------------------------|------------------------------------------|----------------------------------------------|
|response_size_limit                    |int                                       |responseSizeLimit *Optional*                  |
|search_criteria_group_id               |List[OCI.searchCriteriaGroupId]           |searchCriteriaGroupId *Optional*              |
|search_criteria_group_name             |List[OCI.searchCriteriaGroupName]         |searchCriteriaGroupName *Optional*            |
|search_criteria_exact_service_provider |OCI.searchCriteriaExactServiceProvider    |searchCriteriaExactServiceProvider *Optional* |
|search_criteria_service_provider_id    |List[OCI.searchCriteriaServiceProviderId] |searchCriteriaServiceProviderId *Optional*    |
|search_criteria_reseller_id            |List[OCI.searchCriteriaResellerId]        |searchCriteriaResellerId *Optional*           |
</div>


## `GroupGroupPagingAddInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Group Paging instance to a group.

The domain is required in the serviceUserId.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following element
is only used in AS data mode and ignored in XS data mode: networkClassOfService

**Attributes:**

|Name                              |Type                       |Description                      |
|----------------------------------|---------------------------|---------------------------------|
|service_provider_id               |str                        |serviceProviderId                |
|group_id                          |str                        |groupId                          |
|service_user_id                   |str                        |serviceUserId                    |
|service_instance_profile          |OCI.serviceInstanceProfile |serviceInstanceProfile           |
|confirmation_tone_timeout_seconds |int                        |confirmationToneTimeoutSeconds   |
|deliver_originator_clid_instead   |bool                       |deliverOriginatorCLIDInstead     |
|originator_clid_prefix            |str                        |originatorCLIDPrefix *Optional*  |
|network_class_of_service          |str                        |networkClassOfService *Optional* |
</div>


## `GroupGroupPagingGetAvailableOriginatorListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of users that can be assigned as originators to a given paging group.

Searching for users by group only makes sense when the paging group is part of an
Enterprise.

The response is either `GroupGroupPagingGetAvailableOriginatorListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|service_provider_id                   |str                                   |serviceProviderId                            |
|group_id                              |str                                   |groupId                                      |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_exact_user_group      |OCI.searchCriteriaExactUserGroup      |searchCriteriaExactUserGroup *Optional*      |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*              |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                  |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*           |
</div>


## `GroupGroupPagingGetAvailableTargetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of users that can be assigned as targets to a given paging group.

Searching for users by group only makes sense when the paging group is part of an
Enterprise.

The response is either `GroupGroupPagingGetAvailableTargetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|service_user_id                       |str                                   |serviceUserId                                |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_exact_user_group      |OCI.searchCriteriaExactUserGroup      |searchCriteriaExactUserGroup *Optional*      |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*              |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                  |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*           |
</div>


## `GroupGroupPagingModifyInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a Group Paging instance.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following element
is only used in AS data mode and ignored in XS data mode: networkClassOfService

**Attributes:**

|Name                              |Type                       |Description                               |
|----------------------------------|---------------------------|------------------------------------------|
|service_user_id                   |str                        |serviceUserId                             |
|service_instance_profile          |OCI.serviceInstanceProfile |serviceInstanceProfile *Optional*         |
|confirmation_tone_timeout_seconds |int                        |confirmationToneTimeoutSeconds *Optional* |
|deliver_originator_clid_instead   |bool                       |deliverOriginatorCLIDInstead *Optional*   |
|originator_clid_prefix            |str                        |originatorCLIDPrefix *Optional*           |
|network_class_of_service          |str                        |networkClassOfService *Optional*          |
</div>


## `GroupHuntGroupAddInstanceRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Hunt Group instance to a group.

The domain is required in the serviceUserId.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                          |Type                       |Description                     |
|------------------------------|---------------------------|--------------------------------|
|service_provider_id           |str                        |serviceProviderId               |
|group_id                      |str                        |groupId                         |
|service_user_id               |str                        |serviceUserId                   |
|service_instance_profile      |OCI.serviceInstanceProfile |serviceInstanceProfile          |
|policy                        |str                        |policy                          |
|hunt_after_no_answer          |bool                       |huntAfterNoAnswer               |
|no_answer_number_of_rings     |int                        |noAnswerNumberOfRings           |
|forward_after_timeout         |bool                       |forwardAfterTimeout             |
|forward_timeout_seconds       |int                        |forwardTimeoutSeconds           |
|forward_to_phone_number       |str                        |forwardToPhoneNumber *Optional* |
|agent_user_id                 |List[str]                  |agentUserId *Optional*          |
|allow_call_waiting_for_agents |bool                       |allowCallWaitingForAgents       |
</div>


## `GroupHuntGroupAddInstanceRequest17sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Hunt Group instance to a group.

The domain is required in the serviceUserId.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in AS data mode: useSystemHuntGroupCLIDSetting, use value
"true" in XS data mode includeHuntGroupNameInCLID, use value "true" in XS data mode

**Attributes:**

|Name                               |Type                       |Description                     |
|-----------------------------------|---------------------------|--------------------------------|
|service_provider_id                |str                        |serviceProviderId               |
|group_id                           |str                        |groupId                         |
|service_user_id                    |str                        |serviceUserId                   |
|service_instance_profile           |OCI.serviceInstanceProfile |serviceInstanceProfile          |
|policy                             |str                        |policy                          |
|hunt_after_no_answer               |bool                       |huntAfterNoAnswer               |
|no_answer_number_of_rings          |int                        |noAnswerNumberOfRings           |
|forward_after_timeout              |bool                       |forwardAfterTimeout             |
|forward_timeout_seconds            |int                        |forwardTimeoutSeconds           |
|forward_to_phone_number            |str                        |forwardToPhoneNumber *Optional* |
|agent_user_id                      |List[str]                  |agentUserId *Optional*          |
|allow_call_waiting_for_agents      |bool                       |allowCallWaitingForAgents       |
|use_system_hunt_group_clid_setting |bool                       |useSystemHuntGroupCLIDSetting   |
|include_hunt_group_name_in_clid    |bool                       |includeHuntGroupNameInCLID      |
</div>


## `GroupHuntGroupAddInstanceRequest17sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Hunt Group instance to a group.

The domain is required in the serviceUserId.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in AS data mode: useSystemHuntGroupCLIDSetting, use value
"true" in XS data mode includeHuntGroupNameInCLID, use value "true" in XS data mode

**Attributes:**

|Name                                  |Type                       |Description                                 |
|--------------------------------------|---------------------------|--------------------------------------------|
|service_provider_id                   |str                        |serviceProviderId                           |
|group_id                              |str                        |groupId                                     |
|service_user_id                       |str                        |serviceUserId                               |
|service_instance_profile              |OCI.serviceInstanceProfile |serviceInstanceProfile                      |
|policy                                |str                        |policy                                      |
|hunt_after_no_answer                  |bool                       |huntAfterNoAnswer                           |
|no_answer_number_of_rings             |int                        |noAnswerNumberOfRings                       |
|forward_after_timeout                 |bool                       |forwardAfterTimeout                         |
|forward_timeout_seconds               |int                        |forwardTimeoutSeconds                       |
|forward_to_phone_number               |str                        |forwardToPhoneNumber *Optional*             |
|agent_user_id                         |List[str]                  |agentUserId *Optional*                      |
|allow_call_waiting_for_agents         |bool                       |allowCallWaitingForAgents                   |
|use_system_hunt_group_clid_setting    |bool                       |useSystemHuntGroupCLIDSetting               |
|include_hunt_group_name_in_clid       |bool                       |includeHuntGroupNameInCLID                  |
|enable_not_reachable_forwarding       |bool                       |enableNotReachableForwarding                |
|not_reachable_forward_to_phone_number |str                        |notReachableForwardToPhoneNumber *Optional* |
|make_busy_when_not_reachable          |bool                       |makeBusyWhenNotReachable                    |
</div>


## `GroupHuntGroupAddInstanceRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Hunt Group instance to a group.

The domain is required in the serviceUserId.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in AS data mode: useSystemHuntGroupCLIDSetting, use value
"true" in XS data mode includeHuntGroupNameInCLID, use value "true" in XS data mode
Replaced by: `GroupHuntGroupAddInstanceRequest20()` in AS data mode

**Attributes:**

|Name                                  |Type                       |Description                                 |
|--------------------------------------|---------------------------|--------------------------------------------|
|service_provider_id                   |str                        |serviceProviderId                           |
|group_id                              |str                        |groupId                                     |
|service_user_id                       |str                        |serviceUserId                               |
|service_instance_profile              |OCI.serviceInstanceProfile |serviceInstanceProfile                      |
|policy                                |str                        |policy                                      |
|hunt_after_no_answer                  |bool                       |huntAfterNoAnswer                           |
|no_answer_number_of_rings             |int                        |noAnswerNumberOfRings                       |
|forward_after_timeout                 |bool                       |forwardAfterTimeout                         |
|forward_timeout_seconds               |int                        |forwardTimeoutSeconds                       |
|forward_to_phone_number               |str                        |forwardToPhoneNumber *Optional*             |
|agent_user_id                         |List[str]                  |agentUserId *Optional*                      |
|allow_call_waiting_for_agents         |bool                       |allowCallWaitingForAgents                   |
|use_system_hunt_group_clid_setting    |bool                       |useSystemHuntGroupCLIDSetting               |
|include_hunt_group_name_in_clid       |bool                       |includeHuntGroupNameInCLID                  |
|enable_not_reachable_forwarding       |bool                       |enableNotReachableForwarding                |
|not_reachable_forward_to_phone_number |str                        |notReachableForwardToPhoneNumber *Optional* |
|make_busy_when_not_reachable          |bool                       |makeBusyWhenNotReachable                    |
|allow_members_to_control_group_busy   |bool                       |allowMembersToControlGroupBusy              |
|enable_group_busy                     |bool                       |enableGroupBusy                             |
|network_class_of_service              |str                        |networkClassOfService *Optional*            |
</div>


## `GroupHuntGroupAddInstanceRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Hunt Group instance to a group.

The domain is required in the serviceUserId.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in AS data mode: useSystemHuntGroupCLIDSetting, use value
"true" in XS data mode includeHuntGroupNameInCLID, use value "true" in XS data mode

**Attributes:**

|Name                                       |Type                       |Description                                 |
|-------------------------------------------|---------------------------|--------------------------------------------|
|service_provider_id                        |str                        |serviceProviderId                           |
|group_id                                   |str                        |groupId                                     |
|service_user_id                            |str                        |serviceUserId                               |
|service_instance_profile                   |OCI.serviceInstanceProfile |serviceInstanceProfile                      |
|policy                                     |str                        |policy                                      |
|hunt_after_no_answer                       |bool                       |huntAfterNoAnswer                           |
|no_answer_number_of_rings                  |int                        |noAnswerNumberOfRings                       |
|forward_after_timeout                      |bool                       |forwardAfterTimeout                         |
|forward_timeout_seconds                    |int                        |forwardTimeoutSeconds                       |
|forward_to_phone_number                    |str                        |forwardToPhoneNumber *Optional*             |
|agent_user_id                              |List[str]                  |agentUserId *Optional*                      |
|allow_call_waiting_for_agents              |bool                       |allowCallWaitingForAgents                   |
|use_system_hunt_group_clid_setting         |bool                       |useSystemHuntGroupCLIDSetting               |
|include_hunt_group_name_in_clid            |bool                       |includeHuntGroupNameInCLID                  |
|enable_not_reachable_forwarding            |bool                       |enableNotReachableForwarding                |
|not_reachable_forward_to_phone_number      |str                        |notReachableForwardToPhoneNumber *Optional* |
|make_busy_when_not_reachable               |bool                       |makeBusyWhenNotReachable                    |
|allow_members_to_control_group_busy        |bool                       |allowMembersToControlGroupBusy              |
|enable_group_busy                          |bool                       |enableGroupBusy                             |
|apply_group_busy_when_terminating_to_agent |bool                       |applyGroupBusyWhenTerminatingToAgent        |
|network_class_of_service                   |str                        |networkClassOfService *Optional*            |
</div>


## `GroupHuntGroupConsolidatedAddInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Hunt Group instance to a group.

The domain is required in the serviceUserId.  If the phoneNumber has not been assigned
to the group and addPhoneNumberToGroup is set to true, it will be added to group if
the command is executed by a service provider administrator or above and the number is
already assigned to the service provider.  The command will fail otherwise.  The
weight element inside the agentWeight element will only take effect if the policy
element is set to "Weighted" in the request.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in AS data mode: useSystemHuntGroupCLIDSetting, use value
"true" in XS data mode includeHuntGroupNameInCLID, use value "true" in XS data mode

**Attributes:**

|Name                                                                              |Type                       |Description                                                                      |
|----------------------------------------------------------------------------------|---------------------------|---------------------------------------------------------------------------------|
|service_provider_id                                                               |str                        |serviceProviderId                                                                |
|group_id                                                                          |str                        |groupId                                                                          |
|service_user_id                                                                   |str                        |serviceUserId                                                                    |
|add_phone_number_to_group                                                         |bool                       |addPhoneNumberToGroup *Optional*                                                 |
|service_instance_profile                                                          |OCI.serviceInstanceProfile |serviceInstanceProfile                                                           |
|policy                                                                            |str                        |policy                                                                           |
|hunt_after_no_answer                                                              |bool                       |huntAfterNoAnswer                                                                |
|no_answer_number_of_rings                                                         |int                        |noAnswerNumberOfRings                                                            |
|forward_after_timeout                                                             |bool                       |forwardAfterTimeout                                                              |
|forward_timeout_seconds                                                           |int                        |forwardTimeoutSeconds                                                            |
|forward_to_phone_number                                                           |str                        |forwardToPhoneNumber *Optional*                                                  |
|agent_user_id                                                                     |List[str]                  |agentUserId *Optional*                                                           |
|agent_weight                                                                      |List[OCI.agentWeight]      |agentWeight *Optional*                                                           |
|allow_call_waiting_for_agents                                                     |bool                       |allowCallWaitingForAgents                                                        |
|use_system_hunt_group_clid_setting                                                |bool                       |useSystemHuntGroupCLIDSetting                                                    |
|include_hunt_group_name_in_clid                                                   |bool                       |includeHuntGroupNameInCLID                                                       |
|enable_not_reachable_forwarding                                                   |bool                       |enableNotReachableForwarding                                                     |
|not_reachable_forward_to_phone_number                                             |str                        |notReachableForwardToPhoneNumber *Optional*                                      |
|make_busy_when_not_reachable                                                      |bool                       |makeBusyWhenNotReachable                                                         |
|allow_members_to_control_group_busy                                               |bool                       |allowMembersToControlGroupBusy                                                   |
|enable_group_busy                                                                 |bool                       |enableGroupBusy                                                                  |
|apply_group_busy_when_terminating_to_agent                                        |bool                       |applyGroupBusyWhenTerminatingToAgent                                             |
|network_class_of_service                                                          |str                        |networkClassOfService *Optional*                                                 |
|service                                                                           |List[OCI.service]          |service *Optional*                                                               |
|is_active                                                                         |bool                       |isActive                                                                         |
|directory_number_hunting_agent_user_id_list                                       |List[str]                  |directoryNumberHuntingAgentUserIdList *Optional*                                 |
|directory_number_hunting_use_terminate_call_to_agent_first                        |bool                       |directoryNumberHuntingUseTerminateCallToAgentFirst *Optional*                    |
|directory_number_hunting_use_original_agent_services_for_busy_and_no_answer_calls |bool                       |directoryNumberHuntingUseOriginalAgentServicesForBusyAndNoAnswerCalls *Optional* |
</div>


## `GroupHuntGroupGetAvailableUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of users that can be assigned to a Hunt Group group.

Searching for users by group only makes sense when the hunt group is part of an
Enterprise.

The response is either `GroupHuntGroupGetAvailableUserListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|service_provider_id                   |str                                   |serviceProviderId                            |
|group_id                              |str                                   |groupId                                      |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_exact_user_group      |OCI.searchCriteriaExactUserGroup      |searchCriteriaExactUserGroup *Optional*      |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*              |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                  |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*           |
</div>


## `GroupHuntGroupModifyInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a Hunt Group instance.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in AS data mode: useSystemHuntGroupCLIDSetting
includeHuntGroupNameInCLID applyGroupBusyWhenTerminatingToAgent networkClassOfService

**Attributes:**

|Name                                       |Type                       |Description                                     |
|-------------------------------------------|---------------------------|------------------------------------------------|
|service_user_id                            |str                        |serviceUserId                                   |
|service_instance_profile                   |OCI.serviceInstanceProfile |serviceInstanceProfile *Optional*               |
|policy                                     |str                        |policy *Optional*                               |
|hunt_after_no_answer                       |bool                       |huntAfterNoAnswer *Optional*                    |
|no_answer_number_of_rings                  |int                        |noAnswerNumberOfRings *Optional*                |
|forward_after_timeout                      |bool                       |forwardAfterTimeout *Optional*                  |
|forward_timeout_seconds                    |int                        |forwardTimeoutSeconds *Optional*                |
|forward_to_phone_number                    |str                        |forwardToPhoneNumber *Optional*                 |
|agent_user_id_list                         |OCI.agentUserIdList        |agentUserIdList *Optional*                      |
|allow_call_waiting_for_agents              |bool                       |allowCallWaitingForAgents *Optional*            |
|use_system_hunt_group_clid_setting         |bool                       |useSystemHuntGroupCLIDSetting *Optional*        |
|include_hunt_group_name_in_clid            |bool                       |includeHuntGroupNameInCLID *Optional*           |
|enable_not_reachable_forwarding            |bool                       |enableNotReachableForwarding *Optional*         |
|not_reachable_forward_to_phone_number      |str                        |notReachableForwardToPhoneNumber *Optional*     |
|make_busy_when_not_reachable               |bool                       |makeBusyWhenNotReachable *Optional*             |
|allow_members_to_control_group_busy        |bool                       |allowMembersToControlGroupBusy *Optional*       |
|enable_group_busy                          |bool                       |enableGroupBusy *Optional*                      |
|apply_group_busy_when_terminating_to_agent |bool                       |applyGroupBusyWhenTerminatingToAgent *Optional* |
|network_class_of_service                   |str                        |networkClassOfService *Optional*                |
</div>


## `GroupIncomingCallingPlanModifyListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Change the group's incoming calling plan settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type                            |Description                      |
|-----------------------|--------------------------------|---------------------------------|
|service_provider_id    |str                             |serviceProviderId                |
|group_id               |str                             |groupId                          |
|group_permissions      |OCI.groupPermissions            |groupPermissions *Optional*      |
|department_permissions |List[OCI.departmentPermissions] |departmentPermissions *Optional* |
</div>


## `GroupInstantGroupCallAddInstanceRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add an Instant Group Call service instance to a group.

The domain is required in the serviceUserId.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                      |Type                       |Description                       |
|--------------------------|---------------------------|----------------------------------|
|service_provider_id       |str                        |serviceProviderId                 |
|group_id                  |str                        |groupId                           |
|service_user_id           |str                        |serviceUserId                     |
|service_instance_profile  |OCI.serviceInstanceProfile |serviceInstanceProfile            |
|destination_phone_number  |List[str]                  |destinationPhoneNumber *Optional* |
|is_answer_timeout_enabled |bool                       |isAnswerTimeoutEnabled            |
|answer_timeout_minutes    |int                        |answerTimeoutMinutes *Optional*   |
|network_class_of_service  |str                        |networkClassOfService *Optional*  |
</div>


## `GroupInstantGroupCallModifyInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify an Instant Group Call service instance.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                          |Type                           |Description                           |
|------------------------------|-------------------------------|--------------------------------------|
|service_user_id               |str                            |serviceUserId                         |
|service_instance_profile      |OCI.serviceInstanceProfile     |serviceInstanceProfile *Optional*     |
|destination_phone_number_list |OCI.destinationPhoneNumberList |destinationPhoneNumberList *Optional* |
|is_answer_timeout_enabled     |bool                           |isAnswerTimeoutEnabled *Optional*     |
|answer_timeout_minutes        |int                            |answerTimeoutMinutes *Optional*       |
|network_class_of_service      |str                            |networkClassOfService *Optional*      |
</div>


## `GroupMWIDeliveryToMobileEndpointCustomTemplateAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Create a MWI Delivery to Mobile Endpoint Custom Template.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type             |Description       |
|--------------------|-----------------|------------------|
|service_provider_id |str              |serviceProviderId |
|group_id            |str              |groupId           |
|language            |str              |language          |
|type                |str              |type              |
|is_enabled          |bool             |isEnabled         |
|template_body       |OCI.templateBody |templateBody      |
</div>


## `GroupMWIDeliveryToMobileEndpointCustomTemplateModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a MWI Delivery to Mobile Endpoint Custom Template.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type             |Description             |
|--------------------|-----------------|------------------------|
|service_provider_id |str              |serviceProviderId       |
|group_id            |str              |groupId                 |
|language            |str              |language                |
|type                |str              |type                    |
|is_enabled          |bool             |isEnabled *Optional*    |
|template_body       |OCI.templateBody |templateBody *Optional* |
</div>


## `GroupMeetMeConferencingAddInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Meet-Me Conferencing bridge to a group.

The domain is required in the serviceUserId.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                      |Type                       |Description                      |
|--------------------------|---------------------------|---------------------------------|
|service_provider_id       |str                        |serviceProviderId                |
|group_id                  |str                        |groupId                          |
|service_user_id           |str                        |serviceUserId                    |
|service_instance_profile  |OCI.serviceInstanceProfile |serviceInstanceProfile           |
|allocated_ports           |OCI.allocatedPorts         |allocatedPorts                   |
|network_class_of_service  |str                        |networkClassOfService *Optional* |
|allow_individual_out_dial |bool                       |allowIndividualOutDial           |
|operator_number           |str                        |operatorNumber *Optional*        |
|conference_host_user_id   |List[str]                  |conferenceHostUserId *Optional*  |
</div>


## `GroupMeetMeConferencingAddInstanceRequest18`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Meet-Me Conferencing bridge to a group.

The domain is required in the serviceUserId.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                  |Type                             |Description                       |
|--------------------------------------|---------------------------------|----------------------------------|
|service_provider_id                   |str                              |serviceProviderId                 |
|group_id                              |str                              |groupId                           |
|service_user_id                       |str                              |serviceUserId                     |
|service_instance_profile              |OCI.serviceInstanceProfile       |serviceInstanceProfile            |
|allocated_ports                       |OCI.allocatedPorts               |allocatedPorts                    |
|network_class_of_service              |str                              |networkClassOfService *Optional*  |
|allow_individual_out_dial             |bool                             |allowIndividualOutDial            |
|operator_number                       |str                              |operatorNumber *Optional*         |
|conference_host_user_id               |List[str]                        |conferenceHostUserId *Optional*   |
|play_warning_prompt                   |bool                             |playWarningPrompt                 |
|conference_end_warning_prompt_minutes |int                              |conferenceEndWarningPromptMinutes |
|enable_max_conference_duration        |bool                             |enableMaxConferenceDuration       |
|max_conference_duration_minutes       |OCI.maxConferenceDurationMinutes |maxConferenceDurationMinutes      |
</div>


## `GroupMeetMeConferencingAddInstanceRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Meet-Me Conferencing bridge to a group.

The domain is required in the serviceUserId.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                      |Type                                      |Description                           |
|------------------------------------------|------------------------------------------|--------------------------------------|
|service_provider_id                       |str                                       |serviceProviderId                     |
|group_id                                  |str                                       |groupId                               |
|service_user_id                           |str                                       |serviceUserId                         |
|service_instance_profile                  |OCI.serviceInstanceProfile                |serviceInstanceProfile                |
|allocated_ports                           |OCI.allocatedPorts                        |allocatedPorts                        |
|network_class_of_service                  |str                                       |networkClassOfService *Optional*      |
|security_pin_length                       |int                                       |securityPinLength                     |
|allow_individual_out_dial                 |bool                                      |allowIndividualOutDial                |
|operator_number                           |str                                       |operatorNumber *Optional*             |
|conference_host_user_id                   |List[str]                                 |conferenceHostUserId *Optional*       |
|play_warning_prompt                       |bool                                      |playWarningPrompt                     |
|conference_end_warning_prompt_minutes     |int                                       |conferenceEndWarningPromptMinutes     |
|enable_max_conference_duration            |bool                                      |enableMaxConferenceDuration           |
|max_conference_duration_minutes           |OCI.maxConferenceDurationMinutes          |maxConferenceDurationMinutes          |
|max_scheduled_conference_duration_minutes |OCI.maxScheduledConferenceDurationMinutes |maxScheduledConferenceDurationMinutes |
</div>


## `GroupMeetMeConferencingGetAvailableUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of users that can be assigned to a Meet-Me Conferencing bridge.

Searching for users by group only makes sense when the Meet-Me Conferencing is part of
an Enterprise.

The response is either `GroupMeetMeConferencingGetAvailableUserListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|service_provider_id                   |str                                   |serviceProviderId                            |
|group_id                              |str                                   |groupId                                      |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*              |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_exact_user_group      |OCI.searchCriteriaExactUserGroup      |searchCriteriaExactUserGroup *Optional*      |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                  |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*           |
</div>


## `GroupMeetMeConferencingModifyInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a Meet-Me Conferencing bridge.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                      |Type                                      |Description                                      |
|------------------------------------------|------------------------------------------|-------------------------------------------------|
|service_user_id                           |str                                       |serviceUserId                                    |
|service_instance_profile                  |OCI.serviceInstanceProfile                |serviceInstanceProfile *Optional*                |
|allocated_ports                           |OCI.allocatedPorts                        |allocatedPorts *Optional*                        |
|network_class_of_service                  |str                                       |networkClassOfService *Optional*                 |
|security_pin_length                       |int                                       |securityPinLength *Optional*                     |
|allow_individual_out_dial                 |bool                                      |allowIndividualOutDial *Optional*                |
|operator_number                           |str                                       |operatorNumber *Optional*                        |
|conference_host_user_id_list              |OCI.conferenceHostUserIdList              |conferenceHostUserIdList *Optional*              |
|play_warning_prompt                       |bool                                      |playWarningPrompt *Optional*                     |
|conference_end_warning_prompt_minutes     |int                                       |conferenceEndWarningPromptMinutes *Optional*     |
|enable_max_conference_duration            |bool                                      |enableMaxConferenceDuration *Optional*           |
|max_conference_duration_minutes           |OCI.maxConferenceDurationMinutes          |maxConferenceDurationMinutes *Optional*          |
|max_scheduled_conference_duration_minutes |OCI.maxScheduledConferenceDurationMinutes |maxScheduledConferenceDurationMinutes *Optional* |
</div>


## `GroupMusicOnHoldAddInstanceRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Music On Hold Instance to a department.

The response is either `SuccessResponse()` or `ErrorResponse()`.

Replaced By: GroupMusicOnHoldAddInstanceRequest14Sp4

**Attributes:**

|Name                       |Type                     |Description                     |
|---------------------------|-------------------------|--------------------------------|
|service_provider_id        |str                      |serviceProviderId               |
|group_id                   |str                      |groupId                         |
|department                 |OCI.department           |department                      |
|is_active_during_call_hold |bool                     |isActiveDuringCallHold          |
|is_active_during_call_park |bool                     |isActiveDuringCallPark          |
|message_selection          |str                      |messageSelection                |
|access_device_endpoint     |OCI.accessDeviceEndpoint |accessDeviceEndpoint *Optional* |
|audio_file                 |OCI.audioFile            |audioFile *Optional*            |
|video_file                 |OCI.videoFile            |videoFile *Optional*            |
</div>


## `GroupMusicOnHoldAddInstanceRequest14sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Music On Hold Instance to a department.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                          |Type                     |Description                     |
|------------------------------|-------------------------|--------------------------------|
|service_provider_id           |str                      |serviceProviderId               |
|group_id                      |str                      |groupId                         |
|department                    |OCI.department           |department                      |
|is_active_during_call_hold    |bool                     |isActiveDuringCallHold          |
|is_active_during_call_park    |bool                     |isActiveDuringCallPark          |
|is_active_during_busy_camp_on |bool                     |isActiveDuringBusyCampOn        |
|message_selection             |str                      |messageSelection                |
|access_device_endpoint        |OCI.accessDeviceEndpoint |accessDeviceEndpoint *Optional* |
|audio_file                    |OCI.audioFile            |audioFile *Optional*            |
|video_file                    |OCI.videoFile            |videoFile *Optional*            |
</div>


## `GroupMusicOnHoldModifyInstanceRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify data for a group or department Music On Hold Instance.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                          |Type                     |Description                         |
|------------------------------|-------------------------|------------------------------------|
|service_provider_id           |str                      |serviceProviderId                   |
|group_id                      |str                      |groupId                             |
|department                    |OCI.department           |department *Optional*               |
|is_active_during_call_hold    |bool                     |isActiveDuringCallHold *Optional*   |
|is_active_during_call_park    |bool                     |isActiveDuringCallPark *Optional*   |
|is_active_during_busy_camp_on |bool                     |isActiveDuringBusyCampOn *Optional* |
|message_selection             |str                      |messageSelection *Optional*         |
|access_device_endpoint        |OCI.accessDeviceEndpoint |accessDeviceEndpoint *Optional*     |
|audio_file                    |OCI.audioFile            |audioFile *Optional*                |
|video_file                    |OCI.videoFile            |videoFile *Optional*                |
</div>


## `GroupNetworkClassOfServiceGetAssignedUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of users within a group that have a given Network Class of Service
assigned.

The response is either a `GroupNetworkClassOfServiceGetAssignedUserListResponse()` or
an `ErorResponse()`.

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|service_provider_id                   |str                                   |serviceProviderId                            |
|group_id                              |str                                   |groupId                                      |
|network_class_of_service              |str                                   |networkClassOfService                        |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                  |
|search_criteria_email_address         |List[OCI.searchCriteriaEmailAddress]  |searchCriteriaEmailAddress *Optional*        |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*              |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*           |
</div>


## `GroupNetworkClassOfServiceGetAssignedUserListRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of users within a group that have a given Network Class of Service
assigned.

The response is either a `GroupNetworkClassOfServiceGetAssignedUserListResponse21()`
or an `ErorResponse()`.

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|service_provider_id                   |str                                   |serviceProviderId                            |
|group_id                              |str                                   |groupId                                      |
|network_class_of_service              |str                                   |networkClassOfService                        |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                  |
|search_criteria_email_address         |List[OCI.searchCriteriaEmailAddress]  |searchCriteriaEmailAddress *Optional*        |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*              |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*           |
</div>


## `GroupOfficeZoneGetAssignedUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of users within a group that have a given Office Zone assigned.

The response is either a `GroupOfficeZoneGetAssignedUserListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|service_provider_id                   |str                                   |serviceProviderId                            |
|group_id                              |str                                   |groupId                                      |
|office_zone_name                      |str                                   |officeZoneName                               |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                  |
|search_criteria_email_address         |List[OCI.searchCriteriaEmailAddress]  |searchCriteriaEmailAddress *Optional*        |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*              |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*           |
</div>


## `GroupOutgoingCallingPlanCallMeNowModifyListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Call Me Now call permissions for a group default and it's departments.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type                            |Description                      |
|-----------------------|--------------------------------|---------------------------------|
|service_provider_id    |str                             |serviceProviderId                |
|group_id               |str                             |groupId                          |
|group_permissions      |OCI.groupPermissions            |groupPermissions *Optional*      |
|department_permissions |List[OCI.departmentPermissions] |departmentPermissions *Optional* |
</div>


## `GroupOutgoingCallingPlanOriginatingModifyListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the originating permissions for a group default and it's departments.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type                            |Description                      |
|-----------------------|--------------------------------|---------------------------------|
|service_provider_id    |str                             |serviceProviderId                |
|group_id               |str                             |groupId                          |
|group_permissions      |OCI.groupPermissions            |groupPermissions *Optional*      |
|department_permissions |List[OCI.departmentPermissions] |departmentPermissions *Optional* |
</div>


## `GroupOutgoingCallingPlanRedirectedModifyListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the call forwarded/transferred permissions for a group default and it's
departments.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type                            |Description                      |
|-----------------------|--------------------------------|---------------------------------|
|service_provider_id    |str                             |serviceProviderId                |
|group_id               |str                             |groupId                          |
|group_permissions      |OCI.groupPermissions            |groupPermissions *Optional*      |
|department_permissions |List[OCI.departmentPermissions] |departmentPermissions *Optional* |
</div>


## `GroupOutgoingCallingPlanRedirectingModifyListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the initiating call forwards/transfer permissions for a group default and it's
departments.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type                            |Description                      |
|-----------------------|--------------------------------|---------------------------------|
|service_provider_id    |str                             |serviceProviderId                |
|group_id               |str                             |groupId                          |
|group_permissions      |OCI.groupPermissions            |groupPermissions *Optional*      |
|department_permissions |List[OCI.departmentPermissions] |departmentPermissions *Optional* |
</div>


## `GroupOutgoingCallingPlanTransferNumbersModifyListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the list of transfer numbers for a group default and it's departments.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type                        |Description                  |
|--------------------|----------------------------|-----------------------------|
|service_provider_id |str                         |serviceProviderId            |
|group_id            |str                         |groupId                      |
|group_numbers       |OCI.groupNumbers            |groupNumbers *Optional*      |
|department_numbers  |List[OCI.departmentNumbers] |departmentNumbers *Optional* |
</div>


## `GroupPhoneDirectoryGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a table containing the phone directory for a group.

If the specified group is part of an enterprise, the directory includes all users in
the enterprise and all entries in the enterprise common phone list and the common
phone list of the specified group.  If the specified group is part of a service
provider, the directory includes all users in the group and all entries in the common
phone list of the specified group.  It is possible to search by various criteria to
restrict the number of rows returned.  Multiple search criteria are logically ANDed
together.

The response is either `GroupPhoneDirectoryGetListResponse()` or `ErrorResponse()`.
Replace by: `GroupPhoneDirectoryGetListRequest17()`

**Attributes:**

|Name                                  |Type                                      |Description                                  |
|--------------------------------------|------------------------------------------|---------------------------------------------|
|service_provider_id                   |str                                       |serviceProviderId                            |
|group_id                              |str                                       |groupId                                      |
|is_extended_info_requested            |bool                                      |isExtendedInfoRequested                      |
|response_size_limit                   |int                                       |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]      |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName]     |searchCriteriaUserFirstName *Optional*       |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]                |searchCriteriaDn *Optional*                  |
|search_criteria_group_location_code   |List[OCI.searchCriteriaGroupLocationCode] |searchCriteriaGroupLocationCode *Optional*   |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]         |searchCriteriaExtension *Optional*           |
|search_criteria_mobile_phone_number   |List[OCI.searchCriteriaMobilePhoneNumber] |searchCriteriaMobilePhoneNumber *Optional*   |
|search_criteria_email_address         |List[OCI.searchCriteriaEmailAddress]      |searchCriteriaEmailAddress *Optional*        |
|search_criteria_yahoo_id              |List[OCI.searchCriteriaYahooId]           |searchCriteriaYahooId *Optional*             |
|search_criteria_exact_user_group      |OCI.searchCriteriaExactUserGroup          |searchCriteriaExactUserGroup *Optional*      |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment     |searchCriteriaExactUserDepartment *Optional* |
</div>


## `GroupPhoneDirectoryGetListRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a table containing the phone directory for a group.

If the specified group is part of an enterprise, the directory includes all users in
the enterprise and all entries in the enterprise common phone list and the common
phone list of the specified group.  If the specified group is part of a service
provider, the directory includes all users in the group and all entries in the common
phone list of the specified group.  It is possible to search by various criteria to
restrict the number of rows returned.  Multiple search criteria are logically ANDed
together.

The response is either `GroupPhoneDirectoryGetListResponse17()` or `ErrorResponse()`.
Replaced by: `GroupPhoneDirectoryGetListRequest18()`

**Attributes:**

|Name                                  |Type                                      |Description                                  |
|--------------------------------------|------------------------------------------|---------------------------------------------|
|service_provider_id                   |str                                       |serviceProviderId                            |
|group_id                              |str                                       |groupId                                      |
|is_extended_info_requested            |bool                                      |isExtendedInfoRequested                      |
|response_size_limit                   |int                                       |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]      |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName]     |searchCriteriaUserFirstName *Optional*       |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]                |searchCriteriaDn *Optional*                  |
|search_criteria_group_location_code   |List[OCI.searchCriteriaGroupLocationCode] |searchCriteriaGroupLocationCode *Optional*   |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]         |searchCriteriaExtension *Optional*           |
|search_criteria_mobile_phone_number   |List[OCI.searchCriteriaMobilePhoneNumber] |searchCriteriaMobilePhoneNumber *Optional*   |
|search_criteria_email_address         |List[OCI.searchCriteriaEmailAddress]      |searchCriteriaEmailAddress *Optional*        |
|search_criteria_yahoo_id              |List[OCI.searchCriteriaYahooId]           |searchCriteriaYahooId *Optional*             |
|search_criteria_exact_user_group      |OCI.searchCriteriaExactUserGroup          |searchCriteriaExactUserGroup *Optional*      |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment     |searchCriteriaExactUserDepartment *Optional* |
</div>


## `GroupPhoneDirectoryGetListRequest17sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a table containing the phone directory for a group.

If the specified group is part of an enterprise, the directory includes all users in
the enterprise and all entries in the enterprise common phone list and the common
phone list of the specified group.  If the specified group is part of a service
provider, the directory includes all users in the group and all entries in the common
phone list of the specified group.  It is possible to search by various criteria to
restrict the number of rows returned.  Multiple search criteria are logically ANDed
together.

The response is either `GroupPhoneDirectoryGetListResponse17sp3()` or
`ErrorResponse()`. Replaced by: `GroupPhoneDirectoryGetListRequest18()`

**Attributes:**

|Name                                  |Type                                      |Description                                  |
|--------------------------------------|------------------------------------------|---------------------------------------------|
|service_provider_id                   |str                                       |serviceProviderId                            |
|group_id                              |str                                       |groupId                                      |
|is_extended_info_requested            |bool                                      |isExtendedInfoRequested                      |
|response_size_limit                   |int                                       |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]      |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName]     |searchCriteriaUserFirstName *Optional*       |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]                |searchCriteriaDn *Optional*                  |
|search_criteria_group_location_code   |List[OCI.searchCriteriaGroupLocationCode] |searchCriteriaGroupLocationCode *Optional*   |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]         |searchCriteriaExtension *Optional*           |
|search_criteria_mobile_phone_number   |List[OCI.searchCriteriaMobilePhoneNumber] |searchCriteriaMobilePhoneNumber *Optional*   |
|search_criteria_email_address         |List[OCI.searchCriteriaEmailAddress]      |searchCriteriaEmailAddress *Optional*        |
|search_criteria_yahoo_id              |List[OCI.searchCriteriaYahooId]           |searchCriteriaYahooId *Optional*             |
|search_criteria_exact_user_group      |OCI.searchCriteriaExactUserGroup          |searchCriteriaExactUserGroup *Optional*      |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment     |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_imp_id                |List[OCI.searchCriteriaImpId]             |searchCriteriaImpId *Optional*               |
</div>


## `GroupPhoneDirectoryGetListRequest18`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a table containing the phone directory for a group.

If the specified group is part of an enterprise, the directory includes all users in
the enterprise and all entries in the enterprise common phone list and the common
phone list of the specified group.  If the specified group is part of a service
provider, the directory includes all users in the group and all entries in the common
phone list of the specified group.  It is possible to search by various criteria to
restrict the number of rows returned.  Multiple search criteria are logically ANDed
together.

The response is either `GroupPhoneDirectoryGetListResponse18()` or `ErrorResponse()`.

Replaced By: `GroupPhoneDirectoryGetPagedSortedListRequest()`

**Attributes:**

|Name                                  |Type                                      |Description                                  |
|--------------------------------------|------------------------------------------|---------------------------------------------|
|service_provider_id                   |str                                       |serviceProviderId                            |
|group_id                              |str                                       |groupId                                      |
|is_extended_info_requested            |bool                                      |isExtendedInfoRequested                      |
|response_size_limit                   |int                                       |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]      |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName]     |searchCriteriaUserFirstName *Optional*       |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]                |searchCriteriaDn *Optional*                  |
|search_criteria_group_location_code   |List[OCI.searchCriteriaGroupLocationCode] |searchCriteriaGroupLocationCode *Optional*   |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]         |searchCriteriaExtension *Optional*           |
|search_criteria_mobile_phone_number   |List[OCI.searchCriteriaMobilePhoneNumber] |searchCriteriaMobilePhoneNumber *Optional*   |
|search_criteria_email_address         |List[OCI.searchCriteriaEmailAddress]      |searchCriteriaEmailAddress *Optional*        |
|search_criteria_yahoo_id              |List[OCI.searchCriteriaYahooId]           |searchCriteriaYahooId *Optional*             |
|search_criteria_exact_user_group      |OCI.searchCriteriaExactUserGroup          |searchCriteriaExactUserGroup *Optional*      |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment     |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]            |searchCriteriaUserId *Optional*              |
|search_criteria_imp_id                |List[OCI.searchCriteriaImpId]             |searchCriteriaImpId *Optional*               |
</div>


## `GroupPhoneDirectoryGetPagedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a table containing the phone directory for a group.

If the specified group is part of an enterprise, the directory includes all users in
the enterprise and all entries in the enterprise common phone list and the common
phone list of the specified group.  If the specified group is part of a service
provider, the directory includes all users in the group and all entries in the common
phone list of the specified group.  It is possible to search by various criteria to
restrict the number of rows returned.  Multiple search criteria are logically ANDed
together.

The response is either `GroupPhoneDirectoryGetPagedListResponse()` or
`ErrorResponse()`.

Replaced By: `GroupPhoneDirectoryGetPagedSortedListRequest()`

**Attributes:**

|Name                                  |Type                                      |Description                                  |
|--------------------------------------|------------------------------------------|---------------------------------------------|
|service_provider_id                   |str                                       |serviceProviderId                            |
|group_id                              |str                                       |groupId                                      |
|is_extended_info_requested            |bool                                      |isExtendedInfoRequested                      |
|response_paging_control               |OCI.responsePagingControl                 |responsePagingControl                        |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]      |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName]     |searchCriteriaUserFirstName *Optional*       |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]                |searchCriteriaDn *Optional*                  |
|search_criteria_group_location_code   |List[OCI.searchCriteriaGroupLocationCode] |searchCriteriaGroupLocationCode *Optional*   |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]         |searchCriteriaExtension *Optional*           |
|search_criteria_mobile_phone_number   |List[OCI.searchCriteriaMobilePhoneNumber] |searchCriteriaMobilePhoneNumber *Optional*   |
|search_criteria_email_address         |List[OCI.searchCriteriaEmailAddress]      |searchCriteriaEmailAddress *Optional*        |
|search_criteria_yahoo_id              |List[OCI.searchCriteriaYahooId]           |searchCriteriaYahooId *Optional*             |
|search_criteria_exact_user_group      |OCI.searchCriteriaExactUserGroup          |searchCriteriaExactUserGroup *Optional*      |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment     |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]            |searchCriteriaUserId *Optional*              |
|search_criteria_imp_id                |List[OCI.searchCriteriaImpId]             |searchCriteriaImpId *Optional*               |
</div>


## `GroupPreAlertingAnnouncementModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the group level pre-alerting service settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`GroupPreAlertingAnnouncementModifyRequest20()` in AS data mode

**Attributes:**

|Name                        |Type          |Description                          |
|----------------------------|--------------|-------------------------------------|
|service_provider_id         |str           |serviceProviderId                    |
|group_id                    |str           |groupId                              |
|announcement_interruption   |str           |announcementInterruption *Optional*  |
|interruption_digit_sequence |str           |interruptionDigitSequence *Optional* |
|audio_selection             |str           |audioSelection *Optional*            |
|audio_file                  |OCI.audioFile |audioFile *Optional*                 |
|video_selection             |str           |videoSelection *Optional*            |
|video_file                  |OCI.videoFile |videoFile *Optional*                 |
</div>


## `GroupPreAlertingAnnouncementModifyRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the group level pre-alerting service settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                        |Type          |Description                          |
|----------------------------|--------------|-------------------------------------|
|service_provider_id         |str           |serviceProviderId                    |
|group_id                    |str           |groupId                              |
|announcement_interruption   |str           |announcementInterruption *Optional*  |
|interruption_digit_sequence |str           |interruptionDigitSequence *Optional* |
|audio_selection             |str           |audioSelection *Optional*            |
|audio_file                  |OCI.audioFile |audioFile *Optional*                 |
|video_selection             |str           |videoSelection *Optional*            |
|video_file                  |OCI.videoFile |videoFile *Optional*                 |
</div>


## `GroupRoutePointAddInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Route Point instance to a group.

The Route Point is a Call Center queue that performs the same function but allows an
external system to perform the distribution of calls instead of making those decisions
itself.  The domain is required in the serviceUserId.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replace by
`GroupRoutePointAddInstanceRequest22()`

**Attributes:**

|Name                                     |Type                       |Description                             |
|-----------------------------------------|---------------------------|----------------------------------------|
|service_provider_id                      |str                        |serviceProviderId                       |
|group_id                                 |str                        |groupId                                 |
|service_user_id                          |str                        |serviceUserId                           |
|service_instance_profile                 |OCI.serviceInstanceProfile |serviceInstanceProfile                  |
|network_class_of_service                 |str                        |networkClassOfService *Optional*        |
|external_preferred_audio_codec           |str                        |externalPreferredAudioCodec             |
|internal_preferred_audio_codec           |str                        |internalPreferredAudioCodec             |
|queue_length                             |int                        |queueLength                             |
|no_answer_timeout_rings                  |int                        |noAnswerTimeoutRings                    |
|enable_video                             |bool                       |enableVideo                             |
|play_ringing_when_offering_call          |bool                       |playRingingWhenOfferingCall             |
|override_agent_wrap_up_time              |bool                       |overrideAgentWrapUpTime                 |
|wrap_up_seconds                          |int                        |wrapUpSeconds *Optional*                |
|enable_automatic_state_change_for_agents |bool                       |enableAutomaticStateChangeForAgents     |
|agent_state_after_call                   |str                        |agentStateAfterCall                     |
|agent_unavailable_code                   |str                        |agentUnavailableCode *Optional*         |
|force_delivery_of_calls                  |bool                       |forceDeliveryOfCalls                    |
|force_delivery_wait_time_seconds         |int                        |forceDeliveryWaitTimeSeconds *Optional* |
</div>


## `GroupRoutePointAddInstanceRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Route Point instance to a group.

The Route Point is a Call Center queue that performs the same function but allows an
external system to perform the distribution of calls instead of making those decisions
itself.  The domain is required in the serviceUserId.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by
`GroupRoutePointAddInstanceRequest23()`.

**Attributes:**

|Name                                     |Type                       |Description                             |
|-----------------------------------------|---------------------------|----------------------------------------|
|service_provider_id                      |str                        |serviceProviderId                       |
|group_id                                 |str                        |groupId                                 |
|service_user_id                          |str                        |serviceUserId                           |
|service_instance_profile                 |OCI.serviceInstanceProfile |serviceInstanceProfile                  |
|network_class_of_service                 |str                        |networkClassOfService *Optional*        |
|external_preferred_audio_codec           |str                        |externalPreferredAudioCodec             |
|internal_preferred_audio_codec           |str                        |internalPreferredAudioCodec             |
|queue_length                             |int                        |queueLength                             |
|no_answer_timeout_rings                  |int                        |noAnswerTimeoutRings                    |
|enable_video                             |bool                       |enableVideo                             |
|play_ringing_when_offering_call          |bool                       |playRingingWhenOfferingCall             |
|override_agent_wrap_up_time              |bool                       |overrideAgentWrapUpTime                 |
|wrap_up_seconds                          |int                        |wrapUpSeconds *Optional*                |
|enable_automatic_state_change_for_agents |bool                       |enableAutomaticStateChangeForAgents     |
|agent_state_after_call                   |str                        |agentStateAfterCall                     |
|agent_unavailable_code                   |str                        |agentUnavailableCode *Optional*         |
|force_delivery_of_calls                  |bool                       |forceDeliveryOfCalls                    |
|force_delivery_wait_time_seconds         |int                        |forceDeliveryWaitTimeSeconds *Optional* |
</div>


## `GroupRoutePointAddInstanceRequest23`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Route Point instance to a group.

The Route Point is a Call Center queue that performs the same function but allows an
external system to perform the distribution of calls instead of making those decisions
itself.  The domain is required in the serviceUserId.

The response is either `SuccessResponse()` or `ErrorResponse()`. The Following
elements are only used in AS data mode and ignored in XS data mode: -
sendCallAdmissionNotification, use value ‘false’ in XS data mode.  -
callAdmissionTimerSeconds, use value ‘3’ in XS data mode.

**Attributes:**

|Name                                     |Type                       |Description                             |
|-----------------------------------------|---------------------------|----------------------------------------|
|service_provider_id                      |str                        |serviceProviderId                       |
|group_id                                 |str                        |groupId                                 |
|service_user_id                          |str                        |serviceUserId                           |
|service_instance_profile                 |OCI.serviceInstanceProfile |serviceInstanceProfile                  |
|network_class_of_service                 |str                        |networkClassOfService *Optional*        |
|external_preferred_audio_codec           |str                        |externalPreferredAudioCodec             |
|internal_preferred_audio_codec           |str                        |internalPreferredAudioCodec             |
|queue_length                             |int                        |queueLength                             |
|no_answer_timeout_rings                  |int                        |noAnswerTimeoutRings                    |
|enable_video                             |bool                       |enableVideo                             |
|play_ringing_when_offering_call          |bool                       |playRingingWhenOfferingCall             |
|override_agent_wrap_up_time              |bool                       |overrideAgentWrapUpTime                 |
|wrap_up_seconds                          |int                        |wrapUpSeconds *Optional*                |
|enable_automatic_state_change_for_agents |bool                       |enableAutomaticStateChangeForAgents     |
|agent_state_after_call                   |str                        |agentStateAfterCall                     |
|agent_unavailable_code                   |str                        |agentUnavailableCode *Optional*         |
|force_delivery_of_calls                  |bool                       |forceDeliveryOfCalls                    |
|force_delivery_wait_time_seconds         |int                        |forceDeliveryWaitTimeSeconds *Optional* |
|send_call_admission_notification         |bool                       |sendCallAdmissionNotification           |
|call_admission_timer_seconds             |int                        |callAdmissionTimerSeconds               |
|enable_unlimited_queue_length            |bool                       |enableUnlimitedQueueLength *Optional*   |
</div>


## `GroupRoutePointExternalSystemGetAssignedRoutePointListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a list of route points within in a group that have a given external system
assigned.

The response is either
`GroupRoutePointExternalSystemGetAssignedRoutePointListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                             |Type                                   |Description                             |
|---------------------------------|---------------------------------------|----------------------------------------|
|service_provider_id              |str                                    |serviceProviderId                       |
|group_id                         |str                                    |groupId                                 |
|external_system                  |str                                    |externalSystem                          |
|response_size_limit              |int                                    |responseSizeLimit *Optional*            |
|search_criteria_route_point_name |List[OCI.searchCriteriaRoutePointName] |searchCriteriaRoutePointName *Optional* |
</div>


## `GroupRoutePointForcedForwardingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a route point's forced forwarding settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                |Type              |Description                                 |
|------------------------------------|------------------|--------------------------------------------|
|service_user_id                     |str               |serviceUserId                               |
|is_active                           |bool              |isActive *Optional*                         |
|forward_to_phone_number             |str               |forwardToPhoneNumber *Optional*             |
|play_announcement_before_forwarding |bool              |playAnnouncementBeforeForwarding *Optional* |
|audio_message_selection             |str               |audioMessageSelection *Optional*            |
|audio_url_list                      |OCI.audioUrlList  |audioUrlList *Optional*                     |
|audio_file_list                     |OCI.audioFileList |audioFileList *Optional*                    |
|video_message_selection             |str               |videoMessageSelection *Optional*            |
|video_url_list                      |OCI.videoUrlList  |videoUrlList *Optional*                     |
|video_file_list                     |OCI.videoFileList |videoFileList *Optional*                    |
</div>


## `GroupRoutePointForcedForwardingModifyRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a route point's forced forwarding settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                |Type              |Description                                 |
|------------------------------------|------------------|--------------------------------------------|
|service_user_id                     |str               |serviceUserId                               |
|is_active                           |bool              |isActive *Optional*                         |
|forward_to_phone_number             |str               |forwardToPhoneNumber *Optional*             |
|play_announcement_before_forwarding |bool              |playAnnouncementBeforeForwarding *Optional* |
|audio_message_selection             |str               |audioMessageSelection *Optional*            |
|audio_url_list                      |OCI.audioUrlList  |audioUrlList *Optional*                     |
|audio_file_list                     |OCI.audioFileList |audioFileList *Optional*                    |
|video_message_selection             |str               |videoMessageSelection *Optional*            |
|video_url_list                      |OCI.videoUrlList  |videoUrlList *Optional*                     |
|video_file_list                     |OCI.videoFileList |videoFileList *Optional*                    |
</div>


## `GroupRoutePointGetInstanceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of Route Point instances within a group.

It is possible to search by various criteria to restrict the number of rows returned.

The response is either `GroupRoutePointGetInstanceListResponse()` or
`ErrorResponse()`. It is possible to get the instances within a specified department.

**Attributes:**

|Name                             |Type                                   |Description                             |
|---------------------------------|---------------------------------------|----------------------------------------|
|service_provider_id              |str                                    |serviceProviderId                       |
|group_id                         |str                                    |groupId                                 |
|group_department_name            |str                                    |groupDepartmentName *Optional*          |
|response_size_limit              |int                                    |responseSizeLimit *Optional*            |
|search_criteria_route_point_name |List[OCI.searchCriteriaRoutePointName] |searchCriteriaRoutePointName *Optional* |
</div>


## `GroupRoutePointHolidayServiceModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a route point's holiday service settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                            |Type              |Description                             |
|--------------------------------|------------------|----------------------------------------|
|service_user_id                 |str               |serviceUserId                           |
|action                          |str               |action *Optional*                       |
|holiday_schedule                |str               |holidaySchedule *Optional*              |
|transfer_phone_number           |str               |transferPhoneNumber *Optional*          |
|play_announcement_before_action |bool              |playAnnouncementBeforeAction *Optional* |
|audio_message_selection         |str               |audioMessageSelection *Optional*        |
|audio_url_list                  |OCI.audioUrlList  |audioUrlList *Optional*                 |
|audio_file_list                 |OCI.audioFileList |audioFileList *Optional*                |
|video_message_selection         |str               |videoMessageSelection *Optional*        |
|video_url_list                  |OCI.videoUrlList  |videoUrlList *Optional*                 |
|video_file_list                 |OCI.videoFileList |videoFileList *Optional*                |
</div>


## `GroupRoutePointHolidayServiceModifyRequest17sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a route point's holiday service settings.

Only Group and Enterprise level schedules are accepted.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                            |Type                |Description                             |
|--------------------------------|--------------------|----------------------------------------|
|service_user_id                 |str                 |serviceUserId                           |
|action                          |str                 |action *Optional*                       |
|holiday_schedule                |OCI.holidaySchedule |holidaySchedule *Optional*              |
|transfer_phone_number           |str                 |transferPhoneNumber *Optional*          |
|play_announcement_before_action |bool                |playAnnouncementBeforeAction *Optional* |
|audio_message_selection         |str                 |audioMessageSelection *Optional*        |
|audio_url_list                  |OCI.audioUrlList    |audioUrlList *Optional*                 |
|audio_file_list                 |OCI.audioFileList   |audioFileList *Optional*                |
|video_message_selection         |str                 |videoMessageSelection *Optional*        |
|video_url_list                  |OCI.videoUrlList    |videoUrlList *Optional*                 |
|video_file_list                 |OCI.videoFileList   |videoFileList *Optional*                |
</div>


## `GroupRoutePointHolidayServiceModifyRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a route point's holiday service settings.

Only Group and Enterprise level schedules are accepted.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                            |Type                |Description                             |
|--------------------------------|--------------------|----------------------------------------|
|service_user_id                 |str                 |serviceUserId                           |
|action                          |str                 |action *Optional*                       |
|holiday_schedule                |OCI.holidaySchedule |holidaySchedule *Optional*              |
|transfer_phone_number           |str                 |transferPhoneNumber *Optional*          |
|play_announcement_before_action |bool                |playAnnouncementBeforeAction *Optional* |
|audio_message_selection         |str                 |audioMessageSelection *Optional*        |
|audio_url_list                  |OCI.audioUrlList    |audioUrlList *Optional*                 |
|audio_file_list                 |OCI.audioFileList   |audioFileList *Optional*                |
|video_message_selection         |str                 |videoMessageSelection *Optional*        |
|video_url_list                  |OCI.videoUrlList    |videoUrlList *Optional*                 |
|video_file_list                 |OCI.videoFileList   |videoFileList *Optional*                |
</div>


## `GroupRoutePointModifyInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a Route Point instance.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by
`GroupRoutePointModifyInstanceRequest22()`.

**Attributes:**

|Name                                     |Type                       |Description                                    |
|-----------------------------------------|---------------------------|-----------------------------------------------|
|service_user_id                          |str                        |serviceUserId                                  |
|service_instance_profile                 |OCI.serviceInstanceProfile |serviceInstanceProfile *Optional*              |
|network_class_of_service                 |str                        |networkClassOfService *Optional*               |
|external_preferred_audio_codec           |str                        |externalPreferredAudioCodec *Optional*         |
|internal_preferred_audio_codec           |str                        |internalPreferredAudioCodec *Optional*         |
|queue_length                             |int                        |queueLength *Optional*                         |
|no_answer_timeout_rings                  |int                        |noAnswerTimeoutRings *Optional*                |
|enable_video                             |bool                       |enableVideo *Optional*                         |
|play_ringing_when_offering_call          |bool                       |playRingingWhenOfferingCall *Optional*         |
|override_agent_wrap_up_time              |bool                       |overrideAgentWrapUpTime *Optional*             |
|wrap_up_seconds                          |int                        |wrapUpSeconds *Optional*                       |
|enable_automatic_state_change_for_agents |bool                       |enableAutomaticStateChangeForAgents *Optional* |
|agent_state_after_call                   |str                        |agentStateAfterCall *Optional*                 |
|agent_unavailable_code                   |str                        |agentUnavailableCode *Optional*                |
|force_delivery_of_calls                  |bool                       |forceDeliveryOfCalls *Optional*                |
|force_delivery_wait_time_seconds         |int                        |forceDeliveryWaitTimeSeconds *Optional*        |
</div>


## `GroupRoutePointModifyInstanceRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a Route Point instance.

The response is either `SuccessResponse()` or `ErrorResponse()`. The Following
elements are only used in AS data mode and ignored in XS data mode: -
sendCallAdmissionNotification, use value ‘false’ in XS data mode.  -
callAdmissionTimerSeconds, use value ‘3’ in XS data mode.

**Attributes:**

|Name                                     |Type                       |Description                                    |
|-----------------------------------------|---------------------------|-----------------------------------------------|
|service_user_id                          |str                        |serviceUserId                                  |
|service_instance_profile                 |OCI.serviceInstanceProfile |serviceInstanceProfile *Optional*              |
|network_class_of_service                 |str                        |networkClassOfService *Optional*               |
|external_preferred_audio_codec           |str                        |externalPreferredAudioCodec *Optional*         |
|internal_preferred_audio_codec           |str                        |internalPreferredAudioCodec *Optional*         |
|queue_length                             |int                        |queueLength *Optional*                         |
|no_answer_timeout_rings                  |int                        |noAnswerTimeoutRings *Optional*                |
|enable_video                             |bool                       |enableVideo *Optional*                         |
|play_ringing_when_offering_call          |bool                       |playRingingWhenOfferingCall *Optional*         |
|override_agent_wrap_up_time              |bool                       |overrideAgentWrapUpTime *Optional*             |
|wrap_up_seconds                          |int                        |wrapUpSeconds *Optional*                       |
|enable_automatic_state_change_for_agents |bool                       |enableAutomaticStateChangeForAgents *Optional* |
|agent_state_after_call                   |str                        |agentStateAfterCall *Optional*                 |
|agent_unavailable_code                   |str                        |agentUnavailableCode *Optional*                |
|force_delivery_of_calls                  |bool                       |forceDeliveryOfCalls *Optional*                |
|force_delivery_wait_time_seconds         |int                        |forceDeliveryWaitTimeSeconds *Optional*        |
|send_call_admission_notification         |bool                       |sendCallAdmissionNotification *Optional*       |
|call_admission_timer_seconds             |int                        |callAdmissionTimerSeconds *Optional*           |
|enable_unlimited_queue_length            |bool                       |enableUnlimitedQueueLength *Optional*          |
</div>


## `GroupRoutePointNightServiceModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a route point's night service settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                            |Type                    |Description                             |
|--------------------------------|------------------------|----------------------------------------|
|service_user_id                 |str                     |serviceUserId                           |
|action                          |str                     |action *Optional*                       |
|business_hours                  |str                     |businessHours *Optional*                |
|force_night_service             |bool                    |forceNightService *Optional*            |
|transfer_phone_number           |str                     |transferPhoneNumber *Optional*          |
|play_announcement_before_action |bool                    |playAnnouncementBeforeAction *Optional* |
|audio_message_selection         |str                     |audioMessageSelection *Optional*        |
|audio_url_list                  |OCI.audioUrlList        |audioUrlList *Optional*                 |
|audio_file_list                 |OCI.audioFileList       |audioFileList *Optional*                |
|video_message_selection         |str                     |videoMessageSelection *Optional*        |
|video_url_list                  |OCI.videoUrlList        |videoUrlList *Optional*                 |
|video_file_list                 |OCI.videoFileList       |videoFileList *Optional*                |
|manual_announcement_mode        |str                     |manualAnnouncementMode *Optional*       |
|manual_audio_message_selection  |str                     |manualAudioMessageSelection *Optional*  |
|manual_audio_url_list           |OCI.manualAudioUrlList  |manualAudioUrlList *Optional*           |
|manual_audio_file_list          |OCI.manualAudioFileList |manualAudioFileList *Optional*          |
|manual_video_message_selection  |str                     |manualVideoMessageSelection *Optional*  |
|manual_video_url_list           |OCI.manualVideoUrlList  |manualVideoUrlList *Optional*           |
|manual_video_file_list          |OCI.manualVideoFileList |manualVideoFileList *Optional*          |
</div>


## `GroupRoutePointNightServiceModifyRequest17sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a route point's night service settings.

Only Group and Enterprise level schedules are accepted.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                            |Type                    |Description                             |
|--------------------------------|------------------------|----------------------------------------|
|service_user_id                 |str                     |serviceUserId                           |
|action                          |str                     |action *Optional*                       |
|business_hours                  |OCI.businessHours       |businessHours *Optional*                |
|force_night_service             |bool                    |forceNightService *Optional*            |
|transfer_phone_number           |str                     |transferPhoneNumber *Optional*          |
|play_announcement_before_action |bool                    |playAnnouncementBeforeAction *Optional* |
|audio_message_selection         |str                     |audioMessageSelection *Optional*        |
|audio_url_list                  |OCI.audioUrlList        |audioUrlList *Optional*                 |
|audio_file_list                 |OCI.audioFileList       |audioFileList *Optional*                |
|video_message_selection         |str                     |videoMessageSelection *Optional*        |
|video_url_list                  |OCI.videoUrlList        |videoUrlList *Optional*                 |
|video_file_list                 |OCI.videoFileList       |videoFileList *Optional*                |
|manual_announcement_mode        |str                     |manualAnnouncementMode *Optional*       |
|manual_audio_message_selection  |str                     |manualAudioMessageSelection *Optional*  |
|manual_audio_url_list           |OCI.manualAudioUrlList  |manualAudioUrlList *Optional*           |
|manual_audio_file_list          |OCI.manualAudioFileList |manualAudioFileList *Optional*          |
|manual_video_message_selection  |str                     |manualVideoMessageSelection *Optional*  |
|manual_video_url_list           |OCI.manualVideoUrlList  |manualVideoUrlList *Optional*           |
|manual_video_file_list          |OCI.manualVideoFileList |manualVideoFileList *Optional*          |
</div>


## `GroupRoutePointNightServiceModifyRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a route point's night service settings.

Only Group and Enterprise level schedules are accepted.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                            |Type                    |Description                             |
|--------------------------------|------------------------|----------------------------------------|
|service_user_id                 |str                     |serviceUserId                           |
|action                          |str                     |action *Optional*                       |
|business_hours                  |OCI.businessHours       |businessHours *Optional*                |
|force_night_service             |bool                    |forceNightService *Optional*            |
|transfer_phone_number           |str                     |transferPhoneNumber *Optional*          |
|play_announcement_before_action |bool                    |playAnnouncementBeforeAction *Optional* |
|audio_message_selection         |str                     |audioMessageSelection *Optional*        |
|audio_url_list                  |OCI.audioUrlList        |audioUrlList *Optional*                 |
|audio_file_list                 |OCI.audioFileList       |audioFileList *Optional*                |
|video_message_selection         |str                     |videoMessageSelection *Optional*        |
|video_url_list                  |OCI.videoUrlList        |videoUrlList *Optional*                 |
|video_file_list                 |OCI.videoFileList       |videoFileList *Optional*                |
|manual_announcement_mode        |str                     |manualAnnouncementMode *Optional*       |
|manual_audio_message_selection  |str                     |manualAudioMessageSelection *Optional*  |
|manual_audio_url_list           |OCI.manualAudioUrlList  |manualAudioUrlList *Optional*           |
|manual_audio_file_list          |OCI.manualAudioFileList |manualAudioFileList *Optional*          |
|manual_video_message_selection  |str                     |manualVideoMessageSelection *Optional*  |
|manual_video_url_list           |OCI.manualVideoUrlList  |manualVideoUrlList *Optional*           |
|manual_video_file_list          |OCI.manualVideoFileList |manualVideoFileList *Optional*          |
</div>


## `GroupRoutePointOverflowModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a route point's overflow settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                         |Type              |Description                                         |
|---------------------------------------------|------------------|----------------------------------------------------|
|service_user_id                              |str               |serviceUserId                                       |
|action                                       |str               |action *Optional*                                   |
|transfer_phone_number                        |str               |transferPhoneNumber *Optional*                      |
|overflow_after_timeout                       |bool              |overflowAfterTimeout *Optional*                     |
|timeout_seconds                              |int               |timeoutSeconds *Optional*                           |
|play_announcement_before_overflow_processing |bool              |playAnnouncementBeforeOverflowProcessing *Optional* |
|audio_message_selection                      |str               |audioMessageSelection *Optional*                    |
|audio_url_list                               |OCI.audioUrlList  |audioUrlList *Optional*                             |
|audio_file_list                              |OCI.audioFileList |audioFileList *Optional*                            |
|video_message_selection                      |str               |videoMessageSelection *Optional*                    |
|video_url_list                               |OCI.videoUrlList  |videoUrlList *Optional*                             |
|video_file_list                              |OCI.videoFileList |videoFileList *Optional*                            |
</div>


## `GroupRoutePointOverflowModifyRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a route point's overflow settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                         |Type              |Description                                         |
|---------------------------------------------|------------------|----------------------------------------------------|
|service_user_id                              |str               |serviceUserId                                       |
|action                                       |str               |action *Optional*                                   |
|transfer_phone_number                        |str               |transferPhoneNumber *Optional*                      |
|overflow_after_timeout                       |bool              |overflowAfterTimeout *Optional*                     |
|timeout_seconds                              |int               |timeoutSeconds *Optional*                           |
|play_announcement_before_overflow_processing |bool              |playAnnouncementBeforeOverflowProcessing *Optional* |
|audio_message_selection                      |str               |audioMessageSelection *Optional*                    |
|audio_url_list                               |OCI.audioUrlList  |audioUrlList *Optional*                             |
|audio_file_list                              |OCI.audioFileList |audioFileList *Optional*                            |
|video_message_selection                      |str               |videoMessageSelection *Optional*                    |
|video_url_list                               |OCI.videoUrlList  |videoUrlList *Optional*                             |
|video_file_list                              |OCI.videoFileList |videoFileList *Optional*                            |
</div>


## `GroupScheduleGetPagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of schedules viewable by a group.

The response is either a `GroupScheduleGetPagedSortedListResponse()` or an
`ErrorResponse()`. If no sortOrder is included, the response is sorted by Name
ascending by default.  If the responsePagingControl element is not provided, the
paging startIndex will be set to 1 by default, and the responsePageSize will be set to
the maximum responsePageSize by default.  Multiple search criteria are logically ANDed
together unless the searchCriteriaModeOr option is included.  Then the search criteria
are logically ORed together.

**Attributes:**

|Name                                 |Type                                       |Description                                 |
|-------------------------------------|-------------------------------------------|--------------------------------------------|
|service_provider_id                  |str                                        |serviceProviderId                           |
|group_id                             |str                                        |groupId                                     |
|response_paging_control              |OCI.responsePagingControl                  |responsePagingControl *Optional*            |
|sort_by_schedule_name                |OCI.sortByScheduleName                     |sortByScheduleName *Optional*               |
|search_criteria_schedule_name        |List[OCI.searchCriteriaScheduleName]       |searchCriteriaScheduleName *Optional*       |
|search_criteria_exact_schedule_type  |List[OCI.searchCriteriaExactScheduleType]  |searchCriteriaExactScheduleType *Optional*  |
|search_criteria_exact_schedule_level |List[OCI.searchCriteriaExactScheduleLevel] |searchCriteriaExactScheduleLevel *Optional* |
|search_criteria_mode_or              |bool                                       |searchCriteriaModeOr *Optional*             |
</div>


## `GroupSeriesCompletionGetAvailableUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of users that can be assigned to a Series Completion group.

The available user list for a new Series Completion group can be obtained by not
setting the name.

The response is either `GroupSeriesCompletionGetAvailableUserListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|service_provider_id                   |str                                   |serviceProviderId                            |
|group_id                              |str                                   |groupId                                      |
|name                                  |str                                   |name *Optional*                              |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*              |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                  |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*           |
</div>


## `GroupServiceModifyAuthorizationListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests to change the group's service authorization status.

The boolean flags are used to authorize or unauthorize services and packs.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                        |Type                                |Description                          |
|----------------------------|------------------------------------|-------------------------------------|
|service_provider_id         |str                                 |serviceProviderId                    |
|group_id                    |str                                 |groupId                              |
|service_pack_authorization  |List[OCI.servicePackAuthorization]  |servicePackAuthorization *Optional*  |
|group_service_authorization |List[OCI.groupServiceAuthorization] |groupServiceAuthorization *Optional* |
|user_service_authorization  |List[OCI.userServiceAuthorization]  |userServiceAuthorization *Optional*  |
</div>


## `GroupSessionAdmissionControlGetAvailableDeviceListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of devices can be assigned to session admission control group
for the group.

The response is either an
`GroupSessionAdmissionControlGetAvailableDeviceListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                               |Type                                     |Description                               |
|-----------------------------------|-----------------------------------------|------------------------------------------|
|service_provider_id                |str                                      |serviceProviderId                         |
|group_id                           |str                                      |groupId                                   |
|response_size_limit                |int                                      |responseSizeLimit *Optional*              |
|search_criteria_device_name        |List[OCI.searchCriteriaDeviceName]       |searchCriteriaDeviceName *Optional*       |
|search_criteria_device_mac_address |List[OCI.searchCriteriaDeviceMACAddress] |searchCriteriaDeviceMACAddress *Optional* |
|search_criteria_device_net_address |List[OCI.searchCriteriaDeviceNetAddress] |searchCriteriaDeviceNetAddress *Optional* |
|search_criteria_exact_device_type  |OCI.searchCriteriaExactDeviceType        |searchCriteriaExactDeviceType *Optional*  |
|search_criteria_exact_device_level |OCI.searchCriteriaExactDeviceLevel       |searchCriteriaExactDeviceLevel *Optional* |
</div>


## `GroupSessionAdmissionControlGroupModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a session admission control group for the group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Note that to
provision the accessInfoPattern element, the captureAccessInfoInPaniHeader system
parameter needs to be set to "true".

**Attributes:**

|Name                                               |Type           |Description                                           |
|---------------------------------------------------|---------------|------------------------------------------------------|
|service_provider_id                                |str            |serviceProviderId                                     |
|group_id                                           |str            |groupId                                               |
|name                                               |str            |name                                                  |
|new_name                                           |str            |newName *Optional*                                    |
|max_session                                        |int            |maxSession *Optional*                                 |
|max_user_originating_sessions                      |int            |maxUserOriginatingSessions *Optional*                 |
|max_user_terminating_sessions                      |int            |maxUserTerminatingSessions *Optional*                 |
|reserved_session                                   |int            |reservedSession *Optional*                            |
|reserved_user_originating_sessions                 |int            |reservedUserOriginatingSessions *Optional*            |
|reserved_user_terminating_sessions                 |int            |reservedUserTerminatingSessions *Optional*            |
|become_default_group                               |bool           |becomeDefaultGroup *Optional*                         |
|count_intra_sac_group_sessions                     |bool           |countIntraSACGroupSessions *Optional*                 |
|device_list                                        |OCI.deviceList |deviceList *Optional*                                 |
|block_emergency_and_repair_calls_due_to_sac_limits |bool           |blockEmergencyAndRepairCallsDueToSACLimits *Optional* |
|media_group_name                                   |str            |mediaGroupName *Optional*                             |
|access_info_pattern                                |str            |accessInfoPattern *Optional*                          |
</div>


## `GroupTrunkGroupAddInstanceRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Trunk Group instance to a group.

The domain is required in the serviceUserId.  The publicUserIdentity in the
ServiceInstanceAddProfile is not allowed for trunk groups.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                         |Type                       |Description                          |
|-----------------------------|---------------------------|-------------------------------------|
|service_provider_id          |str                        |serviceProviderId                    |
|group_id                     |str                        |groupId                              |
|service_user_id              |str                        |serviceUserId                        |
|service_instance_profile     |OCI.serviceInstanceProfile |serviceInstanceProfile               |
|access_device_endpoint       |OCI.accessDeviceEndpoint   |accessDeviceEndpoint *Optional*      |
|max_active_calls             |int                        |maxActiveCalls                       |
|max_incoming_calls           |int                        |maxIncomingCalls *Optional*          |
|max_outgoing_calls           |int                        |maxOutgoingCalls *Optional*          |
|require_authentication       |bool                       |requireAuthentication                |
|sip_authentication_user_name |str                        |sipAuthenticationUserName *Optional* |
|sip_authentication_password  |str                        |sipAuthenticationPassword *Optional* |
</div>


## `GroupTrunkGroupAddInstanceRequest14sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Trunk Group instance to a group.

The domain is required in the serviceUserId.  The publicUserIdentity in the
ServiceInstanceAddProfile is not allowed for trunk groups.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                           |Type                       |Description                                          |
|-----------------------------------------------|---------------------------|-----------------------------------------------------|
|service_provider_id                            |str                        |serviceProviderId                                    |
|group_id                                       |str                        |groupId                                              |
|service_user_id                                |str                        |serviceUserId                                        |
|service_instance_profile                       |OCI.serviceInstanceProfile |serviceInstanceProfile                               |
|access_device_endpoint                         |OCI.accessDeviceEndpoint   |accessDeviceEndpoint *Optional*                      |
|max_active_calls                               |int                        |maxActiveCalls                                       |
|max_incoming_calls                             |int                        |maxIncomingCalls *Optional*                          |
|max_outgoing_calls                             |int                        |maxOutgoingCalls *Optional*                          |
|enable_bursting                                |bool                       |enableBursting                                       |
|bursting_max_active_calls                      |int                        |burstingMaxActiveCalls *Optional*                    |
|bursting_max_incoming_calls                    |int                        |burstingMaxIncomingCalls *Optional*                  |
|bursting_max_outgoing_calls                    |int                        |burstingMaxOutgoingCalls *Optional*                  |
|capacity_exceeded_action                       |str                        |capacityExceededAction *Optional*                    |
|capacity_exceeded_forward_address              |str                        |capacityExceededForwardAddress *Optional*            |
|capacity_exceeded_reroute_trunk_group_id       |str                        |capacityExceededRerouteTrunkGroupId *Optional*       |
|capacity_exceeded_trap_initial_calls           |int                        |capacityExceededTrapInitialCalls                     |
|capacity_exceeded_trap_offset_calls            |int                        |capacityExceededTrapOffsetCalls                      |
|unreachable_destination_action                 |str                        |unreachableDestinationAction *Optional*              |
|unreachable_destination_forward_address        |str                        |unreachableDestinationForwardAddress *Optional*      |
|unreachable_destination_reroute_trunk_group_id |str                        |unreachableDestinationRerouteTrunkGroupId *Optional* |
|unreachable_destination_trap_initial_calls     |int                        |unreachableDestinationTrapInitialCalls               |
|unreachable_destination_trap_offset_calls      |int                        |unreachableDestinationTrapOffsetCalls                |
|invitation_timeout                             |int                        |invitationTimeout                                    |
|require_authentication                         |bool                       |requireAuthentication                                |
|sip_authentication_user_name                   |str                        |sipAuthenticationUserName *Optional*                 |
|sip_authentication_password                    |str                        |sipAuthenticationPassword *Optional*                 |
</div>


## `GroupTrunkGroupAddInstanceRequest14sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Trunk Group instance to a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                            |Type                                           |Description                                           |
|------------------------------------------------|-----------------------------------------------|------------------------------------------------------|
|service_provider_id                             |str                                            |serviceProviderId                                     |
|group_id                                        |str                                            |groupId                                               |
|name                                            |str                                            |name                                                  |
|pilot_user                                      |OCI.pilotUser                                  |pilotUser *Optional*                                  |
|department                                      |OCI.department                                 |department *Optional*                                 |
|access_device                                   |OCI.accessDevice                               |accessDevice *Optional*                               |
|max_active_calls                                |int                                            |maxActiveCalls                                        |
|max_incoming_calls                              |int                                            |maxIncomingCalls *Optional*                           |
|max_outgoing_calls                              |int                                            |maxOutgoingCalls *Optional*                           |
|enable_bursting                                 |bool                                           |enableBursting                                        |
|bursting_max_active_calls                       |int                                            |burstingMaxActiveCalls *Optional*                     |
|bursting_max_incoming_calls                     |int                                            |burstingMaxIncomingCalls *Optional*                   |
|bursting_max_outgoing_calls                     |int                                            |burstingMaxOutgoingCalls *Optional*                   |
|capacity_exceeded_action                        |str                                            |capacityExceededAction *Optional*                     |
|capacity_exceeded_forward_address               |str                                            |capacityExceededForwardAddress *Optional*             |
|capacity_exceeded_reroute_trunk_group_key       |OCI.capacityExceededRerouteTrunkGroupKey       |capacityExceededRerouteTrunkGroupKey *Optional*       |
|capacity_exceeded_trap_initial_calls            |int                                            |capacityExceededTrapInitialCalls                      |
|capacity_exceeded_trap_offset_calls             |int                                            |capacityExceededTrapOffsetCalls                       |
|unreachable_destination_action                  |str                                            |unreachableDestinationAction *Optional*               |
|unreachable_destination_forward_address         |str                                            |unreachableDestinationForwardAddress *Optional*       |
|unreachable_destination_reroute_trunk_group_key |OCI.unreachableDestinationRerouteTrunkGroupKey |unreachableDestinationRerouteTrunkGroupKey *Optional* |
|unreachable_destination_trap_initial_calls      |int                                            |unreachableDestinationTrapInitialCalls                |
|unreachable_destination_trap_offset_calls       |int                                            |unreachableDestinationTrapOffsetCalls                 |
|invitation_timeout                              |int                                            |invitationTimeout                                     |
|require_authentication                          |bool                                           |requireAuthentication                                 |
|sip_authentication_user_name                    |str                                            |sipAuthenticationUserName *Optional*                  |
|sip_authentication_password                     |str                                            |sipAuthenticationPassword *Optional*                  |
|hosted_user_id                                  |List[str]                                      |hostedUserId *Optional*                               |
</div>


## `GroupTrunkGroupAddInstanceRequest14sp9`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Trunk Group instance to a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                            |Type                                           |Description                                           |
|------------------------------------------------|-----------------------------------------------|------------------------------------------------------|
|service_provider_id                             |str                                            |serviceProviderId                                     |
|group_id                                        |str                                            |groupId                                               |
|name                                            |str                                            |name                                                  |
|pilot_user                                      |OCI.pilotUser                                  |pilotUser *Optional*                                  |
|department                                      |OCI.department                                 |department *Optional*                                 |
|access_device                                   |OCI.accessDevice                               |accessDevice *Optional*                               |
|max_active_calls                                |int                                            |maxActiveCalls                                        |
|max_incoming_calls                              |int                                            |maxIncomingCalls *Optional*                           |
|max_outgoing_calls                              |int                                            |maxOutgoingCalls *Optional*                           |
|enable_bursting                                 |bool                                           |enableBursting                                        |
|bursting_max_active_calls                       |int                                            |burstingMaxActiveCalls *Optional*                     |
|bursting_max_incoming_calls                     |int                                            |burstingMaxIncomingCalls *Optional*                   |
|bursting_max_outgoing_calls                     |int                                            |burstingMaxOutgoingCalls *Optional*                   |
|capacity_exceeded_action                        |str                                            |capacityExceededAction *Optional*                     |
|capacity_exceeded_forward_address               |str                                            |capacityExceededForwardAddress *Optional*             |
|capacity_exceeded_reroute_trunk_group_key       |OCI.capacityExceededRerouteTrunkGroupKey       |capacityExceededRerouteTrunkGroupKey *Optional*       |
|capacity_exceeded_trap_initial_calls            |int                                            |capacityExceededTrapInitialCalls                      |
|capacity_exceeded_trap_offset_calls             |int                                            |capacityExceededTrapOffsetCalls                       |
|unreachable_destination_action                  |str                                            |unreachableDestinationAction *Optional*               |
|unreachable_destination_forward_address         |str                                            |unreachableDestinationForwardAddress *Optional*       |
|unreachable_destination_reroute_trunk_group_key |OCI.unreachableDestinationRerouteTrunkGroupKey |unreachableDestinationRerouteTrunkGroupKey *Optional* |
|unreachable_destination_trap_initial_calls      |int                                            |unreachableDestinationTrapInitialCalls                |
|unreachable_destination_trap_offset_calls       |int                                            |unreachableDestinationTrapOffsetCalls                 |
|invitation_timeout                              |int                                            |invitationTimeout                                     |
|require_authentication                          |bool                                           |requireAuthentication                                 |
|sip_authentication_user_name                    |str                                            |sipAuthenticationUserName *Optional*                  |
|sip_authentication_password                     |str                                            |sipAuthenticationPassword *Optional*                  |
|hosted_user_id                                  |List[str]                                      |hostedUserId *Optional*                               |
|trunk_group_identity                            |str                                            |trunkGroupIdentity *Optional*                         |
|otg_dtg_identity                                |str                                            |otgDtgIdentity *Optional*                             |
|include_trunk_group_identity                    |bool                                           |includeTrunkGroupIdentity                             |
|include_dtg_identity                            |bool                                           |includeDtgIdentity                                    |
|enable_network_address_identity                 |bool                                           |enableNetworkAddressIdentity                          |
|allow_unscreened_calls                          |bool                                           |allowUnscreenedCalls                                  |
|allow_unscreened_emergency_calls                |bool                                           |allowUnscreenedEmergencyCalls                         |
|use_pilot_user_calling_line_identity            |bool                                           |usePilotUserCallingLineIdentity                       |
|use_pilot_user_charge_number                    |bool                                           |usePilotUserChargeNumber                              |
|call_forwarding_always_action                   |str                                            |callForwardingAlwaysAction *Optional*                 |
|call_forwarding_always_forward_address          |str                                            |callForwardingAlwaysForwardAddress *Optional*         |
|call_forwarding_always_reroute_trunk_group_key  |OCI.callForwardingAlwaysRerouteTrunkGroupKey   |callForwardingAlwaysRerouteTrunkGroupKey *Optional*   |
</div>


## `GroupTrunkGroupAddInstanceRequest15`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Trunk Group instance to a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                            |Type                                           |Description                                           |
|------------------------------------------------|-----------------------------------------------|------------------------------------------------------|
|service_provider_id                             |str                                            |serviceProviderId                                     |
|group_id                                        |str                                            |groupId                                               |
|name                                            |str                                            |name                                                  |
|pilot_user                                      |OCI.pilotUser                                  |pilotUser *Optional*                                  |
|department                                      |OCI.department                                 |department *Optional*                                 |
|access_device                                   |OCI.accessDevice                               |accessDevice *Optional*                               |
|max_active_calls                                |int                                            |maxActiveCalls                                        |
|max_incoming_calls                              |int                                            |maxIncomingCalls *Optional*                           |
|max_outgoing_calls                              |int                                            |maxOutgoingCalls *Optional*                           |
|enable_bursting                                 |bool                                           |enableBursting                                        |
|bursting_max_active_calls                       |int                                            |burstingMaxActiveCalls *Optional*                     |
|bursting_max_incoming_calls                     |int                                            |burstingMaxIncomingCalls *Optional*                   |
|bursting_max_outgoing_calls                     |int                                            |burstingMaxOutgoingCalls *Optional*                   |
|capacity_exceeded_action                        |str                                            |capacityExceededAction *Optional*                     |
|capacity_exceeded_forward_address               |str                                            |capacityExceededForwardAddress *Optional*             |
|capacity_exceeded_reroute_trunk_group_key       |OCI.capacityExceededRerouteTrunkGroupKey       |capacityExceededRerouteTrunkGroupKey *Optional*       |
|capacity_exceeded_trap_initial_calls            |int                                            |capacityExceededTrapInitialCalls                      |
|capacity_exceeded_trap_offset_calls             |int                                            |capacityExceededTrapOffsetCalls                       |
|unreachable_destination_action                  |str                                            |unreachableDestinationAction *Optional*               |
|unreachable_destination_forward_address         |str                                            |unreachableDestinationForwardAddress *Optional*       |
|unreachable_destination_reroute_trunk_group_key |OCI.unreachableDestinationRerouteTrunkGroupKey |unreachableDestinationRerouteTrunkGroupKey *Optional* |
|invitation_timeout                              |int                                            |invitationTimeout                                     |
|require_authentication                          |bool                                           |requireAuthentication                                 |
|sip_authentication_user_name                    |str                                            |sipAuthenticationUserName *Optional*                  |
|sip_authentication_password                     |str                                            |sipAuthenticationPassword *Optional*                  |
|hosted_user_id                                  |List[str]                                      |hostedUserId *Optional*                               |
</div>


## `GroupTrunkGroupAddInstanceRequest15sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Trunk Group instance to a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                            |Type                                           |Description                                           |
|------------------------------------------------|-----------------------------------------------|------------------------------------------------------|
|service_provider_id                             |str                                            |serviceProviderId                                     |
|group_id                                        |str                                            |groupId                                               |
|name                                            |str                                            |name                                                  |
|pilot_user                                      |OCI.pilotUser                                  |pilotUser *Optional*                                  |
|department                                      |OCI.department                                 |department *Optional*                                 |
|access_device                                   |OCI.accessDevice                               |accessDevice *Optional*                               |
|max_active_calls                                |int                                            |maxActiveCalls                                        |
|max_incoming_calls                              |int                                            |maxIncomingCalls *Optional*                           |
|max_outgoing_calls                              |int                                            |maxOutgoingCalls *Optional*                           |
|enable_bursting                                 |bool                                           |enableBursting                                        |
|bursting_max_active_calls                       |int                                            |burstingMaxActiveCalls *Optional*                     |
|bursting_max_incoming_calls                     |int                                            |burstingMaxIncomingCalls *Optional*                   |
|bursting_max_outgoing_calls                     |int                                            |burstingMaxOutgoingCalls *Optional*                   |
|capacity_exceeded_action                        |str                                            |capacityExceededAction *Optional*                     |
|capacity_exceeded_forward_address               |str                                            |capacityExceededForwardAddress *Optional*             |
|capacity_exceeded_reroute_trunk_group_key       |OCI.capacityExceededRerouteTrunkGroupKey       |capacityExceededRerouteTrunkGroupKey *Optional*       |
|capacity_exceeded_trap_initial_calls            |int                                            |capacityExceededTrapInitialCalls                      |
|capacity_exceeded_trap_offset_calls             |int                                            |capacityExceededTrapOffsetCalls                       |
|unreachable_destination_action                  |str                                            |unreachableDestinationAction *Optional*               |
|unreachable_destination_forward_address         |str                                            |unreachableDestinationForwardAddress *Optional*       |
|unreachable_destination_reroute_trunk_group_key |OCI.unreachableDestinationRerouteTrunkGroupKey |unreachableDestinationRerouteTrunkGroupKey *Optional* |
|invitation_timeout                              |int                                            |invitationTimeout                                     |
|require_authentication                          |bool                                           |requireAuthentication                                 |
|sip_authentication_user_name                    |str                                            |sipAuthenticationUserName *Optional*                  |
|sip_authentication_password                     |str                                            |sipAuthenticationPassword *Optional*                  |
|hosted_user_id                                  |List[str]                                      |hostedUserId *Optional*                               |
|trunk_group_identity                            |str                                            |trunkGroupIdentity *Optional*                         |
|otg_dtg_identity                                |str                                            |otgDtgIdentity *Optional*                             |
|include_trunk_group_identity                    |bool                                           |includeTrunkGroupIdentity                             |
|include_dtg_identity                            |bool                                           |includeDtgIdentity                                    |
|enable_network_address_identity                 |bool                                           |enableNetworkAddressIdentity                          |
|allow_unscreened_calls                          |bool                                           |allowUnscreenedCalls                                  |
|allow_unscreened_emergency_calls                |bool                                           |allowUnscreenedEmergencyCalls                         |
|pilot_user_calling_line_identity_policy         |str                                            |pilotUserCallingLineIdentityPolicy                    |
|pilot_user_charge_number_policy                 |str                                            |pilotUserChargeNumberPolicy                           |
|call_forwarding_always_action                   |str                                            |callForwardingAlwaysAction *Optional*                 |
|call_forwarding_always_forward_address          |str                                            |callForwardingAlwaysForwardAddress *Optional*         |
|call_forwarding_always_reroute_trunk_group_key  |OCI.callForwardingAlwaysRerouteTrunkGroupKey   |callForwardingAlwaysRerouteTrunkGroupKey *Optional*   |
</div>


## `GroupTrunkGroupAddInstanceRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Replaced By `GroupTrunkGroupAddInstanceRequest17sp4()` Add a Trunk Group instance to a
group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                            |Type                                           |Description                                           |
|------------------------------------------------|-----------------------------------------------|------------------------------------------------------|
|service_provider_id                             |str                                            |serviceProviderId                                     |
|group_id                                        |str                                            |groupId                                               |
|name                                            |str                                            |name                                                  |
|pilot_user                                      |OCI.pilotUser                                  |pilotUser *Optional*                                  |
|department                                      |OCI.department                                 |department *Optional*                                 |
|access_device                                   |OCI.accessDevice                               |accessDevice *Optional*                               |
|max_active_calls                                |int                                            |maxActiveCalls                                        |
|max_incoming_calls                              |int                                            |maxIncomingCalls *Optional*                           |
|max_outgoing_calls                              |int                                            |maxOutgoingCalls *Optional*                           |
|enable_bursting                                 |bool                                           |enableBursting                                        |
|bursting_max_active_calls                       |int                                            |burstingMaxActiveCalls *Optional*                     |
|bursting_max_incoming_calls                     |int                                            |burstingMaxIncomingCalls *Optional*                   |
|bursting_max_outgoing_calls                     |int                                            |burstingMaxOutgoingCalls *Optional*                   |
|capacity_exceeded_action                        |str                                            |capacityExceededAction *Optional*                     |
|capacity_exceeded_forward_address               |str                                            |capacityExceededForwardAddress *Optional*             |
|capacity_exceeded_reroute_trunk_group_key       |OCI.capacityExceededRerouteTrunkGroupKey       |capacityExceededRerouteTrunkGroupKey *Optional*       |
|capacity_exceeded_trap_initial_calls            |int                                            |capacityExceededTrapInitialCalls                      |
|capacity_exceeded_trap_offset_calls             |int                                            |capacityExceededTrapOffsetCalls                       |
|unreachable_destination_action                  |str                                            |unreachableDestinationAction *Optional*               |
|unreachable_destination_forward_address         |str                                            |unreachableDestinationForwardAddress *Optional*       |
|unreachable_destination_reroute_trunk_group_key |OCI.unreachableDestinationRerouteTrunkGroupKey |unreachableDestinationRerouteTrunkGroupKey *Optional* |
|invitation_timeout                              |int                                            |invitationTimeout                                     |
|require_authentication                          |bool                                           |requireAuthentication                                 |
|sip_authentication_user_name                    |str                                            |sipAuthenticationUserName *Optional*                  |
|sip_authentication_password                     |str                                            |sipAuthenticationPassword *Optional*                  |
|hosted_user_id                                  |List[str]                                      |hostedUserId *Optional*                               |
|trunk_group_identity                            |str                                            |trunkGroupIdentity *Optional*                         |
|otg_dtg_identity                                |str                                            |otgDtgIdentity *Optional*                             |
|include_trunk_group_identity                    |bool                                           |includeTrunkGroupIdentity                             |
|include_dtg_identity                            |bool                                           |includeDtgIdentity                                    |
|enable_network_address_identity                 |bool                                           |enableNetworkAddressIdentity                          |
|allow_unscreened_calls                          |bool                                           |allowUnscreenedCalls                                  |
|allow_unscreened_emergency_calls                |bool                                           |allowUnscreenedEmergencyCalls                         |
|pilot_user_calling_line_identity_policy         |str                                            |pilotUserCallingLineIdentityPolicy                    |
|pilot_user_charge_number_policy                 |str                                            |pilotUserChargeNumberPolicy                           |
|call_forwarding_always_action                   |str                                            |callForwardingAlwaysAction *Optional*                 |
|call_forwarding_always_forward_address          |str                                            |callForwardingAlwaysForwardAddress *Optional*         |
|call_forwarding_always_reroute_trunk_group_key  |OCI.callForwardingAlwaysRerouteTrunkGroupKey   |callForwardingAlwaysRerouteTrunkGroupKey *Optional*   |
|peering_domain                                  |str                                            |peeringDomain *Optional*                              |
|route_to_peering_domain                         |bool                                           |routeToPeeringDomain                                  |
</div>


## `GroupTrunkGroupAddInstanceRequest17sp3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Trunk Group instance to a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`GroupTrunkGroupAddInstanceRequest17sp4()`

**Attributes:**

|Name                                            |Type                                           |Description                                           |
|------------------------------------------------|-----------------------------------------------|------------------------------------------------------|
|service_provider_id                             |str                                            |serviceProviderId                                     |
|group_id                                        |str                                            |groupId                                               |
|name                                            |str                                            |name                                                  |
|pilot_user                                      |OCI.pilotUser                                  |pilotUser *Optional*                                  |
|department                                      |OCI.department                                 |department *Optional*                                 |
|access_device                                   |OCI.accessDevice                               |accessDevice *Optional*                               |
|max_active_calls                                |int                                            |maxActiveCalls                                        |
|max_incoming_calls                              |int                                            |maxIncomingCalls *Optional*                           |
|max_outgoing_calls                              |int                                            |maxOutgoingCalls *Optional*                           |
|enable_bursting                                 |bool                                           |enableBursting                                        |
|bursting_max_active_calls                       |int                                            |burstingMaxActiveCalls *Optional*                     |
|bursting_max_incoming_calls                     |int                                            |burstingMaxIncomingCalls *Optional*                   |
|bursting_max_outgoing_calls                     |int                                            |burstingMaxOutgoingCalls *Optional*                   |
|capacity_exceeded_action                        |str                                            |capacityExceededAction *Optional*                     |
|capacity_exceeded_forward_address               |str                                            |capacityExceededForwardAddress *Optional*             |
|capacity_exceeded_reroute_trunk_group_key       |OCI.capacityExceededRerouteTrunkGroupKey       |capacityExceededRerouteTrunkGroupKey *Optional*       |
|capacity_exceeded_trap_initial_calls            |int                                            |capacityExceededTrapInitialCalls                      |
|capacity_exceeded_trap_offset_calls             |int                                            |capacityExceededTrapOffsetCalls                       |
|unreachable_destination_action                  |str                                            |unreachableDestinationAction *Optional*               |
|unreachable_destination_forward_address         |str                                            |unreachableDestinationForwardAddress *Optional*       |
|unreachable_destination_reroute_trunk_group_key |OCI.unreachableDestinationRerouteTrunkGroupKey |unreachableDestinationRerouteTrunkGroupKey *Optional* |
|invitation_timeout                              |int                                            |invitationTimeout                                     |
|require_authentication                          |bool                                           |requireAuthentication                                 |
|sip_authentication_user_name                    |str                                            |sipAuthenticationUserName *Optional*                  |
|sip_authentication_password                     |str                                            |sipAuthenticationPassword *Optional*                  |
|hosted_user_id                                  |List[str]                                      |hostedUserId *Optional*                               |
|trunk_group_identity                            |str                                            |trunkGroupIdentity *Optional*                         |
|otg_dtg_identity                                |str                                            |otgDtgIdentity *Optional*                             |
|include_trunk_group_identity                    |bool                                           |includeTrunkGroupIdentity                             |
|include_dtg_identity                            |bool                                           |includeDtgIdentity                                    |
|enable_network_address_identity                 |bool                                           |enableNetworkAddressIdentity                          |
|allow_unscreened_calls                          |bool                                           |allowUnscreenedCalls                                  |
|allow_unscreened_emergency_calls                |bool                                           |allowUnscreenedEmergencyCalls                         |
|pilot_user_calling_line_identity_policy         |str                                            |pilotUserCallingLineIdentityPolicy                    |
|pilot_user_charge_number_policy                 |str                                            |pilotUserChargeNumberPolicy                           |
|call_forwarding_always_action                   |str                                            |callForwardingAlwaysAction *Optional*                 |
|call_forwarding_always_forward_address          |str                                            |callForwardingAlwaysForwardAddress *Optional*         |
|call_forwarding_always_reroute_trunk_group_key  |OCI.callForwardingAlwaysRerouteTrunkGroupKey   |callForwardingAlwaysRerouteTrunkGroupKey *Optional*   |
|peering_domain                                  |str                                            |peeringDomain *Optional*                              |
|route_to_peering_domain                         |bool                                           |routeToPeeringDomain                                  |
|prefix_enabled                                  |bool                                           |prefixEnabled                                         |
|prefix                                          |str                                            |prefix *Optional*                                     |
|stateful_rerouting_enabled                      |bool                                           |statefulReroutingEnabled                              |
|send_continuous_options_message                 |bool                                           |sendContinuousOptionsMessage                          |
|continuous_options_sending_interval_seconds     |int                                            |continuousOptionsSendingIntervalSeconds               |
|failure_options_sending_interval_seconds        |int                                            |failureOptionsSendingIntervalSeconds                  |
|failure_threshold_counter                       |int                                            |failureThresholdCounter                               |
|success_threshold_counter                       |int                                            |successThresholdCounter                               |
|invite_failure_threshold_counter                |int                                            |inviteFailureThresholdCounter                         |
|invite_failure_threshold_window_seconds         |int                                            |inviteFailureThresholdWindowSeconds                   |
</div>


## `GroupTrunkGroupAddInstanceRequest17sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Trunk Group instance to a group.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                             |Type                                           |Description                                           |
|-------------------------------------------------|-----------------------------------------------|------------------------------------------------------|
|service_provider_id                              |str                                            |serviceProviderId                                     |
|group_id                                         |str                                            |groupId                                               |
|name                                             |str                                            |name                                                  |
|pilot_user                                       |OCI.pilotUser                                  |pilotUser *Optional*                                  |
|department                                       |OCI.department                                 |department *Optional*                                 |
|access_device                                    |OCI.accessDevice                               |accessDevice *Optional*                               |
|max_active_calls                                 |int                                            |maxActiveCalls                                        |
|max_incoming_calls                               |int                                            |maxIncomingCalls *Optional*                           |
|max_outgoing_calls                               |int                                            |maxOutgoingCalls *Optional*                           |
|enable_bursting                                  |bool                                           |enableBursting                                        |
|bursting_max_active_calls                        |int                                            |burstingMaxActiveCalls *Optional*                     |
|bursting_max_incoming_calls                      |int                                            |burstingMaxIncomingCalls *Optional*                   |
|bursting_max_outgoing_calls                      |int                                            |burstingMaxOutgoingCalls *Optional*                   |
|capacity_exceeded_action                         |str                                            |capacityExceededAction *Optional*                     |
|capacity_exceeded_forward_address                |str                                            |capacityExceededForwardAddress *Optional*             |
|capacity_exceeded_reroute_trunk_group_key        |OCI.capacityExceededRerouteTrunkGroupKey       |capacityExceededRerouteTrunkGroupKey *Optional*       |
|capacity_exceeded_trap_initial_calls             |int                                            |capacityExceededTrapInitialCalls                      |
|capacity_exceeded_trap_offset_calls              |int                                            |capacityExceededTrapOffsetCalls                       |
|unreachable_destination_action                   |str                                            |unreachableDestinationAction *Optional*               |
|unreachable_destination_forward_address          |str                                            |unreachableDestinationForwardAddress *Optional*       |
|unreachable_destination_reroute_trunk_group_key  |OCI.unreachableDestinationRerouteTrunkGroupKey |unreachableDestinationRerouteTrunkGroupKey *Optional* |
|invitation_timeout                               |int                                            |invitationTimeout                                     |
|require_authentication                           |bool                                           |requireAuthentication                                 |
|sip_authentication_user_name                     |str                                            |sipAuthenticationUserName *Optional*                  |
|sip_authentication_password                      |str                                            |sipAuthenticationPassword *Optional*                  |
|hosted_user_id                                   |List[str]                                      |hostedUserId *Optional*                               |
|trunk_group_identity                             |str                                            |trunkGroupIdentity *Optional*                         |
|otg_dtg_identity                                 |str                                            |otgDtgIdentity *Optional*                             |
|allow_termination_to_trunk_group_identity        |bool                                           |allowTerminationToTrunkGroupIdentity                  |
|allow_termination_to_dtg_identity                |bool                                           |allowTerminationToDtgIdentity                         |
|include_trunk_group_identity                     |bool                                           |includeTrunkGroupIdentity                             |
|include_dtg_identity                             |bool                                           |includeDtgIdentity                                    |
|include_trunk_group_identity_for_network_calls   |bool                                           |includeTrunkGroupIdentityForNetworkCalls              |
|include_otg_identity_for_network_calls           |bool                                           |includeOtgIdentityForNetworkCalls                     |
|enable_network_address_identity                  |bool                                           |enableNetworkAddressIdentity                          |
|allow_unscreened_calls                           |bool                                           |allowUnscreenedCalls                                  |
|allow_unscreened_emergency_calls                 |bool                                           |allowUnscreenedEmergencyCalls                         |
|pilot_user_calling_line_identity_policy          |str                                            |pilotUserCallingLineIdentityPolicy                    |
|pilot_user_charge_number_policy                  |str                                            |pilotUserChargeNumberPolicy                           |
|call_forwarding_always_action                    |str                                            |callForwardingAlwaysAction *Optional*                 |
|call_forwarding_always_forward_address           |str                                            |callForwardingAlwaysForwardAddress *Optional*         |
|call_forwarding_always_reroute_trunk_group_key   |OCI.callForwardingAlwaysRerouteTrunkGroupKey   |callForwardingAlwaysRerouteTrunkGroupKey *Optional*   |
|peering_domain                                   |str                                            |peeringDomain *Optional*                              |
|route_to_peering_domain                          |bool                                           |routeToPeeringDomain                                  |
|prefix_enabled                                   |bool                                           |prefixEnabled                                         |
|prefix                                           |str                                            |prefix *Optional*                                     |
|stateful_rerouting_enabled                       |bool                                           |statefulReroutingEnabled                              |
|send_continuous_options_message                  |bool                                           |sendContinuousOptionsMessage                          |
|continuous_options_sending_interval_seconds      |int                                            |continuousOptionsSendingIntervalSeconds               |
|failure_options_sending_interval_seconds         |int                                            |failureOptionsSendingIntervalSeconds                  |
|failure_threshold_counter                        |int                                            |failureThresholdCounter                               |
|success_threshold_counter                        |int                                            |successThresholdCounter                               |
|invite_failure_threshold_counter                 |int                                            |inviteFailureThresholdCounter                         |
|invite_failure_threshold_window_seconds          |int                                            |inviteFailureThresholdWindowSeconds                   |
|pilot_user_calling_line_asserted_identity_policy |str                                            |pilotUserCallingLineAssertedIdentityPolicy            |
|use_system_calling_line_asserted_identity_policy |bool                                           |useSystemCallingLineAssertedIdentityPolicy            |
</div>


## `GroupTrunkGroupAddInstanceRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Trunk Group instance to a group.

The command will fail if enableNetworkAddressIdentity is set to true and administrator
is not System/Provisioning level administrator.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by
`GroupTrunkGroupAddInstanceRequest19sp1()`.

**Attributes:**

|Name                                             |Type                                           |Description                                           |
|-------------------------------------------------|-----------------------------------------------|------------------------------------------------------|
|service_provider_id                              |str                                            |serviceProviderId                                     |
|group_id                                         |str                                            |groupId                                               |
|name                                             |str                                            |name                                                  |
|pilot_user                                       |OCI.pilotUser                                  |pilotUser *Optional*                                  |
|department                                       |OCI.department                                 |department *Optional*                                 |
|access_device                                    |OCI.accessDevice                               |accessDevice *Optional*                               |
|max_active_calls                                 |int                                            |maxActiveCalls                                        |
|max_incoming_calls                               |int                                            |maxIncomingCalls *Optional*                           |
|max_outgoing_calls                               |int                                            |maxOutgoingCalls *Optional*                           |
|enable_bursting                                  |bool                                           |enableBursting                                        |
|bursting_max_active_calls                        |int                                            |burstingMaxActiveCalls *Optional*                     |
|bursting_max_incoming_calls                      |int                                            |burstingMaxIncomingCalls *Optional*                   |
|bursting_max_outgoing_calls                      |int                                            |burstingMaxOutgoingCalls *Optional*                   |
|capacity_exceeded_action                         |str                                            |capacityExceededAction *Optional*                     |
|capacity_exceeded_forward_address                |str                                            |capacityExceededForwardAddress *Optional*             |
|capacity_exceeded_reroute_trunk_group_key        |OCI.capacityExceededRerouteTrunkGroupKey       |capacityExceededRerouteTrunkGroupKey *Optional*       |
|capacity_exceeded_trap_initial_calls             |int                                            |capacityExceededTrapInitialCalls                      |
|capacity_exceeded_trap_offset_calls              |int                                            |capacityExceededTrapOffsetCalls                       |
|unreachable_destination_action                   |str                                            |unreachableDestinationAction *Optional*               |
|unreachable_destination_forward_address          |str                                            |unreachableDestinationForwardAddress *Optional*       |
|unreachable_destination_reroute_trunk_group_key  |OCI.unreachableDestinationRerouteTrunkGroupKey |unreachableDestinationRerouteTrunkGroupKey *Optional* |
|invitation_timeout                               |int                                            |invitationTimeout                                     |
|require_authentication                           |bool                                           |requireAuthentication                                 |
|sip_authentication_user_name                     |str                                            |sipAuthenticationUserName *Optional*                  |
|sip_authentication_password                      |str                                            |sipAuthenticationPassword *Optional*                  |
|hosted_user_id                                   |List[str]                                      |hostedUserId *Optional*                               |
|trunk_group_identity                             |str                                            |trunkGroupIdentity *Optional*                         |
|otg_dtg_identity                                 |str                                            |otgDtgIdentity *Optional*                             |
|allow_termination_to_trunk_group_identity        |bool                                           |allowTerminationToTrunkGroupIdentity                  |
|allow_termination_to_dtg_identity                |bool                                           |allowTerminationToDtgIdentity                         |
|include_trunk_group_identity                     |bool                                           |includeTrunkGroupIdentity                             |
|include_dtg_identity                             |bool                                           |includeDtgIdentity                                    |
|include_trunk_group_identity_for_network_calls   |bool                                           |includeTrunkGroupIdentityForNetworkCalls              |
|include_otg_identity_for_network_calls           |bool                                           |includeOtgIdentityForNetworkCalls                     |
|enable_network_address_identity                  |bool                                           |enableNetworkAddressIdentity                          |
|allow_unscreened_calls                           |bool                                           |allowUnscreenedCalls                                  |
|allow_unscreened_emergency_calls                 |bool                                           |allowUnscreenedEmergencyCalls                         |
|pilot_user_calling_line_identity_policy          |str                                            |pilotUserCallingLineIdentityPolicy                    |
|pilot_user_charge_number_policy                  |str                                            |pilotUserChargeNumberPolicy                           |
|call_forwarding_always_action                    |str                                            |callForwardingAlwaysAction *Optional*                 |
|call_forwarding_always_forward_address           |str                                            |callForwardingAlwaysForwardAddress *Optional*         |
|call_forwarding_always_reroute_trunk_group_key   |OCI.callForwardingAlwaysRerouteTrunkGroupKey   |callForwardingAlwaysRerouteTrunkGroupKey *Optional*   |
|peering_domain                                   |str                                            |peeringDomain *Optional*                              |
|route_to_peering_domain                          |bool                                           |routeToPeeringDomain                                  |
|prefix_enabled                                   |bool                                           |prefixEnabled                                         |
|prefix                                           |str                                            |prefix *Optional*                                     |
|stateful_rerouting_enabled                       |bool                                           |statefulReroutingEnabled                              |
|send_continuous_options_message                  |bool                                           |sendContinuousOptionsMessage                          |
|continuous_options_sending_interval_seconds      |int                                            |continuousOptionsSendingIntervalSeconds               |
|failure_options_sending_interval_seconds         |int                                            |failureOptionsSendingIntervalSeconds                  |
|failure_threshold_counter                        |int                                            |failureThresholdCounter                               |
|success_threshold_counter                        |int                                            |successThresholdCounter                               |
|invite_failure_threshold_counter                 |int                                            |inviteFailureThresholdCounter                         |
|invite_failure_threshold_window_seconds          |int                                            |inviteFailureThresholdWindowSeconds                   |
|pilot_user_calling_line_asserted_identity_policy |str                                            |pilotUserCallingLineAssertedIdentityPolicy            |
|use_system_calling_line_asserted_identity_policy |bool                                           |useSystemCallingLineAssertedIdentityPolicy            |
|pilot_user_call_optimization_policy              |str                                            |pilotUserCallOptimizationPolicy                       |
</div>


## `GroupTrunkGroupAddInstanceRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Trunk Group instance to a group.

The command will fail if enableNetworkAddressIdentity is set to true and administrator
is not System/Provisioning level administrator.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`GroupTrunkGroupAddInstanceRequest20sp1()`

**Attributes:**

|Name                                                        |Type                                           |Description                                           |
|------------------------------------------------------------|-----------------------------------------------|------------------------------------------------------|
|service_provider_id                                         |str                                            |serviceProviderId                                     |
|group_id                                                    |str                                            |groupId                                               |
|name                                                        |str                                            |name                                                  |
|pilot_user                                                  |OCI.pilotUser                                  |pilotUser *Optional*                                  |
|department                                                  |OCI.department                                 |department *Optional*                                 |
|access_device                                               |OCI.accessDevice                               |accessDevice *Optional*                               |
|max_active_calls                                            |int                                            |maxActiveCalls                                        |
|max_incoming_calls                                          |int                                            |maxIncomingCalls *Optional*                           |
|max_outgoing_calls                                          |int                                            |maxOutgoingCalls *Optional*                           |
|enable_bursting                                             |bool                                           |enableBursting                                        |
|bursting_max_active_calls                                   |int                                            |burstingMaxActiveCalls *Optional*                     |
|bursting_max_incoming_calls                                 |int                                            |burstingMaxIncomingCalls *Optional*                   |
|bursting_max_outgoing_calls                                 |int                                            |burstingMaxOutgoingCalls *Optional*                   |
|capacity_exceeded_action                                    |str                                            |capacityExceededAction *Optional*                     |
|capacity_exceeded_forward_address                           |str                                            |capacityExceededForwardAddress *Optional*             |
|capacity_exceeded_reroute_trunk_group_key                   |OCI.capacityExceededRerouteTrunkGroupKey       |capacityExceededRerouteTrunkGroupKey *Optional*       |
|capacity_exceeded_trap_initial_calls                        |int                                            |capacityExceededTrapInitialCalls                      |
|capacity_exceeded_trap_offset_calls                         |int                                            |capacityExceededTrapOffsetCalls                       |
|unreachable_destination_action                              |str                                            |unreachableDestinationAction *Optional*               |
|unreachable_destination_forward_address                     |str                                            |unreachableDestinationForwardAddress *Optional*       |
|unreachable_destination_reroute_trunk_group_key             |OCI.unreachableDestinationRerouteTrunkGroupKey |unreachableDestinationRerouteTrunkGroupKey *Optional* |
|invitation_timeout                                          |int                                            |invitationTimeout                                     |
|require_authentication                                      |bool                                           |requireAuthentication                                 |
|sip_authentication_user_name                                |str                                            |sipAuthenticationUserName *Optional*                  |
|sip_authentication_password                                 |str                                            |sipAuthenticationPassword *Optional*                  |
|hosted_user_id                                              |List[str]                                      |hostedUserId *Optional*                               |
|trunk_group_identity                                        |str                                            |trunkGroupIdentity *Optional*                         |
|otg_dtg_identity                                            |str                                            |otgDtgIdentity *Optional*                             |
|allow_termination_to_trunk_group_identity                   |bool                                           |allowTerminationToTrunkGroupIdentity                  |
|allow_termination_to_dtg_identity                           |bool                                           |allowTerminationToDtgIdentity                         |
|include_trunk_group_identity                                |bool                                           |includeTrunkGroupIdentity                             |
|include_dtg_identity                                        |bool                                           |includeDtgIdentity                                    |
|include_trunk_group_identity_for_network_calls              |bool                                           |includeTrunkGroupIdentityForNetworkCalls              |
|include_otg_identity_for_network_calls                      |bool                                           |includeOtgIdentityForNetworkCalls                     |
|enable_network_address_identity                             |bool                                           |enableNetworkAddressIdentity                          |
|allow_unscreened_calls                                      |bool                                           |allowUnscreenedCalls                                  |
|allow_unscreened_emergency_calls                            |bool                                           |allowUnscreenedEmergencyCalls                         |
|pilot_user_calling_line_identity_for_external_calls_policy  |str                                            |pilotUserCallingLineIdentityForExternalCallsPolicy    |
|pilot_user_charge_number_policy                             |str                                            |pilotUserChargeNumberPolicy                           |
|call_forwarding_always_action                               |str                                            |callForwardingAlwaysAction *Optional*                 |
|call_forwarding_always_forward_address                      |str                                            |callForwardingAlwaysForwardAddress *Optional*         |
|call_forwarding_always_reroute_trunk_group_key              |OCI.callForwardingAlwaysRerouteTrunkGroupKey   |callForwardingAlwaysRerouteTrunkGroupKey *Optional*   |
|peering_domain                                              |str                                            |peeringDomain *Optional*                              |
|route_to_peering_domain                                     |bool                                           |routeToPeeringDomain                                  |
|prefix_enabled                                              |bool                                           |prefixEnabled                                         |
|prefix                                                      |str                                            |prefix *Optional*                                     |
|stateful_rerouting_enabled                                  |bool                                           |statefulReroutingEnabled                              |
|send_continuous_options_message                             |bool                                           |sendContinuousOptionsMessage                          |
|continuous_options_sending_interval_seconds                 |int                                            |continuousOptionsSendingIntervalSeconds               |
|failure_options_sending_interval_seconds                    |int                                            |failureOptionsSendingIntervalSeconds                  |
|failure_threshold_counter                                   |int                                            |failureThresholdCounter                               |
|success_threshold_counter                                   |int                                            |successThresholdCounter                               |
|invite_failure_threshold_counter                            |int                                            |inviteFailureThresholdCounter                         |
|invite_failure_threshold_window_seconds                     |int                                            |inviteFailureThresholdWindowSeconds                   |
|pilot_user_calling_line_asserted_identity_policy            |str                                            |pilotUserCallingLineAssertedIdentityPolicy            |
|use_system_calling_line_asserted_identity_policy            |bool                                           |useSystemCallingLineAssertedIdentityPolicy            |
|pilot_user_call_optimization_policy                         |str                                            |pilotUserCallOptimizationPolicy                       |
|clid_source_for_screened_calls_policy                       |str                                            |clidSourceForScreenedCallsPolicy                      |
|use_system_clid_source_for_screened_calls_policy            |bool                                           |useSystemCLIDSourceForScreenedCallsPolicy             |
|user_lookup_policy                                          |str                                            |userLookupPolicy                                      |
|use_system_user_lookup_policy                               |bool                                           |useSystemUserLookupPolicy                             |
|pilot_user_calling_line_identity_for_emergency_calls_policy |str                                            |pilotUserCallingLineIdentityForEmergencyCallsPolicy   |
|pilot_user_network_class_of_service                         |str                                            |pilotUserNetworkClassOfService *Optional*             |
</div>


## `GroupTrunkGroupAddInstanceRequest20sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Trunk Group instance to a group.

The command will fail if enableNetworkAddressIdentity is set to true and administrator
is not System/Provisioning level administrator.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`GroupTrunkGroupAddInstanceRequest21()`

**Attributes:**

|Name                                                        |Type                                           |Description                                           |
|------------------------------------------------------------|-----------------------------------------------|------------------------------------------------------|
|service_provider_id                                         |str                                            |serviceProviderId                                     |
|group_id                                                    |str                                            |groupId                                               |
|name                                                        |str                                            |name                                                  |
|pilot_user                                                  |OCI.pilotUser                                  |pilotUser *Optional*                                  |
|department                                                  |OCI.department                                 |department *Optional*                                 |
|access_device                                               |OCI.accessDevice                               |accessDevice *Optional*                               |
|max_active_calls                                            |int                                            |maxActiveCalls                                        |
|max_incoming_calls                                          |int                                            |maxIncomingCalls *Optional*                           |
|max_outgoing_calls                                          |int                                            |maxOutgoingCalls *Optional*                           |
|enable_bursting                                             |bool                                           |enableBursting                                        |
|bursting_max_active_calls                                   |int                                            |burstingMaxActiveCalls *Optional*                     |
|bursting_max_incoming_calls                                 |int                                            |burstingMaxIncomingCalls *Optional*                   |
|bursting_max_outgoing_calls                                 |int                                            |burstingMaxOutgoingCalls *Optional*                   |
|capacity_exceeded_action                                    |str                                            |capacityExceededAction *Optional*                     |
|capacity_exceeded_forward_address                           |str                                            |capacityExceededForwardAddress *Optional*             |
|capacity_exceeded_reroute_trunk_group_key                   |OCI.capacityExceededRerouteTrunkGroupKey       |capacityExceededRerouteTrunkGroupKey *Optional*       |
|capacity_exceeded_trap_initial_calls                        |int                                            |capacityExceededTrapInitialCalls                      |
|capacity_exceeded_trap_offset_calls                         |int                                            |capacityExceededTrapOffsetCalls                       |
|unreachable_destination_action                              |str                                            |unreachableDestinationAction *Optional*               |
|unreachable_destination_forward_address                     |str                                            |unreachableDestinationForwardAddress *Optional*       |
|unreachable_destination_reroute_trunk_group_key             |OCI.unreachableDestinationRerouteTrunkGroupKey |unreachableDestinationRerouteTrunkGroupKey *Optional* |
|invitation_timeout                                          |int                                            |invitationTimeout                                     |
|require_authentication                                      |bool                                           |requireAuthentication                                 |
|sip_authentication_user_name                                |str                                            |sipAuthenticationUserName *Optional*                  |
|sip_authentication_password                                 |str                                            |sipAuthenticationPassword *Optional*                  |
|hosted_user_id                                              |List[str]                                      |hostedUserId *Optional*                               |
|trunk_group_identity                                        |str                                            |trunkGroupIdentity *Optional*                         |
|otg_dtg_identity                                            |str                                            |otgDtgIdentity *Optional*                             |
|allow_termination_to_trunk_group_identity                   |bool                                           |allowTerminationToTrunkGroupIdentity                  |
|allow_termination_to_dtg_identity                           |bool                                           |allowTerminationToDtgIdentity                         |
|include_trunk_group_identity                                |bool                                           |includeTrunkGroupIdentity                             |
|include_dtg_identity                                        |bool                                           |includeDtgIdentity                                    |
|include_trunk_group_identity_for_network_calls              |bool                                           |includeTrunkGroupIdentityForNetworkCalls              |
|include_otg_identity_for_network_calls                      |bool                                           |includeOtgIdentityForNetworkCalls                     |
|enable_network_address_identity                             |bool                                           |enableNetworkAddressIdentity                          |
|allow_unscreened_calls                                      |bool                                           |allowUnscreenedCalls                                  |
|allow_unscreened_emergency_calls                            |bool                                           |allowUnscreenedEmergencyCalls                         |
|pilot_user_calling_line_identity_for_external_calls_policy  |str                                            |pilotUserCallingLineIdentityForExternalCallsPolicy    |
|pilot_user_charge_number_policy                             |str                                            |pilotUserChargeNumberPolicy                           |
|call_forwarding_always_action                               |str                                            |callForwardingAlwaysAction *Optional*                 |
|call_forwarding_always_forward_address                      |str                                            |callForwardingAlwaysForwardAddress *Optional*         |
|call_forwarding_always_reroute_trunk_group_key              |OCI.callForwardingAlwaysRerouteTrunkGroupKey   |callForwardingAlwaysRerouteTrunkGroupKey *Optional*   |
|peering_domain                                              |str                                            |peeringDomain *Optional*                              |
|route_to_peering_domain                                     |bool                                           |routeToPeeringDomain                                  |
|prefix_enabled                                              |bool                                           |prefixEnabled                                         |
|prefix                                                      |str                                            |prefix *Optional*                                     |
|stateful_rerouting_enabled                                  |bool                                           |statefulReroutingEnabled                              |
|send_continuous_options_message                             |bool                                           |sendContinuousOptionsMessage                          |
|continuous_options_sending_interval_seconds                 |int                                            |continuousOptionsSendingIntervalSeconds               |
|failure_options_sending_interval_seconds                    |int                                            |failureOptionsSendingIntervalSeconds                  |
|failure_threshold_counter                                   |int                                            |failureThresholdCounter                               |
|success_threshold_counter                                   |int                                            |successThresholdCounter                               |
|invite_failure_threshold_counter                            |int                                            |inviteFailureThresholdCounter                         |
|invite_failure_threshold_window_seconds                     |int                                            |inviteFailureThresholdWindowSeconds                   |
|pilot_user_calling_line_asserted_identity_policy            |str                                            |pilotUserCallingLineAssertedIdentityPolicy            |
|use_system_calling_line_asserted_identity_policy            |bool                                           |useSystemCallingLineAssertedIdentityPolicy            |
|pilot_user_call_optimization_policy                         |str                                            |pilotUserCallOptimizationPolicy                       |
|clid_source_for_screened_calls_policy                       |str                                            |clidSourceForScreenedCallsPolicy                      |
|use_system_clid_source_for_screened_calls_policy            |bool                                           |useSystemCLIDSourceForScreenedCallsPolicy             |
|user_lookup_policy                                          |str                                            |userLookupPolicy                                      |
|use_system_user_lookup_policy                               |bool                                           |useSystemUserLookupPolicy                             |
|pilot_user_calling_line_identity_for_emergency_calls_policy |str                                            |pilotUserCallingLineIdentityForEmergencyCallsPolicy   |
|pilot_user_network_class_of_service                         |str                                            |pilotUserNetworkClassOfService *Optional*             |
</div>


## `GroupTrunkGroupAddInstanceRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Trunk Group instance to a group.

The command will fail if enableNetworkAddressIdentity is set to true and administrator
is not System/Provisioning level administrator.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Following
attributes are only used in IMS mode: implicitRegistrationSetSupportPolicy
useSystemImplicitRegistrationSetSupportPolicy
sipIdentityForPilotAndProxyTrunkModesPolicy
useSystemSIPIdentityForPilotAndProxyTrunkModesPolicy Replaced by:
`GroupTrunkGroupAddInstanceRequest22()`

**Attributes:**

|Name                                                           |Type                                           |Description                                           |
|---------------------------------------------------------------|-----------------------------------------------|------------------------------------------------------|
|service_provider_id                                            |str                                            |serviceProviderId                                     |
|group_id                                                       |str                                            |groupId                                               |
|name                                                           |str                                            |name                                                  |
|pilot_user                                                     |OCI.pilotUser                                  |pilotUser *Optional*                                  |
|department                                                     |OCI.department                                 |department *Optional*                                 |
|access_device                                                  |OCI.accessDevice                               |accessDevice *Optional*                               |
|max_active_calls                                               |int                                            |maxActiveCalls                                        |
|max_incoming_calls                                             |int                                            |maxIncomingCalls *Optional*                           |
|max_outgoing_calls                                             |int                                            |maxOutgoingCalls *Optional*                           |
|enable_bursting                                                |bool                                           |enableBursting                                        |
|bursting_max_active_calls                                      |int                                            |burstingMaxActiveCalls *Optional*                     |
|bursting_max_incoming_calls                                    |int                                            |burstingMaxIncomingCalls *Optional*                   |
|bursting_max_outgoing_calls                                    |int                                            |burstingMaxOutgoingCalls *Optional*                   |
|capacity_exceeded_action                                       |str                                            |capacityExceededAction *Optional*                     |
|capacity_exceeded_forward_address                              |str                                            |capacityExceededForwardAddress *Optional*             |
|capacity_exceeded_reroute_trunk_group_key                      |OCI.capacityExceededRerouteTrunkGroupKey       |capacityExceededRerouteTrunkGroupKey *Optional*       |
|capacity_exceeded_trap_initial_calls                           |int                                            |capacityExceededTrapInitialCalls                      |
|capacity_exceeded_trap_offset_calls                            |int                                            |capacityExceededTrapOffsetCalls                       |
|unreachable_destination_action                                 |str                                            |unreachableDestinationAction *Optional*               |
|unreachable_destination_forward_address                        |str                                            |unreachableDestinationForwardAddress *Optional*       |
|unreachable_destination_reroute_trunk_group_key                |OCI.unreachableDestinationRerouteTrunkGroupKey |unreachableDestinationRerouteTrunkGroupKey *Optional* |
|invitation_timeout                                             |int                                            |invitationTimeout                                     |
|require_authentication                                         |bool                                           |requireAuthentication                                 |
|sip_authentication_user_name                                   |str                                            |sipAuthenticationUserName *Optional*                  |
|sip_authentication_password                                    |str                                            |sipAuthenticationPassword *Optional*                  |
|hosted_user_id                                                 |List[str]                                      |hostedUserId *Optional*                               |
|trunk_group_identity                                           |str                                            |trunkGroupIdentity *Optional*                         |
|otg_dtg_identity                                               |str                                            |otgDtgIdentity *Optional*                             |
|allow_termination_to_trunk_group_identity                      |bool                                           |allowTerminationToTrunkGroupIdentity                  |
|allow_termination_to_dtg_identity                              |bool                                           |allowTerminationToDtgIdentity                         |
|include_trunk_group_identity                                   |bool                                           |includeTrunkGroupIdentity                             |
|include_dtg_identity                                           |bool                                           |includeDtgIdentity                                    |
|include_trunk_group_identity_for_network_calls                 |bool                                           |includeTrunkGroupIdentityForNetworkCalls              |
|include_otg_identity_for_network_calls                         |bool                                           |includeOtgIdentityForNetworkCalls                     |
|enable_network_address_identity                                |bool                                           |enableNetworkAddressIdentity                          |
|allow_unscreened_calls                                         |bool                                           |allowUnscreenedCalls                                  |
|allow_unscreened_emergency_calls                               |bool                                           |allowUnscreenedEmergencyCalls                         |
|pilot_user_calling_line_identity_for_external_calls_policy     |str                                            |pilotUserCallingLineIdentityForExternalCallsPolicy    |
|pilot_user_charge_number_policy                                |str                                            |pilotUserChargeNumberPolicy                           |
|call_forwarding_always_action                                  |str                                            |callForwardingAlwaysAction *Optional*                 |
|call_forwarding_always_forward_address                         |str                                            |callForwardingAlwaysForwardAddress *Optional*         |
|call_forwarding_always_reroute_trunk_group_key                 |OCI.callForwardingAlwaysRerouteTrunkGroupKey   |callForwardingAlwaysRerouteTrunkGroupKey *Optional*   |
|peering_domain                                                 |str                                            |peeringDomain *Optional*                              |
|route_to_peering_domain                                        |bool                                           |routeToPeeringDomain                                  |
|prefix_enabled                                                 |bool                                           |prefixEnabled                                         |
|prefix                                                         |str                                            |prefix *Optional*                                     |
|stateful_rerouting_enabled                                     |bool                                           |statefulReroutingEnabled                              |
|send_continuous_options_message                                |bool                                           |sendContinuousOptionsMessage                          |
|continuous_options_sending_interval_seconds                    |int                                            |continuousOptionsSendingIntervalSeconds               |
|failure_options_sending_interval_seconds                       |int                                            |failureOptionsSendingIntervalSeconds                  |
|failure_threshold_counter                                      |int                                            |failureThresholdCounter                               |
|success_threshold_counter                                      |int                                            |successThresholdCounter                               |
|invite_failure_threshold_counter                               |int                                            |inviteFailureThresholdCounter                         |
|invite_failure_threshold_window_seconds                        |int                                            |inviteFailureThresholdWindowSeconds                   |
|pilot_user_calling_line_asserted_identity_policy               |str                                            |pilotUserCallingLineAssertedIdentityPolicy            |
|use_system_calling_line_asserted_identity_policy               |bool                                           |useSystemCallingLineAssertedIdentityPolicy            |
|pilot_user_call_optimization_policy                            |str                                            |pilotUserCallOptimizationPolicy                       |
|clid_source_for_screened_calls_policy                          |str                                            |clidSourceForScreenedCallsPolicy                      |
|use_system_clid_source_for_screened_calls_policy               |bool                                           |useSystemCLIDSourceForScreenedCallsPolicy             |
|user_lookup_policy                                             |str                                            |userLookupPolicy                                      |
|use_system_user_lookup_policy                                  |bool                                           |useSystemUserLookupPolicy                             |
|pilot_user_calling_line_identity_for_emergency_calls_policy    |str                                            |pilotUserCallingLineIdentityForEmergencyCallsPolicy   |
|pilot_user_network_class_of_service                            |str                                            |pilotUserNetworkClassOfService *Optional*             |
|implicit_registration_set_support_policy                       |str                                            |implicitRegistrationSetSupportPolicy                  |
|use_system_implicit_registration_set_support_policy            |bool                                           |useSystemImplicitRegistrationSetSupportPolicy         |
|sip_identity_for_pilot_and_proxy_trunk_modes_policy            |str                                            |sipIdentityForPilotAndProxyTrunkModesPolicy           |
|use_system_sip_identity_for_pilot_and_proxy_trunk_modes_policy |bool                                           |useSystemSIPIdentityForPilotAndProxyTrunkModesPolicy  |
|use_system_support_connected_identity_policy                   |bool                                           |useSystemSupportConnectedIdentityPolicy               |
|support_connected_identity_policy                              |str                                            |supportConnectedIdentityPolicy                        |
</div>


## `GroupTrunkGroupAddInstanceRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Trunk Group instance to a group.

The command will fail if enableNetworkAddressIdentity is set to true and administrator
is not System/Provisioning level administrator.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Following
attributes are only used in IMS mode: implicitRegistrationSetSupportPolicy
useSystemImplicitRegistrationSetSupportPolicy
sipIdentityForPilotAndProxyTrunkModesPolicy
useSystemSIPIdentityForPilotAndProxyTrunkModesPolicy

**Attributes:**

|Name                                                           |Type                                           |Description                                           |
|---------------------------------------------------------------|-----------------------------------------------|------------------------------------------------------|
|service_provider_id                                            |str                                            |serviceProviderId                                     |
|group_id                                                       |str                                            |groupId                                               |
|name                                                           |str                                            |name                                                  |
|pilot_user                                                     |OCI.pilotUser                                  |pilotUser *Optional*                                  |
|department                                                     |OCI.department                                 |department *Optional*                                 |
|access_device                                                  |OCI.accessDevice                               |accessDevice *Optional*                               |
|max_active_calls                                               |int                                            |maxActiveCalls                                        |
|max_incoming_calls                                             |int                                            |maxIncomingCalls *Optional*                           |
|max_outgoing_calls                                             |int                                            |maxOutgoingCalls *Optional*                           |
|enable_bursting                                                |bool                                           |enableBursting                                        |
|bursting_max_active_calls                                      |int                                            |burstingMaxActiveCalls *Optional*                     |
|bursting_max_incoming_calls                                    |int                                            |burstingMaxIncomingCalls *Optional*                   |
|bursting_max_outgoing_calls                                    |int                                            |burstingMaxOutgoingCalls *Optional*                   |
|capacity_exceeded_action                                       |str                                            |capacityExceededAction *Optional*                     |
|capacity_exceeded_forward_address                              |str                                            |capacityExceededForwardAddress *Optional*             |
|capacity_exceeded_reroute_trunk_group_key                      |OCI.capacityExceededRerouteTrunkGroupKey       |capacityExceededRerouteTrunkGroupKey *Optional*       |
|capacity_exceeded_trap_initial_calls                           |int                                            |capacityExceededTrapInitialCalls                      |
|capacity_exceeded_trap_offset_calls                            |int                                            |capacityExceededTrapOffsetCalls                       |
|unreachable_destination_action                                 |str                                            |unreachableDestinationAction *Optional*               |
|unreachable_destination_forward_address                        |str                                            |unreachableDestinationForwardAddress *Optional*       |
|unreachable_destination_reroute_trunk_group_key                |OCI.unreachableDestinationRerouteTrunkGroupKey |unreachableDestinationRerouteTrunkGroupKey *Optional* |
|invitation_timeout                                             |int                                            |invitationTimeout                                     |
|require_authentication                                         |bool                                           |requireAuthentication                                 |
|sip_authentication_user_name                                   |str                                            |sipAuthenticationUserName *Optional*                  |
|sip_authentication_password                                    |str                                            |sipAuthenticationPassword *Optional*                  |
|hosted_user_id                                                 |List[str]                                      |hostedUserId *Optional*                               |
|trunk_group_identity                                           |str                                            |trunkGroupIdentity *Optional*                         |
|otg_dtg_identity                                               |str                                            |otgDtgIdentity *Optional*                             |
|allow_termination_to_trunk_group_identity                      |bool                                           |allowTerminationToTrunkGroupIdentity                  |
|allow_termination_to_dtg_identity                              |bool                                           |allowTerminationToDtgIdentity                         |
|include_trunk_group_identity                                   |bool                                           |includeTrunkGroupIdentity                             |
|include_dtg_identity                                           |bool                                           |includeDtgIdentity                                    |
|include_trunk_group_identity_for_network_calls                 |bool                                           |includeTrunkGroupIdentityForNetworkCalls              |
|include_otg_identity_for_network_calls                         |bool                                           |includeOtgIdentityForNetworkCalls                     |
|enable_network_address_identity                                |bool                                           |enableNetworkAddressIdentity                          |
|allow_unscreened_calls                                         |bool                                           |allowUnscreenedCalls                                  |
|allow_unscreened_emergency_calls                               |bool                                           |allowUnscreenedEmergencyCalls                         |
|pilot_user_calling_line_identity_for_external_calls_policy     |str                                            |pilotUserCallingLineIdentityForExternalCallsPolicy    |
|pilot_user_charge_number_policy                                |str                                            |pilotUserChargeNumberPolicy                           |
|call_forwarding_always_action                                  |str                                            |callForwardingAlwaysAction *Optional*                 |
|call_forwarding_always_forward_address                         |str                                            |callForwardingAlwaysForwardAddress *Optional*         |
|call_forwarding_always_reroute_trunk_group_key                 |OCI.callForwardingAlwaysRerouteTrunkGroupKey   |callForwardingAlwaysRerouteTrunkGroupKey *Optional*   |
|peering_domain                                                 |str                                            |peeringDomain *Optional*                              |
|route_to_peering_domain                                        |bool                                           |routeToPeeringDomain                                  |
|prefix_enabled                                                 |bool                                           |prefixEnabled                                         |
|prefix                                                         |str                                            |prefix *Optional*                                     |
|stateful_rerouting_enabled                                     |bool                                           |statefulReroutingEnabled                              |
|send_continuous_options_message                                |bool                                           |sendContinuousOptionsMessage                          |
|continuous_options_sending_interval_seconds                    |int                                            |continuousOptionsSendingIntervalSeconds               |
|failure_options_sending_interval_seconds                       |int                                            |failureOptionsSendingIntervalSeconds                  |
|failure_threshold_counter                                      |int                                            |failureThresholdCounter                               |
|success_threshold_counter                                      |int                                            |successThresholdCounter                               |
|invite_failure_threshold_counter                               |int                                            |inviteFailureThresholdCounter                         |
|invite_failure_threshold_window_seconds                        |int                                            |inviteFailureThresholdWindowSeconds                   |
|pilot_user_calling_line_asserted_identity_policy               |str                                            |pilotUserCallingLineAssertedIdentityPolicy            |
|use_system_calling_line_asserted_identity_policy               |bool                                           |useSystemCallingLineAssertedIdentityPolicy            |
|pilot_user_call_optimization_policy                            |str                                            |pilotUserCallOptimizationPolicy                       |
|clid_source_for_screened_calls_policy                          |str                                            |clidSourceForScreenedCallsPolicy                      |
|use_system_clid_source_for_screened_calls_policy               |bool                                           |useSystemCLIDSourceForScreenedCallsPolicy             |
|user_lookup_policy                                             |str                                            |userLookupPolicy                                      |
|use_system_user_lookup_policy                                  |bool                                           |useSystemUserLookupPolicy                             |
|pilot_user_calling_line_identity_for_emergency_calls_policy    |str                                            |pilotUserCallingLineIdentityForEmergencyCallsPolicy   |
|pilot_user_network_class_of_service                            |str                                            |pilotUserNetworkClassOfService *Optional*             |
|implicit_registration_set_support_policy                       |str                                            |implicitRegistrationSetSupportPolicy                  |
|use_system_implicit_registration_set_support_policy            |bool                                           |useSystemImplicitRegistrationSetSupportPolicy         |
|sip_identity_for_pilot_and_proxy_trunk_modes_policy            |str                                            |sipIdentityForPilotAndProxyTrunkModesPolicy           |
|use_system_sip_identity_for_pilot_and_proxy_trunk_modes_policy |bool                                           |useSystemSIPIdentityForPilotAndProxyTrunkModesPolicy  |
|use_system_support_connected_identity_policy                   |bool                                           |useSystemSupportConnectedIdentityPolicy               |
|support_connected_identity_policy                              |str                                            |supportConnectedIdentityPolicy                        |
</div>


## `GroupTrunkGroupGetAvailableHostedUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of hosted users that can be assigned to a Trunk Group.

The response is either `GroupTrunkGroupGetAvailableHostedUserListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|trunk_group_key                       |OCI.trunkGroupKey                     |trunkGroupKey                                |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*              |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                  |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*           |
</div>


## `GroupTrunkGroupGetInstanceUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of user's on a Trunk Group Instance.

The response is either a `GroupTrunkGroupGetInstanceUserListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|service_user_id                       |str                                   |serviceUserId                                |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                  |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
</div>


## `GroupTrunkGroupGetInstanceUserListRequest14sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of user's on a Trunk Group Instance.

The response is either a `GroupTrunkGroupGetInstanceUserListResponse14sp4()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|trunk_group_key                       |OCI.trunkGroupKey                     |trunkGroupKey                                |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                  |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*              |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*           |
</div>


## `GroupTrunkGroupModifyInstanceRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a Trunk Group Instance in a group.

The publicUserIdentity in the ServiceInstanceModifyProfile is not allowed for trunk
groups.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                           |Type                       |Description                                          |
|-----------------------------------------------|---------------------------|-----------------------------------------------------|
|service_user_id                                |str                        |serviceUserId                                        |
|service_instance_profile                       |OCI.serviceInstanceProfile |serviceInstanceProfile *Optional*                    |
|access_device_endpoint                         |OCI.accessDeviceEndpoint   |accessDeviceEndpoint *Optional*                      |
|max_active_calls                               |int                        |maxActiveCalls *Optional*                            |
|max_incoming_calls                             |int                        |maxIncomingCalls *Optional*                          |
|max_outgoing_calls                             |int                        |maxOutgoingCalls *Optional*                          |
|enable_bursting                                |bool                       |enableBursting *Optional*                            |
|bursting_max_active_calls                      |int                        |burstingMaxActiveCalls *Optional*                    |
|bursting_max_incoming_calls                    |int                        |burstingMaxIncomingCalls *Optional*                  |
|bursting_max_outgoing_calls                    |int                        |burstingMaxOutgoingCalls *Optional*                  |
|capacity_exceeded_action                       |str                        |capacityExceededAction *Optional*                    |
|capacity_exceeded_forward_address              |str                        |capacityExceededForwardAddress *Optional*            |
|capacity_exceeded_reroute_trunk_group_id       |str                        |capacityExceededRerouteTrunkGroupId *Optional*       |
|capacity_exceeded_trap_initial_calls           |int                        |capacityExceededTrapInitialCalls *Optional*          |
|capacity_exceeded_trap_offset_calls            |int                        |capacityExceededTrapOffsetCalls *Optional*           |
|unreachable_destination_action                 |str                        |unreachableDestinationAction *Optional*              |
|unreachable_destination_forward_address        |str                        |unreachableDestinationForwardAddress *Optional*      |
|unreachable_destination_reroute_trunk_group_id |str                        |unreachableDestinationRerouteTrunkGroupId *Optional* |
|unreachable_destination_trap_initial_calls     |int                        |unreachableDestinationTrapInitialCalls *Optional*    |
|unreachable_destination_trap_offset_calls      |int                        |unreachableDestinationTrapOffsetCalls *Optional*     |
|invitation_timeout                             |int                        |invitationTimeout *Optional*                         |
|require_authentication                         |bool                       |requireAuthentication *Optional*                     |
|sip_authentication_user_name                   |str                        |sipAuthenticationUserName *Optional*                 |
|sip_authentication_password                    |str                        |sipAuthenticationPassword *Optional*                 |
</div>


## `GroupUserCallForwardingSettingsGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of users and the service settings for a Call Forwarding service.

The response is either `GroupUserCallForwardingSettingsGetListResponse()` or
`ErrorResponse()`. By default, virtual users and non-virtual users that match the
selected search criteria are included in the response when "includeVirtualUsers" is
present; otherwise, if "includeVirtualUsers" is absent, then only non-virtual users
are returned.  The search can be performed using multiple criteria.  If search
criteria is specified, only the users matching all of the specified search criteria
are included in the response.  If no search criteria is specified, all results are
returned.

**Attributes:**

|Name                                      |Type                                      |Description                                    |
|------------------------------------------|------------------------------------------|-----------------------------------------------|
|service_provider_id                       |str                                       |serviceProviderId                              |
|group_id                                  |str                                       |groupId                                        |
|call_forwarding_service                   |str                                       |callForwardingService                          |
|response_paging_control                   |OCI.responsePagingControl                 |responsePagingControl                          |
|sort_by_user_last_name                    |OCI.sortByUserLastName                    |sortByUserLastName *Optional*                  |
|sort_by_user_first_name                   |OCI.sortByUserFirstName                   |sortByUserFirstName *Optional*                 |
|sort_by_user_department                   |OCI.sortByUserDepartment                  |sortByUserDepartment *Optional*                |
|sort_by_dn                                |OCI.sortByDn                              |sortByDn *Optional*                            |
|sort_by_extension                         |OCI.sortByExtension                       |sortByExtension *Optional*                     |
|sort_by_forwarded_to_number               |OCI.sortByForwardedToNumber               |sortByForwardedToNumber *Optional*             |
|include_virtual_users                     |bool                                      |includeVirtualUsers *Optional*                 |
|search_criteria_user_last_name            |List[OCI.searchCriteriaUserLastName]      |searchCriteriaUserLastName *Optional*          |
|search_criteria_user_first_name           |List[OCI.searchCriteriaUserFirstName]     |searchCriteriaUserFirstName *Optional*         |
|search_criteria_user_id                   |List[OCI.searchCriteriaUserId]            |searchCriteriaUserId *Optional*                |
|search_criteria_dn                        |List[OCI.searchCriteriaDn]                |searchCriteriaDn *Optional*                    |
|search_criteria_extension                 |List[OCI.searchCriteriaExtension]         |searchCriteriaExtension *Optional*             |
|search_criteria_email_address             |List[OCI.searchCriteriaEmailAddress]      |searchCriteriaEmailAddress *Optional*          |
|search_criteria_exact_user_department     |OCI.searchCriteriaExactUserDepartment     |searchCriteriaExactUserDepartment *Optional*   |
|search_criteria_exact_user_in_trunk_group |OCI.searchCriteriaExactUserInTrunkGroup   |searchCriteriaExactUserInTrunkGroup *Optional* |
|search_criteria_forwarded_to_number       |List[OCI.searchCriteriaForwardedToNumber] |searchCriteriaForwardedToNumber *Optional*     |
</div>


## `GroupUserCallWaitingSettingsGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of users and the Call Waiting service status (active or not active).

The response is either `GroupUserCallWaitingSettingsGetListResponse()` or
`ErrorResponse()`. By default, virtual users and non-virtual users that match the
selected search criteria are included in the response when "includeVirtualUsers" is
present; otherwise, if "includeVirtualUsers" is absent, then only non-virtual users
are returned.  The search can be performed using multiple criteria.  If search
criteria is specified, only the users matching all of the specified search criteria
are included in the response.  If no search criteria is specified, all results are
returned.

**Attributes:**

|Name                                      |Type                                    |Description                                    |
|------------------------------------------|----------------------------------------|-----------------------------------------------|
|service_provider_id                       |str                                     |serviceProviderId                              |
|group_id                                  |str                                     |groupId                                        |
|response_paging_control                   |OCI.responsePagingControl               |responsePagingControl                          |
|sort_by_user_last_name                    |OCI.sortByUserLastName                  |sortByUserLastName *Optional*                  |
|sort_by_user_first_name                   |OCI.sortByUserFirstName                 |sortByUserFirstName *Optional*                 |
|sort_by_user_department                   |OCI.sortByUserDepartment                |sortByUserDepartment *Optional*                |
|sort_by_dn                                |OCI.sortByDn                            |sortByDn *Optional*                            |
|sort_by_extension                         |OCI.sortByExtension                     |sortByExtension *Optional*                     |
|sort_by_service_status                    |OCI.sortByServiceStatus                 |sortByServiceStatus *Optional*                 |
|include_virtual_users                     |bool                                    |includeVirtualUsers *Optional*                 |
|search_criteria_user_last_name            |List[OCI.searchCriteriaUserLastName]    |searchCriteriaUserLastName *Optional*          |
|search_criteria_user_first_name           |List[OCI.searchCriteriaUserFirstName]   |searchCriteriaUserFirstName *Optional*         |
|search_criteria_user_id                   |List[OCI.searchCriteriaUserId]          |searchCriteriaUserId *Optional*                |
|search_criteria_dn                        |List[OCI.searchCriteriaDn]              |searchCriteriaDn *Optional*                    |
|search_criteria_extension                 |List[OCI.searchCriteriaExtension]       |searchCriteriaExtension *Optional*             |
|search_criteria_email_address             |List[OCI.searchCriteriaEmailAddress]    |searchCriteriaEmailAddress *Optional*          |
|search_criteria_exact_user_department     |OCI.searchCriteriaExactUserDepartment   |searchCriteriaExactUserDepartment *Optional*   |
|search_criteria_exact_user_in_trunk_group |OCI.searchCriteriaExactUserInTrunkGroup |searchCriteriaExactUserInTrunkGroup *Optional* |
|search_criteria_service_status            |OCI.searchCriteriaServiceStatus         |searchCriteriaServiceStatus *Optional*         |
</div>


## `GroupUserCallingPlanSettingsGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of users and the default or custom calling plan setting.

The response is either `GroupUserCallingPlanSettingsGetListResponse()` or
`ErrorResponse()`. By default, virtual users and non-virtual users that match the
selected search criteria are included in the response when "includeVirtualUsers" is
present; otherwise, if "includeVirtualUsers" is absent, then only non-virtual users
are returned.  The search can be performed using multiple criteria.  If search
criteria is specified, only the users matching all of the specified search criteria
are included in the response.  If no search criteria is specified, all results are
returned.

**Attributes:**

|Name                                      |Type                                    |Description                                    |
|------------------------------------------|----------------------------------------|-----------------------------------------------|
|service_provider_id                       |str                                     |serviceProviderId                              |
|group_id                                  |str                                     |groupId                                        |
|calling_plan_service                      |str                                     |callingPlanService                             |
|response_paging_control                   |OCI.responsePagingControl               |responsePagingControl                          |
|sort_by_user_last_name                    |OCI.sortByUserLastName                  |sortByUserLastName *Optional*                  |
|sort_by_user_first_name                   |OCI.sortByUserFirstName                 |sortByUserFirstName *Optional*                 |
|sort_by_user_department                   |OCI.sortByUserDepartment                |sortByUserDepartment *Optional*                |
|sort_by_dn                                |OCI.sortByDn                            |sortByDn *Optional*                            |
|sort_by_extension                         |OCI.sortByExtension                     |sortByExtension *Optional*                     |
|include_virtual_users                     |bool                                    |includeVirtualUsers *Optional*                 |
|search_criteria_user_last_name            |List[OCI.searchCriteriaUserLastName]    |searchCriteriaUserLastName *Optional*          |
|search_criteria_user_first_name           |List[OCI.searchCriteriaUserFirstName]   |searchCriteriaUserFirstName *Optional*         |
|search_criteria_user_id                   |List[OCI.searchCriteriaUserId]          |searchCriteriaUserId *Optional*                |
|search_criteria_dn                        |List[OCI.searchCriteriaDn]              |searchCriteriaDn *Optional*                    |
|search_criteria_extension                 |List[OCI.searchCriteriaExtension]       |searchCriteriaExtension *Optional*             |
|search_criteria_email_address             |List[OCI.searchCriteriaEmailAddress]    |searchCriteriaEmailAddress *Optional*          |
|search_criteria_exact_user_department     |OCI.searchCriteriaExactUserDepartment   |searchCriteriaExactUserDepartment *Optional*   |
|search_criteria_exact_user_in_trunk_group |OCI.searchCriteriaExactUserInTrunkGroup |searchCriteriaExactUserInTrunkGroup *Optional* |
</div>


## `GroupUserHotelingGuestSettingsGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of users and their Hoteling Guest service status (active or not active).

The response is either `GroupUserHotelingGuestSettingsGetListResponse()` or
`ErrorResponse()`. By default, virtual users and non-virtual users that match the
selected search criteria are included in the response when "includeVirtualUsers" is
present; otherwise, if "includeVirtualUsers" is absent, then only non-virtual users
are returned.  The search can be performed using multiple criteria.  If search
criteria is specified, only the users matching all of the specified search criteria
are included in the response.  If no search criteria is specified, all results are
returned.

**Attributes:**

|Name                                      |Type                                    |Description                                    |
|------------------------------------------|----------------------------------------|-----------------------------------------------|
|service_provider_id                       |str                                     |serviceProviderId                              |
|group_id                                  |str                                     |groupId                                        |
|response_paging_control                   |OCI.responsePagingControl               |responsePagingControl                          |
|sort_by_user_last_name                    |OCI.sortByUserLastName                  |sortByUserLastName *Optional*                  |
|sort_by_user_first_name                   |OCI.sortByUserFirstName                 |sortByUserFirstName *Optional*                 |
|sort_by_user_department                   |OCI.sortByUserDepartment                |sortByUserDepartment *Optional*                |
|sort_by_dn                                |OCI.sortByDn                            |sortByDn *Optional*                            |
|sort_by_extension                         |OCI.sortByExtension                     |sortByExtension *Optional*                     |
|sort_by_service_status                    |OCI.sortByServiceStatus                 |sortByServiceStatus *Optional*                 |
|include_virtual_users                     |bool                                    |includeVirtualUsers *Optional*                 |
|search_criteria_user_last_name            |List[OCI.searchCriteriaUserLastName]    |searchCriteriaUserLastName *Optional*          |
|search_criteria_user_first_name           |List[OCI.searchCriteriaUserFirstName]   |searchCriteriaUserFirstName *Optional*         |
|search_criteria_user_id                   |List[OCI.searchCriteriaUserId]          |searchCriteriaUserId *Optional*                |
|search_criteria_dn                        |List[OCI.searchCriteriaDn]              |searchCriteriaDn *Optional*                    |
|search_criteria_extension                 |List[OCI.searchCriteriaExtension]       |searchCriteriaExtension *Optional*             |
|search_criteria_email_address             |List[OCI.searchCriteriaEmailAddress]    |searchCriteriaEmailAddress *Optional*          |
|search_criteria_exact_user_department     |OCI.searchCriteriaExactUserDepartment   |searchCriteriaExactUserDepartment *Optional*   |
|search_criteria_exact_user_in_trunk_group |OCI.searchCriteriaExactUserInTrunkGroup |searchCriteriaExactUserInTrunkGroup *Optional* |
</div>


## `GroupVirtualOnNetEnterpriseExtensionsAddUserRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Adds Virtual On-Net users to a Group.

It is possible to add either: a single user, or a list of users, or a range of users,
or any combination thereof.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                      |Type                       |Description                      |
|--------------------------|---------------------------|---------------------------------|
|service_provider_id       |str                        |serviceProviderId                |
|group_id                  |str                        |groupId                          |
|virtual_on_net_user       |List[OCI.virtualOnNetUser] |virtualOnNetUser *Optional*      |
|virtual_on_net_user_range |OCI.virtualOnNetUserRange  |virtualOnNetUserRange *Optional* |
</div>


## `GroupVirtualOnNetEnterpriseExtensionsGetUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the list of Virtual On-Net users in a Group.

It is possible to search by various criteria to restrict the number of rows returned.
Multiple search criteria are logically ANDed together.

The response is either a `GroupVirtualOnNetEnterpriseExtensionsGetUserListResponse()`
or an `ErrorResponse()`.

**Attributes:**

|Name                                                |Type                                            |Description                                            |
|----------------------------------------------------|------------------------------------------------|-------------------------------------------------------|
|service_provider_id                                 |str                                             |serviceProviderId                                      |
|group_id                                            |str                                             |groupId                                                |
|response_size_limit                                 |int                                             |responseSizeLimit *Optional*                           |
|search_criteria_user_last_name                      |List[OCI.searchCriteriaUserLastName]            |searchCriteriaUserLastName *Optional*                  |
|search_criteria_user_first_name                     |List[OCI.searchCriteriaUserFirstName]           |searchCriteriaUserFirstName *Optional*                 |
|search_criteria_dn                                  |List[OCI.searchCriteriaDn]                      |searchCriteriaDn *Optional*                            |
|search_criteria_extension                           |List[OCI.searchCriteriaExtension]               |searchCriteriaExtension *Optional*                     |
|search_criteria_exact_virtual_on_net_call_type_name |OCI.searchCriteriaExactVirtualOnNetCallTypeName |searchCriteriaExactVirtualOnNetCallTypeName *Optional* |
</div>


## `GroupVoiceMessagingGroupConsolidatedModifyVoicePortalRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the group's voice messaging settings and voice portal branding
settings.

If UnassignPhoneNumbersLevel is set to 'Group', the user's primary phone number, fax
number and any alternate numbers, will be un-assigned from the group if the command is
executed by a service provider administrator or above.  When set to 'Service
Provider', they will be un-assigned from the group and service provider if the command
is executed by a provisioning administrator or above.  When omitted, the number(s)
will be left assigned to the group.  An `ErrorResponse()` will be returned if any
number cannot be unassigned because of insufficient privilege.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                                                |Type                           |Description                                                          |
|--------------------------------------------------------------------|-------------------------------|---------------------------------------------------------------------|
|service_provider_id                                                 |str                            |serviceProviderId                                                    |
|group_id                                                            |str                            |groupId                                                              |
|unassign_phone_numbers                                              |str                            |unassignPhoneNumbers *Optional*                                      |
|add_phone_number_to_group                                           |bool                           |addPhoneNumberToGroup *Optional*                                     |
|service_instance_profile                                            |OCI.serviceInstanceProfile     |serviceInstanceProfile *Optional*                                    |
|is_active                                                           |bool                           |isActive *Optional*                                                  |
|enable_extended_scope                                               |bool                           |enableExtendedScope *Optional*                                       |
|allow_identification_by_phone_number_or_voice_mail_aliases_on_login |bool                           |allowIdentificationByPhoneNumberOrVoiceMailAliasesOnLogin *Optional* |
|use_voice_portal_wizard                                             |bool                           |useVoicePortalWizard *Optional*                                      |
|voice_portal_external_routing_scope                                 |str                            |voicePortalExternalRoutingScope *Optional*                           |
|use_external_routing                                                |bool                           |useExternalRouting *Optional*                                        |
|external_routing_address                                            |str                            |externalRoutingAddress *Optional*                                    |
|home_zone_name                                                      |str                            |homeZoneName *Optional*                                              |
|network_class_of_service                                            |str                            |networkClassOfService *Optional*                                     |
|voice_portal_greeting_selection                                     |str                            |voicePortalGreetingSelection *Optional*                              |
|voice_portal_greeting_file                                          |OCI.voicePortalGreetingFile    |voicePortalGreetingFile *Optional*                                   |
|voice_messaging_greeting_selection                                  |str                            |voiceMessagingGreetingSelection *Optional*                           |
|voice_messaging_greeting_file                                       |OCI.voiceMessagingGreetingFile |voiceMessagingGreetingFile *Optional*                                |
</div>


## `GroupVoiceMessagingGroupModifyVoicePortalRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the group voice portal information for a voice messaging group.

The following elements are only used in AS data mode: networkClassOfService The
following elements are only used in AS data mode and ignored in XS data mode:
expressMode

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                                                |Type                       |Description                                                          |
|--------------------------------------------------------------------|---------------------------|---------------------------------------------------------------------|
|service_provider_id                                                 |str                        |serviceProviderId                                                    |
|group_id                                                            |str                        |groupId                                                              |
|service_instance_profile                                            |OCI.serviceInstanceProfile |serviceInstanceProfile *Optional*                                    |
|is_active                                                           |bool                       |isActive *Optional*                                                  |
|enable_extended_scope                                               |bool                       |enableExtendedScope *Optional*                                       |
|allow_identification_by_phone_number_or_voice_mail_aliases_on_login |bool                       |allowIdentificationByPhoneNumberOrVoiceMailAliasesOnLogin *Optional* |
|use_voice_portal_wizard                                             |bool                       |useVoicePortalWizard *Optional*                                      |
|voice_portal_external_routing_scope                                 |str                        |voicePortalExternalRoutingScope *Optional*                           |
|use_external_routing                                                |bool                       |useExternalRouting *Optional*                                        |
|external_routing_address                                            |str                        |externalRoutingAddress *Optional*                                    |
|home_zone_name                                                      |str                        |homeZoneName *Optional*                                              |
|network_class_of_service                                            |str                        |networkClassOfService *Optional*                                     |
|express_mode                                                        |bool                       |expressMode *Optional*                                               |
</div>


## `GroupVoiceXmlAddInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a VoiceXML instance to a group.

The domain is required in the serviceUserId.  For a valid voiceXml instance to work
properly, a device with Static Registration is expected with a valid contact.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                     |Type                       |Description                      |
|-------------------------|---------------------------|---------------------------------|
|service_provider_id      |str                        |serviceProviderId                |
|group_id                 |str                        |groupId                          |
|service_user_id          |str                        |serviceUserId                    |
|service_instance_profile |OCI.serviceInstanceProfile |serviceInstanceProfile           |
|network_class_of_service |str                        |networkClassOfService *Optional* |
|access_device_endpoint   |OCI.accessDeviceEndpoint   |accessDeviceEndpoint *Optional*  |
</div>


## `GroupVoiceXmlModifyInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a VoiceXML instance.

For a valid voiceXml instance to work properly, a device with Static Registration is
expected with a valid contact.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                     |Type                       |Description                       |
|-------------------------|---------------------------|----------------------------------|
|service_user_id          |str                        |serviceUserId                     |
|service_instance_profile |OCI.serviceInstanceProfile |serviceInstanceProfile *Optional* |
|network_class_of_service |str                        |networkClassOfService *Optional*  |
|access_device_endpoint   |OCI.accessDeviceEndpoint   |accessDeviceEndpoint *Optional*   |
</div>


## `GroupXsiPolicyProfileGetAssignedUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of user within a group that have a given user Xsi policy profile assigned.

The response is either a `GroupXsiPolicyProfileGetAssignedUserListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                            |Type                                  |Description                            |
|--------------------------------|--------------------------------------|---------------------------------------|
|service_provider_id             |str                                   |serviceProviderId                      |
|group_id                        |str                                   |groupId                                |
|xsi_policy_profile              |OCI.xsiPolicyProfile                  |xsiPolicyProfile                       |
|response_size_limit             |int                                   |responseSizeLimit *Optional*           |
|search_criteria_user_id         |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*        |
|search_criteria_user_last_name  |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*  |
|search_criteria_user_first_name |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional* |
|search_criteria_dn              |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*            |
|search_criteria_extension       |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*     |
</div>


## `ResellerGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a list of resellers in the system.

It is possible to search by various criteria to restrict the number of rows returned.
Multiple search criteria are logically ANDed together.

The response is either a `ResellerGetListResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                          |Type                                 |Description                           |
|------------------------------|-------------------------------------|--------------------------------------|
|response_size_limit           |int                                  |responseSizeLimit *Optional*          |
|search_criteria_reseller_id   |List[OCI.searchCriteriaResellerId]   |searchCriteriaResellerId *Optional*   |
|search_criteria_reseller_name |List[OCI.searchCriteriaResellerName] |searchCriteriaResellerName *Optional* |
</div>


## `ResellerNetworkClassOfServiceGetAssignedServiceProviderListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of service provider/enterprises within a reseller that have a given Network
Class of Service assigned.

The response is either a
`ResellerNetworkClassOfServiceGetAssignedServiceProviderListResponse()` or an
`ErorResponse()`.

**Attributes:**

|Name                                  |Type                                        |Description                                  |
|--------------------------------------|--------------------------------------------|---------------------------------------------|
|reseller_id                           |str                                         |resellerId                                   |
|network_class_of_service              |str                                         |networkClassOfService                        |
|response_size_limit                   |int                                         |responseSizeLimit *Optional*                 |
|search_criteria_service_provider_id   |List[OCI.searchCriteriaServiceProviderId]   |searchCriteriaServiceProviderId *Optional*   |
|search_criteria_service_provider_name |List[OCI.searchCriteriaServiceProviderName] |searchCriteriaServiceProviderName *Optional* |
</div>


## `ResellerXsiPolicyProfileGetAssignedServiceProviderListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of service provider/enterprises within a reseller that have a given Service
provider Xsi policy profile assigned.

The response is either a
`ResellerXsiPolichProfileGetAssignedServiceProviderListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                    |Type                                        |Description                                    |
|----------------------------------------|--------------------------------------------|-----------------------------------------------|
|reseller_id                             |str                                         |resellerId                                     |
|xsi_policy_profile                      |OCI.xsiPolicyProfile                        |xsiPolicyProfile                               |
|response_size_limit                     |int                                         |responseSizeLimit *Optional*                   |
|search_criteria_service_provider_id     |List[OCI.searchCriteriaServiceProviderId]   |searchCriteriaServiceProviderId *Optional*     |
|search_criteria_service_provider_name   |List[OCI.searchCriteriaServiceProviderName] |searchCriteriaServiceProviderName *Optional*   |
|search_criteria_exact_organization_type |OCI.searchCriteriaExactOrganizationType     |searchCriteriaExactOrganizationType *Optional* |
</div>


## `ServiceProviderAccessDeviceGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of access devices in a service provider.

The following elements are only used in AS data mode and ignored in XS data mode:
serviceProviderExternalId

The response is either `ServiceProviderAccessDeviceGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                        |Description                                  |
|--------------------------------------|--------------------------------------------|---------------------------------------------|
|service_provider_id                   |str                                         |serviceProviderId *Optional*                 |
|service_provider_external_id          |str                                         |serviceProviderExternalId *Optional*         |
|response_size_limit                   |int                                         |responseSizeLimit *Optional*                 |
|search_criteria_device_name           |List[OCI.searchCriteriaDeviceName]          |searchCriteriaDeviceName *Optional*          |
|search_criteria_device_mac_address    |List[OCI.searchCriteriaDeviceMACAddress]    |searchCriteriaDeviceMACAddress *Optional*    |
|search_criteria_device_net_address    |List[OCI.searchCriteriaDeviceNetAddress]    |searchCriteriaDeviceNetAddress *Optional*    |
|search_criteria_exact_device_type     |OCI.searchCriteriaExactDeviceType           |searchCriteriaExactDeviceType *Optional*     |
|search_criteria_access_device_version |List[OCI.searchCriteriaAccessDeviceVersion] |searchCriteriaAccessDeviceVersion *Optional* |
</div>


## `ServiceProviderAccessDeviceGetPagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of service provider level access devices.

The response is either `ServiceProviderAccessDeviceGetPagedSortedListResponse()` or
`ErrorResponse()`. If no sortOrder is included, the response is sorted by Device Name
ascending by default.  If the responsePagingControl element is not provided, the
paging startIndex will be set to 1 by default, and the responsePageSize will be set to
the maximum responsePageSize by default.  Multiple search criteria are logically ANDed
together unless the searchCriteriaModeOr option is included.  Then the search criteria
are logically ORed together.  The getVisualDeviceManagementAPIDevicesOnly element can
only be set when CloudPBX is licenced.  If the getVisualDeviceManagementAPIDevicesOnly
element is not set, all devices are returned with Visual Device Management API flag
set to empty.  If the getVisualDeviceManagementAPIDevicesOnly element is set to true,
only SIP devices supporting Visual Device Management API are returned.  If the
getVisualDeviceManagementAPIDevicesOnly element is set to false, all SIP devices are
returned with their current Visual Device Management API flag value.

**Attributes:**

|Name                                          |Type                                        |Description                                        |
|----------------------------------------------|--------------------------------------------|---------------------------------------------------|
|service_provider_id                           |str                                         |serviceProviderId                                  |
|response_paging_control                       |OCI.responsePagingControl                   |responsePagingControl *Optional*                   |
|sort_by_device_name                           |OCI.sortByDeviceName                        |sortByDeviceName *Optional*                        |
|sort_by_device_type                           |OCI.sortByDeviceType                        |sortByDeviceType *Optional*                        |
|sort_by_device_net_address                    |OCI.sortByDeviceNetAddress                  |sortByDeviceNetAddress *Optional*                  |
|sort_by_device_mac_address                    |OCI.sortByDeviceMACAddress                  |sortByDeviceMACAddress *Optional*                  |
|search_criteria_device_name                   |List[OCI.searchCriteriaDeviceName]          |searchCriteriaDeviceName *Optional*                |
|search_criteria_device_mac_address            |List[OCI.searchCriteriaDeviceMACAddress]    |searchCriteriaDeviceMACAddress *Optional*          |
|search_criteria_device_net_address            |List[OCI.searchCriteriaDeviceNetAddress]    |searchCriteriaDeviceNetAddress *Optional*          |
|search_criteria_exact_device_type             |List[OCI.searchCriteriaExactDeviceType]     |searchCriteriaExactDeviceType *Optional*           |
|search_criteria_access_device_version         |List[OCI.searchCriteriaAccessDeviceVersion] |searchCriteriaAccessDeviceVersion *Optional*       |
|search_criteria_mode_or                       |bool                                        |searchCriteriaModeOr *Optional*                    |
|get_visual_device_management_api_devices_only |bool                                        |getVisualDeviceManagementAPIDevicesOnly *Optional* |
</div>


## `ServiceProviderAccessDeviceGetUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of users on a specified device.

The response is either `ServiceProviderAccessDeviceGetResponse()` or
`ErrorResponse()`. The following elements are only used in XS data mode and ignored in
AS data mode: searchCriteriaAccessDeviceEndpointPrivateIdentity Replaced by:
`ServiceProviderAccessDeviceGetUserListRequest21sp1()` in AS data mode.

**Attributes:**

|Name                                                    |Type                                                        |Description                                                  |
|--------------------------------------------------------|------------------------------------------------------------|-------------------------------------------------------------|
|service_provider_id                                     |str                                                         |serviceProviderId                                            |
|device_name                                             |str                                                         |deviceName                                                   |
|response_size_limit                                     |int                                                         |responseSizeLimit *Optional*                                 |
|search_criteria_line_port_user_part                     |List[OCI.searchCriteriaLinePortUserPart]                    |searchCriteriaLinePortUserPart *Optional*                    |
|search_criteria_line_port_domain                        |List[OCI.searchCriteriaLinePortDomain]                      |searchCriteriaLinePortDomain *Optional*                      |
|search_criteria_user_last_name                          |List[OCI.searchCriteriaUserLastName]                        |searchCriteriaUserLastName *Optional*                        |
|search_criteria_user_first_name                         |List[OCI.searchCriteriaUserFirstName]                       |searchCriteriaUserFirstName *Optional*                       |
|search_criteria_dn                                      |List[OCI.searchCriteriaDn]                                  |searchCriteriaDn *Optional*                                  |
|search_criteria_user_id                                 |List[OCI.searchCriteriaUserId]                              |searchCriteriaUserId *Optional*                              |
|search_criteria_group_id                                |List[OCI.searchCriteriaGroupId]                             |searchCriteriaGroupId *Optional*                             |
|search_criteria_exact_endpoint_type                     |OCI.searchCriteriaExactEndpointType                         |searchCriteriaExactEndpointType *Optional*                   |
|search_criteria_exact_user_type                         |OCI.searchCriteriaExactUserType                             |searchCriteriaExactUserType *Optional*                       |
|search_criteria_extension                               |List[OCI.searchCriteriaExtension]                           |searchCriteriaExtension *Optional*                           |
|search_criteria_exact_user_department                   |OCI.searchCriteriaExactUserDepartment                       |searchCriteriaExactUserDepartment *Optional*                 |
|search_criteria_exact_port_number                       |OCI.searchCriteriaExactPortNumber                           |searchCriteriaExactPortNumber *Optional*                     |
|search_criteria_access_device_endpoint_private_identity |List[OCI.searchCriteriaAccessDeviceEndpointPrivateIdentity] |searchCriteriaAccessDeviceEndpointPrivateIdentity *Optional* |
</div>


## `ServiceProviderAccessDeviceGetUserListRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of users on a specified device.

The response is either `ServiceProviderAccessDeviceGetUserListResponse21sp1()` or
`ErrorResponse()`. The following elements are only used in XS data mode and ignored in
AS data mode: searchCriteriaAccessDeviceEndpointPrivateIdentity

**Attributes:**

|Name                                                    |Type                                                        |Description                                                  |
|--------------------------------------------------------|------------------------------------------------------------|-------------------------------------------------------------|
|service_provider_id                                     |str                                                         |serviceProviderId                                            |
|device_name                                             |str                                                         |deviceName                                                   |
|response_size_limit                                     |int                                                         |responseSizeLimit *Optional*                                 |
|search_criteria_line_port_user_part                     |List[OCI.searchCriteriaLinePortUserPart]                    |searchCriteriaLinePortUserPart *Optional*                    |
|search_criteria_line_port_domain                        |List[OCI.searchCriteriaLinePortDomain]                      |searchCriteriaLinePortDomain *Optional*                      |
|search_criteria_user_last_name                          |List[OCI.searchCriteriaUserLastName]                        |searchCriteriaUserLastName *Optional*                        |
|search_criteria_user_first_name                         |List[OCI.searchCriteriaUserFirstName]                       |searchCriteriaUserFirstName *Optional*                       |
|search_criteria_dn                                      |List[OCI.searchCriteriaDn]                                  |searchCriteriaDn *Optional*                                  |
|search_criteria_user_id                                 |List[OCI.searchCriteriaUserId]                              |searchCriteriaUserId *Optional*                              |
|search_criteria_group_id                                |List[OCI.searchCriteriaGroupId]                             |searchCriteriaGroupId *Optional*                             |
|search_criteria_exact_endpoint_type                     |OCI.searchCriteriaExactEndpointType                         |searchCriteriaExactEndpointType *Optional*                   |
|search_criteria_exact_user_type                         |OCI.searchCriteriaExactUserType                             |searchCriteriaExactUserType *Optional*                       |
|search_criteria_extension                               |List[OCI.searchCriteriaExtension]                           |searchCriteriaExtension *Optional*                           |
|search_criteria_exact_user_department                   |OCI.searchCriteriaExactUserDepartment                       |searchCriteriaExactUserDepartment *Optional*                 |
|search_criteria_exact_port_number                       |OCI.searchCriteriaExactPortNumber                           |searchCriteriaExactPortNumber *Optional*                     |
|search_criteria_access_device_endpoint_private_identity |List[OCI.searchCriteriaAccessDeviceEndpointPrivateIdentity] |searchCriteriaAccessDeviceEndpointPrivateIdentity *Optional* |
|search_criteria_user_hotline_contact                    |List[OCI.searchCriteriaUserHotlineContact]                  |searchCriteriaUserHotlineContact *Optional*                  |
</div>


## `ServiceProviderBroadWorksMobilityMobileSubscriberDirectoryNumberGetSummaryListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a summary table of all Mobile Subscriber Directory Numbers in a service
provider.

This command is applicable only for service providers and will fail for enterprises.

The response is either
`ServiceProviderBroadWorksMobilityMobileSubscriberDirectoryNumberGetSummaryListResponse()`
or `ErrorResponse()`.

**Attributes:**

|Name                                               |Type                                                    |Description                                              |
|---------------------------------------------------|--------------------------------------------------------|---------------------------------------------------------|
|service_provider_id                                |str                                                     |serviceProviderId                                        |
|response_size_limit                                |int                                                     |responseSizeLimit *Optional*                             |
|search_criteria_mobile_subscriber_directory_number |List[OCI.searchCriteriaMobileSubscriberDirectoryNumber] |searchCriteriaMobileSubscriberDirectoryNumber *Optional* |
|search_criteria_group_id                           |List[OCI.searchCriteriaGroupId]                         |searchCriteriaGroupId *Optional*                         |
|search_criteria_exact_mobile_network               |OCI.searchCriteriaExactMobileNetwork                    |searchCriteriaExactMobileNetwork *Optional*              |
</div>


## `ServiceProviderCommunicationBarringDigitPatternCriteriaGetPatternListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get an existing Digit Pattern Criteria.

The response is either a
`ServiceProviderCommunicationBarringDigitPatternCriteriaGetPatternListResponse()` or
an `ErrorResponse()`.

**Attributes:**

|Name                          |Type                                 |Description                           |
|------------------------------|-------------------------------------|--------------------------------------|
|service_provider_id           |str                                  |serviceProviderId                     |
|name                          |str                                  |name                                  |
|response_size_limit           |int                                  |responseSizeLimit *Optional*          |
|search_criteria_digit_pattern |List[OCI.searchCriteriaDigitPattern] |searchCriteriaDigitPattern *Optional* |
</div>


## `ServiceProviderCommunicationBarringProfileGetAssignedGroupListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of groups within a service provider that have a given Communication Barring
Profile assigned.

The response is either a
`ServiceProviderCommunicationBarringProfileGetAssignedGroupListResponse()` or an
`ErorResponse()`.

**Attributes:**

|Name                       |Type                              |Description                        |
|---------------------------|----------------------------------|-----------------------------------|
|service_provider_id        |str                               |serviceProviderId                  |
|profile                    |str                               |profile                            |
|response_size_limit        |int                               |responseSizeLimit *Optional*       |
|search_criteria_group_id   |List[OCI.searchCriteriaGroupId]   |searchCriteriaGroupId *Optional*   |
|search_criteria_group_name |List[OCI.searchCriteriaGroupName] |searchCriteriaGroupName *Optional* |
</div>


## `ServiceProviderCommunicationBarringProfileModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an existing Communication Barring Profile.

The priorities for OriginatingRules, RedirectingRules, CallMeNowRules and
IncomingRules are requantized to consecutive integers as part of the modify.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode: callMeNowDefaultAction
callMeNowDefaultCallTimeout callMeNowRule applyToAttendedCallTransfers

**Attributes:**

|Name                                |Type                |Description                                 |
|------------------------------------|--------------------|--------------------------------------------|
|service_provider_id                 |str                 |serviceProviderId                           |
|name                                |str                 |name                                        |
|new_name                            |str                 |newName *Optional*                          |
|description                         |str                 |description *Optional*                      |
|originating_default_action          |str                 |originatingDefaultAction *Optional*         |
|originating_default_treatment_id    |str                 |originatingDefaultTreatmentId *Optional*    |
|originating_default_transfer_number |str                 |originatingDefaultTransferNumber *Optional* |
|originating_default_call_timeout    |int                 |originatingDefaultCallTimeout *Optional*    |
|originating_rule                    |OCI.originatingRule |originatingRule *Optional*                  |
|redirecting_default_action          |str                 |redirectingDefaultAction *Optional*         |
|redirecting_default_call_timeout    |int                 |redirectingDefaultCallTimeout *Optional*    |
|redirecting_rule                    |OCI.redirectingRule |redirectingRule *Optional*                  |
|call_me_now_default_action          |str                 |callMeNowDefaultAction *Optional*           |
|call_me_now_default_call_timeout    |int                 |callMeNowDefaultCallTimeout *Optional*      |
|call_me_now_rule                    |OCI.callMeNowRule   |callMeNowRule *Optional*                    |
|incoming_default_action             |str                 |incomingDefaultAction *Optional*            |
|incoming_default_call_timeout       |int                 |incomingDefaultCallTimeout *Optional*       |
|incoming_rule                       |OCI.incomingRule    |incomingRule *Optional*                     |
|become_default                      |bool                |becomeDefault *Optional*                    |
|apply_to_attended_call_transfers    |bool                |applyToAttendedCallTransfers *Optional*     |
</div>


## `ServiceProviderConsolidatedAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a service provider or enterprise.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode:
serviceProviderExtenalId The following elements are only used in Amplify data mode and
ignored in AS and XS data mode: servicePolicy, callProcessingSliceId,
provisioningSliceId, subscriberPartition.  When the callProcessingSliceId or
provisioningSliceId is not specified in the AmplifyDataMode, the default slice Id is
assigned to the service provider.  Only Provisioning admin and above can change the
callProcessingSliceId, provisioningSliceId, andsubscriberPartition.  The following
elements are only used in Amplify and XS data mode and ignored in AS data mode:
preferredDataCenter.  Only Provisioning admin and above can change the
preferredDataCenter.  The following data elements are only used in AS data mode:
resellerId resellerName The following behavior is only applicable in CloudPBX: - when
new resellerId, that does not exist in the system, is specified, the new Reseller is
created the given resellerId and resellerName (if provided) and enterprise/Service
Provider is moved to the newly created Reseller.  resellerName element is ignored if
the reseller the service provider is being moved to already exists.  The following
elements are optional for the service provider.  If the elements are included, they
will be either added, authorized, or modified on the service provider.  Should any of
the following elements be rejected to due existing system settings, the service
provider will not be added and the response will be an `ErrorResponse()`: domain admin
groupServiceAuthorization userServiceAuthorization servicePack phoneNumber dnRange
routingProfile meetMeConferencingAllocatedPorts trunkGroupMaxActiveCalls
trunkGroupBurstingMaxActiveCalls voiceMessagingGroupSettings
voiceMessagingVoicePortalScope When a group or user service is included that is not
activated or is not licensed, the response will be an `ErrorResponse()`.

**Attributes:**

|Name                                     |Type                                 |Description                                    |
|-----------------------------------------|-------------------------------------|-----------------------------------------------|
|is_enterprise                            |bool                                 |isEnterprise *Optional*                        |
|use_custom_routing_profile               |bool                                 |useCustomRoutingProfile *Optional*             |
|service_provider_id                      |str                                  |serviceProviderId *Optional*                   |
|service_provider_external_id             |str                                  |serviceProviderExternalId *Optional*           |
|default_domain                           |str                                  |defaultDomain                                  |
|service_provider_name                    |str                                  |serviceProviderName *Optional*                 |
|support_email                            |str                                  |supportEmail *Optional*                        |
|contact                                  |OCI.contact                          |contact *Optional*                             |
|address                                  |OCI.address                          |address *Optional*                             |
|service_policy                           |str                                  |servicePolicy *Optional*                       |
|call_processing_slice_id                 |str                                  |callProcessingSliceId *Optional*               |
|provisioning_slice_id                    |str                                  |provisioningSliceId *Optional*                 |
|subscriber_partition                     |str                                  |subscriberPartition *Optional*                 |
|preferred_data_center                    |str                                  |preferredDataCenter *Optional*                 |
|reseller_id                              |str                                  |resellerId *Optional*                          |
|reseller_name                            |str                                  |resellerName *Optional*                        |
|domain                                   |List[str]                            |domain *Optional*                              |
|admin                                    |List[OCI.admin]                      |admin *Optional*                               |
|group_service_authorization              |List[OCI.groupServiceAuthorization]  |groupServiceAuthorization *Optional*           |
|user_service_authorization               |List[OCI.userServiceAuthorization]   |userServiceAuthorization *Optional*            |
|service_pack                             |List[OCI.servicePack]                |servicePack *Optional*                         |
|phone_number                             |List[str]                            |phoneNumber *Optional*                         |
|dn_range                                 |List[OCI.dnRange]                    |dnRange *Optional*                             |
|routing_profile                          |str                                  |routingProfile *Optional*                      |
|meet_me_conferencing_allocated_ports     |OCI.meetMeConferencingAllocatedPorts |meetMeConferencingAllocatedPorts *Optional*    |
|trunk_group_max_active_calls             |OCI.trunkGroupMaxActiveCalls         |trunkGroupMaxActiveCalls *Optional*            |
|trunk_group_bursting_max_active_calls    |OCI.trunkGroupBurstingMaxActiveCalls |trunkGroupBurstingMaxActiveCalls *Optional*    |
|voice_messaging_group_settings           |OCI.voiceMessagingGroupSettings      |voiceMessagingGroupSettings *Optional*         |
|voice_messaging_group_voice_portal_scope |str                                  |voiceMessagingGroupVoicePortalScope *Optional* |
</div>


## `ServiceProviderDeviceManagementEventGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request device management's events for a specific queue.

It is possible to restrict the number of rows returned using responseSizeLimit.  If
eventQueueType is not specified, the events from all the event queues are returned.

The response is either a `ServiceProviderDeviceManagementEventGetListResponse()` or an
`ErrorResponse()`. Deprecated by:
`ServiceProviderDeviceManagementEventGetListRequest22()`.

**Attributes:**

|Name                                                                        |Type                                                                  |Description                                                                  |
|----------------------------------------------------------------------------|----------------------------------------------------------------------|-----------------------------------------------------------------------------|
|service_provider_id                                                         |str                                                                   |serviceProviderId                                                            |
|event_queue_type                                                            |str                                                                   |eventQueueType *Optional*                                                    |
|response_size_limit                                                         |int                                                                   |responseSizeLimit *Optional*                                                 |
|search_criteria_exact_device_management_event_status_in_progress_or_pending |OCI.searchCriteriaExactDeviceManagementEventStatusInProgressOrPending |searchCriteriaExactDeviceManagementEventStatusInProgressOrPending *Optional* |
|search_criteria_exact_device_management_event_status_completed              |OCI.searchCriteriaExactDeviceManagementEventStatusCompleted           |searchCriteriaExactDeviceManagementEventStatusCompleted *Optional*           |
|search_criteria_exact_device_management_event_action                        |OCI.searchCriteriaExactDeviceManagementEventAction                    |searchCriteriaExactDeviceManagementEventAction *Optional*                    |
|search_criteria_exact_device_management_event_level                         |OCI.searchCriteriaExactDeviceManagementEventLevel                     |searchCriteriaExactDeviceManagementEventLevel *Optional*                     |
|search_criteria_exact_device_management_event_type                          |OCI.searchCriteriaExactDeviceManagementEventType                      |searchCriteriaExactDeviceManagementEventType *Optional*                      |
|search_criteria_device_management_event_additional_info                     |List[OCI.searchCriteriaDeviceManagementEventAdditionalInfo]           |searchCriteriaDeviceManagementEventAdditionalInfo *Optional*                 |
|search_criteria_device_management_event_login_id                            |List[OCI.searchCriteriaDeviceManagementEventLoginId]                  |searchCriteriaDeviceManagementEventLoginId *Optional*                        |
</div>


## `ServiceProviderDeviceManagementEventGetListRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request device management's events for a specific queue.

It is possible to restrict the number of rows returned using responseSizeLimit.  If
eventQueueType is not specified, the events from all the event queues are returned.

The response is either a `ServiceProviderDeviceManagementEventGetListResponse22()` or
an `ErrorResponse()`.

**Attributes:**

|Name                                                                        |Type                                                                  |Description                                                                  |
|----------------------------------------------------------------------------|----------------------------------------------------------------------|-----------------------------------------------------------------------------|
|service_provider_id                                                         |str                                                                   |serviceProviderId                                                            |
|event_queue_type                                                            |str                                                                   |eventQueueType *Optional*                                                    |
|response_size_limit                                                         |int                                                                   |responseSizeLimit *Optional*                                                 |
|search_criteria_exact_device_management_event_status_in_progress_or_pending |OCI.searchCriteriaExactDeviceManagementEventStatusInProgressOrPending |searchCriteriaExactDeviceManagementEventStatusInProgressOrPending *Optional* |
|search_criteria_exact_device_management_event_status_completed              |OCI.searchCriteriaExactDeviceManagementEventStatusCompleted           |searchCriteriaExactDeviceManagementEventStatusCompleted *Optional*           |
|search_criteria_exact_device_management_event_action                        |OCI.searchCriteriaExactDeviceManagementEventAction                    |searchCriteriaExactDeviceManagementEventAction *Optional*                    |
|search_criteria_exact_device_management_event_level                         |OCI.searchCriteriaExactDeviceManagementEventLevel                     |searchCriteriaExactDeviceManagementEventLevel *Optional*                     |
|search_criteria_exact_device_management_event_type                          |OCI.searchCriteriaExactDeviceManagementEventType                      |searchCriteriaExactDeviceManagementEventType *Optional*                      |
|search_criteria_device_management_event_additional_info                     |List[OCI.searchCriteriaDeviceManagementEventAdditionalInfo]           |searchCriteriaDeviceManagementEventAdditionalInfo *Optional*                 |
|search_criteria_device_management_event_login_id                            |List[OCI.searchCriteriaDeviceManagementEventLoginId]                  |searchCriteriaDeviceManagementEventLoginId *Optional*                        |
</div>


## `ServiceProviderDnGetSummaryListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a summary table of all DNs in a service provider.

Dns assigned to the IMRN pool are not listed in the response.  The search can be done
using multiple criteria.  Only results matching all the search criteria are included
in the results.

The response is either `ServiceProviderDnGetSummaryListResponse()` or
`ErrorResponse()`. The following elements are only used in XS data mode and ignored in
AS data mode: searchCriteriaDn, searchCriteriaGroupId

**Attributes:**

|Name                     |Type                            |Description                      |
|-------------------------|--------------------------------|---------------------------------|
|service_provider_id      |str                             |serviceProviderId                |
|search_criteria_group_id |List[OCI.searchCriteriaGroupId] |searchCriteriaGroupId *Optional* |
|search_criteria_dn       |List[OCI.searchCriteriaDn]      |searchCriteriaDn *Optional*      |
</div>


## `ServiceProviderDomainGetAssignedGroupListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests a list of groups within a service provider that have a given domain assigned.

It is possible to search by various criteria to restrict the number of rows returned.
Multiple search criteria are logically ANDed together.

The response is either a `ServiceProviderDomainGetAssignedGroupListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                       |Type                              |Description                        |
|---------------------------|----------------------------------|-----------------------------------|
|service_provider_id        |str                               |serviceProviderId                  |
|domain                     |str                               |domain                             |
|response_size_limit        |int                               |responseSizeLimit *Optional*       |
|search_criteria_group_id   |List[OCI.searchCriteriaGroupId]   |searchCriteriaGroupId *Optional*   |
|search_criteria_group_name |List[OCI.searchCriteriaGroupName] |searchCriteriaGroupName *Optional* |
</div>


## `ServiceProviderDomainGetAssignedListRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of all matching domains assigned to a service provider .

The response is either `ServiceProviderDomainGetAssignedListResponse22()` or
`ErrorResponse()`. The following elements are only used in AS data mode and will be
ignored in XS data mode: responseSizeLimit searchCriteriaDomainName
searchCriteriaExactDomainLevel

**Attributes:**

|Name                               |Type                               |Description                               |
|-----------------------------------|-----------------------------------|------------------------------------------|
|service_provider_id                |str                                |serviceProviderId                         |
|response_size_limit                |int                                |responseSizeLimit *Optional*              |
|search_criteria_domain_name        |List[OCI.searchCriteriaDomainName] |searchCriteriaDomainName *Optional*       |
|search_criteria_exact_domain_level |OCI.searchCriteriaExactDomainLevel |searchCriteriaExactDomainLevel *Optional* |
</div>


## `ServiceProviderEndpointGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to search endpoints in the service provider/enterprise.

The response is either `ServiceProviderEndpointGetListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                     |Description                                  |
|--------------------------------------|-----------------------------------------|---------------------------------------------|
|service_provider_id                   |str                                      |serviceProviderId                            |
|response_size_limit                   |int                                      |responseSizeLimit *Optional*                 |
|search_criteria_group_id              |List[OCI.searchCriteriaGroupId]          |searchCriteriaGroupId *Optional*             |
|search_criteria_line_port_user_part   |List[OCI.searchCriteriaLinePortUserPart] |searchCriteriaLinePortUserPart *Optional*    |
|search_criteria_line_port_domain      |List[OCI.searchCriteriaLinePortDomain]   |searchCriteriaLinePortDomain *Optional*      |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]     |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName]    |searchCriteriaUserFirstName *Optional*       |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]           |searchCriteriaUserId *Optional*              |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]               |searchCriteriaDn *Optional*                  |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]        |searchCriteriaExtension *Optional*           |
|search_criteria_device_type           |List[OCI.searchCriteriaDeviceType]       |searchCriteriaDeviceType *Optional*          |
|search_criteria_device_name           |List[OCI.searchCriteriaDeviceName]       |searchCriteriaDeviceName *Optional*          |
|search_criteria_device_mac_address    |List[OCI.searchCriteriaDeviceMACAddress] |searchCriteriaDeviceMACAddress *Optional*    |
|search_criteria_device_net_address    |List[OCI.searchCriteriaDeviceNetAddress] |searchCriteriaDeviceNetAddress *Optional*    |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment    |searchCriteriaExactUserDepartment *Optional* |
</div>


## `ServiceProviderGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a list of service providers and/or enterprises in the system.

It is possible to search by various criteria to restrict the number of rows returned.
Multiple search criteria are logically ANDed together.  If reseller administrator
sends the request, searchCriteriaResellerId is ignored.  Service providers/enterprise
within the administrator's reseller meeting the search criteria are returned.

The response is either a `ServiceProviderGetListResponse()` or an `ErrorResponse()`.
The following data elements are only used in AS data mode: searchCriteriaResellerId

**Attributes:**

|Name                                  |Type                                        |Description                                  |
|--------------------------------------|--------------------------------------------|---------------------------------------------|
|is_enterprise                         |bool                                        |isEnterprise *Optional*                      |
|response_size_limit                   |int                                         |responseSizeLimit *Optional*                 |
|search_criteria_service_provider_id   |List[OCI.searchCriteriaServiceProviderId]   |searchCriteriaServiceProviderId *Optional*   |
|search_criteria_service_provider_name |List[OCI.searchCriteriaServiceProviderName] |searchCriteriaServiceProviderName *Optional* |
|search_criteria_reseller_id           |List[OCI.searchCriteriaResellerId]          |searchCriteriaResellerId *Optional*          |
</div>


## `ServiceProviderMWIDeliveryToMobileEndpointCustomTemplateAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Create a MWI Delivery to Mobile Endpoint Custom Template.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type             |Description       |
|--------------------|-----------------|------------------|
|service_provider_id |str              |serviceProviderId |
|language            |str              |language          |
|type                |str              |type              |
|is_enabled          |bool             |isEnabled         |
|template_body       |OCI.templateBody |templateBody      |
</div>


## `ServiceProviderMWIDeliveryToMobileEndpointCustomTemplateModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a MWI Delivery to Mobile Endpoint Custom Template.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type             |Description             |
|--------------------|-----------------|------------------------|
|service_provider_id |str              |serviceProviderId       |
|language            |str              |language                |
|type                |str              |type                    |
|is_enabled          |bool             |isEnabled *Optional*    |
|template_body       |OCI.templateBody |templateBody *Optional* |
</div>


## `ServiceProviderNetworkClassOfServiceGetAssignedGroupListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of groups within a service provider that have a given Network Class of
Service assigned.

The response is either a
`ServiceProviderNetworkClassOfServiceGetAssignedGroupListResponse()` or an
`ErorResponse()`.

**Attributes:**

|Name                       |Type                              |Description                        |
|---------------------------|----------------------------------|-----------------------------------|
|service_provider_id        |str                               |serviceProviderId                  |
|network_class_of_service   |str                               |networkClassOfService              |
|response_size_limit        |int                               |responseSizeLimit *Optional*       |
|search_criteria_group_id   |List[OCI.searchCriteriaGroupId]   |searchCriteriaGroupId *Optional*   |
|search_criteria_group_name |List[OCI.searchCriteriaGroupName] |searchCriteriaGroupName *Optional* |
</div>


## `ServiceProviderNumberPortabilityQueryGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the Service Provider Number Portability Query Digit Pattern Trigger
List information.

The response is either a `ServiceProviderNumberPortabilityQueryGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                                                    |Type                                                                      |Description                                                                |
|------------------------------------------------------------------------|--------------------------------------------------------------------------|---------------------------------------------------------------------------|
|service_provider_id                                                     |str                                                                       |serviceProviderId                                                          |
|include_digit_patterns                                                  |bool                                                                      |includeDigitPatterns                                                       |
|search_criteria_service_provider_number_portability_query_digit_pattern |List[OCI.searchCriteriaServiceProviderNumberPortabilityQueryDigitPattern] |searchCriteriaServiceProviderNumberPortabilityQueryDigitPattern *Optional* |
|response_size_limit                                                     |int                                                                       |responseSizeLimit *Optional*                                               |
</div>


## `ServiceProviderOfficeZoneGetAssignedGroupListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of groups within a service provider that have a given Office Zone assigned.

The response is either a `ServiceProviderOfficeZoneGetAssignedGroupListResponse()` or
an `ErrorResponse()`.

**Attributes:**

|Name                       |Type                              |Description                        |
|---------------------------|----------------------------------|-----------------------------------|
|service_provider_id        |str                               |serviceProviderId                  |
|office_zone_name           |str                               |officeZoneName                     |
|response_size_limit        |int                               |responseSizeLimit *Optional*       |
|search_criteria_group_id   |List[OCI.searchCriteriaGroupId]   |searchCriteriaGroupId *Optional*   |
|search_criteria_group_name |List[OCI.searchCriteriaGroupName] |searchCriteriaGroupName *Optional* |
</div>


## `ServiceProviderRouteListEnterpriseTrunkNumberPrefixAddListRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add number prefixes to a service provider.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type             |Description       |
|--------------------|-----------------|------------------|
|service_provider_id |str              |serviceProviderId |
|prefix              |List[OCI.prefix] |prefix            |
</div>


## `ServiceProviderRouteListEnterpriseTrunkNumberPrefixModifyListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a list of number prefixes in a service provider.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type                   |Description             |
|--------------------|-----------------------|------------------------|
|service_provider_id |str                    |serviceProviderId       |
|number_prefix       |List[OCI.numberPrefix] |numberPrefix *Optional* |
</div>


## `ServiceProviderRouteListEnterpriseTrunkNumberRangeAddListRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add number ranges to a service provider.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type                  |Description       |
|--------------------|----------------------|------------------|
|service_provider_id |str                   |serviceProviderId |
|number_range        |List[OCI.numberRange] |numberRange       |
</div>


## `ServiceProviderRoutePointExternalSystemGetAssignedGroupListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests a list of groups within a service provider that have a given external system
assigned.

It is possible to search by various criteria to restrict the number of rows returned.
Multiple search criteria are logically ANDed together.

The response is either a
`ServiceProviderRoutePointExternalSystemGetAssignedGroupListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                       |Type                              |Description                        |
|---------------------------|----------------------------------|-----------------------------------|
|service_provider_id        |str                               |serviceProviderId                  |
|external_system            |str                               |externalSystem                     |
|response_size_limit        |int                               |responseSizeLimit *Optional*       |
|search_criteria_group_id   |List[OCI.searchCriteriaGroupId]   |searchCriteriaGroupId *Optional*   |
|search_criteria_group_name |List[OCI.searchCriteriaGroupName] |searchCriteriaGroupName *Optional* |
</div>


## `ServiceProviderServiceModifyAuthorizationListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests to change the service provider's service authorization status.

The boolean flags are used to authorize or unauthorize services.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                        |Type                                |Description                          |
|----------------------------|------------------------------------|-------------------------------------|
|service_provider_id         |str                                 |serviceProviderId                    |
|group_service_authorization |List[OCI.groupServiceAuthorization] |groupServiceAuthorization *Optional* |
|user_service_authorization  |List[OCI.userServiceAuthorization]  |userServiceAuthorization *Optional*  |
</div>


## `ServiceProviderServicePackMigrationTaskGetAvailableGroupListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests a list of groups to migrate.

The response is either
`ServiceProviderServicePackMigrationTaskGetAvailabeGroupListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                       |Type                              |Description                        |
|---------------------------|----------------------------------|-----------------------------------|
|service_provider_id        |str                               |serviceProviderId                  |
|response_size_limit        |int                               |responseSizeLimit *Optional*       |
|search_criteria_group_id   |List[OCI.searchCriteriaGroupId]   |searchCriteriaGroupId *Optional*   |
|search_criteria_group_name |List[OCI.searchCriteriaGroupName] |searchCriteriaGroupName *Optional* |
</div>


## `ServiceProviderXsiPolicyProfileGetAssignedGroupListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of group within a service provider that have a given group Xsi policy
profile assigned.

The response is either a
`ServiceProviderXsiPolicyProfileGetAssignedGroupListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                       |Type                              |Description                        |
|---------------------------|----------------------------------|-----------------------------------|
|service_provider_id        |str                               |serviceProviderId                  |
|xsi_policy_profile         |OCI.xsiPolicyProfile              |xsiPolicyProfile                   |
|response_size_limit        |int                               |responseSizeLimit *Optional*       |
|search_criteria_group_id   |List[OCI.searchCriteriaGroupId]   |searchCriteriaGroupId *Optional*   |
|search_criteria_group_name |List[OCI.searchCriteriaGroupName] |searchCriteriaGroupName *Optional* |
</div>


## `SystemAccessDeviceGetAllRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of all access devices in the entire system.

Prior to release 14, this functionality was provided with the
`SystemAccessDeviceGetListRequest14()`. If reseller administrator sends the request,
searchCriteriaResellerId is ignored.  All the device profiles in the administrator's
reseller meeting the search criteria are returned.

The response is either `SystemAccessDeviceGetAllResponse()` or `ErrorResponse()`. The
following data elements are only used in AS data mode: searchCriteriaResellerId

**Attributes:**

|Name                                          |Type                                         |Description                                         |
|----------------------------------------------|---------------------------------------------|----------------------------------------------------|
|response_size_limit                           |int                                          |responseSizeLimit *Optional*                        |
|search_criteria_device_name                   |List[OCI.searchCriteriaDeviceName]           |searchCriteriaDeviceName *Optional*                 |
|search_criteria_device_mac_address            |List[OCI.searchCriteriaDeviceMACAddress]     |searchCriteriaDeviceMACAddress *Optional*           |
|search_criteria_device_net_address            |List[OCI.searchCriteriaDeviceNetAddress]     |searchCriteriaDeviceNetAddress *Optional*           |
|search_criteria_group_id                      |List[OCI.searchCriteriaGroupId]              |searchCriteriaGroupId *Optional*                    |
|search_criteria_exact_device_type             |OCI.searchCriteriaExactDeviceType            |searchCriteriaExactDeviceType *Optional*            |
|search_criteria_exact_device_service_provider |OCI.searchCriteriaExactDeviceServiceProvider |searchCriteriaExactDeviceServiceProvider *Optional* |
|search_criteria_service_provider_id           |List[OCI.searchCriteriaServiceProviderId]    |searchCriteriaServiceProviderId *Optional*          |
|search_criteria_reseller_id                   |List[OCI.searchCriteriaResellerId]           |searchCriteriaResellerId *Optional*                 |
</div>


## `SystemAccessDeviceGetListRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of access devices defined at the System-level.

Prior to release 14, this command requested a list of all devices in the entire
system.  That functionality is now moved to the `SystemAccessDeviceGetAllRequest()`.

The response is either `SystemAccessDeviceGetListResponse14()` or `ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                        |Description                                  |
|--------------------------------------|--------------------------------------------|---------------------------------------------|
|response_size_limit                   |int                                         |responseSizeLimit *Optional*                 |
|search_criteria_device_name           |List[OCI.searchCriteriaDeviceName]          |searchCriteriaDeviceName *Optional*          |
|search_criteria_device_mac_address    |List[OCI.searchCriteriaDeviceMACAddress]    |searchCriteriaDeviceMACAddress *Optional*    |
|search_criteria_device_net_address    |List[OCI.searchCriteriaDeviceNetAddress]    |searchCriteriaDeviceNetAddress *Optional*    |
|search_criteria_exact_device_type     |OCI.searchCriteriaExactDeviceType           |searchCriteriaExactDeviceType *Optional*     |
|search_criteria_access_device_version |List[OCI.searchCriteriaAccessDeviceVersion] |searchCriteriaAccessDeviceVersion *Optional* |
</div>


## `SystemAccessDeviceGetPagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of system-level access devices.

The response is either `SystemAccessDeviceGetPagedSortedListResponse()` or
`ErrorResponse()`. If no sortOrder is included, the response is sorted by Device Name
ascending by default.  If the responsePagingControl element is not provided, the
paging startIndex will be set to 1 by default, and the responsePageSize will be set to
the maximum responsePageSize by default.  Multiple search criteria are logically ANDed
together unless the searchCriteriaModeOr option is included.  Then the search criteria
are logically ORed together.  The getVisualDeviceManagementAPIDevicesOnly element can
only be set when CloudPBX is licenced.  If the getVisualDeviceManagementAPIDevicesOnly
element is not set, all devices are returned with Visual Device Management API flag
set to empty.  If the getVisualDeviceManagementAPIDevicesOnly element is set to true,
only SIP devices supporting Visual Device Management API are returned.  If the
getVisualDeviceManagementAPIDevicesOnly element is set to false, all SIP devices are
returned with their current Visual Device Management API flag value.

**Attributes:**

|Name                                          |Type                                        |Description                                        |
|----------------------------------------------|--------------------------------------------|---------------------------------------------------|
|response_paging_control                       |OCI.responsePagingControl                   |responsePagingControl *Optional*                   |
|sort_by_device_name                           |OCI.sortByDeviceName                        |sortByDeviceName *Optional*                        |
|sort_by_device_type                           |OCI.sortByDeviceType                        |sortByDeviceType *Optional*                        |
|sort_by_device_net_address                    |OCI.sortByDeviceNetAddress                  |sortByDeviceNetAddress *Optional*                  |
|sort_by_device_mac_address                    |OCI.sortByDeviceMACAddress                  |sortByDeviceMACAddress *Optional*                  |
|search_criteria_device_name                   |List[OCI.searchCriteriaDeviceName]          |searchCriteriaDeviceName *Optional*                |
|search_criteria_device_mac_address            |List[OCI.searchCriteriaDeviceMACAddress]    |searchCriteriaDeviceMACAddress *Optional*          |
|search_criteria_device_net_address            |List[OCI.searchCriteriaDeviceNetAddress]    |searchCriteriaDeviceNetAddress *Optional*          |
|search_criteria_exact_device_type             |List[OCI.searchCriteriaExactDeviceType]     |searchCriteriaExactDeviceType *Optional*           |
|search_criteria_access_device_version         |List[OCI.searchCriteriaAccessDeviceVersion] |searchCriteriaAccessDeviceVersion *Optional*       |
|search_criteria_mode_or                       |bool                                        |searchCriteriaModeOr *Optional*                    |
|get_visual_device_management_api_devices_only |bool                                        |getVisualDeviceManagementAPIDevicesOnly *Optional* |
</div>


## `SystemAccessDeviceGetUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the users associated with a specified system access device.

The response is either `SystemAccessDeviceGetUserListResponse()` or `ErrorResponse()`.
The following elements are only used in XS data mode and ignored in AS data mode:
searchCriteriaAccessDeviceEndpointPrivateIdentity Replaced by:
`SystemAccessDeviceGetUserListRequest21sp1()` in AS data mode.

**Attributes:**

|Name                                                    |Type                                                        |Description                                                  |
|--------------------------------------------------------|------------------------------------------------------------|-------------------------------------------------------------|
|device_name                                             |str                                                         |deviceName                                                   |
|response_size_limit                                     |int                                                         |responseSizeLimit *Optional*                                 |
|search_criteria_line_port_user_part                     |List[OCI.searchCriteriaLinePortUserPart]                    |searchCriteriaLinePortUserPart *Optional*                    |
|search_criteria_line_port_domain                        |List[OCI.searchCriteriaLinePortDomain]                      |searchCriteriaLinePortDomain *Optional*                      |
|search_criteria_user_last_name                          |List[OCI.searchCriteriaUserLastName]                        |searchCriteriaUserLastName *Optional*                        |
|search_criteria_user_first_name                         |List[OCI.searchCriteriaUserFirstName]                       |searchCriteriaUserFirstName *Optional*                       |
|search_criteria_dn                                      |List[OCI.searchCriteriaDn]                                  |searchCriteriaDn *Optional*                                  |
|search_criteria_user_id                                 |List[OCI.searchCriteriaUserId]                              |searchCriteriaUserId *Optional*                              |
|search_criteria_group_id                                |List[OCI.searchCriteriaGroupId]                             |searchCriteriaGroupId *Optional*                             |
|search_criteria_exact_service_provider                  |OCI.searchCriteriaExactServiceProvider                      |searchCriteriaExactServiceProvider *Optional*                |
|search_criteria_service_provider_id                     |List[OCI.searchCriteriaServiceProviderId]                   |searchCriteriaServiceProviderId *Optional*                   |
|search_criteria_exact_endpoint_type                     |OCI.searchCriteriaExactEndpointType                         |searchCriteriaExactEndpointType *Optional*                   |
|search_criteria_exact_user_type                         |OCI.searchCriteriaExactUserType                             |searchCriteriaExactUserType *Optional*                       |
|search_criteria_extension                               |List[OCI.searchCriteriaExtension]                           |searchCriteriaExtension *Optional*                           |
|search_criteria_exact_port_number                       |OCI.searchCriteriaExactPortNumber                           |searchCriteriaExactPortNumber *Optional*                     |
|search_criteria_access_device_endpoint_private_identity |List[OCI.searchCriteriaAccessDeviceEndpointPrivateIdentity] |searchCriteriaAccessDeviceEndpointPrivateIdentity *Optional* |
</div>


## `SystemAccessDeviceGetUserListRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the users associated with a specified system access device.

The response is either `SystemAccessDeviceGetUserListResponse21sp1()` or
`ErrorResponse()`. The following elements are only used in XS data mode and ignored in
AS data mode: searchCriteriaAccessDeviceEndpointPrivateIdentity

**Attributes:**

|Name                                                    |Type                                                        |Description                                                  |
|--------------------------------------------------------|------------------------------------------------------------|-------------------------------------------------------------|
|device_name                                             |str                                                         |deviceName                                                   |
|response_size_limit                                     |int                                                         |responseSizeLimit *Optional*                                 |
|search_criteria_line_port_user_part                     |List[OCI.searchCriteriaLinePortUserPart]                    |searchCriteriaLinePortUserPart *Optional*                    |
|search_criteria_line_port_domain                        |List[OCI.searchCriteriaLinePortDomain]                      |searchCriteriaLinePortDomain *Optional*                      |
|search_criteria_user_last_name                          |List[OCI.searchCriteriaUserLastName]                        |searchCriteriaUserLastName *Optional*                        |
|search_criteria_user_first_name                         |List[OCI.searchCriteriaUserFirstName]                       |searchCriteriaUserFirstName *Optional*                       |
|search_criteria_dn                                      |List[OCI.searchCriteriaDn]                                  |searchCriteriaDn *Optional*                                  |
|search_criteria_user_id                                 |List[OCI.searchCriteriaUserId]                              |searchCriteriaUserId *Optional*                              |
|search_criteria_group_id                                |List[OCI.searchCriteriaGroupId]                             |searchCriteriaGroupId *Optional*                             |
|search_criteria_exact_service_provider                  |OCI.searchCriteriaExactServiceProvider                      |searchCriteriaExactServiceProvider *Optional*                |
|search_criteria_service_provider_id                     |List[OCI.searchCriteriaServiceProviderId]                   |searchCriteriaServiceProviderId *Optional*                   |
|search_criteria_exact_endpoint_type                     |OCI.searchCriteriaExactEndpointType                         |searchCriteriaExactEndpointType *Optional*                   |
|search_criteria_exact_user_type                         |OCI.searchCriteriaExactUserType                             |searchCriteriaExactUserType *Optional*                       |
|search_criteria_extension                               |List[OCI.searchCriteriaExtension]                           |searchCriteriaExtension *Optional*                           |
|search_criteria_exact_port_number                       |OCI.searchCriteriaExactPortNumber                           |searchCriteriaExactPortNumber *Optional*                     |
|search_criteria_access_device_endpoint_private_identity |List[OCI.searchCriteriaAccessDeviceEndpointPrivateIdentity] |searchCriteriaAccessDeviceEndpointPrivateIdentity *Optional* |
|search_criteria_user_hotline_contact                    |List[OCI.searchCriteriaUserHotlineContact]                  |searchCriteriaUserHotlineContact *Optional*                  |
</div>


## `SystemAlternateUserIdGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of alternate user ids.

If reseller administrator sends the request, searchCriteriaResellerId is ignored.  All
the alternate user ids in the administrator's reseller meeting the search criteria are
returned.

The response is either `SystemAlternateUserIdGetListResponse()` or `ErrorResponse()`.
The following data elements are only used in AS data mode: searchCriteriaResellerId

**Attributes:**

|Name                                |Type                                      |Description                                |
|------------------------------------|------------------------------------------|-------------------------------------------|
|response_size_limit                 |int                                       |responseSizeLimit *Optional*               |
|search_criteria_alternate_user_id   |List[OCI.searchCriteriaAlternateUserId]   |searchCriteriaAlternateUserId *Optional*   |
|search_criteria_user_id             |List[OCI.searchCriteriaUserId]            |searchCriteriaUserId *Optional*            |
|search_criteria_group_id            |List[OCI.searchCriteriaGroupId]           |searchCriteriaGroupId *Optional*           |
|search_criteria_service_provider_id |List[OCI.searchCriteriaServiceProviderId] |searchCriteriaServiceProviderId *Optional* |
|search_criteria_reseller_id         |List[OCI.searchCriteriaResellerId]        |searchCriteriaResellerId *Optional*        |
</div>


## `SystemBroadWorksMobilityGeographicalPoolIMRNGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of BroadWorks Mobility IMRN numbers from a geographical pool.

The response is either a
`SystemBroadWorksMobilityGeographicalPoolIMRNGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                   |Type                         |Description                   |
|-----------------------|-----------------------------|------------------------------|
|geographical_pool_name |str                          |geographicalPoolName          |
|search_criteria_imrn   |List[OCI.searchCriteriaIMRN] |searchCriteriaIMRN *Optional* |
</div>


## `SystemBroadWorksMobilityGetIMRNListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of BroadWorks Mobility IMRN numbers defined in the system.

The response is either a `SystemBroadWorksMobilityGetIMRNListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                 |Type                         |Description                   |
|---------------------|-----------------------------|------------------------------|
|search_criteria_imrn |List[OCI.searchCriteriaIMRN] |searchCriteriaIMRN *Optional* |
</div>


## `SystemBroadWorksMobilityGetMobileNetworkIMRNListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of BroadWorks Mobility IMRN numbers from a Mobile Network.

The response is either a `SystemBroadWorksMobilityGetMobileNetworkIMRNListResponse()`
or an `ErrorResponse()`.

**Attributes:**

|Name                 |Type                         |Description                   |
|---------------------|-----------------------------|------------------------------|
|mobile_network_name  |str                          |mobileNetworkName             |
|search_criteria_imrn |List[OCI.searchCriteriaIMRN] |searchCriteriaIMRN *Optional* |
</div>


## `SystemBroadWorksMobilityMobileSubscriberDirectoryNumberGetSummaryListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a summary table of all Mobile Subscriber Directory Numbers in a system.

If reseller administrator sends the request, searchCriteriaResellerId is ignored.  All
the mobile subscriber directory numbers in the administrator's reseller meeting the
search criteria are returned.

The response is either
`SystemBroadWorksMobilityMobileSubscriberDirectoryNumberGetSummaryListResponse()` or
`ErrorResponse()`. The following data elements are only used in AS data mode:
searchCriteriaResellerId

**Attributes:**

|Name                                               |Type                                                    |Description                                              |
|---------------------------------------------------|--------------------------------------------------------|---------------------------------------------------------|
|response_size_limit                                |int                                                     |responseSizeLimit *Optional*                             |
|search_criteria_mobile_subscriber_directory_number |List[OCI.searchCriteriaMobileSubscriberDirectoryNumber] |searchCriteriaMobileSubscriberDirectoryNumber *Optional* |
|search_criteria_exact_mobile_network               |OCI.searchCriteriaExactMobileNetwork                    |searchCriteriaExactMobileNetwork *Optional*              |
|search_criteria_service_provider_id                |List[OCI.searchCriteriaServiceProviderId]               |searchCriteriaServiceProviderId *Optional*               |
|search_criteria_exact_organization_type            |OCI.searchCriteriaExactOrganizationType                 |searchCriteriaExactOrganizationType *Optional*           |
|search_criteria_group_id                           |List[OCI.searchCriteriaGroupId]                         |searchCriteriaGroupId *Optional*                         |
|search_criteria_user_id                            |List[OCI.searchCriteriaUserId]                          |searchCriteriaUserId *Optional*                          |
|search_criteria_user_last_name                     |List[OCI.searchCriteriaUserLastName]                    |searchCriteriaUserLastName *Optional*                    |
|search_criteria_user_first_name                    |List[OCI.searchCriteriaUserFirstName]                   |searchCriteriaUserFirstName *Optional*                   |
|search_criteria_dn                                 |List[OCI.searchCriteriaDn]                              |searchCriteriaDn *Optional*                              |
|search_criteria_extension                          |List[OCI.searchCriteriaExtension]                       |searchCriteriaExtension *Optional*                       |
|search_criteria_reseller_id                        |List[OCI.searchCriteriaResellerId]                      |searchCriteriaResellerId *Optional*                      |
</div>


## `SystemCallCenterEnhancedReportingScheduledReportGetActiveListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of all active call center reporting scheduled reports in the
system.

The response is either a
`SystemCallCenterEnhancedReportingScheduledReportGetActiveListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                                                     |Type                                                                |Description                                                                |
|-------------------------------------------------------------------------|--------------------------------------------------------------------|---------------------------------------------------------------------------|
|response_size_limit                                                      |int                                                                 |responseSizeLimit *Optional*                                               |
|search_criteria_call_center_scheduled_report_name                        |List[OCI.searchCriteriaCallCenterScheduledReportName]               |searchCriteriaCallCenterScheduledReportName *Optional*                     |
|search_criteria_group_id                                                 |List[OCI.searchCriteriaGroupId]                                     |searchCriteriaGroupId *Optional*                                           |
|search_criteria_exact_call_center_scheduled_report_service_provider      |OCI.searchCriteriaExactCallCenterScheduledReportServiceProvider     |searchCriteriaExactCallCenterScheduledReportServiceProvider *Optional*     |
|search_criteria_service_provider_id                                      |List[OCI.searchCriteriaServiceProviderId]                           |searchCriteriaServiceProviderId *Optional*                                 |
|search_criteria_exact_call_center_scheduled_report_created_by_supervisor |OCI.searchCriteriaExactCallCenterScheduledReportCreatedBySupervisor |searchCriteriaExactCallCenterScheduledReportCreatedBySupervisor *Optional* |
|search_criteria_call_center_report_template_name                         |List[OCI.searchCriteriaCallCenterReportTemplateName]                |searchCriteriaCallCenterReportTemplateName *Optional*                      |
</div>


## `SystemCallCenterEnhancedReportingScheduledReportGetCompletedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of all completed call center reporting scheduled reports in
the system.

The response is either a
`SystemCallCenterEnhancedReportingScheduledReportGetCompletedListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                                                     |Type                                                                |Description                                                                |
|-------------------------------------------------------------------------|--------------------------------------------------------------------|---------------------------------------------------------------------------|
|response_size_limit                                                      |int                                                                 |responseSizeLimit *Optional*                                               |
|search_criteria_call_center_scheduled_report_name                        |List[OCI.searchCriteriaCallCenterScheduledReportName]               |searchCriteriaCallCenterScheduledReportName *Optional*                     |
|search_criteria_group_id                                                 |List[OCI.searchCriteriaGroupId]                                     |searchCriteriaGroupId *Optional*                                           |
|search_criteria_exact_call_center_scheduled_report_service_provider      |OCI.searchCriteriaExactCallCenterScheduledReportServiceProvider     |searchCriteriaExactCallCenterScheduledReportServiceProvider *Optional*     |
|search_criteria_service_provider_id                                      |List[OCI.searchCriteriaServiceProviderId]                           |searchCriteriaServiceProviderId *Optional*                                 |
|search_criteria_exact_call_center_scheduled_report_created_by_supervisor |OCI.searchCriteriaExactCallCenterScheduledReportCreatedBySupervisor |searchCriteriaExactCallCenterScheduledReportCreatedBySupervisor *Optional* |
|search_criteria_call_center_report_template_name                         |List[OCI.searchCriteriaCallCenterReportTemplateName]                |searchCriteriaCallCenterReportTemplateName *Optional*                      |
</div>


## `SystemCallCenterEnhancedReportingScheduledReportGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of all call center reporting scheduled reports in the system.

The response is either an
`SystemCallCenterEnhancedReportingScheduledReportGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                                                     |Type                                                                |Description                                                                |
|-------------------------------------------------------------------------|--------------------------------------------------------------------|---------------------------------------------------------------------------|
|response_size_limit                                                      |int                                                                 |responseSizeLimit *Optional*                                               |
|search_criteria_call_center_scheduled_report_name                        |List[OCI.searchCriteriaCallCenterScheduledReportName]               |searchCriteriaCallCenterScheduledReportName *Optional*                     |
|search_criteria_group_id                                                 |List[OCI.searchCriteriaGroupId]                                     |searchCriteriaGroupId *Optional*                                           |
|search_criteria_exact_call_center_scheduled_report_service_provider      |OCI.searchCriteriaExactCallCenterScheduledReportServiceProvider     |searchCriteriaExactCallCenterScheduledReportServiceProvider *Optional*     |
|search_criteria_service_provider_id                                      |List[OCI.searchCriteriaServiceProviderId]                           |searchCriteriaServiceProviderId *Optional*                                 |
|search_criteria_exact_call_center_scheduled_report_created_by_supervisor |OCI.searchCriteriaExactCallCenterScheduledReportCreatedBySupervisor |searchCriteriaExactCallCenterScheduledReportCreatedBySupervisor *Optional* |
|search_criteria_call_center_report_template_name                         |List[OCI.searchCriteriaCallCenterReportTemplateName]                |searchCriteriaCallCenterReportTemplateName *Optional*                      |
</div>


## `SystemClassmarkGetUtilizationListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of all users associated with a Class Mark in system.

It is possible to search by various criteria.  Multiple search criteria are logically
ANDed together.

The response is either a `SystemClassmarkGetUtilizationListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                      |Type                                      |Description                                     |
|------------------------------------------|------------------------------------------|------------------------------------------------|
|classmark                                 |str                                       |classmark                                       |
|response_size_limit                       |int                                       |responseSizeLimit *Optional*                    |
|search_criteria_group_id                  |List[OCI.searchCriteriaGroupId]           |searchCriteriaGroupId *Optional*                |
|search_criteria_exact_service_provider_id |OCI.searchCriteriaExactServiceProviderId  |searchCriteriaExactServiceProviderId *Optional* |
|search_criteria_service_provider_id       |List[OCI.searchCriteriaServiceProviderId] |searchCriteriaServiceProviderId *Optional*      |
|search_criteria_user_first_name           |List[OCI.searchCriteriaUserFirstName]     |searchCriteriaUserFirstName *Optional*          |
|search_criteria_user_last_name            |List[OCI.searchCriteriaUserLastName]      |searchCriteriaUserLastName *Optional*           |
|search_criteria_dn                        |List[OCI.searchCriteriaDn]                |searchCriteriaDn *Optional*                     |
|search_criteria_user_id                   |List[OCI.searchCriteriaUserId]            |searchCriteriaUserId *Optional*                 |
|search_criteria_extension                 |List[OCI.searchCriteriaExtension]         |searchCriteriaExtension *Optional*              |
</div>


## `SystemCommunicationBarringDigitPatternCriteriaGetPatternListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get an existing Digit Pattern Criteria.

The response is either a
`SystemCommunicationBarringDigitPatternCriteriaGetPatternListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                          |Type                                 |Description                           |
|------------------------------|-------------------------------------|--------------------------------------|
|name                          |str                                  |name                                  |
|response_size_limit           |int                                  |responseSizeLimit *Optional*          |
|search_criteria_digit_pattern |List[OCI.searchCriteriaDigitPattern] |searchCriteriaDigitPattern *Optional* |
</div>


## `SystemCommunicationBarringProfileModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify an existing Communication Barring Profile.

When the originatingDefaultAction is not Treatment, originatingDefaultTreatmentId will
be automatically cleared.  Also when the action of originatingRule is not Treatment,
treatmentId will be automatically cleared for the rule.  The priorities for
IncomingRules are requantized to consecutive integers as part of the modify.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode: callMeNowDefaultAction
callMeNowDefaultCallTimeout callMeNowRule applyToAttendedCallTransfers

**Attributes:**

|Name                                |Type                |Description                                 |
|------------------------------------|--------------------|--------------------------------------------|
|name                                |str                 |name                                        |
|new_name                            |str                 |newName *Optional*                          |
|description                         |str                 |description *Optional*                      |
|originating_default_action          |str                 |originatingDefaultAction *Optional*         |
|originating_default_treatment_id    |str                 |originatingDefaultTreatmentId *Optional*    |
|originating_default_transfer_number |str                 |originatingDefaultTransferNumber *Optional* |
|originating_default_call_timeout    |int                 |originatingDefaultCallTimeout *Optional*    |
|originating_rule                    |OCI.originatingRule |originatingRule *Optional*                  |
|redirecting_default_action          |str                 |redirectingDefaultAction *Optional*         |
|redirecting_default_call_timeout    |int                 |redirectingDefaultCallTimeout *Optional*    |
|redirecting_rule                    |OCI.redirectingRule |redirectingRule *Optional*                  |
|incoming_default_action             |str                 |incomingDefaultAction *Optional*            |
|incoming_default_call_timeout       |int                 |incomingDefaultCallTimeout *Optional*       |
|incoming_rule                       |OCI.incomingRule    |incomingRule *Optional*                     |
|call_me_now_default_action          |str                 |callMeNowDefaultAction *Optional*           |
|call_me_now_default_call_timeout    |int                 |callMeNowDefaultCallTimeout *Optional*      |
|call_me_now_rule                    |OCI.callMeNowRule   |callMeNowRule *Optional*                    |
|apply_to_attended_call_transfers    |bool                |applyToAttendedCallTransfers *Optional*     |
</div>


## `SystemDeviceFamilyGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of device family managed by the Device Management System.

If includeSystemLevel is specified, all system level device families and the reseller
device families matching search criteria are returned even when
searchCriteriaResellerId is specified.  If reseller administrator sends the request,
searchCriteriaResellerId is ignored and automatically set to the administrator's
reseller.

The response is either `SystemDeviceFamilyGetListResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                        |Type                               |Description                         |
|----------------------------|-----------------------------------|------------------------------------|
|include_system_level        |bool                               |includeSystemLevel *Optional*       |
|search_criteria_reseller_id |List[OCI.searchCriteriaResellerId] |searchCriteriaResellerId *Optional* |
</div>


## `SystemDeviceManagementEventGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request device management's events for a specific queue.

It is possible to restrict the number of rows returned using responseSizeLimit.  If
eventQueueType is not specified, the events from all the event queues are returned.

The response is either a `SystemDeviceManagementEventGetListResponse()` or an
`ErrorResponse()`. Deprecated by: `SystemDeviceManagementEventGetListRequest22()`.

**Attributes:**

|Name                                                                        |Type                                                                  |Description                                                                  |
|----------------------------------------------------------------------------|----------------------------------------------------------------------|-----------------------------------------------------------------------------|
|event_queue_type                                                            |str                                                                   |eventQueueType *Optional*                                                    |
|response_size_limit                                                         |int                                                                   |responseSizeLimit *Optional*                                                 |
|search_criteria_exact_device_management_event_status_in_progress_or_pending |OCI.searchCriteriaExactDeviceManagementEventStatusInProgressOrPending |searchCriteriaExactDeviceManagementEventStatusInProgressOrPending *Optional* |
|search_criteria_exact_device_management_event_status_completed              |OCI.searchCriteriaExactDeviceManagementEventStatusCompleted           |searchCriteriaExactDeviceManagementEventStatusCompleted *Optional*           |
|search_criteria_exact_device_management_event_action                        |OCI.searchCriteriaExactDeviceManagementEventAction                    |searchCriteriaExactDeviceManagementEventAction *Optional*                    |
|search_criteria_exact_device_management_event_level                         |OCI.searchCriteriaExactDeviceManagementEventLevel                     |searchCriteriaExactDeviceManagementEventLevel *Optional*                     |
|search_criteria_exact_device_management_event_type                          |OCI.searchCriteriaExactDeviceManagementEventType                      |searchCriteriaExactDeviceManagementEventType *Optional*                      |
|search_criteria_device_management_event_additional_info                     |List[OCI.searchCriteriaDeviceManagementEventAdditionalInfo]           |searchCriteriaDeviceManagementEventAdditionalInfo *Optional*                 |
|search_criteria_device_management_event_login_id                            |List[OCI.searchCriteriaDeviceManagementEventLoginId]                  |searchCriteriaDeviceManagementEventLoginId *Optional*                        |
</div>


## `SystemDeviceManagementEventGetListRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request device management's events for a specific queue.

It is possible to restrict the number of rows returned using responseSizeLimit.  If
eventQueueType is not specified, the events from all the event queues are returned.

The response is either a `SystemDeviceManagementEventGetListResponse22()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                                                        |Type                                                                  |Description                                                                  |
|----------------------------------------------------------------------------|----------------------------------------------------------------------|-----------------------------------------------------------------------------|
|event_queue_type                                                            |str                                                                   |eventQueueType *Optional*                                                    |
|response_size_limit                                                         |int                                                                   |responseSizeLimit *Optional*                                                 |
|search_criteria_exact_device_management_event_status_in_progress_or_pending |OCI.searchCriteriaExactDeviceManagementEventStatusInProgressOrPending |searchCriteriaExactDeviceManagementEventStatusInProgressOrPending *Optional* |
|search_criteria_exact_device_management_event_status_completed              |OCI.searchCriteriaExactDeviceManagementEventStatusCompleted           |searchCriteriaExactDeviceManagementEventStatusCompleted *Optional*           |
|search_criteria_exact_device_management_event_action                        |OCI.searchCriteriaExactDeviceManagementEventAction                    |searchCriteriaExactDeviceManagementEventAction *Optional*                    |
|search_criteria_exact_device_management_event_level                         |OCI.searchCriteriaExactDeviceManagementEventLevel                     |searchCriteriaExactDeviceManagementEventLevel *Optional*                     |
|search_criteria_exact_device_management_event_type                          |OCI.searchCriteriaExactDeviceManagementEventType                      |searchCriteriaExactDeviceManagementEventType *Optional*                      |
|search_criteria_device_management_event_additional_info                     |List[OCI.searchCriteriaDeviceManagementEventAdditionalInfo]           |searchCriteriaDeviceManagementEventAdditionalInfo *Optional*                 |
|search_criteria_device_management_event_login_id                            |List[OCI.searchCriteriaDeviceManagementEventLoginId]                  |searchCriteriaDeviceManagementEventLoginId *Optional*                        |
</div>


## `SystemDeviceProfileAuthenticationLockoutGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get device password authentication lockout data in the system.

The response is either a `SystemDeviceProfileAuthenticationLockoutGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                    |Type                                      |Description                                    |
|----------------------------------------|------------------------------------------|-----------------------------------------------|
|response_size_limit                     |int                                       |responseSizeLimit *Optional*                   |
|search_criteria_service_provider_id     |List[OCI.searchCriteriaServiceProviderId] |searchCriteriaServiceProviderId *Optional*     |
|search_criteria_exact_organization_type |OCI.searchCriteriaExactOrganizationType   |searchCriteriaExactOrganizationType *Optional* |
|search_criteria_group_id                |List[OCI.searchCriteriaGroupId]           |searchCriteriaGroupId *Optional*               |
|search_criteria_device_name             |List[OCI.searchCriteriaDeviceName]        |searchCriteriaDeviceName *Optional*            |
|search_criteria_exact_device_type       |OCI.searchCriteriaExactDeviceType         |searchCriteriaExactDeviceType *Optional*       |
</div>


## `SystemDnGetSummaryListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a summary table of all DNs in the system.

If resellerId is specified, the DNs assigned to the enterprises/service providers
within the reseller are returned.  If reseller administrator sends the request and
resellerId is not specified, the administrator's resellerId is used.  The search can
be done using multiple criteria.  Only results matching all the search criteria are
included in the results.

The response is either `SystemDnGetSummaryListResponse()` or `ErrorResponse()`. The
following data elements are only used in AS data mode: resellerId The following
elements are only used in XS data mode and ignored in AS data mode: searchCriteriaDn,
searchCriteriaServiceProviderId, searchCriteriaExactOrganizationType

**Attributes:**

|Name                                    |Type                                      |Description                                    |
|----------------------------------------|------------------------------------------|-----------------------------------------------|
|reseller_id                             |str                                       |resellerId *Optional*                          |
|search_criteria_dn                      |List[OCI.searchCriteriaDn]                |searchCriteriaDn *Optional*                    |
|search_criteria_service_provider_id     |List[OCI.searchCriteriaServiceProviderId] |searchCriteriaServiceProviderId *Optional*     |
|search_criteria_exact_organization_type |OCI.searchCriteriaExactOrganizationType   |searchCriteriaExactOrganizationType *Optional* |
</div>


## `SystemDomainGetListRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of all matching system-level domains and all matching reseller level
domains.

If excludeReseller is specified, returns all matching system-level domain names only.
If resellerId is specified, returns all matching system-level domain names and the
given reseller's domains.  If reseller administrator sends the request and resellerId
is not specified, the administrator's resellerId is used.

The response is either `SystemDomainGetListResponse22V2()` or `ErrorResponse()`. The
following elements are only used in AS data mode and will be ingored in XS data mode:
includeReseller resellerId responseSizeLimit searchCriteriaDomainName
searchCriteriaResellerId searchCriteriaExactDomainLevel

**Attributes:**

|Name                               |Type                               |Description                               |
|-----------------------------------|-----------------------------------|------------------------------------------|
|exclude_reseller                   |bool                               |excludeReseller *Optional*                |
|reseller_id                        |str                                |resellerId *Optional*                     |
|response_size_limit                |int                                |responseSizeLimit *Optional*              |
|search_criteria_domain_name        |List[OCI.searchCriteriaDomainName] |searchCriteriaDomainName *Optional*       |
|search_criteria_reseller_id        |List[OCI.searchCriteriaResellerId] |searchCriteriaResellerId *Optional*       |
|search_criteria_exact_domain_level |OCI.searchCriteriaExactDomainLevel |searchCriteriaExactDomainLevel *Optional* |
</div>


## `SystemEndpointGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to search endpoints in the system.

If reseller administrator sends the request, searchCriteriaResellerId is ignored.  All
endpoints in the administrator's reseller meeting the search criteria are returned.

The response is either `SystemEndpointGetListResponse()` or `ErrorResponse()`. The
following data elements are only used in AS data mode: searchCriteriaResellerId

**Attributes:**

|Name                                    |Type                                      |Description                                    |
|----------------------------------------|------------------------------------------|-----------------------------------------------|
|response_size_limit                     |int                                       |responseSizeLimit *Optional*                   |
|search_criteria_service_provider_id     |List[OCI.searchCriteriaServiceProviderId] |searchCriteriaServiceProviderId *Optional*     |
|search_criteria_exact_organization_type |OCI.searchCriteriaExactOrganizationType   |searchCriteriaExactOrganizationType *Optional* |
|search_criteria_group_id                |List[OCI.searchCriteriaGroupId]           |searchCriteriaGroupId *Optional*               |
|search_criteria_line_port_user_part     |List[OCI.searchCriteriaLinePortUserPart]  |searchCriteriaLinePortUserPart *Optional*      |
|search_criteria_line_port_domain        |List[OCI.searchCriteriaLinePortDomain]    |searchCriteriaLinePortDomain *Optional*        |
|search_criteria_user_last_name          |List[OCI.searchCriteriaUserLastName]      |searchCriteriaUserLastName *Optional*          |
|search_criteria_user_first_name         |List[OCI.searchCriteriaUserFirstName]     |searchCriteriaUserFirstName *Optional*         |
|search_criteria_user_id                 |List[OCI.searchCriteriaUserId]            |searchCriteriaUserId *Optional*                |
|search_criteria_dn                      |List[OCI.searchCriteriaDn]                |searchCriteriaDn *Optional*                    |
|search_criteria_extension               |List[OCI.searchCriteriaExtension]         |searchCriteriaExtension *Optional*             |
|search_criteria_device_type             |List[OCI.searchCriteriaDeviceType]        |searchCriteriaDeviceType *Optional*            |
|search_criteria_device_name             |List[OCI.searchCriteriaDeviceName]        |searchCriteriaDeviceName *Optional*            |
|search_criteria_device_mac_address      |List[OCI.searchCriteriaDeviceMACAddress]  |searchCriteriaDeviceMACAddress *Optional*      |
|search_criteria_device_net_address      |List[OCI.searchCriteriaDeviceNetAddress]  |searchCriteriaDeviceNetAddress *Optional*      |
|search_criteria_reseller_id             |List[OCI.searchCriteriaResellerId]        |searchCriteriaResellerId *Optional*            |
</div>


## `SystemGetRegistrationContactListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of registration contacts.

This request handles all levels of administration privileges.  The content of the
response will only contain items within the scope of the requester's login id.  At the
system level any of the choice parameters may be specified to filter the registrations
listed.  At the reseller level, the resellerId must be specified.  ResellerId is not
valid at service provider, group or user level.  At the service provider level the
serviceProviderId must be specified for the service provider and group options.  When
using the userId or linePort options the specified value must be valid for that
service provider login.  At the group level the servicProviderId and the groupId must
be specified for the group option.  When using the userId or linePort options the
specified value must be valid for that group login.  The serviceProviderId option is
not valid at the group level.  At the user level when using the userId or linePort
options the specified value must be valid for that user login.  The serviceProviderId
and groupId options are not valid at the user level.

The response is either `SystemGetRegistrationContactListResponse()` or
`ErrorResponse()`. The following elements are only used in AS data mode: resellerId

**Attributes:**

|Name                             |Type                                    |Description                              |
|---------------------------------|----------------------------------------|-----------------------------------------|
|reseller_id                      |str                                     |resellerId *Optional*                    |
|service_provider_id              |str                                     |serviceProviderId *Optional*             |
|svc_provider_id                  |str                                     |svcProviderId *Optional*                 |
|group_id                         |str                                     |groupId *Optional*                       |
|user_id                          |str                                     |userId *Optional*                        |
|line_port                        |str                                     |linePort *Optional*                      |
|device_level                     |str                                     |deviceLevel *Optional*                   |
|device_name                      |str                                     |deviceName *Optional*                    |
|device_type                      |str                                     |deviceType *Optional*                    |
|search_criteria_registration_uri |List[OCI.searchCriteriaRegistrationURI] |searchCriteriaRegistrationURI *Optional* |
|search_criteria_sip_contact      |List[OCI.searchCriteriaSIPContact]      |searchCriteriaSIPContact *Optional*      |
|endpoint_type                    |str                                     |endpointType *Optional*                  |
|expired                          |bool                                    |expired *Optional*                       |
</div>


## `SystemGetRegistrationContactListRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of registration contacts.

This request handles all levels of administration privileges.  The content of the
response will only contain items within the scope of the requester's login id.  At the
system level any of the choice parameters may be specified to filter the registrations
listed.  At the reseller level, the resellerId must be specified.  ResellerId is not
valid at service provider, group or user level.  At the service provider level the
serviceProviderId must be specified for the service provider and group options.  When
using the userId or linePort options the specified value must be valid for that
service provider login.  At the group level the servicProviderId and the groupId must
be specified for the group option.  When using the userId or linePort options the
specified value must be valid for that group login.  The serviceProviderId option is
not valid at the group level.  At the user level when using the userId or linePort
options the specified value must be valid for that user login.  The serviceProviderId
and groupId options are not valid at the user level.

The response is either `SystemGetRegistrationContactListResponse21sp1()` or
`ErrorResponse()`. The RegistrationEndpointType21sp1 is sent in response The Endpoint
Type column contains one of the enumerated RegistrationEndpointType21sp1 values.  The
value Mobility in Endpoint Type column is only applicable in AS data mode.  The
following elements are only used in AS data mode: resellerId

**Attributes:**

|Name                             |Type                                    |Description                              |
|---------------------------------|----------------------------------------|-----------------------------------------|
|reseller_id                      |str                                     |resellerId *Optional*                    |
|service_provider_id              |str                                     |serviceProviderId *Optional*             |
|svc_provider_id                  |str                                     |svcProviderId *Optional*                 |
|group_id                         |str                                     |groupId *Optional*                       |
|user_id                          |str                                     |userId *Optional*                        |
|line_port                        |str                                     |linePort *Optional*                      |
|device_level                     |str                                     |deviceLevel *Optional*                   |
|device_name                      |str                                     |deviceName *Optional*                    |
|device_type                      |str                                     |deviceType *Optional*                    |
|search_criteria_registration_uri |List[OCI.searchCriteriaRegistrationURI] |searchCriteriaRegistrationURI *Optional* |
|search_criteria_sip_contact      |List[OCI.searchCriteriaSIPContact]      |searchCriteriaSIPContact *Optional*      |
|endpoint_type                    |str                                     |endpointType *Optional*                  |
|expired                          |bool                                    |expired *Optional*                       |
</div>


## `SystemHomeNetworkGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of all Home Networks.

The response is either a `SystemHomeNetworkGetListResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                             |Type                                   |Description                             |
|---------------------------------|---------------------------------------|----------------------------------------|
|response_size_limit              |int                                    |responseSizeLimit *Optional*            |
|search_criteria_home_msc_address |List[OCI.searchCriteriaHomeMscAddress] |searchCriteriaHomeMscAddress *Optional* |
</div>


## `SystemNumberPortabilityQueryDigitPatternGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the System Number Portability Query Digit Pattern List information.

The response is either a `SystemNumberPortabilityQueryDigitPatternGetListResponse()`
or an `ErrorResponse()`.

**Attributes:**

|Name                                                   |Type                                                       |Description                                                 |
|-------------------------------------------------------|-----------------------------------------------------------|------------------------------------------------------------|
|search_criteria_number_portability_query_digit_pattern |List[OCI.searchCriteriaNumberPortabilityQueryDigitPattern] |searchCriteriaNumberPortabilityQueryDigitPattern *Optional* |
|search_criteria_number_portability_status              |List[OCI.searchCriteriaNumberPortabilityStatus]            |searchCriteriaNumberPortabilityStatus *Optional*            |
|response_size_limit                                    |int                                                        |responseSizeLimit *Optional*                                |
</div>


## `SystemPreferredCarrierGetGroupListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests a list of groups using the specified carrier.

It is possible to restrict the number of rows returned by specifying various search
criteria.  Multiple search criteria are logically ANDed together.

The response is either a `SystemPreferredCarrierGetGroupListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                   |Type                                      |Description                                   |
|---------------------------------------|------------------------------------------|----------------------------------------------|
|carrier                                |str                                       |carrier                                       |
|response_size_limit                    |int                                       |responseSizeLimit *Optional*                  |
|search_criteria_group_id               |List[OCI.searchCriteriaGroupId]           |searchCriteriaGroupId *Optional*              |
|search_criteria_group_name             |List[OCI.searchCriteriaGroupName]         |searchCriteriaGroupName *Optional*            |
|search_criteria_exact_service_provider |OCI.searchCriteriaExactServiceProvider    |searchCriteriaExactServiceProvider *Optional* |
|search_criteria_service_provider_id    |List[OCI.searchCriteriaServiceProviderId] |searchCriteriaServiceProviderId *Optional*    |
</div>


## `SystemPreferredCarrierGetUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests a list of users using the specified carrier.

It is possible to restrict the number of rows returned by specifying various search
criteria.  Multiple search criteria are logically ANDed together.

The response is either a `SystemPreferreredCarrierGetUserListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                            |Type                                  |Description                            |
|--------------------------------|--------------------------------------|---------------------------------------|
|carrier                         |str                                   |carrier                                |
|response_size_limit             |int                                   |responseSizeLimit *Optional*           |
|search_criteria_user_last_name  |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*  |
|search_criteria_user_first_name |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional* |
|search_criteria_dn              |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*            |
|search_criteria_email_address   |List[OCI.searchCriteriaEmailAddress]  |searchCriteriaEmailAddress *Optional*  |
|search_criteria_user_id         |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*        |
|search_criteria_extension       |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*     |
</div>


## `SystemRoamingNetworkGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of all Roaming Networks.

The response is either a `SystemRoamingNetworkGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                |Type                                      |Description                                |
|------------------------------------|------------------------------------------|-------------------------------------------|
|response_size_limit                 |int                                       |responseSizeLimit *Optional*               |
|search_criteria_roaming_msc_address |List[OCI.searchCriteriaRoamingMscAddress] |searchCriteriaRoamingMscAddress *Optional* |
</div>


## `SystemSIPAuthenticationEndpointLockoutGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get sip authentication endpoint lockout data in the system.

The response is either a `SystemSIPAuthenticationEndpointLockoutGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                    |Type                                      |Description                                    |
|----------------------------------------|------------------------------------------|-----------------------------------------------|
|response_size_limit                     |int                                       |responseSizeLimit *Optional*                   |
|search_criteria_service_provider_id     |List[OCI.searchCriteriaServiceProviderId] |searchCriteriaServiceProviderId *Optional*     |
|search_criteria_exact_organization_type |OCI.searchCriteriaExactOrganizationType   |searchCriteriaExactOrganizationType *Optional* |
|search_criteria_group_id                |List[OCI.searchCriteriaGroupId]           |searchCriteriaGroupId *Optional*               |
|search_criteria_line_port_user_part     |List[OCI.searchCriteriaLinePortUserPart]  |searchCriteriaLinePortUserPart *Optional*      |
|search_criteria_line_port_domain        |List[OCI.searchCriteriaLinePortDomain]    |searchCriteriaLinePortDomain *Optional*        |
|search_criteria_user_last_name          |List[OCI.searchCriteriaUserLastName]      |searchCriteriaUserLastName *Optional*          |
|search_criteria_user_first_name         |List[OCI.searchCriteriaUserFirstName]     |searchCriteriaUserFirstName *Optional*         |
|search_criteria_user_id                 |List[OCI.searchCriteriaUserId]            |searchCriteriaUserId *Optional*                |
</div>


## `SystemSIPAuthenticationTrunkGroupLockoutGetRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get sip authentication trunk group lockout data in the system.

The response is either a `SystemSIPAuthenticationTrunkGroupLockoutGetResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                    |Type                                      |Description                                    |
|----------------------------------------|------------------------------------------|-----------------------------------------------|
|response_size_limit                     |int                                       |responseSizeLimit *Optional*                   |
|search_criteria_service_provider_id     |List[OCI.searchCriteriaServiceProviderId] |searchCriteriaServiceProviderId *Optional*     |
|search_criteria_exact_organization_type |OCI.searchCriteriaExactOrganizationType   |searchCriteriaExactOrganizationType *Optional* |
|search_criteria_group_id                |List[OCI.searchCriteriaGroupId]           |searchCriteriaGroupId *Optional*               |
|search_criteria_trunk_group_name        |List[OCI.searchCriteriaTrunkGroupName]    |searchCriteriaTrunkGroupName *Optional*        |
</div>


## `SystemSIPDeviceTypeGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the list of sip device types in the system.

If includeSystemLevel is specified, all system level device types and the reseller
device types matching search criteria are returned even when searchCriteriaResellerId
is specified.  If reseller administrator sends the request, searchCriteriaResellerId
is ignored.  All system level device types and the device types in the administrator's
reseller meeting the search criteria are returned.  See Also:
`SystemDeviceTypeGetAvailableListRequest22()` in AS data mode,
`SystemDeviceTypeGetAvailableListRequest19()` in XS data mode.

The response is either `SystemSIPDeviceTypeGetListResponse()` or `ErrorResponse()`.
The following data elements are only used in AS data mode and ignored in XS data mode:
searchCriteriaExactDeviceTypeConfigurationOptionType

**Attributes:**

|Name                                         |Type                                               |Description                                         |
|---------------------------------------------|---------------------------------------------------|----------------------------------------------------|
|response_size_limit                          |int                                                |responseSizeLimit *Optional*                        |
|search_criteria_device_type                  |List[OCI.searchCriteriaDeviceType]                 |searchCriteriaDeviceType *Optional*                 |
|search_criteria_exact_signaling_address_type |OCI.searchCriteriaExactSignalingAddressType        |searchCriteriaExactSignalingAddressType *Optional*  |
|search_criteria_reseller_id                  |List[OCI.searchCriteriaResellerId]                 |searchCriteriaResellerId *Optional*                 |
|search_criteria_device_configuration_options |List[OCI.searchCriteriaDeviceConfigurationOptions] |searchCriteriaDeviceConfigurationOptions *Optional* |
|include_system_level                         |bool                                               |includeSystemLevel *Optional*                       |
</div>


## `SystemSecurityClassificationGetClassificationTrunkGroupUsageListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of users that currently have the specified Security Classification
assigned.

The response is either
`SystemSecurityClassificationGetClassificationTrunkGroupUsageListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                                    |Type                                      |Description                                    |
|----------------------------------------|------------------------------------------|-----------------------------------------------|
|security_classification                 |str                                       |securityClassification                         |
|response_size_limit                     |int                                       |responseSizeLimit *Optional*                   |
|search_criteria_trunk_group_name        |List[OCI.searchCriteriaTrunkGroupName]    |searchCriteriaTrunkGroupName *Optional*        |
|search_criteria_group_id                |List[OCI.searchCriteriaGroupId]           |searchCriteriaGroupId *Optional*               |
|search_criteria_service_provider_id     |List[OCI.searchCriteriaServiceProviderId] |searchCriteriaServiceProviderId *Optional*     |
|search_criteria_exact_organization_type |OCI.searchCriteriaExactOrganizationType   |searchCriteriaExactOrganizationType *Optional* |
</div>


## `SystemSecurityClassificationGetClassificationUserUsageListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of users that currently have the specified Security Classification
assigned.

The response is either
`SystemSecurityClassificationGetClassificationUserUsageListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                            |Type                                  |Description                            |
|--------------------------------|--------------------------------------|---------------------------------------|
|security_classification         |str                                   |securityClassification                 |
|response_size_limit             |int                                   |responseSizeLimit *Optional*           |
|search_criteria_user_id         |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*        |
|search_criteria_user_last_name  |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*  |
|search_criteria_user_first_name |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional* |
|search_criteria_dn              |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*            |
|search_criteria_extension       |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*     |
</div>


## `SystemServiceCodeGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get all service codes that have been defined in the system.

It is possible to search by various criteria to restrict the number of rows returned.
Multiple search criteria are logically ANDed together.

The response is either `SystemServiceCodeGetListResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                     |Type                                           |Description                                     |
|-----------------------------------------|-----------------------------------------------|------------------------------------------------|
|response_size_limit                      |int                                            |responseSizeLimit *Optional*                    |
|search_criteria_service_code             |List[OCI.searchCriteriaServiceCode]            |searchCriteriaServiceCode *Optional*            |
|search_criteria_service_code_description |List[OCI.searchCriteriaServiceCodeDescription] |searchCriteriaServiceCodeDescription *Optional* |
</div>


## `SystemThirdPartyVoiceMailSupportGetDnListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a list of ThirdPartyVoiceMailSupport User DN's defined in the system.

The response is either a `SystemThirdPartyVoiceMailSupportGetDnListResponse()` or an
`ErrorResponse()`. The search can be done using multiple criterion.

**Attributes:**

|Name                              |Type                                    |Description                              |
|----------------------------------|----------------------------------------|-----------------------------------------|
|response_size_limit               |int                                     |responseSizeLimit *Optional*             |
|search_criteria_system_service_dn |List[OCI.searchCriteriaSystemServiceDn] |searchCriteriaSystemServiceDn *Optional* |
</div>


## `SystemTwoStageDialingGetDnListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get a list of Two Stage Dialing dns defined in the system.

The response is either a `SystemTwoStageDialingGetDnListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                              |Type                                    |Description                              |
|----------------------------------|----------------------------------------|-----------------------------------------|
|response_size_limit               |int                                     |responseSizeLimit *Optional*             |
|search_criteria_system_service_dn |List[OCI.searchCriteriaSystemServiceDn] |searchCriteriaSystemServiceDn *Optional* |
</div>


## `SystemVerifyTranslationAndRoutingRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Represents a Verify Translation and Routing request which can be either a request
containing parameters or a request containing a SIP message.

Returns a `SystemVerifyTranslationAndRoutingResponse()`.

**Attributes:**

|Name        |Type           |Description           |
|------------|---------------|----------------------|
|parameters  |OCI.parameters |parameters *Optional* |
|sip_message |str            |sipMessage *Optional* |
</div>


## `SystemXsiPolicyProfileGetAssignedServiceProviderListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get usage of specific policy profile.

The response is either a
`SystemXsiPolicyProfileGetAssignedServiceProviderListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                    |Type                                        |Description                                    |
|----------------------------------------|--------------------------------------------|-----------------------------------------------|
|xsi_policy_profile                      |OCI.xsiPolicyProfile                        |xsiPolicyProfile                               |
|response_size_limit                     |int                                         |responseSizeLimit *Optional*                   |
|search_criteria_service_provider_id     |List[OCI.searchCriteriaServiceProviderId]   |searchCriteriaServiceProviderId *Optional*     |
|search_criteria_service_provider_name   |List[OCI.searchCriteriaServiceProviderName] |searchCriteriaServiceProviderName *Optional*   |
|search_criteria_exact_organization_type |OCI.searchCriteriaExactOrganizationType     |searchCriteriaExactOrganizationType *Optional* |
|search_criteria_reseller_id             |List[OCI.searchCriteriaResellerId]          |searchCriteriaResellerId *Optional*            |
</div>


## `SystemZoneCallingRestrictionsNetAddressGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Gets a list of IP Addresses and/or Ranges assigned to a zone Response is
`SystemZoneCallingRestrictionsNetAddressGetListResponse()`.

Replaced by: `SystemZoneNetAddressGetListRequest()`

**Attributes:**

|Name                            |Type                                  |Description                            |
|--------------------------------|--------------------------------------|---------------------------------------|
|zone_name                       |str                                   |zoneName                               |
|response_size_limit             |int                                   |responseSizeLimit *Optional*           |
|search_criteria_zone_ip_address |List[OCI.searchCriteriaZoneIPAddress] |searchCriteriaZoneIPAddress *Optional* |
</div>


## `SystemZoneLocationBasedPhysicalLocationGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Gets a list of physical locations assigned to a zone.

Response is `SystemZoneLocationBasedPhysicalLocationGetListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                              |Type                                     |Description                               |
|----------------------------------|-----------------------------------------|------------------------------------------|
|zone_name                         |str                                      |zoneName                                  |
|response_size_limit               |int                                      |responseSizeLimit *Optional*              |
|search_criteria_physical_location |List[OCI.searchCriteriaPhysicalLocation] |searchCriteriaPhysicalLocation *Optional* |
</div>


## `SystemZoneNetAddressGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Gets a list of IP Addresses and/or Ranges assigned to a zone.

Response is `SystemZoneNetAddressGetListResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                            |Type                                  |Description                            |
|--------------------------------|--------------------------------------|---------------------------------------|
|zone_name                       |str                                   |zoneName                               |
|response_size_limit             |int                                   |responseSizeLimit *Optional*           |
|search_criteria_zone_ip_address |List[OCI.searchCriteriaZoneIPAddress] |searchCriteriaZoneIPAddress *Optional* |
</div>


## `UserAddRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a user.

The domain is required in the userId.  The password is not required if external
authentication is enabled.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                         |Type                         |Description                         |
|-----------------------------|-----------------------------|------------------------------------|
|service_provider_id          |str                          |serviceProviderId                   |
|group_id                     |str                          |groupId                             |
|user_id                      |str                          |userId                              |
|last_name                    |str                          |lastName                            |
|first_name                   |str                          |firstName                           |
|calling_line_id_last_name    |str                          |callingLineIdLastName               |
|calling_line_id_first_name   |str                          |callingLineIdFirstName              |
|hiragana_last_name           |str                          |hiraganaLastName *Optional*         |
|hiragana_first_name          |str                          |hiraganaFirstName *Optional*        |
|phone_number                 |str                          |phoneNumber *Optional*              |
|extension                    |str                          |extension *Optional*                |
|calling_line_id_phone_number |str                          |callingLineIdPhoneNumber *Optional* |
|password                     |str                          |password *Optional*                 |
|department                   |OCI.department               |department *Optional*               |
|language                     |str                          |language *Optional*                 |
|time_zone                    |str                          |timeZone *Optional*                 |
|alias                        |List[str]                    |alias *Optional*                    |
|access_device_endpoint       |OCI.accessDeviceEndpoint     |accessDeviceEndpoint *Optional*     |
|trunk_group_device_endpoint  |OCI.trunkGroupDeviceEndpoint |trunkGroupDeviceEndpoint *Optional* |
|title                        |str                          |title *Optional*                    |
|pager_phone_number           |str                          |pagerPhoneNumber *Optional*         |
|mobile_phone_number          |str                          |mobilePhoneNumber *Optional*        |
|email_address                |str                          |emailAddress *Optional*             |
|yahoo_id                     |str                          |yahooId *Optional*                  |
|address_location             |str                          |addressLocation *Optional*          |
|address                      |OCI.address                  |address *Optional*                  |
</div>


## `UserAddRequest14sp9`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Replaced By `UserAddRequest17sp4()` Request to add a user.

The domain is required in the userId.  The password is not required if external
authentication is enabled.  The officeZoneName and primaryZoneName elements are
ignored and provided here for backwards compatibility only.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                         |Type                     |Description                         |
|-----------------------------|-------------------------|------------------------------------|
|service_provider_id          |str                      |serviceProviderId                   |
|group_id                     |str                      |groupId                             |
|user_id                      |str                      |userId                              |
|last_name                    |str                      |lastName                            |
|first_name                   |str                      |firstName                           |
|calling_line_id_last_name    |str                      |callingLineIdLastName               |
|calling_line_id_first_name   |str                      |callingLineIdFirstName              |
|hiragana_last_name           |str                      |hiraganaLastName *Optional*         |
|hiragana_first_name          |str                      |hiraganaFirstName *Optional*        |
|phone_number                 |str                      |phoneNumber *Optional*              |
|extension                    |str                      |extension *Optional*                |
|calling_line_id_phone_number |str                      |callingLineIdPhoneNumber *Optional* |
|password                     |str                      |password *Optional*                 |
|department                   |OCI.department           |department *Optional*               |
|language                     |str                      |language *Optional*                 |
|time_zone                    |str                      |timeZone *Optional*                 |
|alias                        |List[str]                |alias *Optional*                    |
|access_device_endpoint       |OCI.accessDeviceEndpoint |accessDeviceEndpoint *Optional*     |
|trunk_addressing             |OCI.trunkAddressing      |trunkAddressing *Optional*          |
|title                        |str                      |title *Optional*                    |
|pager_phone_number           |str                      |pagerPhoneNumber *Optional*         |
|mobile_phone_number          |str                      |mobilePhoneNumber *Optional*        |
|email_address                |str                      |emailAddress *Optional*             |
|yahoo_id                     |str                      |yahooId *Optional*                  |
|address_location             |str                      |addressLocation *Optional*          |
|address                      |OCI.address              |address *Optional*                  |
|network_class_of_service     |str                      |networkClassOfService *Optional*    |
|office_zone_name             |str                      |officeZoneName *Optional*           |
|primary_zone_name            |str                      |primaryZoneName *Optional*          |
</div>


## `UserAddRequest17sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a user.

The domain is required in the userId.  The password is not required if external
authentication is enabled.  The following elements are only used in AS data mode and
ignored in XS data mode: nameDialingName alternateUserId

The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by:
`UserAddRequest21()`

**Attributes:**

|Name                         |Type                      |Description                         |
|-----------------------------|--------------------------|------------------------------------|
|service_provider_id          |str                       |serviceProviderId                   |
|group_id                     |str                       |groupId                             |
|user_id                      |str                       |userId                              |
|last_name                    |str                       |lastName                            |
|first_name                   |str                       |firstName                           |
|calling_line_id_last_name    |str                       |callingLineIdLastName               |
|calling_line_id_first_name   |str                       |callingLineIdFirstName              |
|name_dialing_name            |OCI.nameDialingName       |nameDialingName *Optional*          |
|hiragana_last_name           |str                       |hiraganaLastName *Optional*         |
|hiragana_first_name          |str                       |hiraganaFirstName *Optional*        |
|phone_number                 |str                       |phoneNumber *Optional*              |
|extension                    |str                       |extension *Optional*                |
|calling_line_id_phone_number |str                       |callingLineIdPhoneNumber *Optional* |
|password                     |str                       |password *Optional*                 |
|department                   |OCI.department            |department *Optional*               |
|language                     |str                       |language *Optional*                 |
|time_zone                    |str                       |timeZone *Optional*                 |
|alias                        |List[str]                 |alias *Optional*                    |
|access_device_endpoint       |OCI.accessDeviceEndpoint  |accessDeviceEndpoint *Optional*     |
|trunk_addressing             |OCI.trunkAddressing       |trunkAddressing *Optional*          |
|title                        |str                       |title *Optional*                    |
|pager_phone_number           |str                       |pagerPhoneNumber *Optional*         |
|mobile_phone_number          |str                       |mobilePhoneNumber *Optional*        |
|email_address                |str                       |emailAddress *Optional*             |
|yahoo_id                     |str                       |yahooId *Optional*                  |
|address_location             |str                       |addressLocation *Optional*          |
|address                      |OCI.address               |address *Optional*                  |
|network_class_of_service     |str                       |networkClassOfService *Optional*    |
|alternate_user_id            |List[OCI.alternateUserId] |alternateUserId *Optional*          |
</div>


## `UserAddRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a user.

The domain is required in the userId.  The password is not required if external
authentication is enabled.  The following elements are only used in AS data mode and
will fail in XS data mode: trunkAddressing The following elements are only used in AS
data mode and ignored in XS data mode: nameDialingName The following elements are only
used in XS data mode and ignored in AS data mode: allowVideo

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements can only be used by a system administrator:. allowVideo alternateUserId The
following elements can only be used by a provisioning administrator:. alternateUserId
Replaced by: `UserAddRequest22()` in AS data mode.

**Attributes:**

|Name                         |Type                      |Description                         |
|-----------------------------|--------------------------|------------------------------------|
|service_provider_id          |str                       |serviceProviderId                   |
|group_id                     |str                       |groupId                             |
|user_id                      |str                       |userId                              |
|last_name                    |str                       |lastName                            |
|first_name                   |str                       |firstName                           |
|calling_line_id_last_name    |str                       |callingLineIdLastName               |
|calling_line_id_first_name   |str                       |callingLineIdFirstName              |
|name_dialing_name            |OCI.nameDialingName       |nameDialingName *Optional*          |
|hiragana_last_name           |str                       |hiraganaLastName *Optional*         |
|hiragana_first_name          |str                       |hiraganaFirstName *Optional*        |
|phone_number                 |str                       |phoneNumber *Optional*              |
|extension                    |str                       |extension *Optional*                |
|calling_line_id_phone_number |str                       |callingLineIdPhoneNumber *Optional* |
|password                     |str                       |password *Optional*                 |
|department                   |OCI.department            |department *Optional*               |
|language                     |str                       |language *Optional*                 |
|time_zone                    |str                       |timeZone *Optional*                 |
|alias                        |List[str]                 |alias *Optional*                    |
|access_device_endpoint       |OCI.accessDeviceEndpoint  |accessDeviceEndpoint *Optional*     |
|trunk_addressing             |OCI.trunkAddressing       |trunkAddressing *Optional*          |
|title                        |str                       |title *Optional*                    |
|pager_phone_number           |str                       |pagerPhoneNumber *Optional*         |
|mobile_phone_number          |str                       |mobilePhoneNumber *Optional*        |
|email_address                |str                       |emailAddress *Optional*             |
|yahoo_id                     |str                       |yahooId *Optional*                  |
|address_location             |str                       |addressLocation *Optional*          |
|address                      |OCI.address               |address *Optional*                  |
|network_class_of_service     |str                       |networkClassOfService *Optional*    |
|alternate_user_id            |List[OCI.alternateUserId] |alternateUserId *Optional*          |
|allow_video                  |bool                      |allowVideo *Optional*               |
</div>


## `UserAnnouncementFileGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of announcement names with associated media type and filesize for a User
and given Announcement Repository Type The response is either a
`UserAnnouncementFileGetListResponse()` or an `ErrorResponse()`.


**Attributes:**

|Name                                   |Type                                         |Description                                   |
|---------------------------------------|---------------------------------------------|----------------------------------------------|
|user_id                                |str                                          |userId                                        |
|announcement_file_type                 |str                                          |announcementFileType *Optional*               |
|include_announcement_table             |bool                                         |includeAnnouncementTable                      |
|response_size_limit                    |int                                          |responseSizeLimit *Optional*                  |
|search_criteria_announcement_file_name |List[OCI.searchCriteriaAnnouncementFileName] |searchCriteriaAnnouncementFileName *Optional* |
</div>


## `UserAnnouncementFileGetPagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of announcement files for a user.

If the responsePagingControl element is not provided, the paging startIndex will be
set to 1 by default, and the responsePageSize will be set to the maximum
responsePageSize by default.  If no sortOrder is provided, the response is sorted by
Name ascending by default.  Multiple search criteria are logically ANDed together
unless the searchCriteriaModeOr option is included.  Then the search criteria are
logically ORed together.

The response is either a `UserAnnouncementFileGetPagedSortedListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                         |Type                                         |Description                                        |
|---------------------------------------------|---------------------------------------------|---------------------------------------------------|
|user_id                                      |str                                          |userId                                             |
|response_paging_control                      |OCI.responsePagingControl                    |responsePagingControl *Optional*                   |
|sort_by_announcement_file_name               |OCI.sortByAnnouncementFileName               |sortByAnnouncementFileName *Optional*              |
|sort_by_announcement_file_size               |OCI.sortByAnnouncementFileSize               |sortByAnnouncementFileSize *Optional*              |
|search_criteria_announcement_file_name       |List[OCI.searchCriteriaAnnouncementFileName] |searchCriteriaAnnouncementFileName *Optional*      |
|search_criteria_exact_announcement_file_type |OCI.searchCriteriaExactAnnouncementFileType  |searchCriteriaExactAnnouncementFileType *Optional* |
|search_criteria_exact_media_file_type        |List[OCI.searchCriteriaExactMediaFileType]   |searchCriteriaExactMediaFileType *Optional*        |
|search_criteria_mode_or                      |bool                                         |searchCriteriaModeOr *Optional*                    |
</div>


## `UserBroadWorksAnywhereGetPhoneNumberPagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of all the BroadWorks Anywhere phone numbers for the user.

If no sortOrder is included the response is sorted by Phone Number ascending by
default.

The response is either a
`UserBroadWorksAnywhereGetPhoneNumberPagedSortedListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                   |Type                                   |Description                                   |
|---------------------------------------|---------------------------------------|----------------------------------------------|
|user_id                                |str                                    |userId                                        |
|response_paging_control                |OCI.responsePagingControl              |responsePagingControl *Optional*              |
|sort_by_location                       |OCI.sortByLocation                     |sortByLocation *Optional*                     |
|sort_by_enabled                        |OCI.sortByEnabled                      |sortByEnabled *Optional*                      |
|search_criteria_location               |List[OCI.searchCriteriaLocation]       |searchCriteriaLocation *Optional*             |
|search_criteria_exact_location_enabled |OCI.searchCriteriaExactLocationEnabled |searchCriteriaExactLocationEnabled *Optional* |
</div>


## `UserBroadWorksAnywhereModifySelectiveCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify selective criteria for the user's BroadWorks Anywhere phone number.

The following elements are only used in AS data mode: callToNumbers For the
callToNumbers in the callToNumberList, the extension element is not used and the
number element is only used when the type is BroadWorks Mobility.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type                 |Description                 |
|--------------------|---------------------|----------------------------|
|user_id             |str                  |userId                      |
|phone_number        |str                  |phoneNumber                 |
|criteria_name       |str                  |criteriaName                |
|new_criteria_name   |str                  |newCriteriaName *Optional*  |
|time_schedule       |OCI.timeSchedule     |timeSchedule *Optional*     |
|from_dn_criteria    |OCI.fromDnCriteria   |fromDnCriteria *Optional*   |
|holiday_schedule    |OCI.holidaySchedule  |holidaySchedule *Optional*  |
|blacklisted         |bool                 |blacklisted *Optional*      |
|call_to_number_list |OCI.callToNumberList |callToNumberList *Optional* |
</div>


## `UserBroadWorksMobilityMobileIdentityAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a mobile identity to the user's list of mobile identities.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The request
fails when the devicesToRing is set to Mobile and the mobileNumberAlerted list is
empty.  Replaced by: `UserBroadWorksMobilityMobileIdentityAddRequest21sp1()`.

**Attributes:**

|Name                           |Type                |Description                    |
|-------------------------------|--------------------|-------------------------------|
|user_id                        |str                 |userId                         |
|mobile_number                  |str                 |mobileNumber                   |
|description                    |str                 |description *Optional*         |
|is_primary                     |bool                |isPrimary                      |
|enable_alerting                |bool                |enableAlerting                 |
|alert_agent_calls              |bool                |alertAgentCalls                |
|alert_click_to_dial_calls      |bool                |alertClickToDialCalls          |
|alert_group_paging_calls       |bool                |alertGroupPagingCalls          |
|use_mobility_calling_line_id   |bool                |useMobilityCallingLineID       |
|enable_diversion_inhibitor     |bool                |enableDiversionInhibitor       |
|require_answer_confirmation    |bool                |requireAnswerConfirmation      |
|broadworks_call_control        |bool                |broadworksCallControl          |
|use_setting_level              |str                 |useSettingLevel                |
|deny_call_originations         |bool                |denyCallOriginations           |
|deny_call_terminations         |bool                |denyCallTerminations           |
|devices_to_ring                |str                 |devicesToRing                  |
|include_shared_call_appearance |bool                |includeSharedCallAppearance    |
|include_broadworks_anywhere    |bool                |includeBroadworksAnywhere      |
|include_executive_assistant    |bool                |includeExecutiveAssistant      |
|mobile_number_alerted          |List[str]           |mobileNumberAlerted *Optional* |
|enable_call_anchoring          |bool                |enableCallAnchoring            |
|time_schedule                  |OCI.timeSchedule    |timeSchedule *Optional*        |
|holiday_schedule               |OCI.holidaySchedule |holidaySchedule *Optional*     |
</div>


## `UserBroadWorksMobilityMobileIdentityAddRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a mobile identity to the user's list of mobile identities.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The request
fails when the devicesToRing is set to Mobile and the mobileNumberAlerted list is
empty.  Replaced by: `UserBroadWorksMobilityMobileIdentityAddRequest22()`.

**Attributes:**

|Name                               |Type                     |Description                        |
|-----------------------------------|-------------------------|-----------------------------------|
|user_id                            |str                      |userId                             |
|mobile_number                      |str                      |mobileNumber                       |
|description                        |str                      |description *Optional*             |
|is_primary                         |bool                     |isPrimary                          |
|enable_alerting                    |bool                     |enableAlerting                     |
|alert_agent_calls                  |bool                     |alertAgentCalls                    |
|alert_click_to_dial_calls          |bool                     |alertClickToDialCalls              |
|alert_group_paging_calls           |bool                     |alertGroupPagingCalls              |
|use_mobility_calling_line_id       |bool                     |useMobilityCallingLineID           |
|enable_diversion_inhibitor         |bool                     |enableDiversionInhibitor           |
|require_answer_confirmation        |bool                     |requireAnswerConfirmation          |
|broadworks_call_control            |bool                     |broadworksCallControl              |
|use_setting_level                  |str                      |useSettingLevel                    |
|deny_call_originations             |bool                     |denyCallOriginations               |
|deny_call_terminations             |bool                     |denyCallTerminations               |
|devices_to_ring                    |str                      |devicesToRing                      |
|include_shared_call_appearance     |bool                     |includeSharedCallAppearance        |
|include_broadworks_anywhere        |bool                     |includeBroadworksAnywhere          |
|include_executive_assistant        |bool                     |includeExecutiveAssistant          |
|mobile_number_alerted              |List[str]                |mobileNumberAlerted *Optional*     |
|enable_call_anchoring              |bool                     |enableCallAnchoring                |
|time_schedule                      |OCI.timeSchedule         |timeSchedule *Optional*            |
|holiday_schedule                   |OCI.holidaySchedule      |holidaySchedule *Optional*         |
|access_device_endpoint             |OCI.accessDeviceEndpoint |accessDeviceEndpoint *Optional*    |
|outbound_alternate_number          |str                      |outboundAlternateNumber *Optional* |
|enable_direct_routing              |bool                     |enableDirectRouting                |
|mark_cdr_as_enterprise_group_calls |bool                     |markCDRAsEnterpriseGroupCalls      |
</div>


## `UserBroadWorksMobilityMobileIdentityAddRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a mobile identity to the user's list of mobile identities.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The request
fails when the devicesToRing is set to Mobile and the mobileNumberAlerted list is
empty.

Replaced By: `UserBroadWorksMobilityMobileIdentityAddRequest22V2()`

**Attributes:**

|Name                               |Type                     |Description                        |
|-----------------------------------|-------------------------|-----------------------------------|
|user_id                            |str                      |userId                             |
|mobile_number                      |str                      |mobileNumber                       |
|description                        |str                      |description *Optional*             |
|is_primary                         |bool                     |isPrimary                          |
|enable_alerting                    |bool                     |enableAlerting                     |
|alert_agent_calls                  |bool                     |alertAgentCalls                    |
|alert_click_to_dial_calls          |bool                     |alertClickToDialCalls              |
|alert_group_paging_calls           |bool                     |alertGroupPagingCalls              |
|use_mobility_calling_line_id       |bool                     |useMobilityCallingLineID           |
|enable_diversion_inhibitor         |bool                     |enableDiversionInhibitor           |
|require_answer_confirmation        |bool                     |requireAnswerConfirmation          |
|broadworks_call_control            |bool                     |broadworksCallControl              |
|use_setting_level                  |str                      |useSettingLevel                    |
|deny_call_originations             |bool                     |denyCallOriginations               |
|deny_call_terminations             |bool                     |denyCallTerminations               |
|devices_to_ring                    |str                      |devicesToRing                      |
|include_shared_call_appearance     |bool                     |includeSharedCallAppearance        |
|include_broadworks_anywhere        |bool                     |includeBroadworksAnywhere          |
|include_executive_assistant        |bool                     |includeExecutiveAssistant          |
|mobile_number_alerted              |List[str]                |mobileNumberAlerted *Optional*     |
|enable_call_anchoring              |bool                     |enableCallAnchoring                |
|time_schedule                      |OCI.timeSchedule         |timeSchedule *Optional*            |
|holiday_schedule                   |OCI.holidaySchedule      |holidaySchedule *Optional*         |
|access_device_endpoint             |OCI.accessDeviceEndpoint |accessDeviceEndpoint *Optional*    |
|outbound_alternate_number          |str                      |outboundAlternateNumber *Optional* |
|enable_direct_routing              |bool                     |enableDirectRouting                |
|mark_cdr_as_enterprise_group_calls |bool                     |markCDRAsEnterpriseGroupCalls      |
|use_mobility_connected_identity    |bool                     |useMobilityConnectedIdentity       |
|network_translation_index          |str                      |networkTranslationIndex *Optional* |
</div>


## `UserBroadWorksMobilityMobileIdentityAddRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a mobile identity to the user's list of mobile identities.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The request
fails when the devicesToRing is set to Mobile and the mobileNumberAlerted list is
empty.

**Attributes:**

|Name                               |Type                     |Description                        |
|-----------------------------------|-------------------------|-----------------------------------|
|user_id                            |str                      |userId                             |
|mobile_number                      |str                      |mobileNumber                       |
|description                        |str                      |description *Optional*             |
|is_primary                         |bool                     |isPrimary                          |
|enable_alerting                    |bool                     |enableAlerting                     |
|alert_agent_calls                  |bool                     |alertAgentCalls                    |
|alert_click_to_dial_calls          |bool                     |alertClickToDialCalls              |
|alert_group_paging_calls           |bool                     |alertGroupPagingCalls              |
|use_mobility_calling_line_id       |bool                     |useMobilityCallingLineID           |
|enable_diversion_inhibitor         |bool                     |enableDiversionInhibitor           |
|require_answer_confirmation        |bool                     |requireAnswerConfirmation          |
|broadworks_call_control            |bool                     |broadworksCallControl              |
|use_setting_level                  |str                      |useSettingLevel                    |
|deny_call_originations             |bool                     |denyCallOriginations               |
|deny_call_terminations             |bool                     |denyCallTerminations               |
|devices_to_ring                    |str                      |devicesToRing                      |
|include_shared_call_appearance     |bool                     |includeSharedCallAppearance        |
|include_broadworks_anywhere        |bool                     |includeBroadworksAnywhere          |
|include_executive_assistant        |bool                     |includeExecutiveAssistant          |
|mobile_number_alerted              |List[str]                |mobileNumberAlerted *Optional*     |
|enable_call_anchoring              |bool                     |enableCallAnchoring                |
|time_schedule                      |OCI.timeSchedule         |timeSchedule *Optional*            |
|holiday_schedule                   |OCI.holidaySchedule      |holidaySchedule *Optional*         |
|access_device_endpoint             |OCI.accessDeviceEndpoint |accessDeviceEndpoint *Optional*    |
|outbound_alternate_number          |str                      |outboundAlternateNumber *Optional* |
|enable_direct_routing              |bool                     |enableDirectRouting                |
|mark_cdr_as_enterprise_group_calls |bool                     |markCDRAsEnterpriseGroupCalls      |
|use_mobility_connected_identity    |bool                     |useMobilityConnectedIdentity       |
|network_translation_index          |str                      |networkTranslationIndex *Optional* |
</div>


## `UserBroadWorksMobilityMobileIdentityConsolidatedAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a mobile identity to the user's list of mobile identities.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The request
fails when the devicesToRing is set to Mobile and the mobileNumberAlerted list is
empty.

Replaced By: `UserBroadWorksMobilityMobileIdentityConsolidatedAddRequest22()`

**Attributes:**

|Name                               |Type                     |Description                        |
|-----------------------------------|-------------------------|-----------------------------------|
|user_id                            |str                      |userId                             |
|mobile_number                      |str                      |mobileNumber                       |
|description                        |str                      |description *Optional*             |
|is_primary                         |bool                     |isPrimary                          |
|enable_alerting                    |bool                     |enableAlerting                     |
|alert_agent_calls                  |bool                     |alertAgentCalls                    |
|alert_click_to_dial_calls          |bool                     |alertClickToDialCalls              |
|alert_group_paging_calls           |bool                     |alertGroupPagingCalls              |
|use_mobility_calling_line_id       |bool                     |useMobilityCallingLineID           |
|enable_diversion_inhibitor         |bool                     |enableDiversionInhibitor           |
|require_answer_confirmation        |bool                     |requireAnswerConfirmation          |
|broadworks_call_control            |bool                     |broadworksCallControl              |
|use_setting_level                  |str                      |useSettingLevel                    |
|deny_call_originations             |bool                     |denyCallOriginations               |
|deny_call_terminations             |bool                     |denyCallTerminations               |
|devices_to_ring                    |str                      |devicesToRing                      |
|include_shared_call_appearance     |bool                     |includeSharedCallAppearance        |
|include_broadworks_anywhere        |bool                     |includeBroadworksAnywhere          |
|include_executive_assistant        |bool                     |includeExecutiveAssistant          |
|mobile_number_alerted              |List[str]                |mobileNumberAlerted *Optional*     |
|enable_call_anchoring              |bool                     |enableCallAnchoring                |
|time_schedule                      |OCI.timeSchedule         |timeSchedule *Optional*            |
|holiday_schedule                   |OCI.holidaySchedule      |holidaySchedule *Optional*         |
|access_device_endpoint             |OCI.accessDeviceEndpoint |accessDeviceEndpoint *Optional*    |
|outbound_alternate_number          |str                      |outboundAlternateNumber *Optional* |
|enable_direct_routing              |bool                     |enableDirectRouting                |
|mark_cdr_as_enterprise_group_calls |bool                     |markCDRAsEnterpriseGroupCalls      |
</div>


## `UserBroadWorksMobilityMobileIdentityConsolidatedAddRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a mobile identity to the user's list of mobile identities.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The request
fails when the devicesToRing is set to Mobile and the mobileNumberAlerted list is
empty.

**Attributes:**

|Name                               |Type                     |Description                        |
|-----------------------------------|-------------------------|-----------------------------------|
|user_id                            |str                      |userId                             |
|mobile_number                      |str                      |mobileNumber                       |
|description                        |str                      |description *Optional*             |
|is_primary                         |bool                     |isPrimary                          |
|enable_alerting                    |bool                     |enableAlerting                     |
|alert_agent_calls                  |bool                     |alertAgentCalls                    |
|alert_click_to_dial_calls          |bool                     |alertClickToDialCalls              |
|alert_group_paging_calls           |bool                     |alertGroupPagingCalls              |
|use_mobility_calling_line_id       |bool                     |useMobilityCallingLineID           |
|enable_diversion_inhibitor         |bool                     |enableDiversionInhibitor           |
|require_answer_confirmation        |bool                     |requireAnswerConfirmation          |
|broadworks_call_control            |bool                     |broadworksCallControl              |
|use_setting_level                  |str                      |useSettingLevel                    |
|deny_call_originations             |bool                     |denyCallOriginations               |
|deny_call_terminations             |bool                     |denyCallTerminations               |
|devices_to_ring                    |str                      |devicesToRing                      |
|include_shared_call_appearance     |bool                     |includeSharedCallAppearance        |
|include_broadworks_anywhere        |bool                     |includeBroadworksAnywhere          |
|include_executive_assistant        |bool                     |includeExecutiveAssistant          |
|mobile_number_alerted              |List[str]                |mobileNumberAlerted *Optional*     |
|enable_call_anchoring              |bool                     |enableCallAnchoring                |
|time_schedule                      |OCI.timeSchedule         |timeSchedule *Optional*            |
|holiday_schedule                   |OCI.holidaySchedule      |holidaySchedule *Optional*         |
|access_device_endpoint             |OCI.accessDeviceEndpoint |accessDeviceEndpoint *Optional*    |
|outbound_alternate_number          |str                      |outboundAlternateNumber *Optional* |
|enable_direct_routing              |bool                     |enableDirectRouting                |
|mark_cdr_as_enterprise_group_calls |bool                     |markCDRAsEnterpriseGroupCalls      |
</div>


## `UserBroadWorksMobilityMobileIdentityConsolidatedModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the settings for one of the user's BroadWorks Mobility mobile Identities.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. If
deleteExistingDevices is set to true, when the devices for the endpoint are changed,
devices with no more endpoint will be deleted if the command is executed with the
correct privilege.  The request fails when enableAlerting or timeSchedule or
holidaySchedule are included in the request when the use mobile identity call
anchoring controls for the user is disabled.  The description, enableAlerting,
alertAgentCalls, alertClickToDialCalls, alertGroupPagingCalls,
useMobilityCallingLineID, enableDiversionInhibitor, requireAnswerConfirmation,
broadworksCallControl, devicesToRing, includeSharedCallAppearance,
includeBroadworksAnywhere, includeExecutiveAssistance, mobileNumberAlerted,
enableCallAnchoring, timeSchedule and holidaySchedule parameters require an
authorization level of User for modification when the BroadWorks Mobility service is
on.  The isPrimary, useSettingLevel, denyCallOrigination, denyCallTerminations,
accessDeviceEndpoint, outboundAlternateNumber, enableDirectRouting,
markCDRAsEnterpriseGroupCalls and networkTranslationIndex parameters require an
authorization level of Group for modification.

**Attributes:**

|Name                               |Type                     |Description                              |
|-----------------------------------|-------------------------|-----------------------------------------|
|user_id                            |str                      |userId                                   |
|mobile_number                      |str                      |mobileNumber                             |
|delete_existing_devices            |bool                     |deleteExistingDevices *Optional*         |
|description                        |str                      |description *Optional*                   |
|is_primary                         |bool                     |isPrimary *Optional*                     |
|enable_alerting                    |bool                     |enableAlerting *Optional*                |
|alert_agent_calls                  |bool                     |alertAgentCalls *Optional*               |
|alert_click_to_dial_calls          |bool                     |alertClickToDialCalls *Optional*         |
|alert_group_paging_calls           |bool                     |alertGroupPagingCalls *Optional*         |
|use_mobility_calling_line_id       |bool                     |useMobilityCallingLineID *Optional*      |
|enable_diversion_inhibitor         |bool                     |enableDiversionInhibitor *Optional*      |
|require_answer_confirmation        |bool                     |requireAnswerConfirmation *Optional*     |
|broadworks_call_control            |bool                     |broadworksCallControl *Optional*         |
|use_setting_level                  |str                      |useSettingLevel *Optional*               |
|deny_call_originations             |bool                     |denyCallOriginations *Optional*          |
|deny_call_terminations             |bool                     |denyCallTerminations *Optional*          |
|devices_to_ring                    |str                      |devicesToRing *Optional*                 |
|include_shared_call_appearance     |bool                     |includeSharedCallAppearance *Optional*   |
|include_broadworks_anywhere        |bool                     |includeBroadworksAnywhere *Optional*     |
|include_executive_assistant        |bool                     |includeExecutiveAssistant *Optional*     |
|mobile_numbers_alerted             |OCI.mobileNumbersAlerted |mobileNumbersAlerted *Optional*          |
|enable_call_anchoring              |bool                     |enableCallAnchoring *Optional*           |
|time_schedule                      |OCI.timeSchedule         |timeSchedule *Optional*                  |
|holiday_schedule                   |OCI.holidaySchedule      |holidaySchedule *Optional*               |
|access_device_endpoint             |OCI.accessDeviceEndpoint |accessDeviceEndpoint *Optional*          |
|outbound_alternate_number          |str                      |outboundAlternateNumber *Optional*       |
|enable_direct_routing              |bool                     |enableDirectRouting *Optional*           |
|mark_cdr_as_enterprise_group_calls |bool                     |markCDRAsEnterpriseGroupCalls *Optional* |
|use_mobility_connected_identity    |bool                     |useMobilityConnectedIdentity *Optional*  |
|network_translation_index          |str                      |networkTranslationIndex *Optional*       |
</div>


## `UserBroadWorksMobilityMobileIdentityModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the settings for one of the user's BroadWorks Mobility mobile Identities.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The request
fails when enableAlerting or timeSchedule or holidaySchedule are included in the
request when the user's use mobile identity call anchoring controls is disabled.  The
description, enableAlerting, alertAgentCalls, alertClickToDialCalls,
alertGroupPagingCalls, useMobilityCallingLineID, enableDiversionInhibitor,
requireAnswerConfirmation, broadworksCallControl, devicesToRing,
includeSharedCallAppearance, includeBroadworksAnywhere, includeExecutiveAssistance,
mobileNumberAlerted, enableCallAnchoring, timeSchedule, holidaySchedule and
useMobilityConnectedIdentity parameters require an authorization level of User for
modification when the BroadWorks Mobility service is on.  The isPrimary,
useSettingLevel, denyCallOrigination, denyCallTerminations, accessDeviceEndpoint,
outboundAlternateNumber, enableDirectRouting, markCDRAsEnterpriseGroupCalls and
networkTranslationIndex parameters require an authorization level of Group for
modification.

**Attributes:**

|Name                               |Type                     |Description                              |
|-----------------------------------|-------------------------|-----------------------------------------|
|user_id                            |str                      |userId                                   |
|mobile_number                      |str                      |mobileNumber                             |
|description                        |str                      |description *Optional*                   |
|is_primary                         |bool                     |isPrimary *Optional*                     |
|enable_alerting                    |bool                     |enableAlerting *Optional*                |
|alert_agent_calls                  |bool                     |alertAgentCalls *Optional*               |
|alert_click_to_dial_calls          |bool                     |alertClickToDialCalls *Optional*         |
|alert_group_paging_calls           |bool                     |alertGroupPagingCalls *Optional*         |
|use_mobility_calling_line_id       |bool                     |useMobilityCallingLineID *Optional*      |
|enable_diversion_inhibitor         |bool                     |enableDiversionInhibitor *Optional*      |
|require_answer_confirmation        |bool                     |requireAnswerConfirmation *Optional*     |
|broadworks_call_control            |bool                     |broadworksCallControl *Optional*         |
|use_setting_level                  |str                      |useSettingLevel *Optional*               |
|deny_call_originations             |bool                     |denyCallOriginations *Optional*          |
|deny_call_terminations             |bool                     |denyCallTerminations *Optional*          |
|devices_to_ring                    |str                      |devicesToRing *Optional*                 |
|include_shared_call_appearance     |bool                     |includeSharedCallAppearance *Optional*   |
|include_broadworks_anywhere        |bool                     |includeBroadworksAnywhere *Optional*     |
|include_executive_assistant        |bool                     |includeExecutiveAssistant *Optional*     |
|mobile_numbers_alerted             |OCI.mobileNumbersAlerted |mobileNumbersAlerted *Optional*          |
|enable_call_anchoring              |bool                     |enableCallAnchoring *Optional*           |
|time_schedule                      |OCI.timeSchedule         |timeSchedule *Optional*                  |
|holiday_schedule                   |OCI.holidaySchedule      |holidaySchedule *Optional*               |
|access_device_endpoint             |OCI.accessDeviceEndpoint |accessDeviceEndpoint *Optional*          |
|outbound_alternate_number          |str                      |outboundAlternateNumber *Optional*       |
|enable_direct_routing              |bool                     |enableDirectRouting *Optional*           |
|mark_cdr_as_enterprise_group_calls |bool                     |markCDRAsEnterpriseGroupCalls *Optional* |
|use_mobility_connected_identity    |bool                     |useMobilityConnectedIdentity *Optional*  |
|network_translation_index          |str                      |networkTranslationIndex *Optional*       |
</div>


## `UserBroadWorksReceptionistEnterpriseGetAvailableUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of available users for BroadWorks Receptionist - Enterprise monitoring.

The response is either
`UserBroadWorksReceptionistEnterpriseGetAvailableUserListResponse()` or
`ErrorResponse()`. The Receptionist Note column is only populated, if the user sending
the request is the owner of the Receptionist Note and a Note exists.

**Attributes:**

|Name                                  |Type                                     |Description                                  |
|--------------------------------------|-----------------------------------------|---------------------------------------------|
|user_id                               |str                                      |userId                                       |
|response_size_limit                   |int                                      |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]     |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName]    |searchCriteriaUserFirstName *Optional*       |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment    |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_exact_user_group      |OCI.searchCriteriaExactUserGroup         |searchCriteriaExactUserGroup *Optional*      |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]           |searchCriteriaUserId *Optional*              |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]               |searchCriteriaDn *Optional*                  |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]        |searchCriteriaExtension *Optional*           |
|search_criteria_imp_id                |List[OCI.searchCriteriaImpId]            |searchCriteriaImpId *Optional*               |
|search_criteria_receptionist_note     |List[OCI.searchCriteriaReceptionistNote] |searchCriteriaReceptionistNote *Optional*    |
</div>


## `UserBroadWorksReceptionistEnterpriseNoteModifyListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a list of notes for an existing Receptionist user.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. If some of the
users add and some users fail to add, then the response will contain a
`WarningResponse()` containing only the a comma delimited list of users that failed to
add.  If the user sending the request is the not the owner of the Receptionist Note,
then an `ErrorResponse()` will be returned.

**Attributes:**

|Name                       |Type                              |Description             |
|---------------------------|----------------------------------|------------------------|
|receptionist_user_id       |str                               |receptionistUserId      |
|receptionist_user_and_note |List[OCI.receptionistUserAndNote] |receptionistUserAndNote |
</div>


## `UserBroadWorksReceptionistOfficeGetAvailableUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the Receptionist Office available user list.

The response is either
`UserBroadWorksReceptionistOfficeGetAvailableUserListResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|user_id                               |str                                   |userId                                       |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*              |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                  |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*           |
|search_criteria_imp_id                |List[OCI.searchCriteriaImpId]         |searchCriteriaImpId *Optional*               |
</div>


## `UserBroadWorksReceptionistSmallBusinessGetAvailableUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of available users for the Receptionist Small Business service.

The response is either
`UserBroadWorksReceptionistSmallBusinessGetAvailableUserListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|user_id                               |str                                   |userId                                       |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_exact_user_group      |OCI.searchCriteriaExactUserGroup      |searchCriteriaExactUserGroup *Optional*      |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*              |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                  |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*           |
|search_criteria_imp_id                |List[OCI.searchCriteriaImpId]         |searchCriteriaImpId *Optional*               |
</div>


## `UserBroadworksMobilityAddMobileIdentityUsingSharedCallAppearanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Adding a new mobile identity using the Share Call Appearance.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The request
fails when the devicesToRing is set to Mobile and the mobileNumberAlerted list is
empty.

**Attributes:**

|Name                               |Type                     |Description                    |
|-----------------------------------|-------------------------|-------------------------------|
|user_id                            |str                      |userId                         |
|access_device_endpoint             |OCI.accessDeviceEndpoint |accessDeviceEndpoint           |
|mobile_number                      |str                      |mobileNumber                   |
|description                        |str                      |description *Optional*         |
|is_primary                         |bool                     |isPrimary                      |
|enable_alerting                    |bool                     |enableAlerting                 |
|alert_agent_calls                  |bool                     |alertAgentCalls                |
|alert_click_to_dial_calls          |bool                     |alertClickToDialCalls          |
|alert_group_paging_calls           |bool                     |alertGroupPagingCalls          |
|use_mobility_calling_line_id       |bool                     |useMobilityCallingLineID       |
|enable_diversion_inhibitor         |bool                     |enableDiversionInhibitor       |
|require_answer_confirmation        |bool                     |requireAnswerConfirmation      |
|broadworks_call_control            |bool                     |broadworksCallControl          |
|use_setting_level                  |str                      |useSettingLevel                |
|deny_call_originations             |bool                     |denyCallOriginations           |
|deny_call_terminations             |bool                     |denyCallTerminations           |
|devices_to_ring                    |str                      |devicesToRing                  |
|include_shared_call_appearance     |bool                     |includeSharedCallAppearance    |
|include_broadworks_anywhere        |bool                     |includeBroadworksAnywhere      |
|include_executive_assistant        |bool                     |includeExecutiveAssistant      |
|mobile_number_alerted              |List[str]                |mobileNumberAlerted *Optional* |
|enable_call_anchoring              |bool                     |enableCallAnchoring            |
|time_schedule                      |OCI.timeSchedule         |timeSchedule *Optional*        |
|holiday_schedule                   |OCI.holidaySchedule      |holidaySchedule *Optional*     |
|enable_direct_routing              |bool                     |enableDirectRouting            |
|mark_cdr_as_enterprise_group_calls |bool                     |markCDRAsEnterpriseGroupCalls  |
</div>


## `UserBroadworksMobilityAddMobileIdentityUsingSharedCallAppearanceRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Adding a new mobile identity using the Share Call Appearance.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode: useHotline, use
value false in XS data mode hotlineContact The request fails when the devicesToRing is
set to Mobile and the mobileNumberAlerted list is empty.

**Attributes:**

|Name                               |Type                     |Description                    |
|-----------------------------------|-------------------------|-------------------------------|
|user_id                            |str                      |userId                         |
|access_device_endpoint             |OCI.accessDeviceEndpoint |accessDeviceEndpoint           |
|mobile_number                      |str                      |mobileNumber                   |
|description                        |str                      |description *Optional*         |
|is_primary                         |bool                     |isPrimary                      |
|enable_alerting                    |bool                     |enableAlerting                 |
|alert_agent_calls                  |bool                     |alertAgentCalls                |
|alert_click_to_dial_calls          |bool                     |alertClickToDialCalls          |
|alert_group_paging_calls           |bool                     |alertGroupPagingCalls          |
|use_mobility_calling_line_id       |bool                     |useMobilityCallingLineID       |
|enable_diversion_inhibitor         |bool                     |enableDiversionInhibitor       |
|require_answer_confirmation        |bool                     |requireAnswerConfirmation      |
|broadworks_call_control            |bool                     |broadworksCallControl          |
|use_setting_level                  |str                      |useSettingLevel                |
|deny_call_originations             |bool                     |denyCallOriginations           |
|deny_call_terminations             |bool                     |denyCallTerminations           |
|devices_to_ring                    |str                      |devicesToRing                  |
|include_shared_call_appearance     |bool                     |includeSharedCallAppearance    |
|include_broadworks_anywhere        |bool                     |includeBroadworksAnywhere      |
|include_executive_assistant        |bool                     |includeExecutiveAssistant      |
|mobile_number_alerted              |List[str]                |mobileNumberAlerted *Optional* |
|enable_call_anchoring              |bool                     |enableCallAnchoring            |
|time_schedule                      |OCI.timeSchedule         |timeSchedule *Optional*        |
|holiday_schedule                   |OCI.holidaySchedule      |holidaySchedule *Optional*     |
|enable_direct_routing              |bool                     |enableDirectRouting            |
|mark_cdr_as_enterprise_group_calls |bool                     |markCDRAsEnterpriseGroupCalls  |
|use_hotline                        |bool                     |useHotline                     |
|hotline_contact                    |str                      |hotlineContact *Optional*      |
</div>


## `UserBusyLampFieldGetAvailableUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of available users for the busy lamp field service.

The response is either `UserBusyLampFieldGetAvailableUserListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|user_id                               |str                                   |userId                                       |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_exact_user_group      |OCI.searchCriteriaExactUserGroup      |searchCriteriaExactUserGroup *Optional*      |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*              |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                  |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*           |
|search_criteria_imp_id                |List[OCI.searchCriteriaImpId]         |searchCriteriaImpId *Optional*               |
</div>


## `UserCallCenterGetAvailableCallCenterPagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
This request gets a list of all call centers which the user can be assigned to as an
agent.

Some of the call centers may already have the user as an agent.  It is the clients
responsibility to discard the call centers that the user is already an agent of.  If
the responsePagingControl element is not provided, the paging startIndex will be set
to 1 by default, and the responsePageSize will be set to the maximum ResponsePageSize
by default.  It is possible to search by various criteria to restrict the number of
rows returned.  Multiple search criteria are logically ANDed together unless the
searchCriteriaModeOr option is included.  Then the search criteria are logically ORed
together.

The response is either a
`UserCallCenterGetAvailableCallCenterPagedSortedListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                    |Type                           |Description                      |
|------------------------|-------------------------------|---------------------------------|
|user_id                 |str                            |userId                           |
|response_paging_control |OCI.responsePagingControl      |responsePagingControl *Optional* |
|sort_by_user_id         |OCI.sortByUserId               |sortByUserId *Optional*          |
|search_criteria_user_id |List[OCI.searchCriteriaUserId] |searchCriteriaUserId *Optional*  |
|search_criteria_mode_or |bool                           |searchCriteriaModeOr *Optional*  |
</div>


## `UserCallCenterGetSupervisedAgentListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of agents supervised by a supervisor on a given call center.

The response is either a `UserCallCenterGetSupervisedAgentListResponse()` or an
`ErrorResponse()`. The search can be done using multiple criterias.  If the
searchCriteriaModeOr is present, any result matching any one criteria is included in
the results.  Otherwise, only results matching all the search criterias are included
in the results.  If no search criteria is specified, all results are returned.  In all
cases, if a responseSizeLimit is specified and the number of matching results is more
than this limit, then an `ErrorResponse()` is returned.  Specifying
searchCriteriaModeOr without any search criteria results in an `ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|supervisor_user_id                    |str                                   |supervisorUserId                             |
|service_user_id                       |str                                   |serviceUserId                                |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_mode_or               |bool                                  |searchCriteriaModeOr *Optional*              |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                  |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*           |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*              |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_imp_id                |List[OCI.searchCriteriaImpId]         |searchCriteriaImpId *Optional*               |
</div>


## `UserCallForwardingSelectiveModifyCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a criteria for the user's call forwarding selective service.

The following elements are only used in AS data mode: callToNumber For the
callToNumbers in the callToNumberList, the extension element is not used and the
number element is only used when the type is BroadWorks Mobility.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                        |Type                 |Description                         |
|----------------------------|---------------------|------------------------------------|
|user_id                     |str                  |userId                              |
|criteria_name               |str                  |criteriaName                        |
|new_criteria_name           |str                  |newCriteriaName *Optional*          |
|time_schedule               |OCI.timeSchedule     |timeSchedule *Optional*             |
|holiday_schedule            |OCI.holidaySchedule  |holidaySchedule *Optional*          |
|forward_to_number_selection |str                  |forwardToNumberSelection *Optional* |
|forward_to_phone_number     |str                  |forwardToPhoneNumber *Optional*     |
|from_dn_criteria            |OCI.fromDnCriteria   |fromDnCriteria *Optional*           |
|call_to_number_list         |OCI.callToNumberList |callToNumberList *Optional*         |
</div>


## `UserCallMeNowModifyCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a criteria for the user's call me now service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name              |Type                |Description                |
|------------------|--------------------|---------------------------|
|user_id           |str                 |userId                     |
|criteria_name     |str                 |criteriaName               |
|new_criteria_name |str                 |newCriteriaName *Optional* |
|time_schedule     |OCI.timeSchedule    |timeSchedule *Optional*    |
|holiday_schedule  |OCI.holidaySchedule |holidaySchedule *Optional* |
|reject_call       |bool                |rejectCall *Optional*      |
|to_dn_criteria    |OCI.toDnCriteria    |toDnCriteria *Optional*    |
</div>


## `UserCallNotifyModifyCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a criteria for the user's call notify service.

The following elements are only used in AS data mode: callToNumber For the
callToNumbers in the callToNumberList, the extension element is not used and the
number element is only used when the type is BroadWorks Mobility.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type                 |Description                 |
|--------------------|---------------------|----------------------------|
|user_id             |str                  |userId                      |
|criteria_name       |str                  |criteriaName                |
|new_criteria_name   |str                  |newCriteriaName *Optional*  |
|time_schedule       |OCI.timeSchedule     |timeSchedule *Optional*     |
|from_dn_criteria    |OCI.fromDnCriteria   |fromDnCriteria *Optional*   |
|holiday_schedule    |OCI.holidaySchedule  |holidaySchedule *Optional*  |
|blacklisted         |bool                 |blacklisted *Optional*      |
|call_to_number_list |OCI.callToNumberList |callToNumberList *Optional* |
</div>


## `UserCommPilotExpressModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's commPilot express service setting.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Engineering
Note: This command is used internally by Call Processing.

**Attributes:**

|Name                    |Type                     |Description                     |
|------------------------|-------------------------|--------------------------------|
|user_id                 |str                      |userId                          |
|profile                 |str                      |profile *Optional*              |
|available_in_office     |OCI.availableInOffice    |availableInOffice *Optional*    |
|available_out_of_office |OCI.availableOutOfOffice |availableOutOfOffice *Optional* |
|busy                    |OCI.busy                 |busy *Optional*                 |
|unavailable             |OCI.unavailable          |unavailable *Optional*          |
</div>


## `UserCustomRingbackUserAddCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a criteria to the user's custom ringback service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                         |Type                     |Description                          |
|-----------------------------|-------------------------|-------------------------------------|
|user_id                      |str                      |userId                               |
|criteria_name                |str                      |criteriaName                         |
|time_schedule                |OCI.timeSchedule         |timeSchedule *Optional*              |
|from_dn_criteria             |OCI.fromDnCriteria       |fromDnCriteria                       |
|audio_selection              |str                      |audioSelection                       |
|audio_file                   |OCI.audioFile            |audioFile *Optional*                 |
|video_selection              |str                      |videoSelection                       |
|video_file                   |OCI.videoFile            |videoFile *Optional*                 |
|call_waiting_audio_selection |str                      |callWaitingAudioSelection *Optional* |
|call_waiting_audio_file      |OCI.callWaitingAudioFile |callWaitingAudioFile *Optional*      |
|call_waiting_video_selection |str                      |callWaitingVideoSelection *Optional* |
|call_waiting_video_file      |OCI.callWaitingVideoFile |callWaitingVideoFile *Optional*      |
</div>


## `UserCustomRingbackUserAddCriteriaRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a criteria to the user's custom ringback service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                         |Type                     |Description                          |
|-----------------------------|-------------------------|-------------------------------------|
|user_id                      |str                      |userId                               |
|criteria_name                |str                      |criteriaName                         |
|time_schedule                |OCI.timeSchedule         |timeSchedule *Optional*              |
|holiday_schedule             |OCI.holidaySchedule      |holidaySchedule *Optional*           |
|blacklisted                  |bool                     |blacklisted                          |
|from_dn_criteria             |OCI.fromDnCriteria       |fromDnCriteria                       |
|audio_selection              |str                      |audioSelection                       |
|audio_file                   |OCI.audioFile            |audioFile *Optional*                 |
|video_selection              |str                      |videoSelection                       |
|video_file                   |OCI.videoFile            |videoFile *Optional*                 |
|call_waiting_audio_selection |str                      |callWaitingAudioSelection *Optional* |
|call_waiting_audio_file      |OCI.callWaitingAudioFile |callWaitingAudioFile *Optional*      |
|call_waiting_video_selection |str                      |callWaitingVideoSelection *Optional* |
|call_waiting_video_file      |OCI.callWaitingVideoFile |callWaitingVideoFile *Optional*      |
</div>


## `UserCustomRingbackUserAddCriteriaRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a criteria to the user's custom ringback service.

For the callToNumber, the extension element is not used and the number element is only
used when the type is BroadWorks Mobility.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                         |Type                     |Description                          |
|-----------------------------|-------------------------|-------------------------------------|
|user_id                      |str                      |userId                               |
|criteria_name                |str                      |criteriaName                         |
|time_schedule                |OCI.timeSchedule         |timeSchedule *Optional*              |
|holiday_schedule             |OCI.holidaySchedule      |holidaySchedule *Optional*           |
|blacklisted                  |bool                     |blacklisted                          |
|from_dn_criteria             |OCI.fromDnCriteria       |fromDnCriteria                       |
|call_to_number               |List[OCI.callToNumber]   |callToNumber *Optional*              |
|audio_selection              |str                      |audioSelection                       |
|audio_file                   |OCI.audioFile            |audioFile *Optional*                 |
|video_selection              |str                      |videoSelection                       |
|video_file                   |OCI.videoFile            |videoFile *Optional*                 |
|call_waiting_audio_selection |str                      |callWaitingAudioSelection *Optional* |
|call_waiting_audio_file      |OCI.callWaitingAudioFile |callWaitingAudioFile *Optional*      |
|call_waiting_video_selection |str                      |callWaitingVideoSelection *Optional* |
|call_waiting_video_file      |OCI.callWaitingVideoFile |callWaitingVideoFile *Optional*      |
</div>


## `UserCustomRingbackUserModifyCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a criteria for the user's custom ringback service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

Replaced By: `UserCustomRingbackUserModifyCriteriaRequest16()`

**Attributes:**

|Name                         |Type                     |Description                          |
|-----------------------------|-------------------------|-------------------------------------|
|user_id                      |str                      |userId                               |
|criteria_name                |str                      |criteriaName                         |
|new_criteria_name            |str                      |newCriteriaName *Optional*           |
|time_schedule                |OCI.timeSchedule         |timeSchedule *Optional*              |
|from_dn_criteria             |OCI.fromDnCriteria       |fromDnCriteria *Optional*            |
|audio_selection              |str                      |audioSelection *Optional*            |
|audio_file                   |OCI.audioFile            |audioFile *Optional*                 |
|video_selection              |str                      |videoSelection *Optional*            |
|video_file                   |OCI.videoFile            |videoFile *Optional*                 |
|call_waiting_audio_selection |str                      |callWaitingAudioSelection *Optional* |
|call_waiting_audio_file      |OCI.callWaitingAudioFile |callWaitingAudioFile *Optional*      |
|call_waiting_video_selection |str                      |callWaitingVideoSelection *Optional* |
|call_waiting_video_file      |OCI.callWaitingVideoFile |callWaitingVideoFile *Optional*      |
</div>


## `UserCustomRingbackUserModifyCriteriaRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a criteria for the user's custom ringback service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                         |Type                     |Description                          |
|-----------------------------|-------------------------|-------------------------------------|
|user_id                      |str                      |userId                               |
|criteria_name                |str                      |criteriaName                         |
|new_criteria_name            |str                      |newCriteriaName *Optional*           |
|time_schedule                |OCI.timeSchedule         |timeSchedule *Optional*              |
|holiday_schedule             |OCI.holidaySchedule      |holidaySchedule *Optional*           |
|blacklisted                  |bool                     |blacklisted *Optional*               |
|from_dn_criteria             |OCI.fromDnCriteria       |fromDnCriteria *Optional*            |
|audio_selection              |str                      |audioSelection *Optional*            |
|audio_file                   |OCI.audioFile            |audioFile *Optional*                 |
|video_selection              |str                      |videoSelection *Optional*            |
|video_file                   |OCI.videoFile            |videoFile *Optional*                 |
|call_waiting_audio_selection |str                      |callWaitingAudioSelection *Optional* |
|call_waiting_audio_file      |OCI.callWaitingAudioFile |callWaitingAudioFile *Optional*      |
|call_waiting_video_selection |str                      |callWaitingVideoSelection *Optional* |
|call_waiting_video_file      |OCI.callWaitingVideoFile |callWaitingVideoFile *Optional*      |
</div>


## `UserCustomRingbackUserModifyCriteriaRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a criteria for the user's custom ringback service.

For the callToNumbers in the callToNumberList, the extension element is not used and
the number element is only used when the type is BroadWorks Mobility.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                         |Type                     |Description                          |
|-----------------------------|-------------------------|-------------------------------------|
|user_id                      |str                      |userId                               |
|criteria_name                |str                      |criteriaName                         |
|new_criteria_name            |str                      |newCriteriaName *Optional*           |
|time_schedule                |OCI.timeSchedule         |timeSchedule *Optional*              |
|holiday_schedule             |OCI.holidaySchedule      |holidaySchedule *Optional*           |
|blacklisted                  |bool                     |blacklisted *Optional*               |
|from_dn_criteria             |OCI.fromDnCriteria       |fromDnCriteria *Optional*            |
|call_to_number_list          |OCI.callToNumberList     |callToNumberList *Optional*          |
|audio_selection              |str                      |audioSelection *Optional*            |
|audio_file                   |OCI.audioFile            |audioFile *Optional*                 |
|video_selection              |str                      |videoSelection *Optional*            |
|video_file                   |OCI.videoFile            |videoFile *Optional*                 |
|call_waiting_audio_selection |str                      |callWaitingAudioSelection *Optional* |
|call_waiting_audio_file      |OCI.callWaitingAudioFile |callWaitingAudioFile *Optional*      |
|call_waiting_video_selection |str                      |callWaitingVideoSelection *Optional* |
|call_waiting_video_file      |OCI.callWaitingVideoFile |callWaitingVideoFile *Optional*      |
</div>


## `UserEnterpriseCommonPhoneListGetPagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get an enterprise's common phone list for a user.

The response is either a `UserEnterpriseCommonPhoneListGetPagedSortedListResponse()`
or an `ErrorResponse()`. The search can be done using multiple criterion.  If the
searchCriteriaModeOr is present, any result matching any one criteria is included in
the results.  Otherwise, only results matching all the search criterion are included
in the results.  If no search criteria is specified, all results are returned.
Specifying searchCriteriaModeOr without any search criteria results in an
`ErrorResponse()`. The sort can be done on the name or the number in the common phone
list.  The following elements are only used in AS data mode and ignored in XS data
mode: searchCriteriaEnterpriseCommonMultiPartPhoneListName

**Attributes:**

|Name                                                         |Type                                                           |Description                                                     |
|-------------------------------------------------------------|---------------------------------------------------------------|----------------------------------------------------------------|
|user_id                                                      |str                                                            |userId                                                          |
|response_paging_control                                      |OCI.responsePagingControl                                      |responsePagingControl                                           |
|sort_by_enterprise_common_phone_list_number                  |OCI.sortByEnterpriseCommonPhoneListNumber                      |sortByEnterpriseCommonPhoneListNumber *Optional*                |
|sort_by_enterprise_common_phone_list_name                    |OCI.sortByEnterpriseCommonPhoneListName                        |sortByEnterpriseCommonPhoneListName *Optional*                  |
|search_criteria_mode_or                                      |bool                                                           |searchCriteriaModeOr *Optional*                                 |
|search_criteria_enterprise_common_phone_list_name            |List[OCI.searchCriteriaEnterpriseCommonPhoneListName]          |searchCriteriaEnterpriseCommonPhoneListName *Optional*          |
|search_criteria_enterprise_common_phone_list_number          |List[OCI.searchCriteriaEnterpriseCommonPhoneListNumber]        |searchCriteriaEnterpriseCommonPhoneListNumber *Optional*        |
|search_criteria_enterprise_common_multi_part_phone_list_name |List[OCI.searchCriteriaEnterpriseCommonMultiPartPhoneListName] |searchCriteriaEnterpriseCommonMultiPartPhoneListName *Optional* |
</div>


## `UserExecutiveGetAvailableAssistantListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of users that can be assigned to an executive.

Searching for users by group only makes sense when the executive user is part of an
Enterprise.

The response is either `UserExecutiveGetAvailableAssistantListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|user_id                               |str                                   |userId                                       |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_exact_user_group      |OCI.searchCriteriaExactUserGroup      |searchCriteriaExactUserGroup *Optional*      |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*              |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                  |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*           |
</div>


## `UserExecutiveModifyFilteringSelectiveCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a filtering selective criteria for an executive.

Both executive and the executive assistant can run this command.  For the
callToNumbers in the callToNumberList, the extension element is not used and the
number element is only used when the type is BroadWorks Mobility.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                |Type                 |Description                 |
|--------------------|---------------------|----------------------------|
|user_id             |str                  |userId                      |
|criteria_name       |str                  |criteriaName                |
|new_criteria_name   |str                  |newCriteriaName *Optional*  |
|time_schedule       |OCI.timeSchedule     |timeSchedule *Optional*     |
|holiday_schedule    |OCI.holidaySchedule  |holidaySchedule *Optional*  |
|filter              |bool                 |filter *Optional*           |
|from_dn_criteria    |OCI.fromDnCriteria   |fromDnCriteria *Optional*   |
|call_to_number_list |OCI.callToNumberList |callToNumberList *Optional* |
</div>


## `UserFlexibleSeatingGuestGetAvailableHostListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of hosts that can be assigned to flexible seating guests.

The response is either `UserFlexibleSeatingGuestGetAvailableUserListResponse()` or
`ErrorResponse()`. The response will include active hosts based on the following
criteria.  - host that has the equivalent device type as the guest, host already
assigned to another guest and for a guest in a Service Provider host in the user’s
group and for a user in an Enterprise a host within the user’s group and host in the
user’s enterprise that has the accessLevel set to Enterprise.

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|user_id                               |str                                   |userId                                       |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*              |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                  |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*           |
</div>


## `UserFlexibleSeatingGuestModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with flexible seating guest.

accessDeviceEndpoint can only be configured by group or a higher level administrator.
The request fails if isActive is set to false and the guest is associated to a host.
The request fails when enableAssociationLimit, associationLimitHours,
unlockPhonePINCode are changed when the guest is associated to a host.  The request
fails when accessDeviceEndpoint is set in the request when the guest is associated to
a host.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`UserFlexibleSeatingGuestModifyRequest22()`.

**Attributes:**

|Name                     |Type                     |Description                       |
|-------------------------|-------------------------|----------------------------------|
|user_id                  |str                      |userId                            |
|is_active                |bool                     |isActive *Optional*               |
|enable_association_limit |bool                     |enableAssociationLimit *Optional* |
|association_limit_hours  |int                      |associationLimitHours *Optional*  |
|unlock_phone_pin_code    |str                      |unlockPhonePINCode *Optional*     |
|access_device_endpoint   |OCI.accessDeviceEndpoint |accessDeviceEndpoint *Optional*   |
|host_user_id             |str                      |hostUserId *Optional*             |
</div>


## `UserGetListInGroupRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the list of users in a group.

It is possible to search by various criteria to restrict the number of rows returned.
Multiple search criteria are logically ANDed together.

The response is either a `UserGetListInGroupResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                      |Type                                    |Description                                    |
|------------------------------------------|----------------------------------------|-----------------------------------------------|
|service_provider_id                       |str                                     |serviceProviderId                              |
|group_id                                  |str                                     |GroupId                                        |
|response_size_limit                       |int                                     |responseSizeLimit *Optional*                   |
|search_criteria_user_last_name            |List[OCI.searchCriteriaUserLastName]    |searchCriteriaUserLastName *Optional*          |
|search_criteria_user_first_name           |List[OCI.searchCriteriaUserFirstName]   |searchCriteriaUserFirstName *Optional*         |
|search_criteria_dn                        |List[OCI.searchCriteriaDn]              |searchCriteriaDn *Optional*                    |
|search_criteria_email_address             |List[OCI.searchCriteriaEmailAddress]    |searchCriteriaEmailAddress *Optional*          |
|search_criteria_exact_user_department     |OCI.searchCriteriaExactUserDepartment   |searchCriteriaExactUserDepartment *Optional*   |
|search_criteria_exact_user_in_trunk_group |OCI.searchCriteriaExactUserInTrunkGroup |searchCriteriaExactUserInTrunkGroup *Optional* |
|search_criteria_user_id                   |List[OCI.searchCriteriaUserId]          |searchCriteriaUserId *Optional*                |
|search_criteria_extension                 |List[OCI.searchCriteriaExtension]       |searchCriteriaExtension *Optional*             |
</div>


## `UserGetListInServiceProviderRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the list of users in a service provider or enterprise.

It is possible to search by various criteria to restrict the number of rows returned.
Multiple search criteria are logically ANDed together.  The following elements are
only used in AS data mode and ignored in XS data mode: serviceProviderExternalId

The response is either a `UserGetListInServiceProviderResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                      |Type                                    |Description                                    |
|------------------------------------------|----------------------------------------|-----------------------------------------------|
|service_provider_id                       |str                                     |serviceProviderId *Optional*                   |
|service_provider_external_id              |str                                     |serviceProviderExternalId *Optional*           |
|response_size_limit                       |int                                     |responseSizeLimit *Optional*                   |
|search_criteria_user_last_name            |List[OCI.searchCriteriaUserLastName]    |searchCriteriaUserLastName *Optional*          |
|search_criteria_user_first_name           |List[OCI.searchCriteriaUserFirstName]   |searchCriteriaUserFirstName *Optional*         |
|search_criteria_dn                        |List[OCI.searchCriteriaDn]              |searchCriteriaDn *Optional*                    |
|search_criteria_email_address             |List[OCI.searchCriteriaEmailAddress]    |searchCriteriaEmailAddress *Optional*          |
|search_criteria_exact_user_in_trunk_group |OCI.searchCriteriaExactUserInTrunkGroup |searchCriteriaExactUserInTrunkGroup *Optional* |
|search_criteria_user_id                   |List[OCI.searchCriteriaUserId]          |searchCriteriaUserId *Optional*                |
|search_criteria_extension                 |List[OCI.searchCriteriaExtension]       |searchCriteriaExtension *Optional*             |
|search_criteria_exact_user_department     |OCI.searchCriteriaExactUserDepartment   |searchCriteriaExactUserDepartment *Optional*   |
</div>


## `UserGetListInSystemRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the list of users in the system.

It is possible to search by various criteria to restrict the number of rows returned.
Multiple search criteria are logically ANDed together.  If reseller administrator
sends the request, searchCriteriaResellerId is ignored.  All the users in the
administrator's reseller meeting the search criteria are returned.

The response is either a `UserGetListInSystemResponse()` or an `ErrorResponse()`. The
following data elements are only used in AS data mode: searchCriteriaResellerId

**Attributes:**

|Name                                                |Type                                             |Description                                             |
|----------------------------------------------------|-------------------------------------------------|--------------------------------------------------------|
|response_size_limit                                 |int                                              |responseSizeLimit *Optional*                            |
|search_criteria_user_last_name                      |List[OCI.searchCriteriaUserLastName]             |searchCriteriaUserLastName *Optional*                   |
|search_criteria_user_first_name                     |List[OCI.searchCriteriaUserFirstName]            |searchCriteriaUserFirstName *Optional*                  |
|search_criteria_dn                                  |List[OCI.searchCriteriaDn]                       |searchCriteriaDn *Optional*                             |
|search_criteria_email_address                       |List[OCI.searchCriteriaEmailAddress]             |searchCriteriaEmailAddress *Optional*                   |
|search_criteria_group_id                            |List[OCI.searchCriteriaGroupId]                  |searchCriteriaGroupId *Optional*                        |
|search_criteria_exact_service_provider              |OCI.searchCriteriaExactServiceProvider           |searchCriteriaExactServiceProvider *Optional*           |
|search_criteria_service_provider_id                 |List[OCI.searchCriteriaServiceProviderId]        |searchCriteriaServiceProviderId *Optional*              |
|search_criteria_exact_user_in_trunk_group           |OCI.searchCriteriaExactUserInTrunkGroup          |searchCriteriaExactUserInTrunkGroup *Optional*          |
|search_criteria_exact_user_network_class_of_service |OCI.searchCriteriaExactUserNetworkClassOfService |searchCriteriaExactUserNetworkClassOfService *Optional* |
|search_criteria_user_id                             |List[OCI.searchCriteriaUserId]                   |searchCriteriaUserId *Optional*                         |
|search_criteria_extension                           |List[OCI.searchCriteriaExtension]                |searchCriteriaExtension *Optional*                      |
|search_criteria_reseller_id                         |List[OCI.searchCriteriaResellerId]               |searchCriteriaResellerId *Optional*                     |
</div>


## `UserGetServiceInstanceListInServiceProviderRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the list of Service Instances in a service provider or an enterprise.

It is possible to search by various criteria to restrict the number of rows returned.
Multiple search criteria are logically ANDed together.
searchCriteriaExactUserDepartment criteria is only applicable for an enterprise and is
ignored if set for a service provider.

The response is either a `UserGetServiceInstanceListInServiceProviderResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|service_provider_id                   |str                                   |serviceProviderId                            |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_group_id              |List[OCI.SearchCriteriaGroupId]       |SearchCriteriaGroupId *Optional*             |
|search_criteria_exact_service_type    |OCI.SearchCriteriaExactServiceType    |SearchCriteriaExactServiceType *Optional*    |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*              |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                  |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*           |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
</div>


## `UserGetServiceInstanceListInSystemRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the list of Service Instances in the system.

It is possible to search by various criteria to restrict the number of rows returned.
Multiple search criteria are logically ANDed together.  If reseller administrator
sends the request, searchCriteriaResellerId is ignored.  All the service instances in
the administrator's reseller meeting the search criteria are returned.

The response is either a `UserGetServiceInstanceListInSystemResponse()` or an
`ErrorResponse()`. The following data elements are only used in AS data mode:
searchCriteriaResellerId

**Attributes:**

|Name                                   |Type                                      |Description                                   |
|---------------------------------------|------------------------------------------|----------------------------------------------|
|response_size_limit                    |int                                       |responseSizeLimit *Optional*                  |
|search_criteria_exact_service_type     |OCI.searchCriteriaExactServiceType        |searchCriteriaExactServiceType *Optional*     |
|search_criteria_user_id                |List[OCI.searchCriteriaUserId]            |searchCriteriaUserId *Optional*               |
|search_criteria_user_last_name         |List[OCI.searchCriteriaUserLastName]      |searchCriteriaUserLastName *Optional*         |
|search_criteria_dn                     |List[OCI.searchCriteriaDn]                |searchCriteriaDn *Optional*                   |
|search_criteria_extension              |List[OCI.searchCriteriaExtension]         |searchCriteriaExtension *Optional*            |
|search_criteria_group_id               |List[OCI.searchCriteriaGroupId]           |searchCriteriaGroupId *Optional*              |
|search_criteria_exact_service_provider |OCI.searchCriteriaExactServiceProvider    |searchCriteriaExactServiceProvider *Optional* |
|search_criteria_service_provider_id    |List[OCI.searchCriteriaServiceProviderId] |searchCriteriaServiceProviderId *Optional*    |
|search_criteria_reseller_id            |List[OCI.searchCriteriaResellerId]        |searchCriteriaResellerId *Optional*           |
</div>


## `UserGroupCommonPhoneListGetPagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a user's group's common phone list.

The response is either a `UserGroupCommonPhoneListGetPagedSortedListResponse()` or an
`ErrorResponse()`. The search can be done using multiple criterion.  If the
searchCriteriaModeOr is present, any result matching any one criteria is included in
the results.  Otherwise, only results matching all the search criterion are included
in the results.  If no search criteria is specified, all results are returned.
Specifying searchCriteriaModeOr without any search criteria results in an
`ErrorResponse()`. The sort can be done on the name or the number in the common phone
list.  The following elements are only used in AS data mode and ignored in XS data
mode: searchCriteriaGroupCommonMultiPartPhoneListName

**Attributes:**

|Name                                                    |Type                                                      |Description                                                |
|--------------------------------------------------------|----------------------------------------------------------|-----------------------------------------------------------|
|user_id                                                 |str                                                       |userId                                                     |
|response_paging_control                                 |OCI.responsePagingControl                                 |responsePagingControl                                      |
|sort_by_group_common_phone_list_number                  |OCI.sortByGroupCommonPhoneListNumber                      |sortByGroupCommonPhoneListNumber *Optional*                |
|sort_by_group_common_phone_list_name                    |OCI.sortByGroupCommonPhoneListName                        |sortByGroupCommonPhoneListName *Optional*                  |
|search_criteria_mode_or                                 |bool                                                      |searchCriteriaModeOr *Optional*                            |
|search_criteria_group_common_phone_list_name            |List[OCI.searchCriteriaGroupCommonPhoneListName]          |searchCriteriaGroupCommonPhoneListName *Optional*          |
|search_criteria_group_common_phone_list_number          |List[OCI.searchCriteriaGroupCommonPhoneListNumber]        |searchCriteriaGroupCommonPhoneListNumber *Optional*        |
|search_criteria_group_common_multi_part_phone_list_name |List[OCI.searchCriteriaGroupCommonMultiPartPhoneListName] |searchCriteriaGroupCommonMultiPartPhoneListName *Optional* |
</div>


## `UserGroupCustomContactDirectoryGetPagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Gets a Custom Contact Directory in a group.

The response is either `UserGroupCustomContactDirectoryGetPagedSortedListResponse()`
or `ErrorResponse()`. The search can be done using multiple criterion.  If the
searchCriteriaModeOr is present, any result matching any one criteria is included in
the results.  Otherwise, only results matching all the search criterion are included
in the results.  If no search criteria is specified, all results are returned.
Specifying searchCriteriaModeOr without any search criteria results in an
`ErrorResponse()`. The sort can be done on the user last name, first name, department,
or contact notes.  The Receptionist Note column is only populated, if the user sending
the request is a the owner of this Receptionist Note and a Note exists.

**Attributes:**

|Name                                |Type                                      |Description                                |
|------------------------------------|------------------------------------------|-------------------------------------------|
|user_id                             |str                                       |userId                                     |
|name                                |str                                       |name                                       |
|response_paging_control             |OCI.responsePagingControl                 |responsePagingControl                      |
|sort_by_user_last_name              |OCI.sortByUserLastName                    |sortByUserLastName *Optional*              |
|sort_by_user_first_name             |OCI.sortByUserFirstName                   |sortByUserFirstName *Optional*             |
|sort_by_user_department             |OCI.sortByUserDepartment                  |sortByUserDepartment *Optional*            |
|sort_by_receptionist_note           |OCI.sortByReceptionistNote                |sortByReceptionistNote *Optional*          |
|search_criteria_mode_or             |bool                                      |searchCriteriaModeOr *Optional*            |
|search_criteria_user_last_name      |List[OCI.searchCriteriaUserLastName]      |searchCriteriaUserLastName *Optional*      |
|search_criteria_user_first_name     |List[OCI.searchCriteriaUserFirstName]     |searchCriteriaUserFirstName *Optional*     |
|search_criteria_dn                  |List[OCI.searchCriteriaDn]                |searchCriteriaDn *Optional*                |
|search_criteria_extension           |List[OCI.searchCriteriaExtension]         |searchCriteriaExtension *Optional*         |
|search_criteria_mobile_phone_number |List[OCI.searchCriteriaMobilePhoneNumber] |searchCriteriaMobilePhoneNumber *Optional* |
|search_criteria_user_id             |List[OCI.searchCriteriaUserId]            |searchCriteriaUserId *Optional*            |
|search_criteria_department_name     |List[OCI.searchCriteriaDepartmentName]    |searchCriteriaDepartmentName *Optional*    |
|search_criteria_imp_id              |List[OCI.searchCriteriaImpId]             |searchCriteriaImpId *Optional*             |
|search_criteria_title               |List[OCI.searchCriteriaTitle]             |searchCriteriaTitle *Optional*             |
|search_criteria_receptionist_note   |List[OCI.searchCriteriaReceptionistNote]  |searchCriteriaReceptionistNote *Optional*  |
</div>


## `UserHotelingGuestGetAvailableUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of users that can be assigned as Hoteling Guests.

The response is either `UserHotelingGuestGetAvailableUserListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|user_id                               |str                                   |userId                                       |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*              |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                  |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*           |
</div>


## `UserIncomingCallingPlanModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Change the user's incoming calling plan settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type                |Description                  |
|--------------------|--------------------|-----------------------------|
|user_id             |str                 |userId                       |
|use_custom_settings |bool                |useCustomSettings *Optional* |
|user_permissions    |OCI.userPermissions |userPermissions *Optional*   |
</div>


## `UserMeetMeConferencingGetAvailableDelegateListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of users that can be assigned as a delegate to a Meet-Me Conference.

Searching for users, who are host on a Meet-Me Conferencing bridge.

The response is either `UserMeetMeConferencingGetAvailableDelegateListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|user_id                               |str                                   |userId                                       |
|conference_key                        |OCI.conferenceKey                     |conferenceKey                                |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*              |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                  |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*           |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
</div>


## `UserModifyRequest17sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a user.

When oldPassword is specified, all password rule applies.  If oldPassword in not
specified, any password rule related to old password does not apply.  The request will
fail if officeZoneName or primaryZoneName is present but the Location-Based Calling
Restrictions service is not assigned to the user.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in AS data mode and ignored in XS data mode:
contact[2]-contact[5] nameDialingName alternateUserIdList The impId and impPassword
are accepted when the Third-Party IMP service is assigned to the user; when Integrated
IMP service is assigned to the user and active, only the impPassword is accepted; all
other cases, the request fails if either field is changed.  Replaced by:
`UserModifyRequest21()`

**Attributes:**

|Name                         |Type                    |Description                         |
|-----------------------------|------------------------|------------------------------------|
|user_id                      |str                     |userId                              |
|last_name                    |str                     |lastName *Optional*                 |
|first_name                   |str                     |firstName *Optional*                |
|calling_line_id_last_name    |str                     |callingLineIdLastName *Optional*    |
|calling_line_id_first_name   |str                     |callingLineIdFirstName *Optional*   |
|name_dialing_name            |OCI.nameDialingName     |nameDialingName *Optional*          |
|hiragana_last_name           |str                     |hiraganaLastName *Optional*         |
|hiragana_first_name          |str                     |hiraganaFirstName *Optional*        |
|phone_number                 |str                     |phoneNumber *Optional*              |
|extension                    |str                     |extension *Optional*                |
|calling_line_id_phone_number |str                     |callingLineIdPhoneNumber *Optional* |
|old_password                 |str                     |oldPassword *Optional*              |
|new_password                 |str                     |newPassword *Optional*              |
|department                   |OCI.department          |department *Optional*               |
|language                     |str                     |language *Optional*                 |
|time_zone                    |str                     |timeZone *Optional*                 |
|sip_alias_list               |OCI.sipAliasList        |sipAliasList *Optional*             |
|endpoint                     |OCI.endpoint            |endpoint *Optional*                 |
|title                        |str                     |title *Optional*                    |
|pager_phone_number           |str                     |pagerPhoneNumber *Optional*         |
|mobile_phone_number          |str                     |mobilePhoneNumber *Optional*        |
|email_address                |str                     |emailAddress *Optional*             |
|yahoo_id                     |str                     |yahooId *Optional*                  |
|address_location             |str                     |addressLocation *Optional*          |
|address                      |OCI.address             |address *Optional*                  |
|network_class_of_service     |str                     |networkClassOfService *Optional*    |
|office_zone_name             |str                     |officeZoneName *Optional*           |
|primary_zone_name            |str                     |primaryZoneName *Optional*          |
|imp_id                       |str                     |impId *Optional*                    |
|imp_password                 |str                     |impPassword *Optional*              |
|alternate_user_id_list       |OCI.alternateUserIdList |alternateUserIdList *Optional*      |
</div>


## `UserModifyRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a user.

When oldPassword is specified, all password rule applies.  If oldPassword in not
specified, any password rule related to old password does not apply.  The request will
fail if officeZoneName or primaryZoneName is present but the Location-Based Calling
Restrictions service is not assigned to the user.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following data
elements are only used in AS data mode: contact[2]-contact[5] nameDialingName
alternateUserIdList The following elements are only used in AS data mode and will fail
in XS data mode: trunkAddressing The following elements are only used in XS data mode
and ignored in AS data mode: allowVideo The allowVideo element can only be used by a
system administrator.  The impId and impPassword are accepted when the Third-Party IMP
service is assigned to the user; when Integrated IMP service is assigned to the user
and active, only the impPassword is accepted; all other cases, the request fails if
either field is changed.  Replaced by : `UserAddRequest22()` in AS mode

**Attributes:**

|Name                         |Type                    |Description                         |
|-----------------------------|------------------------|------------------------------------|
|user_id                      |str                     |userId                              |
|last_name                    |str                     |lastName *Optional*                 |
|first_name                   |str                     |firstName *Optional*                |
|calling_line_id_last_name    |str                     |callingLineIdLastName *Optional*    |
|calling_line_id_first_name   |str                     |callingLineIdFirstName *Optional*   |
|name_dialing_name            |OCI.nameDialingName     |nameDialingName *Optional*          |
|hiragana_last_name           |str                     |hiraganaLastName *Optional*         |
|hiragana_first_name          |str                     |hiraganaFirstName *Optional*        |
|phone_number                 |str                     |phoneNumber *Optional*              |
|extension                    |str                     |extension *Optional*                |
|calling_line_id_phone_number |str                     |callingLineIdPhoneNumber *Optional* |
|old_password                 |str                     |oldPassword *Optional*              |
|new_password                 |str                     |newPassword *Optional*              |
|department                   |OCI.department          |department *Optional*               |
|language                     |str                     |language *Optional*                 |
|time_zone                    |str                     |timeZone *Optional*                 |
|sip_alias_list               |OCI.sipAliasList        |sipAliasList *Optional*             |
|endpoint                     |OCI.endpoint            |endpoint *Optional*                 |
|title                        |str                     |title *Optional*                    |
|pager_phone_number           |str                     |pagerPhoneNumber *Optional*         |
|mobile_phone_number          |str                     |mobilePhoneNumber *Optional*        |
|email_address                |str                     |emailAddress *Optional*             |
|yahoo_id                     |str                     |yahooId *Optional*                  |
|address_location             |str                     |addressLocation *Optional*          |
|address                      |OCI.address             |address *Optional*                  |
|network_class_of_service     |str                     |networkClassOfService *Optional*    |
|office_zone_name             |str                     |officeZoneName *Optional*           |
|primary_zone_name            |str                     |primaryZoneName *Optional*          |
|imp_id                       |str                     |impId *Optional*                    |
|imp_password                 |str                     |impPassword *Optional*              |
|alternate_user_id_list       |OCI.alternateUserIdList |alternateUserIdList *Optional*      |
|allow_video                  |bool                    |allowVideo *Optional*               |
</div>


## `UserModifyRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
The following data elements are only used in AS data mode: contact[2]-contact[5] The
following elements are only used in AS data mode and will fail in XS data mode:
trunkAddressing newUserExternalId The following elements are only used in AS data mode
and ignored in XS data mode: nameDialingName alternateUserIdList newUserExternalId The
following elements are only used in XS data mode and ignored in AS data mode:
allowVideo The allowVideo element can only be used by a system administrator.

The impId and impPassword are accepted when the Third-Party IMP service is assigned to
the user; when Integrated IMP service is assigned to the user and active, only the
impPassword is accepted; all other cases, the request fails if either field is
changed.

**Attributes:**

|Name                         |Type                    |Description                         |
|-----------------------------|------------------------|------------------------------------|
|user_id                      |str                     |userId                              |
|last_name                    |str                     |lastName *Optional*                 |
|first_name                   |str                     |firstName *Optional*                |
|calling_line_id_last_name    |str                     |callingLineIdLastName *Optional*    |
|calling_line_id_first_name   |str                     |callingLineIdFirstName *Optional*   |
|name_dialing_name            |OCI.nameDialingName     |nameDialingName *Optional*          |
|hiragana_last_name           |str                     |hiraganaLastName *Optional*         |
|hiragana_first_name          |str                     |hiraganaFirstName *Optional*        |
|phone_number                 |str                     |phoneNumber *Optional*              |
|extension                    |str                     |extension *Optional*                |
|calling_line_id_phone_number |str                     |callingLineIdPhoneNumber *Optional* |
|old_password                 |str                     |oldPassword *Optional*              |
|new_password                 |str                     |newPassword *Optional*              |
|department                   |OCI.department          |department *Optional*               |
|language                     |str                     |language *Optional*                 |
|time_zone                    |str                     |timeZone *Optional*                 |
|sip_alias_list               |OCI.sipAliasList        |sipAliasList *Optional*             |
|endpoint                     |OCI.endpoint            |endpoint *Optional*                 |
|title                        |str                     |title *Optional*                    |
|pager_phone_number           |str                     |pagerPhoneNumber *Optional*         |
|mobile_phone_number          |str                     |mobilePhoneNumber *Optional*        |
|email_address                |str                     |emailAddress *Optional*             |
|yahoo_id                     |str                     |yahooId *Optional*                  |
|address_location             |str                     |addressLocation *Optional*          |
|address                      |OCI.address             |address *Optional*                  |
|network_class_of_service     |str                     |networkClassOfService *Optional*    |
|office_zone_name             |str                     |officeZoneName *Optional*           |
|primary_zone_name            |str                     |primaryZoneName *Optional*          |
|imp_id                       |str                     |impId *Optional*                    |
|imp_password                 |str                     |impPassword *Optional*              |
|alternate_user_id_list       |OCI.alternateUserIdList |alternateUserIdList *Optional*      |
|allow_video                  |bool                    |allowVideo *Optional*               |
|new_user_external_id         |str                     |newUserExternalId *Optional*        |
</div>


## `UserOutgoingCallingPlanDigitPlanCallMeNowModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Call Me Now call permissions for digit patterns for a user.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type                |Description                  |
|--------------------|--------------------|-----------------------------|
|user_id             |str                 |userId                       |
|use_custom_settings |bool                |useCustomSettings *Optional* |
|user_permissions    |OCI.userPermissions |userPermissions *Optional*   |
</div>


## `UserOutgoingCallingPlanDigitPlanOriginatingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the originating permissions for digit patterns for a user.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type                |Description                  |
|--------------------|--------------------|-----------------------------|
|user_id             |str                 |userId                       |
|use_custom_settings |bool                |useCustomSettings *Optional* |
|user_permissions    |OCI.userPermissions |userPermissions *Optional*   |
</div>


## `UserOutgoingCallingPlanDigitPlanRedirectingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the redirecting permissions for digit patterns for a user.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type                |Description                  |
|--------------------|--------------------|-----------------------------|
|user_id             |str                 |userId                       |
|use_custom_settings |bool                |useCustomSettings *Optional* |
|user_permissions    |OCI.userPermissions |userPermissions *Optional*   |
</div>


## `UserOutgoingCallingPlanPinholeDigitPlanCallMeNowModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Call Me Now permissions for Pinhole digit patterns for a user.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type                |Description                  |
|--------------------|--------------------|-----------------------------|
|user_id             |str                 |userId                       |
|use_custom_settings |bool                |useCustomSettings *Optional* |
|user_permissions    |OCI.userPermissions |userPermissions *Optional*   |
</div>


## `UserOutgoingCallingPlanPinholeDigitPlanOriginatingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the originating permissions for Pinhole digit patterns for a user.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type                |Description                  |
|--------------------|--------------------|-----------------------------|
|user_id             |str                 |userId                       |
|use_custom_settings |bool                |useCustomSettings *Optional* |
|user_permissions    |OCI.userPermissions |userPermissions *Optional*   |
</div>


## `UserOutgoingCallingPlanPinholeDigitPlanRedirectingModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the redirecting permissions for Pinhole digit patterns for a user.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type                |Description                  |
|--------------------|--------------------|-----------------------------|
|user_id             |str                 |userId                       |
|use_custom_settings |bool                |useCustomSettings *Optional* |
|user_permissions    |OCI.userPermissions |userPermissions *Optional*   |
</div>


## `UserPersonalAssistantCallToNumberModifyListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify the user assigned Call to Number List information.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. For the
callToNumbers in the callToNumberList, the extension element is not used and the
number element is only used when the type is BroadWorks Mobility.

**Attributes:**

|Name                |Type                 |Description                 |
|--------------------|---------------------|----------------------------|
|user_id             |str                  |userId                      |
|call_to_number_list |OCI.callToNumberList |callToNumberList *Optional* |
</div>


## `UserPersonalAssistantExclusionNumberGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to get the User Personal Assistant Exclusion Number List information.

The response is either a userPersonalAssistantExclusionNumberGetListResponse or an
`ErrorResponse()`.

**Attributes:**

|Name                                                            |Type                                                                |Description                                                          |
|----------------------------------------------------------------|--------------------------------------------------------------------|---------------------------------------------------------------------|
|user_id                                                         |str                                                                 |userId                                                               |
|search_criteria_personal_assistant_exclusion_number             |List[OCI.searchCriteriaPersonalAssistantExclusionNumber]            |searchCriteriaPersonalAssistantExclusionNumber *Optional*            |
|search_criteria_personal_assistant_exclusion_number_description |List[OCI.searchCriteriaPersonalAssistantExclusionNumberDescription] |searchCriteriaPersonalAssistantExclusionNumberDescription *Optional* |
|response_size_limit                                             |int                                                                 |responseSizeLimit *Optional*                                         |
</div>


## `UserPersonalPhoneListGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a user's personal phone list.

The response is either a `UserPersonalPhoneListGetListResponse()` or an
`ErrorResponse()`. The search can be done using multiple criterion.  If the
searchCriteriaModeOr is present, any result matching any one criteria is included in
the results.  Otherwise, only results matching all the search criterion are included
in the results.  If no search criteria is specified, all results are returned.
Specifying searchCriteriaModeOr without any search criteria results in an
`ErrorResponse()`. In all cases, if a responseSizeLimit is specified and the number of
matching results is more than this limit, then an `ErrorResponse()` is returned.

**Attributes:**

|Name                                            |Type                                                |Description                                          |
|------------------------------------------------|----------------------------------------------------|-----------------------------------------------------|
|user_id                                         |str                                                 |userId                                               |
|response_size_limit                             |int                                                 |responseSizeLimit *Optional*                         |
|search_criteria_mode_or                         |bool                                                |searchCriteriaModeOr *Optional*                      |
|search_criteria_user_personal_phone_list_name   |List[OCI.searchCriteriaUserPersonalPhoneListName]   |searchCriteriaUserPersonalPhoneListName *Optional*   |
|search_criteria_user_personal_phone_list_number |List[OCI.searchCriteriaUserPersonalPhoneListNumber] |searchCriteriaUserPersonalPhoneListNumber *Optional* |
</div>


## `UserPersonalPhoneListGetPagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a user's personal phone list.

The response is either a `UserPersonalPhoneListGetPagedSortedListResponse()` or an
`ErrorResponse()`. The search can be done using multiple criterion.  If the
searchCriteriaModeOr is present, any result matching any one criteria is included in
the results.  Otherwise, only results matching all the search criterion are included
in the results.  If no search criteria is specified, all results are returned.
Specifying searchCriteriaModeOr without any search criteria results in an
`ErrorResponse()`. The sort can done by the personal phone list number or name.  The
following elements are only used in AS data mode and ignored in XS data mode:
searchCriteriaUserPersonalMultiPartPhoneListName

**Attributes:**

|Name                                                     |Type                                                       |Description                                                 |
|---------------------------------------------------------|-----------------------------------------------------------|------------------------------------------------------------|
|user_id                                                  |str                                                        |userId                                                      |
|response_paging_control                                  |OCI.responsePagingControl                                  |responsePagingControl                                       |
|sort_by_user_personal_phone_list_number                  |OCI.sortByUserPersonalPhoneListNumber                      |sortByUserPersonalPhoneListNumber *Optional*                |
|sort_by_user_personal_phone_list_name                    |OCI.sortByUserPersonalPhoneListName                        |sortByUserPersonalPhoneListName *Optional*                  |
|search_criteria_mode_or                                  |bool                                                       |searchCriteriaModeOr *Optional*                             |
|search_criteria_user_personal_phone_list_name            |List[OCI.searchCriteriaUserPersonalPhoneListName]          |searchCriteriaUserPersonalPhoneListName *Optional*          |
|search_criteria_user_personal_phone_list_number          |List[OCI.searchCriteriaUserPersonalPhoneListNumber]        |searchCriteriaUserPersonalPhoneListNumber *Optional*        |
|search_criteria_user_personal_multi_part_phone_list_name |List[OCI.searchCriteriaUserPersonalMultiPartPhoneListName] |searchCriteriaUserPersonalMultiPartPhoneListName *Optional* |
</div>


## `UserPhoneDirectoryGetListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a table containing the phone directory for a user's group.

If the user's group is part of an enterprise, the directory includes all users in the
enterprise and all entries in the enterprise common phone list and the common phone
list of the specified group (if includeCommonPhoneList is set to true). If the user's
group is part of a service provider, the directory includes all users in the group and
all entries in the common phone list (if includeCommonPhoneList is set to true) of the
specified group.

The response is either `UserPhoneDirectoryGetListResponse()` or `ErrorResponse()`. If
the searchCriteriaModeOr is present, any result matching any one criteria is included
in the results.  Otherwise, only results matching all the search criteria are included
in the results.  If no search criteria is specified, all results are returned.  In all
cases, if a responseSizeLimit is specified and the number of matching results is more
than this limit, then an `ErrorResponse()` is returned.  Specifying
searchCriteriaModeOr without any search criteria results in an `ErrorResponse()`.

**Attributes:**

|Name                                           |Type                                          |Description                                          |
|-----------------------------------------------|----------------------------------------------|-----------------------------------------------------|
|user_id                                        |str                                           |userId                                               |
|include_common_phone_list                      |bool                                          |includeCommonPhoneList                               |
|response_size_limit                            |int                                           |responseSizeLimit *Optional*                         |
|search_criteria_mode_or                        |bool                                          |searchCriteriaModeOr *Optional*                      |
|search_criteria_user_last_name                 |List[OCI.searchCriteriaUserLastName]          |searchCriteriaUserLastName *Optional*                |
|search_criteria_user_first_name                |List[OCI.searchCriteriaUserFirstName]         |searchCriteriaUserFirstName *Optional*               |
|search_criteria_dn                             |List[OCI.searchCriteriaDn]                    |searchCriteriaDn *Optional*                          |
|search_criteria_extension                      |List[OCI.searchCriteriaExtension]             |searchCriteriaExtension *Optional*                   |
|search_criteria_mobile_phone_number            |List[OCI.searchCriteriaMobilePhoneNumber]     |searchCriteriaMobilePhoneNumber *Optional*           |
|search_criteria_email_address                  |List[OCI.searchCriteriaEmailAddress]          |searchCriteriaEmailAddress *Optional*                |
|search_criteria_exact_user_department          |OCI.searchCriteriaExactUserDepartment         |searchCriteriaExactUserDepartment *Optional*         |
|search_criteria_exact_user_group               |OCI.searchCriteriaExactUserGroup              |searchCriteriaExactUserGroup *Optional*              |
|search_criteria_exact_custom_contact_directory |OCI.searchCriteriaExactCustomContactDirectory |searchCriteriaExactCustomContactDirectory *Optional* |
|search_criteria_user_id                        |List[OCI.searchCriteriaUserId]                |searchCriteriaUserId *Optional*                      |
|search_criteria_imp_id                         |List[OCI.searchCriteriaImpId]                 |searchCriteriaImpId *Optional*                       |
</div>


## `UserPhoneDirectoryGetPagedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a table containing the phone directory for a user.

Setting isEnterpriseRequested to true will return enterprise directory members in the
response if the user is in an enterprise.  Otherwise, just the group directory members
for a user are returned in the response.

The response is either `UserPhoneDirectoryGetPagedListResponse()` or
`ErrorResponse()`. The search can be done using multiple criteria.  If the
searchCriteriaModeOr is present, any result matching any one criteria is included in
the results.  Otherwise, only results matching all the search criteria are included in
the results.  If no search criteria is specified, all results are returned.  In all
cases, if a responseSizeLimit is specified and the number of matching results is more
than this limit, then an `ErrorResponse()` is returned.  Specifying
searchCriteriaModeOr without any search criteria results in an `ErrorResponse()`. The
boolean sortByFirstName is optional.  If it is not specified, the response is sorted
by Last Name.  The Receptionist Note column is only populated, if the user sending the
request is the owner of the Receptionist Note and a Note exists.

**Attributes:**

|Name                                  |Type                                      |Description                                  |
|--------------------------------------|------------------------------------------|---------------------------------------------|
|user_id                               |str                                       |userId                                       |
|is_enterprise_info_requested          |bool                                      |isEnterpriseInfoRequested                    |
|response_paging_control               |OCI.responsePagingControl                 |responsePagingControl                        |
|search_criteria_mode_or               |bool                                      |searchCriteriaModeOr *Optional*              |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]      |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName]     |searchCriteriaUserFirstName *Optional*       |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]                |searchCriteriaDn *Optional*                  |
|search_criteria_group_location_code   |List[OCI.searchCriteriaGroupLocationCode] |searchCriteriaGroupLocationCode *Optional*   |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]         |searchCriteriaExtension *Optional*           |
|search_criteria_mobile_phone_number   |List[OCI.searchCriteriaMobilePhoneNumber] |searchCriteriaMobilePhoneNumber *Optional*   |
|search_criteria_email_address         |List[OCI.searchCriteriaEmailAddress]      |searchCriteriaEmailAddress *Optional*        |
|search_criteria_yahoo_id              |List[OCI.searchCriteriaYahooId]           |searchCriteriaYahooId *Optional*             |
|search_criteria_exact_user_group      |OCI.searchCriteriaExactUserGroup          |searchCriteriaExactUserGroup *Optional*      |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment     |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]            |searchCriteriaUserId *Optional*              |
|search_criteria_imp_id                |List[OCI.searchCriteriaImpId]             |searchCriteriaImpId *Optional*               |
|sort_by_first_name                    |bool                                      |sortByFirstName *Optional*                   |
|search_criteria_title                 |List[OCI.searchCriteriaTitle]             |searchCriteriaTitle *Optional*               |
|search_criteria_receptionist_note     |List[OCI.searchCriteriaReceptionistNote]  |searchCriteriaReceptionistNote *Optional*    |
</div>


## `UserPhoneDirectoryGetPagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a table containing the phone directory for a user.

Setting isEnterpriseRequested to true will return enterprise directory members in the
response if the user is in an enterprise.  Otherwise, just the group directory members
for a user are returned in the response.

The response is either `UserPhoneDirectoryGetPagedSortedListResponse()` or
`ErrorResponse()`. The search can be done using multiple criteria.  If the
searchCriteriaModeOr is present, any result matching any one criteria is included in
the results.  Otherwise, only results matching all the search criteria are included in
the results.  If no search criteria is specified, all results are returned.
Specifying searchCriteriaModeOr without any search criteria results in an
`ErrorResponse()`. The sort can be performed on user last name, first name,
department, or receptionist note.  The Receptionist Note column is only populated, if
the user sending the request is the owner of the Receptionist Note and a Note exists.
The following elements are only used in AS data mode and ignored in XS data mode:
searchCriteriaMultiPartName

**Attributes:**

|Name                                |Type                                      |Description                                |
|------------------------------------|------------------------------------------|-------------------------------------------|
|user_id                             |str                                       |userId                                     |
|is_enterprise_info_requested        |bool                                      |isEnterpriseInfoRequested                  |
|response_paging_control             |OCI.responsePagingControl                 |responsePagingControl                      |
|sort_by_user_last_name              |OCI.sortByUserLastName                    |sortByUserLastName *Optional*              |
|sort_by_user_first_name             |OCI.sortByUserFirstName                   |sortByUserFirstName *Optional*             |
|sort_by_user_department             |OCI.sortByUserDepartment                  |sortByUserDepartment *Optional*            |
|sort_by_receptionist_note           |OCI.sortByReceptionistNote                |sortByReceptionistNote *Optional*          |
|search_criteria_mode_or             |bool                                      |searchCriteriaModeOr *Optional*            |
|search_criteria_user_last_name      |List[OCI.searchCriteriaUserLastName]      |searchCriteriaUserLastName *Optional*      |
|search_criteria_user_first_name     |List[OCI.searchCriteriaUserFirstName]     |searchCriteriaUserFirstName *Optional*     |
|search_criteria_user_name           |List[OCI.searchCriteriaUserName]          |searchCriteriaUserName *Optional*          |
|search_criteria_dn                  |List[OCI.searchCriteriaDn]                |searchCriteriaDn *Optional*                |
|search_criteria_group_location_code |List[OCI.searchCriteriaGroupLocationCode] |searchCriteriaGroupLocationCode *Optional* |
|search_criteria_extension           |List[OCI.searchCriteriaExtension]         |searchCriteriaExtension *Optional*         |
|search_criteria_mobile_phone_number |List[OCI.searchCriteriaMobilePhoneNumber] |searchCriteriaMobilePhoneNumber *Optional* |
|search_criteria_email_address       |List[OCI.searchCriteriaEmailAddress]      |searchCriteriaEmailAddress *Optional*      |
|search_criteria_yahoo_id            |List[OCI.searchCriteriaYahooId]           |searchCriteriaYahooId *Optional*           |
|search_criteria_exact_user_group    |OCI.searchCriteriaExactUserGroup          |searchCriteriaExactUserGroup *Optional*    |
|search_criteria_department_name     |List[OCI.searchCriteriaDepartmentName]    |searchCriteriaDepartmentName *Optional*    |
|search_criteria_user_id             |List[OCI.searchCriteriaUserId]            |searchCriteriaUserId *Optional*            |
|search_criteria_imp_id              |List[OCI.searchCriteriaImpId]             |searchCriteriaImpId *Optional*             |
|search_criteria_title               |List[OCI.searchCriteriaTitle]             |searchCriteriaTitle *Optional*             |
|search_criteria_receptionist_note   |List[OCI.searchCriteriaReceptionistNote]  |searchCriteriaReceptionistNote *Optional*  |
|search_criteria_multi_part_name     |List[OCI.searchCriteriaMultiPartName]     |searchCriteriaMultiPartName *Optional*     |
</div>


## `UserPreAlertingAnnouncementModifyCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a criteria for the user's pre-alerting service.

The following elements are only used in AS data mode: callToNumber For the
callToNumbers in the callToNumberList, the extension element is not used and the
number element is only used when the type is BroadWorks Mobility.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type                 |Description                 |
|--------------------|---------------------|----------------------------|
|user_id             |str                  |userId                      |
|criteria_name       |str                  |criteriaName                |
|new_criteria_name   |str                  |newCriteriaName *Optional*  |
|time_schedule       |OCI.timeSchedule     |timeSchedule *Optional*     |
|holiday_schedule    |OCI.holidaySchedule  |holidaySchedule *Optional*  |
|blacklisted         |bool                 |blacklisted *Optional*      |
|from_dn_criteria    |OCI.fromDnCriteria   |fromDnCriteria *Optional*   |
|call_to_number_list |OCI.callToNumberList |callToNumberList *Optional* |
</div>


## `UserPreAlertingAnnouncementModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's pre-alerting service setting.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`UserPreAlertingAnnouncementModifyRequest20()` in AS data mode

**Attributes:**

|Name                |Type                         |Description                   |
|--------------------|-----------------------------|------------------------------|
|user_id             |str                          |userId                        |
|is_active           |bool                         |isActive *Optional*           |
|audio_selection     |str                          |audioSelection *Optional*     |
|audio_file          |OCI.audioFile                |audioFile *Optional*          |
|video_selection     |str                          |videoSelection *Optional*     |
|video_file          |OCI.videoFile                |videoFile *Optional*          |
|criteria_activation |List[OCI.criteriaActivation] |criteriaActivation *Optional* |
</div>


## `UserPreAlertingAnnouncementModifyRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's pre-alerting service setting.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type                         |Description                   |
|--------------------|-----------------------------|------------------------------|
|user_id             |str                          |userId                        |
|is_active           |bool                         |isActive *Optional*           |
|audio_selection     |str                          |audioSelection *Optional*     |
|audio_file          |OCI.audioFile                |audioFile *Optional*          |
|video_selection     |str                          |videoSelection *Optional*     |
|video_file          |OCI.videoFile                |videoFile *Optional*          |
|criteria_activation |List[OCI.criteriaActivation] |criteriaActivation *Optional* |
</div>


## `UserPriorityAlertModifyCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a criteria for the user's priority alert service.

The following elements are only used in AS data mode: callToNumberList For the
callToNumbers in the callToNumberList, the extension element is not used and the
number element is only used when the type is BroadWorks Mobility.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type                 |Description                 |
|--------------------|---------------------|----------------------------|
|user_id             |str                  |userId                      |
|criteria_name       |str                  |criteriaName                |
|new_criteria_name   |str                  |newCriteriaName *Optional*  |
|time_schedule       |OCI.timeSchedule     |timeSchedule *Optional*     |
|from_dn_criteria    |OCI.fromDnCriteria   |fromDnCriteria *Optional*   |
|holiday_schedule    |OCI.holidaySchedule  |holidaySchedule *Optional*  |
|blacklisted         |bool                 |blacklisted *Optional*      |
|call_to_number_list |OCI.callToNumberList |callToNumberList *Optional* |
</div>


## `UserPrivacyGetAvailableMonitorsUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Retrieves a list of users in the enterprise or group available for phone status
monitoring the user specified in the userId element.

The response is either `UserPrivacyGetAvailableMonitorsUserListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|user_id                               |str                                   |userId                                       |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_exact_user_group      |OCI.searchCriteriaExactUserGroup      |searchCriteriaExactUserGroup *Optional*      |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*              |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                  |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*           |
|search_criteria_imp_id                |List[OCI.searchCriteriaImpId]         |searchCriteriaImpId *Optional*               |
</div>


## `UserPushToTalkGetAvailableUserListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of available users for the push to talk service.

The response is either `UserPushToTalkGetAvailableUserListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                  |Description                                  |
|--------------------------------------|--------------------------------------|---------------------------------------------|
|user_id                               |str                                   |userId                                       |
|response_size_limit                   |int                                   |responseSizeLimit *Optional*                 |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]  |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName] |searchCriteriaUserFirstName *Optional*       |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_exact_user_group      |OCI.searchCriteriaExactUserGroup      |searchCriteriaExactUserGroup *Optional*      |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]        |searchCriteriaUserId *Optional*              |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]            |searchCriteriaDn *Optional*                  |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]     |searchCriteriaExtension *Optional*           |
|search_criteria_imp_id                |List[OCI.searchCriteriaImpId]         |searchCriteriaImpId *Optional*               |
</div>


## `UserScheduleGetEventDetailListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the list of schedules viewable by a User.

The list can be filtered by schedule type.

The response is either a `UserScheduleGetEventListForGroupResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                |Type                  |Description       |
|--------------------|----------------------|------------------|
|user_id             |str                   |userId            |
|schedule_global_key |OCI.scheduleGlobalKey |scheduleGlobalKey |
</div>


## `UserScheduleGetPagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of schedules viewable by a User.

The list can be filtered by schedule name, schedule type, and schedule level.

The response is either a `UserScheduleGetPagedSortedListResponse()` or an
`ErrorResponse()`. This command is authorized to user who is Executive-Assistant of
the Executive.  If no sortOrder is included, the response is sorted by Name ascending
by default.  If the responsePagingControl element is not provided, the paging
startIndex will be set to 1 by default, and the responsePageSize will be set to the
maximum responsePageSize by default.  Multiple search criteria are logically ANDed
together unless the searchCriteriaModeOr option is included.  Then the search criteria
are logically ORed together.

**Attributes:**

|Name                                 |Type                                       |Description                                 |
|-------------------------------------|-------------------------------------------|--------------------------------------------|
|user_id                              |str                                        |userId                                      |
|response_paging_control              |OCI.responsePagingControl                  |responsePagingControl *Optional*            |
|sort_by_schedule_name                |OCI.sortByScheduleName                     |sortByScheduleName *Optional*               |
|search_criteria_schedule_name        |List[OCI.searchCriteriaScheduleName]       |searchCriteriaScheduleName *Optional*       |
|search_criteria_exact_schedule_type  |List[OCI.searchCriteriaExactScheduleType]  |searchCriteriaExactScheduleType *Optional*  |
|search_criteria_exact_schedule_level |List[OCI.searchCriteriaExactScheduleLevel] |searchCriteriaExactScheduleLevel *Optional* |
|search_criteria_mode_or              |bool                                       |searchCriteriaModeOr *Optional*             |
</div>


## `UserSelectiveCallAcceptanceModifyCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a criteria for the user's selective call acceptance service.

The following elements are only used in AS data mode: callToNumberList For the
callToNumbers in the callToNumberList, the extension element is not used and the
number element is only used when the type is BroadWorks Mobility.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type                 |Description                 |
|--------------------|---------------------|----------------------------|
|user_id             |str                  |userId                      |
|criteria_name       |str                  |criteriaName                |
|new_criteria_name   |str                  |newCriteriaName *Optional*  |
|time_schedule       |OCI.timeSchedule     |timeSchedule *Optional*     |
|from_dn_criteria    |OCI.fromDnCriteria   |fromDnCriteria *Optional*   |
|holiday_schedule    |OCI.holidaySchedule  |holidaySchedule *Optional*  |
|blacklisted         |bool                 |blacklisted *Optional*      |
|call_to_number_list |OCI.callToNumberList |callToNumberList *Optional* |
</div>


## `UserSelectiveCallRejectionModifyCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a criteria for the user's selective call rejection service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name              |Type                |Description                |
|------------------|--------------------|---------------------------|
|user_id           |str                 |userId                     |
|criteria_name     |str                 |criteriaName               |
|new_criteria_name |str                 |newCriteriaName *Optional* |
|time_schedule     |OCI.timeSchedule    |timeSchedule *Optional*    |
|from_dn_criteria  |OCI.fromDnCriteria  |fromDnCriteria *Optional*  |
|holiday_schedule  |OCI.holidaySchedule |holidaySchedule *Optional* |
|blacklisted       |bool                |blacklisted *Optional*     |
</div>


## `UserSelectiveCallRejectionModifyCriteriaRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a criteria for the user's selective call rejection service.

The following elements are only used in AS data mode: callToNumberList For the
callToNumbers in the callToNumberList, the extension element is not used and the
number element is only used when the type is BroadWorks Mobility.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                |Type                 |Description                 |
|--------------------|---------------------|----------------------------|
|user_id             |str                  |userId                      |
|criteria_name       |str                  |criteriaName                |
|new_criteria_name   |str                  |newCriteriaName *Optional*  |
|time_schedule       |OCI.timeSchedule     |timeSchedule *Optional*     |
|from_dn_criteria    |OCI.fromDnCriteria   |fromDnCriteria *Optional*   |
|holiday_schedule    |OCI.holidaySchedule  |holidaySchedule *Optional*  |
|blacklisted         |bool                 |blacklisted *Optional*      |
|call_to_number_list |OCI.callToNumberList |callToNumberList *Optional* |
</div>


## `UserSequentialRingModifyCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a criteria for the user's sequential ring service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name              |Type                |Description                |
|------------------|--------------------|---------------------------|
|user_id           |str                 |userId                     |
|criteria_name     |str                 |criteriaName               |
|new_criteria_name |str                 |newCriteriaName *Optional* |
|time_schedule     |OCI.timeSchedule    |timeSchedule *Optional*    |
|from_dn_criteria  |OCI.fromDnCriteria  |fromDnCriteria *Optional*  |
|holiday_schedule  |OCI.holidaySchedule |holidaySchedule *Optional* |
|blacklisted       |bool                |blacklisted *Optional*     |
</div>


## `UserSharedCallAppearanceAddEndpointRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Associate an access device instance to the user's Shared Call Appearance.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type                     |Description          |
|-----------------------|-------------------------|---------------------|
|user_id                |str                      |userId               |
|access_device_endpoint |OCI.accessDeviceEndpoint |accessDeviceEndpoint |
</div>


## `UserSharedCallAppearanceAddEndpointRequest14sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Associate an access device instance to the user's Shared Call Appearance.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`UserSharedCallAppearanceAddEndpointRequest21()` in XS data mode Replaced by:
`UserSharedCallAppearanceAddEndpointRequest22()` in AS data mode

**Attributes:**

|Name                   |Type                     |Description          |
|-----------------------|-------------------------|---------------------|
|user_id                |str                      |userId               |
|access_device_endpoint |OCI.accessDeviceEndpoint |accessDeviceEndpoint |
|is_active              |bool                     |isActive             |
|allow_origination      |bool                     |allowOrigination     |
|allow_termination      |bool                     |allowTermination     |
</div>


## `UserSharedCallAppearanceAddEndpointRequest21sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Associate an access device instance to the user's Shared Call Appearance.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Replaced by:
`UserSharedCallAppearanceAddEndpointRequest21sp2()`.

**Attributes:**

|Name                   |Type                     |Description          |
|-----------------------|-------------------------|---------------------|
|user_id                |str                      |userId               |
|access_device_endpoint |OCI.accessDeviceEndpoint |accessDeviceEndpoint |
|is_active              |bool                     |isActive             |
|allow_origination      |bool                     |allowOrigination     |
|allow_termination      |bool                     |allowTermination     |
|allow_video            |bool                     |allowVideo           |
</div>


## `UserSharedCallAppearanceAddEndpointRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Associate an access device instance to the user's Shared Call Appearance.

The following elements are ignored in XS data mode: allowVideo, useValue true in AS
data mode

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type                     |Description          |
|-----------------------|-------------------------|---------------------|
|user_id                |str                      |userId               |
|access_device_endpoint |OCI.accessDeviceEndpoint |accessDeviceEndpoint |
|is_active              |bool                     |isActive             |
|allow_origination      |bool                     |allowOrigination     |
|allow_termination      |bool                     |allowTermination     |
|allow_video            |bool                     |allowVideo           |
</div>


## `UserSharedCallAppearanceDeleteEndpointListRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Disassociate one or more of a user's Shared Call Appearance endpoints.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type                           |Description          |
|-----------------------|-------------------------------|---------------------|
|user_id                |str                            |userId               |
|access_device_endpoint |List[OCI.accessDeviceEndpoint] |accessDeviceEndpoint |
</div>


## `UserSharedCallAppearanceGetEndpointRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's Shared Call Appearance endpoint setting.

The response is either a `UserSharedCallAppearanceGetEndpointResponse()` or an
`ErrorResponse()`. Replaced by: `UserSharedCallAppearanceGetEndpointRequest21()` in XS
data mode

**Attributes:**

|Name                   |Type                     |Description          |
|-----------------------|-------------------------|---------------------|
|user_id                |str                      |userId               |
|access_device_endpoint |OCI.accessDeviceEndpoint |accessDeviceEndpoint |
</div>


## `UserSharedCallAppearanceGetEndpointRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the user's Shared Call Appearance endpoint setting.

The response is either a `UserSharedCallAppearanceGetEndpointResponse22()` or an
`ErrorResponse()`.

**Attributes:**

|Name                   |Type                     |Description          |
|-----------------------|-------------------------|---------------------|
|user_id                |str                      |userId               |
|access_device_endpoint |OCI.accessDeviceEndpoint |accessDeviceEndpoint |
</div>


## `UserSharedCallAppearanceModifyEndpointRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Associate/Disassociate an access device instance to the user's Shared Call Appearance.

The following elements are only used in AS data mode and ignored in XS data mode:
useHotline hotlineContact

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type                     |Description                 |
|-----------------------|-------------------------|----------------------------|
|user_id                |str                      |userId                      |
|access_device_endpoint |OCI.accessDeviceEndpoint |accessDeviceEndpoint        |
|is_active              |bool                     |isActive *Optional*         |
|allow_origination      |bool                     |allowOrigination *Optional* |
|allow_termination      |bool                     |allowTermination *Optional* |
|use_hotline            |bool                     |useHotline *Optional*       |
|hotline_contact        |str                      |hotlineContact *Optional*   |
</div>


## `UserSimultaneousRingFamilyModifyCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a criteria for the user's simultaneous ring family service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name              |Type                |Description                |
|------------------|--------------------|---------------------------|
|user_id           |str                 |userId                     |
|criteria_name     |str                 |criteriaName               |
|new_criteria_name |str                 |newCriteriaName *Optional* |
|time_schedule     |OCI.timeSchedule    |timeSchedule *Optional*    |
|holiday_schedule  |OCI.holidaySchedule |holidaySchedule *Optional* |
|blacklisted       |bool                |blacklisted *Optional*     |
|from_dn_criteria  |OCI.fromDnCriteria  |fromDnCriteria *Optional*  |
</div>


## `UserSimultaneousRingFamilyModifyRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's simultaneous ring family service setting.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                          |Type                           |Description                           |
|------------------------------|-------------------------------|--------------------------------------|
|user_id                       |str                            |userId                                |
|is_active                     |bool                           |isActive *Optional*                   |
|do_not_ring_if_on_call        |bool                           |doNotRingIfOnCall *Optional*          |
|simultaneous_ring_number_list |OCI.simultaneousRingNumberList |simultaneousRingNumberList *Optional* |
|criteria_activation           |List[OCI.criteriaActivation]   |criteriaActivation *Optional*         |
</div>


## `UserSimultaneousRingPersonalModifyCriteriaRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a criteria for the user's simultaneous ring personal service.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name              |Type                |Description                |
|------------------|--------------------|---------------------------|
|user_id           |str                 |userId                     |
|criteria_name     |str                 |criteriaName               |
|new_criteria_name |str                 |newCriteriaName *Optional* |
|time_schedule     |OCI.timeSchedule    |timeSchedule *Optional*    |
|holiday_schedule  |OCI.holidaySchedule |holidaySchedule *Optional* |
|blacklisted       |bool                |blacklisted *Optional*     |
|from_dn_criteria  |OCI.fromDnCriteria  |fromDnCriteria *Optional*  |
</div>


## `UserSimultaneousRingPersonalModifyRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's simultaneous ring personal service setting.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                          |Type                           |Description                           |
|------------------------------|-------------------------------|--------------------------------------|
|user_id                       |str                            |userId                                |
|is_active                     |bool                           |isActive *Optional*                   |
|do_not_ring_if_on_call        |bool                           |doNotRingIfOnCall *Optional*          |
|simultaneous_ring_number_list |OCI.simultaneousRingNumberList |simultaneousRingNumberList *Optional* |
|criteria_activation           |List[OCI.criteriaActivation]   |criteriaActivation *Optional*         |
</div>


## `UserVideoAddOnModifyRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's Video Add-On service setting.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                               |Type                     |Description                               |
|-----------------------------------|-------------------------|------------------------------------------|
|user_id                            |str                      |userId                                    |
|is_active                          |bool                     |isActive *Optional*                       |
|max_originating_call_delay_seconds |int                      |maxOriginatingCallDelaySeconds *Optional* |
|access_device_endpoint             |OCI.accessDeviceEndpoint |accessDeviceEndpoint *Optional*           |
</div>


## `UserVoiceMessagingUserModifyGreetingRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's voice messaging greeting.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Engineering
Note: This command is used internally by Call Processing.

Replaced By: `UserVoiceMessagingUserModifyGreetingRequest16()`

**Attributes:**

|Name                             |Type                            |Description                              |
|---------------------------------|--------------------------------|-----------------------------------------|
|user_id                          |str                             |userId                                   |
|busy_announcement_selection      |str                             |busyAnnouncementSelection *Optional*     |
|busy_personal_audio_file         |OCI.busyPersonalAudioFile       |busyPersonalAudioFile *Optional*         |
|busy_personal_video_file         |OCI.busyPersonalVideoFile       |busyPersonalVideoFile *Optional*         |
|no_answer_announcement_selection |str                             |noAnswerAnnouncementSelection *Optional* |
|no_answer_personal_audio_file    |OCI.noAnswerPersonalAudioFile   |noAnswerPersonalAudioFile *Optional*     |
|no_answer_personal_video_file    |OCI.noAnswerPersonalVideoFile   |noAnswerPersonalVideoFile *Optional*     |
|no_answer_alternate_greeting01   |OCI.noAnswerAlternateGreeting01 |noAnswerAlternateGreeting01 *Optional*   |
|no_answer_alternate_greeting02   |OCI.noAnswerAlternateGreeting02 |noAnswerAlternateGreeting02 *Optional*   |
|no_answer_alternate_greeting03   |OCI.noAnswerAlternateGreeting03 |noAnswerAlternateGreeting03 *Optional*   |
|no_answer_number_of_rings        |int                             |noAnswerNumberOfRings *Optional*         |
</div>


## `UserVoiceMessagingUserModifyGreetingRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's voice messaging greeting.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Engineering
Note: This command is used internally by Call Processing.  The following elements are
only used in AS data mode and ignored in XS data mode: disableMessageDeposit
disableMessageDepositAction greetingOnlyForwardDestination Replaced by
`UserVoiceMessagingUserModifyGreetingRequest20()` in AS data mode

**Attributes:**

|Name                                  |Type                            |Description                                  |
|--------------------------------------|--------------------------------|---------------------------------------------|
|user_id                               |str                             |userId                                       |
|busy_announcement_selection           |str                             |busyAnnouncementSelection *Optional*         |
|busy_personal_audio_file              |OCI.busyPersonalAudioFile       |busyPersonalAudioFile *Optional*             |
|busy_personal_video_file              |OCI.busyPersonalVideoFile       |busyPersonalVideoFile *Optional*             |
|no_answer_announcement_selection      |str                             |noAnswerAnnouncementSelection *Optional*     |
|no_answer_personal_audio_file         |OCI.noAnswerPersonalAudioFile   |noAnswerPersonalAudioFile *Optional*         |
|no_answer_personal_video_file         |OCI.noAnswerPersonalVideoFile   |noAnswerPersonalVideoFile *Optional*         |
|extended_away_enabled                 |bool                            |extendedAwayEnabled *Optional*               |
|extended_away_disable_message_deposit |bool                            |extendedAwayDisableMessageDeposit *Optional* |
|extended_away_audio_file              |OCI.extendedAwayAudioFile       |extendedAwayAudioFile *Optional*             |
|extended_away_video_file              |OCI.extendedAwayVideoFile       |extendedAwayVideoFile *Optional*             |
|no_answer_alternate_greeting01        |OCI.noAnswerAlternateGreeting01 |noAnswerAlternateGreeting01 *Optional*       |
|no_answer_alternate_greeting02        |OCI.noAnswerAlternateGreeting02 |noAnswerAlternateGreeting02 *Optional*       |
|no_answer_alternate_greeting03        |OCI.noAnswerAlternateGreeting03 |noAnswerAlternateGreeting03 *Optional*       |
|no_answer_number_of_rings             |int                             |noAnswerNumberOfRings *Optional*             |
|disable_message_deposit               |bool                            |disableMessageDeposit *Optional*             |
|disable_message_deposit_action        |str                             |disableMessageDepositAction *Optional*       |
|greeting_only_forward_destination     |str                             |greetingOnlyForwardDestination *Optional*    |
</div>


## `UserVoiceMessagingUserModifyGreetingRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's voice messaging greeting.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Engineering
Note: This command is used internally by Call Processing.  The following elements are
only used in AS data mode: disableMessageDeposit disableMessageDepositAction
greetingOnlyForwardDestination

**Attributes:**

|Name                                  |Type                            |Description                                  |
|--------------------------------------|--------------------------------|---------------------------------------------|
|user_id                               |str                             |userId                                       |
|busy_announcement_selection           |str                             |busyAnnouncementSelection *Optional*         |
|busy_personal_audio_file              |OCI.busyPersonalAudioFile       |busyPersonalAudioFile *Optional*             |
|busy_personal_video_file              |OCI.busyPersonalVideoFile       |busyPersonalVideoFile *Optional*             |
|no_answer_announcement_selection      |str                             |noAnswerAnnouncementSelection *Optional*     |
|no_answer_personal_audio_file         |OCI.noAnswerPersonalAudioFile   |noAnswerPersonalAudioFile *Optional*         |
|no_answer_personal_video_file         |OCI.noAnswerPersonalVideoFile   |noAnswerPersonalVideoFile *Optional*         |
|no_answer_alternate_greeting01        |OCI.noAnswerAlternateGreeting01 |noAnswerAlternateGreeting01 *Optional*       |
|no_answer_alternate_greeting02        |OCI.noAnswerAlternateGreeting02 |noAnswerAlternateGreeting02 *Optional*       |
|no_answer_alternate_greeting03        |OCI.noAnswerAlternateGreeting03 |noAnswerAlternateGreeting03 *Optional*       |
|extended_away_enabled                 |bool                            |extendedAwayEnabled *Optional*               |
|extended_away_disable_message_deposit |bool                            |extendedAwayDisableMessageDeposit *Optional* |
|extended_away_audio_file              |OCI.extendedAwayAudioFile       |extendedAwayAudioFile *Optional*             |
|extended_away_video_file              |OCI.extendedAwayVideoFile       |extendedAwayVideoFile *Optional*             |
|no_answer_number_of_rings             |int                             |noAnswerNumberOfRings *Optional*             |
|disable_message_deposit               |bool                            |disableMessageDeposit *Optional*             |
|disable_message_deposit_action        |str                             |disableMessageDepositAction *Optional*       |
|greeting_only_forward_destination     |str                             |greetingOnlyForwardDestination *Optional*    |
</div>


## `UserVoiceMessagingUserModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's voice messaging advanced voice management service setting.

Modify a voice mail distribution list for a users voice message.  Modify the user's
voice messaging greeting.  Modify the user's voice messaging outgoing message waiting
indicator service setting.  Modify the user's voice messaging voice portal settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                             |Type                                     |Description                                          |
|-------------------------------------------------|-----------------------------------------|-----------------------------------------------------|
|user_id                                          |str                                      |userId                                               |
|mail_server_selection                            |str                                      |mailServerSelection *Optional*                       |
|group_mail_server_email_address                  |str                                      |groupMailServerEmailAddress *Optional*               |
|group_mail_server_user_id                        |str                                      |groupMailServerUserId *Optional*                     |
|group_mail_server_password                       |str                                      |groupMailServerPassword *Optional*                   |
|use_group_default_mail_server_full_mailbox_limit |bool                                     |useGroupDefaultMailServerFullMailboxLimit *Optional* |
|group_mail_server_full_mailbox_limit             |int                                      |groupMailServerFullMailboxLimit *Optional*           |
|personal_mail_server_net_address                 |str                                      |personalMailServerNetAddress *Optional*              |
|personal_mail_server_protocol                    |str                                      |personalMailServerProtocol *Optional*                |
|personal_mail_server_real_delete_for_imap        |bool                                     |personalMailServerRealDeleteForImap *Optional*       |
|personal_mail_server_email_address               |str                                      |personalMailServerEmailAddress *Optional*            |
|personal_mail_server_user_id                     |str                                      |personalMailServerUserId *Optional*                  |
|personal_mail_server_password                    |str                                      |personalMailServerPassword *Optional*                |
|voice_messaging_distribution_list                |List[OCI.voiceMessagingDistributionList] |voiceMessagingDistributionList *Optional*            |
|busy_announcement_selection                      |str                                      |busyAnnouncementSelection *Optional*                 |
|busy_personal_audio_file                         |OCI.busyPersonalAudioFile                |busyPersonalAudioFile *Optional*                     |
|busy_personal_video_file                         |OCI.busyPersonalVideoFile                |busyPersonalVideoFile *Optional*                     |
|no_answer_announcement_selection                 |str                                      |noAnswerAnnouncementSelection *Optional*             |
|no_answer_personal_audio_file                    |OCI.noAnswerPersonalAudioFile            |noAnswerPersonalAudioFile *Optional*                 |
|no_answer_personal_video_file                    |OCI.noAnswerPersonalVideoFile            |noAnswerPersonalVideoFile *Optional*                 |
|no_answer_alternate_greeting01                   |OCI.noAnswerAlternateGreeting01          |noAnswerAlternateGreeting01 *Optional*               |
|no_answer_alternate_greeting02                   |OCI.noAnswerAlternateGreeting02          |noAnswerAlternateGreeting02 *Optional*               |
|no_answer_alternate_greeting03                   |OCI.noAnswerAlternateGreeting03          |noAnswerAlternateGreeting03 *Optional*               |
|extended_away_enabled                            |bool                                     |extendedAwayEnabled *Optional*                       |
|extended_away_disable_message_deposit            |bool                                     |extendedAwayDisableMessageDeposit *Optional*         |
|extended_away_audio_file                         |OCI.extendedAwayAudioFile                |extendedAwayAudioFile *Optional*                     |
|extended_away_video_file                         |OCI.extendedAwayVideoFile                |extendedAwayVideoFile *Optional*                     |
|no_answer_number_of_rings                        |int                                      |noAnswerNumberOfRings *Optional*                     |
|disable_message_deposit                          |bool                                     |disableMessageDeposit *Optional*                     |
|disable_message_deposit_action                   |str                                      |disableMessageDepositAction *Optional*               |
|greeting_only_forward_destination                |str                                      |greetingOnlyForwardDestination *Optional*            |
|outgoing_smdimw_iis_active                       |bool                                     |outgoingSMDIMWIisActive *Optional*                   |
|outgoing_smdimwi_phone_number_list               |OCI.outgoingSMDIMWIPhoneNumberList       |outgoingSMDIMWIPhoneNumberList *Optional*            |
|voice_managementis_active                        |bool                                     |voiceManagementisActive *Optional*                   |
|processing                                       |str                                      |processing *Optional*                                |
|voice_message_delivery_email_address             |str                                      |voiceMessageDeliveryEmailAddress *Optional*          |
|use_phone_message_waiting_indicator              |bool                                     |usePhoneMessageWaitingIndicator *Optional*           |
|send_voice_message_notify_email                  |bool                                     |sendVoiceMessageNotifyEmail *Optional*               |
|voice_message_notify_email_address               |str                                      |voiceMessageNotifyEmailAddress *Optional*            |
|send_carbon_copy_voice_message                   |bool                                     |sendCarbonCopyVoiceMessage *Optional*                |
|voice_message_carbon_copy_email_address          |str                                      |voiceMessageCarbonCopyEmailAddress *Optional*        |
|transfer_on_zero_to_phone_number                 |bool                                     |transferOnZeroToPhoneNumber *Optional*               |
|transfer_phone_number                            |str                                      |transferPhoneNumber *Optional*                       |
|always_redirect_to_voice_mail                    |bool                                     |alwaysRedirectToVoiceMail *Optional*                 |
|busy_redirect_to_voice_mail                      |bool                                     |busyRedirectToVoiceMail *Optional*                   |
|no_answer_redirect_to_voice_mail                 |bool                                     |noAnswerRedirectToVoiceMail *Optional*               |
|out_of_primary_zone_redirect_to_voice_mail       |bool                                     |outOfPrimaryZoneRedirectToVoiceMail *Optional*       |
|use_personalized_name                            |bool                                     |usePersonalizedName *Optional*                       |
|voice_portal_auto_login                          |bool                                     |voicePortalAutoLogin *Optional*                      |
|personalized_name_audio_file                     |OCI.personalizedNameAudioFile            |personalizedNameAudioFile *Optional*                 |
|user_messaging_alias_list                        |OCI.userMessagingAliasList               |userMessagingAliasList *Optional*                    |
</div>


## `UserVoiceMessagingUserModifyRequest23`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user's voice messaging advanced voice management service setting.

Modify a voice mail distribution list for a users voice message.  Modify the user's
voice messaging greeting.  Modify the user's voice messaging outgoing message waiting
indicator service setting.  Modify the user's voice messaging voice portal settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                             |Type                                     |Description                                          |
|-------------------------------------------------|-----------------------------------------|-----------------------------------------------------|
|user_id                                          |str                                      |userId                                               |
|mail_server_selection                            |str                                      |mailServerSelection *Optional*                       |
|group_mail_server_email_address                  |str                                      |groupMailServerEmailAddress *Optional*               |
|group_mail_server_user_id                        |str                                      |groupMailServerUserId *Optional*                     |
|group_mail_server_password                       |str                                      |groupMailServerPassword *Optional*                   |
|use_group_default_mail_server_full_mailbox_limit |bool                                     |useGroupDefaultMailServerFullMailboxLimit *Optional* |
|group_mail_server_full_mailbox_limit             |int                                      |groupMailServerFullMailboxLimit *Optional*           |
|personal_mail_server_net_address                 |str                                      |personalMailServerNetAddress *Optional*              |
|personal_mail_server_protocol                    |str                                      |personalMailServerProtocol *Optional*                |
|personal_mail_server_real_delete_for_imap        |bool                                     |personalMailServerRealDeleteForImap *Optional*       |
|personal_mail_server_email_address               |str                                      |personalMailServerEmailAddress *Optional*            |
|personal_mail_server_user_id                     |str                                      |personalMailServerUserId *Optional*                  |
|personal_mail_server_password                    |str                                      |personalMailServerPassword *Optional*                |
|voice_messaging_distribution_list                |List[OCI.voiceMessagingDistributionList] |voiceMessagingDistributionList *Optional*            |
|busy_announcement_selection                      |str                                      |busyAnnouncementSelection *Optional*                 |
|busy_personal_audio_file                         |OCI.busyPersonalAudioFile                |busyPersonalAudioFile *Optional*                     |
|busy_personal_video_file                         |OCI.busyPersonalVideoFile                |busyPersonalVideoFile *Optional*                     |
|no_answer_announcement_selection                 |str                                      |noAnswerAnnouncementSelection *Optional*             |
|no_answer_personal_audio_file                    |OCI.noAnswerPersonalAudioFile            |noAnswerPersonalAudioFile *Optional*                 |
|no_answer_personal_video_file                    |OCI.noAnswerPersonalVideoFile            |noAnswerPersonalVideoFile *Optional*                 |
|no_answer_alternate_greeting01                   |OCI.noAnswerAlternateGreeting01          |noAnswerAlternateGreeting01 *Optional*               |
|no_answer_alternate_greeting02                   |OCI.noAnswerAlternateGreeting02          |noAnswerAlternateGreeting02 *Optional*               |
|no_answer_alternate_greeting03                   |OCI.noAnswerAlternateGreeting03          |noAnswerAlternateGreeting03 *Optional*               |
|extended_away_enabled                            |bool                                     |extendedAwayEnabled *Optional*                       |
|extended_away_disable_message_deposit            |bool                                     |extendedAwayDisableMessageDeposit *Optional*         |
|extended_away_audio_file                         |OCI.extendedAwayAudioFile                |extendedAwayAudioFile *Optional*                     |
|extended_away_video_file                         |OCI.extendedAwayVideoFile                |extendedAwayVideoFile *Optional*                     |
|no_answer_number_of_rings                        |int                                      |noAnswerNumberOfRings *Optional*                     |
|disable_message_deposit                          |bool                                     |disableMessageDeposit *Optional*                     |
|disable_message_deposit_action                   |str                                      |disableMessageDepositAction *Optional*               |
|greeting_only_forward_destination                |str                                      |greetingOnlyForwardDestination *Optional*            |
|outgoing_smdimw_iis_active                       |bool                                     |outgoingSMDIMWIisActive *Optional*                   |
|outgoing_smdimwi_phone_number_list               |OCI.outgoingSMDIMWIPhoneNumberList       |outgoingSMDIMWIPhoneNumberList *Optional*            |
|voice_managementis_active                        |bool                                     |voiceManagementisActive *Optional*                   |
|processing                                       |str                                      |processing *Optional*                                |
|voice_message_delivery_email_address             |str                                      |voiceMessageDeliveryEmailAddress *Optional*          |
|use_phone_message_waiting_indicator              |bool                                     |usePhoneMessageWaitingIndicator *Optional*           |
|send_voice_message_notify_email                  |bool                                     |sendVoiceMessageNotifyEmail *Optional*               |
|voice_message_notify_email_address               |str                                      |voiceMessageNotifyEmailAddress *Optional*            |
|send_carbon_copy_voice_message                   |bool                                     |sendCarbonCopyVoiceMessage *Optional*                |
|voice_message_carbon_copy_email_address          |str                                      |voiceMessageCarbonCopyEmailAddress *Optional*        |
|transfer_on_zero_to_phone_number                 |bool                                     |transferOnZeroToPhoneNumber *Optional*               |
|transfer_phone_number                            |str                                      |transferPhoneNumber *Optional*                       |
|always_redirect_to_voice_mail                    |bool                                     |alwaysRedirectToVoiceMail *Optional*                 |
|busy_redirect_to_voice_mail                      |bool                                     |busyRedirectToVoiceMail *Optional*                   |
|no_answer_redirect_to_voice_mail                 |bool                                     |noAnswerRedirectToVoiceMail *Optional*               |
|out_of_primary_zone_redirect_to_voice_mail       |bool                                     |outOfPrimaryZoneRedirectToVoiceMail *Optional*       |
|use_personalized_name                            |bool                                     |usePersonalizedName *Optional*                       |
|voice_portal_auto_login                          |bool                                     |voicePortalAutoLogin *Optional*                      |
|personalized_name_audio_file                     |OCI.personalizedNameAudioFile            |personalizedNameAudioFile *Optional*                 |
|user_messaging_alias_list                        |OCI.userMessagingAliasList               |userMessagingAliasList *Optional*                    |
</div>


## `EnterpriseBroadWorksMobilityMobileSubscriberDirectoryNumberGetAssignmentPagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a summary table of all Mobile Subscriber Directory Numbers in an enterprise.

If the responsePagingControl element is not provided, the paging startIndex will be
set to 1 by default, and the responsePageSize will be set to the maximum
ResponsePageSize by default.  If no sortOrder is included the response is sorted by
Mobile Number ascending by default.  Multiple search criteria are logically ANDed
together unless the searchCriteriaModeOr option is included.  Then the search criteria
are logically ORed together.  The department in both the search criteria and sort by
fields refer to the department of the user.

The response is either
`EnterpriseBroadWorksMobilityMobileSubscriberDirectoryNumberGetAssignmentPagedSortedListResponse()`
or `ErrorResponse()`. Replaced by:
`EnterpriseBroadWorksMobilityMobileSubscriberDirectoryNumberGetAssignmentPagedSortedListRequest22()`

**Attributes:**

|Name                                               |Type                                                    |Description                                              |
|---------------------------------------------------|--------------------------------------------------------|---------------------------------------------------------|
|service_provider_id                                |str                                                     |serviceProviderId                                        |
|response_paging_control                            |OCI.responsePagingControl                               |responsePagingControl *Optional*                         |
|sort_order                                         |List[OCI.sortOrder]                                     |sortOrder *Optional*                                     |
|search_criteria_mobile_subscriber_directory_number |List[OCI.searchCriteriaMobileSubscriberDirectoryNumber] |searchCriteriaMobileSubscriberDirectoryNumber *Optional* |
|search_criteria_group_id                           |List[OCI.searchCriteriaGroupId]                         |searchCriteriaGroupId *Optional*                         |
|search_criteria_user_id                            |List[OCI.searchCriteriaUserId]                          |searchCriteriaUserId *Optional*                          |
|search_criteria_user_last_name                     |List[OCI.searchCriteriaUserLastName]                    |searchCriteriaUserLastName *Optional*                    |
|search_criteria_user_first_name                    |List[OCI.searchCriteriaUserFirstName]                   |searchCriteriaUserFirstName *Optional*                   |
|search_criteria_dn                                 |List[OCI.searchCriteriaDn]                              |searchCriteriaDn *Optional*                              |
|search_criteria_extension                          |List[OCI.searchCriteriaExtension]                       |searchCriteriaExtension *Optional*                       |
|search_criteria_department_name                    |List[OCI.searchCriteriaDepartmentName]                  |searchCriteriaDepartmentName *Optional*                  |
|search_criteria_exact_mobile_network               |List[OCI.searchCriteriaExactMobileNetwork]              |searchCriteriaExactMobileNetwork *Optional*              |
|search_criteria_exact_mobile_dn_availability       |OCI.searchCriteriaExactMobileDnAvailability             |searchCriteriaExactMobileDnAvailability *Optional*       |
|search_criteria_mode_or                            |bool                                                    |searchCriteriaModeOr *Optional*                          |
</div>


## `EnterpriseBroadWorksMobilityMobileSubscriberDirectoryNumberGetAssignmentPagedSortedListRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a summary table of all Mobile Subscriber Directory Numbers in an enterprise.

If the responsePagingControl element is not provided, the paging startIndex will be
set to 1 by default, and the responsePageSize will be set to the maximum
ResponsePageSize by default.  If no sortOrder is included the response is sorted by
Mobile Number ascending by default.  Multiple search criteria are logically ANDed
together unless the searchCriteriaModeOr option is included.  Then the search criteria
are logically ORed together.  The department in both the search criteria and sort by
fields refer to the department of the user.

The response is either
`EnterpriseBroadWorksMobilityMobileSubscriberDirectoryNumberGetAssignmentPagedSortedListResponse22()`
or `ErrorResponse()`.

**Attributes:**

|Name                                               |Type                                                    |Description                                              |
|---------------------------------------------------|--------------------------------------------------------|---------------------------------------------------------|
|service_provider_id                                |str                                                     |serviceProviderId                                        |
|include_total_number_of_rows                       |bool                                                    |includeTotalNumberOfRows *Optional*                      |
|response_paging_control                            |OCI.responsePagingControl                               |responsePagingControl *Optional*                         |
|sort_order                                         |List[OCI.sortOrder]                                     |sortOrder *Optional*                                     |
|search_criteria_mobile_subscriber_directory_number |List[OCI.searchCriteriaMobileSubscriberDirectoryNumber] |searchCriteriaMobileSubscriberDirectoryNumber *Optional* |
|search_criteria_group_id                           |List[OCI.searchCriteriaGroupId]                         |searchCriteriaGroupId *Optional*                         |
|search_criteria_user_id                            |List[OCI.searchCriteriaUserId]                          |searchCriteriaUserId *Optional*                          |
|search_criteria_user_last_name                     |List[OCI.searchCriteriaUserLastName]                    |searchCriteriaUserLastName *Optional*                    |
|search_criteria_user_first_name                    |List[OCI.searchCriteriaUserFirstName]                   |searchCriteriaUserFirstName *Optional*                   |
|search_criteria_dn                                 |List[OCI.searchCriteriaDn]                              |searchCriteriaDn *Optional*                              |
|search_criteria_extension                          |List[OCI.searchCriteriaExtension]                       |searchCriteriaExtension *Optional*                       |
|search_criteria_department_name                    |List[OCI.searchCriteriaDepartmentName]                  |searchCriteriaDepartmentName *Optional*                  |
|search_criteria_exact_mobile_network               |List[OCI.searchCriteriaExactMobileNetwork]              |searchCriteriaExactMobileNetwork *Optional*              |
|search_criteria_exact_mobile_dn_availability       |OCI.searchCriteriaExactMobileDnAvailability             |searchCriteriaExactMobileDnAvailability *Optional*       |
|search_criteria_mode_or                            |bool                                                    |searchCriteriaModeOr *Optional*                          |
</div>


## `EnterpriseCallCenterAgentThresholdProfileGetAvailableAgentPagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of all Agents in the Enterprise that can be assigned to a given Call
Center Agent Threshold Profile in an Enterprise.

An agent is available to be assigned to a given Agent Threshold Profile if it is a
Call Center Standard or Call Center Premium agent and the agent is not yet assigned to
the profile.  If the responsePagingControl element is not provided, the paging
startIndex will be set to 1 by default, and the responsePageSize will be set to the
maximum ResponsePageSize by default.  It is possible to search by various criteria to
restrict the number of rows returned.  The available agent list for a new Call Center
Agent Threshold profile can be obtained by not setting the
excludeAgentsAssignedToProfileName.  When the excludeAgentsAssignedToProfileName is
specified, all agents already assigned to the specified profile are not included in
the response, even if the search criterion element searchCriteriaAgentThresholdProfile
is specified using the same profile name.  If no sortOrder is included the response is
sorted by User Id ascending by default.  Multiple search criteria are logically ANDed
together unless the searchCriteriaModeOr option is included.  Then the search criteria
are logically ORed together.  `ErrorResponse()` is returned if
searchCriteriaExactUserGroup has multiple entries and searchCriteriaModeOr is not
included.

The response is either a
`EnterpriseCallCenterAgentThresholdProfileGetAvailableAgentPagedSortedListResponse()`
or an `ErrorResponse()`.

**Attributes:**

|Name                                    |Type                                          |Description                                    |
|----------------------------------------|----------------------------------------------|-----------------------------------------------|
|service_provider_id                     |str                                           |serviceProviderId                              |
|exclude_agents_assigned_to_profile_name |str                                           |excludeAgentsAssignedToProfileName *Optional*  |
|response_paging_control                 |OCI.responsePagingControl                     |responsePagingControl *Optional*               |
|sort_order                              |List[OCI.sortOrder]                           |sortOrder *Optional*                           |
|search_criteria_user_id                 |List[OCI.searchCriteriaUserId]                |searchCriteriaUserId *Optional*                |
|search_criteria_user_last_name          |List[OCI.searchCriteriaUserLastName]          |searchCriteriaUserLastName *Optional*          |
|search_criteria_user_first_name         |List[OCI.searchCriteriaUserFirstName]         |searchCriteriaUserFirstName *Optional*         |
|search_criteria_dn                      |List[OCI.searchCriteriaDn]                    |searchCriteriaDn *Optional*                    |
|search_criteria_extension               |List[OCI.searchCriteriaExtension]             |searchCriteriaExtension *Optional*             |
|search_criteria_department_name         |List[OCI.searchCriteriaDepartmentName]        |searchCriteriaDepartmentName *Optional*        |
|search_criteria_email_address           |List[OCI.searchCriteriaEmailAddress]          |searchCriteriaEmailAddress *Optional*          |
|search_criteria_agent_threshold_profile |List[OCI.searchCriteriaAgentThresholdProfile] |searchCriteriaAgentThresholdProfile *Optional* |
|search_criteria_exact_user_group        |List[OCI.searchCriteriaExactUserGroup]        |searchCriteriaExactUserGroup *Optional*        |
|search_criteria_mode_or                 |bool                                          |searchCriteriaModeOr *Optional*                |
</div>


## `EnterpriseCallCenterAgentThresholdProfileGetPagedSortedRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Gets an existing specified Call Center Agent Threshold Profile in an Enterprise.

The agentTable is what the search, sort, and pagination fields apply to.  If the
responsePagingControl element is not provided, the paging startIndex will be set to 1
by default, and the responsePageSize will be set to the maximum ResponsePageSize by
default.  It is possible to search by various criteria to restrict the number of rows
returned.  If no sortOrder is included the response is sorted by User Id ascending by
default.  Multiple search criteria are logically ANDed together unless the
searchCriteriaModeOr option is included.  Then the search criteria are logically ORed
together.  `ErrorResponse()` is returned if searchCriteriaExactUserGroup has multiple
entries and searchCriteriaModeOr is not included.

The response is either a
`EnterpriseCallCenterAgentThresholdProfileGetPagedSortedResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                             |Type                                   |Description                             |
|---------------------------------|---------------------------------------|----------------------------------------|
|service_provider_id              |str                                    |serviceProviderId                       |
|profile_name                     |str                                    |profileName                             |
|response_paging_control          |OCI.responsePagingControl              |responsePagingControl *Optional*        |
|sort_order                       |List[OCI.sortOrder]                    |sortOrder *Optional*                    |
|search_criteria_user_id          |List[OCI.searchCriteriaUserId]         |searchCriteriaUserId *Optional*         |
|search_criteria_user_last_name   |List[OCI.searchCriteriaUserLastName]   |searchCriteriaUserLastName *Optional*   |
|search_criteria_user_first_name  |List[OCI.searchCriteriaUserFirstName]  |searchCriteriaUserFirstName *Optional*  |
|search_criteria_dn               |List[OCI.searchCriteriaDn]             |searchCriteriaDn *Optional*             |
|search_criteria_extension        |List[OCI.searchCriteriaExtension]      |searchCriteriaExtension *Optional*      |
|search_criteria_department_name  |List[OCI.searchCriteriaDepartmentName] |searchCriteriaDepartmentName *Optional* |
|search_criteria_exact_user_group |List[OCI.searchCriteriaExactUserGroup] |searchCriteriaExactUserGroup *Optional* |
|search_criteria_group_name       |List[OCI.searchCriteriaGroupName]      |searchCriteriaGroupName *Optional*      |
|search_criteria_email_address    |List[OCI.searchCriteriaEmailAddress]   |searchCriteriaEmailAddress *Optional*   |
|search_criteria_mode_or          |bool                                   |searchCriteriaModeOr *Optional*         |
</div>


## `EnterpriseCallCenterEnhancedReportingScheduledReportAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add an enterprise level call center reporting scheduled report.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The startDate
element is adjusted to the first occurrence of the recurrent schedule that comes at or
after startDate.

**Attributes:**

|Name                               |Type                       |Description                                |
|-----------------------------------|---------------------------|-------------------------------------------|
|service_provider_id                |str                        |serviceProviderId                          |
|name                               |str                        |name                                       |
|description                        |str                        |description *Optional*                     |
|report_template                    |OCI.reportTemplate         |reportTemplate                             |
|schedule                           |OCI.schedule               |schedule                                   |
|sampling_period                    |str                        |samplingPeriod *Optional*                  |
|start_day_of_week                  |str                        |startDayOfWeek *Optional*                  |
|report_time_zone                   |str                        |reportTimeZone                             |
|report_date_format                 |str                        |reportDateFormat                           |
|report_time_format                 |str                        |reportTimeFormat                           |
|report_interval                    |OCI.reportInterval         |reportInterval                             |
|report_format                      |str                        |reportFormat                               |
|agent                              |OCI.agent                  |agent *Optional*                           |
|call_center                        |OCI.callCenter             |callCenter *Optional*                      |
|dnis                               |OCI.dnis                   |dnis *Optional*                            |
|call_completion_threshold_seconds  |int                        |callCompletionThresholdSeconds *Optional*  |
|short_duration_threshold_seconds   |int                        |shortDurationThresholdSeconds *Optional*   |
|service_level_threshold_seconds    |List[int]                  |serviceLevelThresholdSeconds *Optional*    |
|service_level_inclusions           |OCI.serviceLevelInclusions |serviceLevelInclusions *Optional*          |
|service_level_objective_percentage |int                        |serviceLevelObjectivePercentage *Optional* |
|abandoned_call_threshold_seconds   |List[int]                  |abandonedCallThresholdSeconds *Optional*   |
|email_address                      |List[str]                  |emailAddress                               |
</div>


## `EnterpriseCallCenterEnhancedReportingScheduledReportModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify an enterprise level call center reporting scheduled report.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The startDate
element is adjusted to the first occurrence of the recurrent schedule that comes at or
after startDate.

**Attributes:**

|Name                               |Type                              |Description                                |
|-----------------------------------|----------------------------------|-------------------------------------------|
|service_provider_id                |str                               |serviceProviderId                          |
|name                               |str                               |name                                       |
|new_name                           |str                               |newName *Optional*                         |
|description                        |str                               |description *Optional*                     |
|schedule                           |OCI.schedule                      |schedule *Optional*                        |
|sampling_period                    |str                               |samplingPeriod *Optional*                  |
|start_day_of_week                  |str                               |startDayOfWeek *Optional*                  |
|report_time_zone                   |str                               |reportTimeZone *Optional*                  |
|report_date_format                 |str                               |reportDateFormat *Optional*                |
|report_time_format                 |str                               |reportTimeFormat *Optional*                |
|report_interval                    |OCI.reportInterval                |reportInterval *Optional*                  |
|report_format                      |str                               |reportFormat *Optional*                    |
|agent                              |OCI.agent                         |agent *Optional*                           |
|call_center                        |OCI.callCenter                    |callCenter *Optional*                      |
|dnis                               |OCI.dnis                          |dnis *Optional*                            |
|call_completion_threshold_seconds  |int                               |callCompletionThresholdSeconds *Optional*  |
|short_duration_threshold_seconds   |int                               |shortDurationThresholdSeconds *Optional*   |
|service_level_threshold_seconds    |OCI.serviceLevelThresholdSeconds  |serviceLevelThresholdSeconds *Optional*    |
|service_level_inclusions           |OCI.serviceLevelInclusions        |serviceLevelInclusions *Optional*          |
|service_level_objective_percentage |int                               |serviceLevelObjectivePercentage *Optional* |
|abandoned_call_threshold_seconds   |OCI.abandonedCallThresholdSeconds |abandonedCallThresholdSeconds *Optional*   |
|email_address                      |OCI.emailAddress                  |emailAddress *Optional*                    |
</div>


## `EnterprisePhoneDirectoryGetPagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a table containing the phone directory for an enterprise.

The directory includes all users in the enterprise and all entries in the enterprise
common phone list.  If the responsePagingControl element is not provided, the paging
startIndex will be set to 1 by default, and the responsePageSize will be set to the
maximum ResponsePageSize by default.  It is possible to search by various criteria to
restrict the number of rows returned.  If no sortOrder is included the response is
sorted by User Id ascending with a secondary sort by User Last Name ascending by
default.  Multiple search criteria are logically ANDed together unless the
searchCriteriaModeOr option is included.  Then the search criteria are logically ORed
together.  `ErrorResponse()` is returned if searchCriteriaExactUserGroup or
searchCriteriaExactUserDepartment have multiple entries and searchCriteriaModeOr is
not included The following elements are only used in AS data mode and ignored in
Amplify and XS data mode: "sortByImpId" "searchCriteriaImpId"

The response is either `EnterprisePhoneDirectoryGetPagedSortedListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                      |Description                                  |
|--------------------------------------|------------------------------------------|---------------------------------------------|
|enterprise_id                         |str                                       |enterpriseId                                 |
|is_extended_info_requested            |bool                                      |isExtendedInfoRequested                      |
|response_paging_control               |OCI.responsePagingControl                 |responsePagingControl *Optional*             |
|sort_order                            |List[OCI.sortOrder]                       |sortOrder *Optional*                         |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]      |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName]     |searchCriteriaUserFirstName *Optional*       |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]                |searchCriteriaDn *Optional*                  |
|search_criteria_group_location_code   |List[OCI.searchCriteriaGroupLocationCode] |searchCriteriaGroupLocationCode *Optional*   |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]         |searchCriteriaExtension *Optional*           |
|search_criteria_mobile_phone_number   |List[OCI.searchCriteriaMobilePhoneNumber] |searchCriteriaMobilePhoneNumber *Optional*   |
|search_criteria_email_address         |List[OCI.searchCriteriaEmailAddress]      |searchCriteriaEmailAddress *Optional*        |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment     |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_department_name       |List[OCI.searchCriteriaDepartmentName]    |searchCriteriaDepartmentName *Optional*      |
|search_criteria_exact_user_group      |OCI.searchCriteriaExactUserGroup          |searchCriteriaExactUserGroup *Optional*      |
|search_criteria_group_name            |List[OCI.searchCriteriaGroupName]         |searchCriteriaGroupName *Optional*           |
|search_criteria_yahoo_id              |List[OCI.searchCriteriaYahooId]           |searchCriteriaYahooId *Optional*             |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]            |searchCriteriaUserId *Optional*              |
|search_criteria_imp_id                |List[OCI.searchCriteriaImpId]             |searchCriteriaImpId *Optional*               |
|search_criteria_mode_or               |bool                                      |searchCriteriaModeOr *Optional*              |
</div>


## `EnterpriseSessionAdmissionControlGroupModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a session admission control group for the enterprise.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. Note that to
provision the accessInfoPattern element, the captureAccessInfoInPaniHeader system
parameter needs to be set to "true".

**Attributes:**

|Name                                               |Type           |Description                                           |
|---------------------------------------------------|---------------|------------------------------------------------------|
|service_provider_id                                |str            |serviceProviderId                                     |
|name                                               |str            |name                                                  |
|new_name                                           |str            |newName *Optional*                                    |
|max_session                                        |int            |maxSession *Optional*                                 |
|max_user_originating_sessions                      |int            |maxUserOriginatingSessions *Optional*                 |
|max_user_terminating_sessions                      |int            |maxUserTerminatingSessions *Optional*                 |
|reserved_session                                   |int            |reservedSession *Optional*                            |
|reserved_user_originating_sessions                 |int            |reservedUserOriginatingSessions *Optional*            |
|reserved_user_terminating_sessions                 |int            |reservedUserTerminatingSessions *Optional*            |
|become_default_group                               |bool           |becomeDefaultGroup *Optional*                         |
|count_intra_sac_group_sessions                     |bool           |countIntraSACGroupSessions *Optional*                 |
|device_list                                        |OCI.deviceList |deviceList *Optional*                                 |
|block_emergency_and_repair_calls_due_to_sac_limits |bool           |blockEmergencyAndRepairCallsDueToSACLimits *Optional* |
|media_group_name                                   |str            |mediaGroupName *Optional*                             |
|access_info_pattern                                |str            |accessInfoPattern *Optional*                          |
</div>


## `GroupAccessDeviceGetPagedSortedListRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Requests the list of access devices in a group.

The response is either `GroupAccessDeviceGetPagedSortedListResponse()` or
`ErrorResponse()`. If no sortOrder is included, the response is sorted by Device Name
ascending by default.  If the responsePagingControl element is not provided, the
paging startIndex will be set to 1 by default, and the responsePageSize will be set to
the maximum responsePageSize by default.  Multiple search criteria are logically ANDed
together unless the searchCriteriaModeOr option is included.  Then the search criteria
are logically ORed together.  The getVisualDeviceManagementAPIDevicesOnly element can
only be set when CloudPBX is licenced.  If the getVisualDeviceManagementAPIDevicesOnly
element is not set, all devices are returned with Visual Device Management API flag
set to empty.  If the getVisualDeviceManagementAPIDevicesOnly element is set to true,
only SIP devices supporting Visual Device Management API are returned.  If the
getVisualDeviceManagementAPIDevicesOnly element is set to false, all SIP devices are
returned with their current Visual Device Management API flag value.

**Attributes:**

|Name                                          |Type                                        |Description                                        |
|----------------------------------------------|--------------------------------------------|---------------------------------------------------|
|service_provider_id                           |str                                         |serviceProviderId                                  |
|group_id                                      |str                                         |groupId                                            |
|include_total_number_of_rows                  |bool                                        |includeTotalNumberOfRows *Optional*                |
|response_paging_control                       |OCI.responsePagingControl                   |responsePagingControl *Optional*                   |
|sort_order                                    |List[OCI.sortOrder]                         |sortOrder *Optional*                               |
|search_criteria_device_name                   |List[OCI.searchCriteriaDeviceName]          |searchCriteriaDeviceName *Optional*                |
|search_criteria_device_mac_address            |List[OCI.searchCriteriaDeviceMACAddress]    |searchCriteriaDeviceMACAddress *Optional*          |
|search_criteria_device_net_address            |List[OCI.searchCriteriaDeviceNetAddress]    |searchCriteriaDeviceNetAddress *Optional*          |
|search_criteria_exact_device_type             |List[OCI.searchCriteriaExactDeviceType]     |searchCriteriaExactDeviceType *Optional*           |
|search_criteria_access_device_version         |List[OCI.searchCriteriaAccessDeviceVersion] |searchCriteriaAccessDeviceVersion *Optional*       |
|search_criteria_mode_or                       |bool                                        |searchCriteriaModeOr *Optional*                    |
|get_visual_device_management_api_devices_only |bool                                        |getVisualDeviceManagementAPIDevicesOnly *Optional* |
</div>


## `GroupAdminGetPagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of group and department administrators within the group.

The response is either a `GroupAdminGetPagedSortedListResponse()` or an
`ErrorResponse()`. If no sort criterion is included, the response is sorted by
administrator id ascending by default.  If the responsePagingControl element is not
provided, the paging startIndex will be set to 1 by default, and the responsePageSize
will be set to the maximum responsePageSize by default.  Multiple search criteria are
logically ANDed together unless the searchCriteriaModeOr option is included.  Then the
search criteria are logically ORed together.

**Attributes:**

|Name                                   |Type                                        |Description                                  |
|---------------------------------------|--------------------------------------------|---------------------------------------------|
|service_provider_id                    |str                                         |serviceProviderId                            |
|group_id                               |str                                         |groupId                                      |
|response_paging_control                |OCI.responsePagingControl                   |responsePagingControl *Optional*             |
|sort_order                             |List[OCI.sortOrder]                         |sortOrder *Optional*                         |
|search_criteria_admin_id               |List[OCI.searchCriteriaAdminId]             |searchCriteriaAdminId *Optional*             |
|search_criteria_admin_last_name        |List[OCI.searchCriteriaAdminLastName]       |searchCriteriaAdminLastName *Optional*       |
|search_criteria_admin_first_name       |List[OCI.searchCriteriaAdminFirstName]      |searchCriteriaAdminFirstName *Optional*      |
|search_criteria_exact_group_admin_type |List[OCI.searchCriteriaExactGroupAdminType] |searchCriteriaExactGroupAdminType *Optional* |
|search_criteria_language               |List[OCI.searchCriteriaLanguage]            |searchCriteriaLanguage *Optional*            |
|search_criteria_department_name        |List[OCI.searchCriteriaDepartmentName]      |searchCriteriaDepartmentName *Optional*      |
|search_criteria_mode_or                |bool                                        |searchCriteriaModeOr *Optional*              |
</div>


## `GroupAutoAttendantGetInstancePagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of Auto Attendant instances within a group.

The response is either `GroupAutoAttendantGetInstancePagedSortedListResponse()` or
`ErrorResponse()`. If no sortOrder is included the response is sorted by Name
ascending by default.  A limitation to the search by DN activation exists when the
Number Activation mode is set to Off.  In this case DNs not assigned to users are
never returned by queries with the "dnActivationSearchCriteria" included.  If the
responsePagingControl element is not provided, the paging startIndex will be set to 1
by default, and the responsePageSize will be set to the maximum responsePageSize by
default.  Multiple search criteria are logically ANDed together unless the
searchCriteriaModeOr option is included.  Then the search criteria are logically ORed
together.

**Attributes:**

|Name                                      |Type                                     |Description                                     |
|------------------------------------------|-----------------------------------------|------------------------------------------------|
|service_provider_id                       |str                                      |serviceProviderId                               |
|group_id                                  |str                                      |groupId                                         |
|response_paging_control                   |OCI.responsePagingControl                |responsePagingControl *Optional*                |
|sort_order                                |List[OCI.sortOrder]                      |sortOrder *Optional*                            |
|search_criteria_user_id                   |List[OCI.searchCriteriaUserId]           |searchCriteriaUserId *Optional*                 |
|search_criteria_user_last_name            |List[OCI.searchCriteriaUserLastName]     |searchCriteriaUserLastName *Optional*           |
|search_criteria_dn                        |List[OCI.searchCriteriaDn]               |searchCriteriaDn *Optional*                     |
|search_criteria_extension                 |List[OCI.searchCriteriaExtension]        |searchCriteriaExtension *Optional*              |
|search_criteria_exact_dn_activation       |OCI.searchCriteriaExactDnActivation      |searchCriteriaExactDnActivation *Optional*      |
|search_criteria_service_status            |OCI.searchCriteriaServiceStatus          |searchCriteriaServiceStatus *Optional*          |
|search_criteria_exact_auto_attendant_type |OCI.searchCriteriaExactAutoAttendantType |searchCriteriaExactAutoAttendantType *Optional* |
|search_criteria_mode_or                   |bool                                     |searchCriteriaModeOr *Optional*                 |
</div>


## `GroupAutoAttendantSubmenuAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add an Auto Attendant submenu instance.

The response is either `SuccessResponse()` or `ErrorResponse()`. This request is only
valid for Standard auto attendants.  Replaced by:
`GroupAutoAttendantSubmenuAddRequest20()` in AS data mode

**Attributes:**

|Name                           |Type                       |Description                 |
|-------------------------------|---------------------------|----------------------------|
|service_user_id                |str                        |serviceUserId               |
|submenu_id                     |str                        |submenuId                   |
|announcement_selection         |str                        |announcementSelection       |
|audio_file                     |OCI.audioFile              |audioFile *Optional*        |
|video_file                     |OCI.videoFile              |videoFile *Optional*        |
|enable_level_extension_dialing |bool                       |enableLevelExtensionDialing |
|key_configuration              |List[OCI.keyConfiguration] |keyConfiguration *Optional* |
</div>


## `GroupAutoAttendantSubmenuAddRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add an Auto Attendant submenu instance.

The response is either `SuccessResponse()` or `ErrorResponse()`. This request is only
valid for Standard auto attendants.

**Attributes:**

|Name                           |Type                       |Description                 |
|-------------------------------|---------------------------|----------------------------|
|service_user_id                |str                        |serviceUserId               |
|submenu_id                     |str                        |submenuId                   |
|announcement_selection         |str                        |announcementSelection       |
|audio_file                     |OCI.audioFile              |audioFile *Optional*        |
|video_file                     |OCI.videoFile              |videoFile *Optional*        |
|enable_level_extension_dialing |bool                       |enableLevelExtensionDialing |
|key_configuration              |List[OCI.keyConfiguration] |keyConfiguration *Optional* |
</div>


## `GroupAutoAttendantSubmenuModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify an Auto Attendant submenu instance.

The response is either `SuccessResponse()` or `ErrorResponse()`. This request is only
valid for Standard auto attendants.  Replaced by:
`GroupAutoAttendantSubmenuModifyRequest20()` in AS data mode

**Attributes:**

|Name                           |Type                       |Description                            |
|-------------------------------|---------------------------|---------------------------------------|
|service_user_id                |str                        |serviceUserId                          |
|submenu_id                     |str                        |submenuId                              |
|new_submenu_id                 |str                        |newSubmenuId *Optional*                |
|announcement_selection         |str                        |announcementSelection *Optional*       |
|audio_file                     |OCI.audioFile              |audioFile *Optional*                   |
|video_file                     |OCI.videoFile              |videoFile *Optional*                   |
|enable_level_extension_dialing |bool                       |enableLevelExtensionDialing *Optional* |
|key_configuration              |List[OCI.keyConfiguration] |keyConfiguration *Optional*            |
</div>


## `GroupAutoAttendantSubmenuModifyRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify an Auto Attendant submenu instance.

The response is either `SuccessResponse()` or `ErrorResponse()`. This request is only
valid for Standard auto attendants.

**Attributes:**

|Name                           |Type                       |Description                            |
|-------------------------------|---------------------------|---------------------------------------|
|service_user_id                |str                        |serviceUserId                          |
|submenu_id                     |str                        |submenuId                              |
|new_submenu_id                 |str                        |newSubmenuId *Optional*                |
|announcement_selection         |str                        |announcementSelection *Optional*       |
|audio_file                     |OCI.audioFile              |audioFile *Optional*                   |
|video_file                     |OCI.videoFile              |videoFile *Optional*                   |
|enable_level_extension_dialing |bool                       |enableLevelExtensionDialing *Optional* |
|key_configuration              |List[OCI.keyConfiguration] |keyConfiguration *Optional*            |
</div>


## `GroupCallCenterAgentThresholdProfileGetAvailableAgentPagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of all Agents in the Group that can be assigned to a given Call Center
Agent Threshold Profile in a Group.

An agent is available to be assigned to a given Agent Threshold Profile if it is a
Call Center Standard or Call Center Premium agent and the agent is not yet assigned to
the profile.  If the responsePagingControl element is not provided, the paging
startIndex will be set to 1 by default, and the responsePageSize will be set to the
maximum ResponsePageSize by default.  It is possible to search by various criteria to
restrict the number of rows returned.  The available agent list for a new Call Center
Agent Threshold profile can be obtained by not setting the
excludeAgentsAssignedToProfileName.  When the excludeAgentsAssignedToProfileName is
specified, all agents already assigned to the specified profile are not included in
the response, even if the search criterion element searchCriteriaAgentThresholdProfile
is specified using the same profile name.  If no sortOrder is included the response is
sorted by User Id ascending by default.  Multiple search criteria are logically ANDed
together unless the searchCriteriaModeOr option is included.  Then the search criteria
are logically ORed together.

The response is either a
`GroupCallCenterAgentThresholdProfileGetAvailableAgentPagedSortedListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                    |Type                                          |Description                                    |
|----------------------------------------|----------------------------------------------|-----------------------------------------------|
|service_provider_id                     |str                                           |serviceProviderId                              |
|group_id                                |str                                           |groupId                                        |
|exclude_agents_assigned_to_profile_name |str                                           |excludeAgentsAssignedToProfileName *Optional*  |
|response_paging_control                 |OCI.responsePagingControl                     |responsePagingControl *Optional*               |
|sort_order                              |List[OCI.sortOrder]                           |sortOrder *Optional*                           |
|search_criteria_user_id                 |List[OCI.searchCriteriaUserId]                |searchCriteriaUserId *Optional*                |
|search_criteria_user_last_name          |List[OCI.searchCriteriaUserLastName]          |searchCriteriaUserLastName *Optional*          |
|search_criteria_user_first_name         |List[OCI.searchCriteriaUserFirstName]         |searchCriteriaUserFirstName *Optional*         |
|search_criteria_dn                      |List[OCI.searchCriteriaDn]                    |searchCriteriaDn *Optional*                    |
|search_criteria_extension               |List[OCI.searchCriteriaExtension]             |searchCriteriaExtension *Optional*             |
|search_criteria_department_name         |List[OCI.searchCriteriaDepartmentName]        |searchCriteriaDepartmentName *Optional*        |
|search_criteria_email_address           |List[OCI.searchCriteriaEmailAddress]          |searchCriteriaEmailAddress *Optional*          |
|search_criteria_agent_threshold_profile |List[OCI.searchCriteriaAgentThresholdProfile] |searchCriteriaAgentThresholdProfile *Optional* |
|search_criteria_mode_or                 |bool                                          |searchCriteriaModeOr *Optional*                |
</div>


## `GroupCallCenterAgentThresholdProfileGetPagedSortedRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Gets an existing non-default Call Center Agent Threshold Profile in a Group.

If the responsePagingControl element is not provided, the paging startIndex will be
set to 1 by default, and the responsePageSize will be set to the maximum
ResponsePageSize by default.  It is possible to search by various criteria to restrict
the number of rows returned.  If no sortOrder is included the response is sorted by
User Id ascending by default.  Multiple search criteria are logically ANDed together
unless the searchCriteriaModeOr option is included.  Then the search criteria are
logically ORed together.

The response is either a
`GroupCallCenterAgentThresholdProfileGetPagedSortedResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                            |Type                                   |Description                             |
|--------------------------------|---------------------------------------|----------------------------------------|
|service_provider_id             |str                                    |serviceProviderId                       |
|group_id                        |str                                    |groupId                                 |
|profile_name                    |str                                    |profileName                             |
|response_paging_control         |OCI.responsePagingControl              |responsePagingControl *Optional*        |
|sort_order                      |List[OCI.sortOrder]                    |sortOrder *Optional*                    |
|search_criteria_user_id         |List[OCI.searchCriteriaUserId]         |searchCriteriaUserId *Optional*         |
|search_criteria_user_last_name  |List[OCI.searchCriteriaUserLastName]   |searchCriteriaUserLastName *Optional*   |
|search_criteria_user_first_name |List[OCI.searchCriteriaUserFirstName]  |searchCriteriaUserFirstName *Optional*  |
|search_criteria_dn              |List[OCI.searchCriteriaDn]             |searchCriteriaDn *Optional*             |
|search_criteria_extension       |List[OCI.searchCriteriaExtension]      |searchCriteriaExtension *Optional*      |
|search_criteria_department_name |List[OCI.searchCriteriaDepartmentName] |searchCriteriaDepartmentName *Optional* |
|search_criteria_email_address   |List[OCI.searchCriteriaEmailAddress]   |searchCriteriaEmailAddress *Optional*   |
|search_criteria_mode_or         |bool                                   |searchCriteriaModeOr *Optional*         |
</div>


## `GroupCallCenterEnhancedReportingScheduledReportAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a group level call center reporting scheduled report.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The startDate
element is adjusted to the first occurrence of the recurrent schedule that comes at or
after startDate.

**Attributes:**

|Name                               |Type                       |Description                                |
|-----------------------------------|---------------------------|-------------------------------------------|
|service_provider_id                |str                        |serviceProviderId                          |
|group_id                           |str                        |groupId                                    |
|name                               |str                        |name                                       |
|description                        |str                        |description *Optional*                     |
|report_template                    |OCI.reportTemplate         |reportTemplate                             |
|schedule                           |OCI.schedule               |schedule                                   |
|sampling_period                    |str                        |samplingPeriod *Optional*                  |
|start_day_of_week                  |str                        |startDayOfWeek *Optional*                  |
|report_time_zone                   |str                        |reportTimeZone                             |
|report_date_format                 |str                        |reportDateFormat                           |
|report_time_format                 |str                        |reportTimeFormat                           |
|report_interval                    |OCI.reportInterval         |reportInterval                             |
|report_format                      |str                        |reportFormat                               |
|agent                              |OCI.agent                  |agent *Optional*                           |
|call_center                        |OCI.callCenter             |callCenter *Optional*                      |
|dnis                               |OCI.dnis                   |dnis *Optional*                            |
|call_completion_threshold_seconds  |int                        |callCompletionThresholdSeconds *Optional*  |
|short_duration_threshold_seconds   |int                        |shortDurationThresholdSeconds *Optional*   |
|service_level_threshold_seconds    |List[int]                  |serviceLevelThresholdSeconds *Optional*    |
|service_level_inclusions           |OCI.serviceLevelInclusions |serviceLevelInclusions *Optional*          |
|service_level_objective_percentage |int                        |serviceLevelObjectivePercentage *Optional* |
|abandoned_call_threshold_seconds   |List[int]                  |abandonedCallThresholdSeconds *Optional*   |
|email_address                      |List[str]                  |emailAddress                               |
</div>


## `GroupCallCenterEnhancedReportingScheduledReportModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a group level call center reporting scheduled report.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The startDate
element is adjusted to the first occurrence of the recurrent schedule that comes at or
after startDate.

**Attributes:**

|Name                               |Type                              |Description                                |
|-----------------------------------|----------------------------------|-------------------------------------------|
|service_provider_id                |str                               |serviceProviderId                          |
|group_id                           |str                               |groupId                                    |
|name                               |str                               |name                                       |
|new_name                           |str                               |newName *Optional*                         |
|description                        |str                               |description *Optional*                     |
|schedule                           |OCI.schedule                      |schedule *Optional*                        |
|sampling_period                    |str                               |samplingPeriod *Optional*                  |
|start_day_of_week                  |str                               |startDayOfWeek *Optional*                  |
|report_time_zone                   |str                               |reportTimeZone *Optional*                  |
|report_date_format                 |str                               |reportDateFormat *Optional*                |
|report_time_format                 |str                               |reportTimeFormat *Optional*                |
|report_interval                    |OCI.reportInterval                |reportInterval *Optional*                  |
|report_format                      |str                               |reportFormat *Optional*                    |
|agent                              |OCI.agent                         |agent *Optional*                           |
|call_center                        |OCI.callCenter                    |callCenter *Optional*                      |
|dnis                               |OCI.dnis                          |dnis *Optional*                            |
|call_completion_threshold_seconds  |int                               |callCompletionThresholdSeconds *Optional*  |
|short_duration_threshold_seconds   |int                               |shortDurationThresholdSeconds *Optional*   |
|service_level_threshold_seconds    |OCI.serviceLevelThresholdSeconds  |serviceLevelThresholdSeconds *Optional*    |
|service_level_inclusions           |OCI.serviceLevelInclusions        |serviceLevelInclusions *Optional*          |
|service_level_objective_percentage |int                               |serviceLevelObjectivePercentage *Optional* |
|abandoned_call_threshold_seconds   |OCI.abandonedCallThresholdSeconds |abandonedCallThresholdSeconds *Optional*   |
|email_address                      |OCI.emailAddress                  |emailAddress *Optional*                    |
</div>


## `GroupCallCenterGetAvailableAgentPagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of users that can be assigned as agents to a given type of Call Center.

Searching for users by group only makes sense when the call center is part of an
Enterprise.  If the responsePagingControl element is not provided, the paging
startIndex will be set to 1 by default, and the responsePageSize will be set to the
maximum ResponsePageSize by default.  It is possible to search by various criteria to
restrict the number of rows returned.  If no sortOrder is included the response is
sorted by User Id ascending by default.  Multiple search criteria are logically ANDed
together unless the searchCriteriaModeOr option is included.  Then the search criteria
are logically ORed together.  `ErrorResponse()` is returned if
searchCriteriaExactUserGroup has multiple entries and searchCriteriaModeOr is not
included.

The response is either `GroupCallCenterGetAvailableAgentPagedSortedListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                             |Type                                   |Description                             |
|---------------------------------|---------------------------------------|----------------------------------------|
|service_provider_id              |str                                    |serviceProviderId                       |
|group_id                         |str                                    |groupId                                 |
|call_center_type                 |str                                    |callCenterType                          |
|response_paging_control          |OCI.responsePagingControl              |responsePagingControl *Optional*        |
|sort_order                       |List[OCI.sortOrder]                    |sortOrder *Optional*                    |
|search_criteria_user_id          |List[OCI.searchCriteriaUserId]         |searchCriteriaUserId *Optional*         |
|search_criteria_user_last_name   |List[OCI.searchCriteriaUserLastName]   |searchCriteriaUserLastName *Optional*   |
|search_criteria_user_first_name  |List[OCI.searchCriteriaUserFirstName]  |searchCriteriaUserFirstName *Optional*  |
|search_criteria_dn               |List[OCI.searchCriteriaDn]             |searchCriteriaDn *Optional*             |
|search_criteria_extension        |List[OCI.searchCriteriaExtension]      |searchCriteriaExtension *Optional*      |
|search_criteria_department_name  |List[OCI.searchCriteriaDepartmentName] |searchCriteriaDepartmentName *Optional* |
|search_criteria_email_address    |List[OCI.searchCriteriaEmailAddress]   |searchCriteriaEmailAddress *Optional*   |
|search_criteria_exact_user_group |List[OCI.searchCriteriaExactUserGroup] |searchCriteriaExactUserGroup *Optional* |
|search_criteria_mode_or          |bool                                   |searchCriteriaModeOr *Optional*         |
</div>


## `GroupCallCenterGetInstancePagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of Call Center instances within a group.

The response is either `GroupCallCenterGetInstancePagedSortedListResponse()` or
`ErrorResponse()`. It is possible to get the instances within a specified department.
If the responsePagingControl element is not provided, the paging startIndex will be
set to 1 by default, and the responsePageSize will be set to the maximum
ResponsePageSize by default.  It is possible to search by various criteria to restrict
the number of rows returned.  If no sortOrder is included the response is sorted by
User Id ascending by default.  Multiple search criteria are logically ANDed together
unless the searchCriteriaModeOr option is included.  Then the search criteria are
logically ORed together.  `ErrorResponse()` is returned if
searchCriteriaExactHuntPolicy or searchCriteriaExactCallCenterType have multiple
entries and searchCriteriaModeOr is not include.

**Attributes:**

|Name                                   |Type                                        |Description                                  |
|---------------------------------------|--------------------------------------------|---------------------------------------------|
|service_provider_id                    |str                                         |serviceProviderId                            |
|group_id                               |str                                         |groupId                                      |
|response_paging_control                |OCI.responsePagingControl                   |responsePagingControl *Optional*             |
|sort_order                             |List[OCI.sortOrder]                         |sortOrder *Optional*                         |
|search_criteria_user_id                |List[OCI.searchCriteriaUserId]              |searchCriteriaUserId *Optional*              |
|search_criteria_call_center_name       |List[OCI.searchCriteriaCallCenterName]      |searchCriteriaCallCenterName *Optional*      |
|search_criteria_dn                     |List[OCI.searchCriteriaDn]                  |searchCriteriaDn *Optional*                  |
|search_criteria_extension              |List[OCI.searchCriteriaExtension]           |searchCriteriaExtension *Optional*           |
|search_criteria_department_name        |List[OCI.searchCriteriaDepartmentName]      |searchCriteriaDepartmentName *Optional*      |
|search_criteria_service_status         |OCI.searchCriteriaServiceStatus             |searchCriteriaServiceStatus *Optional*       |
|search_criteria_exact_hunt_policy      |List[OCI.searchCriteriaExactHuntPolicy]     |searchCriteriaExactHuntPolicy *Optional*     |
|search_criteria_exact_call_center_type |List[OCI.searchCriteriaExactCallCenterType] |searchCriteriaExactCallCenterType *Optional* |
|search_criteria_mode_or                |bool                                        |searchCriteriaModeOr *Optional*              |
</div>


## `GroupCallCenterModifyAnnouncementRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call center's announcement settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                                  |Type                                |Description                                              |
|------------------------------------------------------|------------------------------------|---------------------------------------------------------|
|service_user_id                                       |str                                 |serviceUserId                                            |
|play_entrance_message                                 |bool                                |playEntranceMessage *Optional*                           |
|mandatory_entrance_message                            |bool                                |mandatoryEntranceMessage *Optional*                      |
|entrance_audio_message_selection                      |str                                 |entranceAudioMessageSelection *Optional*                 |
|entrance_message_audio_file                           |OCI.entranceMessageAudioFile        |entranceMessageAudioFile *Optional*                      |
|entrance_video_message_selection                      |str                                 |entranceVideoMessageSelection *Optional*                 |
|entrance_message_video_file                           |OCI.entranceMessageVideoFile        |entranceMessageVideoFile *Optional*                      |
|play_periodic_comfort_message                         |bool                                |playPeriodicComfortMessage *Optional*                    |
|time_between_comfort_messages_seconds                 |int                                 |timeBetweenComfortMessagesSeconds *Optional*             |
|periodic_comfort_audio_message_selection              |str                                 |periodicComfortAudioMessageSelection *Optional*          |
|periodic_comfort_message_audio_file                   |OCI.periodicComfortMessageAudioFile |periodicComfortMessageAudioFile *Optional*               |
|periodic_comfort_video_message_selection              |str                                 |periodicComfortVideoMessageSelection *Optional*          |
|periodic_comfort_message_video_file                   |OCI.periodicComfortMessageVideoFile |periodicComfortMessageVideoFile *Optional*               |
|enable_media_on_hold_for_queued_calls                 |bool                                |enableMediaOnHoldForQueuedCalls *Optional*               |
|media_on_hold_source                                  |OCI.mediaOnHoldSource               |mediaOnHoldSource *Optional*                             |
|media_on_hold_use_alternate_source_for_internal_calls |bool                                |mediaOnHoldUseAlternateSourceForInternalCalls *Optional* |
|media_on_hold_internal_source                         |OCI.mediaOnHoldInternalSource       |mediaOnHoldInternalSource *Optional*                     |
</div>


## `GroupCallCenterModifyAnnouncementRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call center's announcement settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                                  |Type                                    |Description                                              |
|------------------------------------------------------|----------------------------------------|---------------------------------------------------------|
|service_user_id                                       |str                                     |serviceUserId                                            |
|play_entrance_message                                 |bool                                    |playEntranceMessage *Optional*                           |
|mandatory_entrance_message                            |bool                                    |mandatoryEntranceMessage *Optional*                      |
|entrance_audio_message_selection                      |str                                     |entranceAudioMessageSelection *Optional*                 |
|entrance_message_audio_url_list                       |OCI.entranceMessageAudioUrlList         |entranceMessageAudioUrlList *Optional*                   |
|entrance_message_audio_file_list                      |OCI.entranceMessageAudioFileList        |entranceMessageAudioFileList *Optional*                  |
|entrance_video_message_selection                      |str                                     |entranceVideoMessageSelection *Optional*                 |
|entrance_message_video_url_list                       |OCI.entranceMessageVideoUrlList         |entranceMessageVideoUrlList *Optional*                   |
|entrance_message_video_file_list                      |OCI.entranceMessageVideoFileList        |entranceMessageVideoFileList *Optional*                  |
|play_periodic_comfort_message                         |bool                                    |playPeriodicComfortMessage *Optional*                    |
|time_between_comfort_messages_seconds                 |int                                     |timeBetweenComfortMessagesSeconds *Optional*             |
|periodic_comfort_audio_message_selection              |str                                     |periodicComfortAudioMessageSelection *Optional*          |
|periodic_comfort_message_audio_url_list               |OCI.periodicComfortMessageAudioUrlList  |periodicComfortMessageAudioUrlList *Optional*            |
|periodic_comfort_message_audio_file_list              |OCI.periodicComfortMessageAudioFileList |periodicComfortMessageAudioFileList *Optional*           |
|periodic_comfort_video_message_selection              |str                                     |periodicComfortVideoMessageSelection *Optional*          |
|periodic_comfort_message_video_url_list               |OCI.periodicComfortMessageVideoUrlList  |periodicComfortMessageVideoUrlList *Optional*            |
|periodic_comfort_message_video_file_list              |OCI.periodicComfortMessageVideoFileList |periodicComfortMessageVideoFileList *Optional*           |
|enable_media_on_hold_for_queued_calls                 |bool                                    |enableMediaOnHoldForQueuedCalls *Optional*               |
|media_on_hold_source                                  |OCI.mediaOnHoldSource                   |mediaOnHoldSource *Optional*                             |
|media_on_hold_use_alternate_source_for_internal_calls |bool                                    |mediaOnHoldUseAlternateSourceForInternalCalls *Optional* |
|media_on_hold_internal_source                         |OCI.mediaOnHoldInternalSource           |mediaOnHoldInternalSource *Optional*                     |
|play_whisper_message                                  |bool                                    |playWhisperMessage *Optional*                            |
|whisper_audio_message_selection                       |str                                     |whisperAudioMessageSelection *Optional*                  |
|whisper_message_audio_url_list                        |OCI.whisperMessageAudioUrlList          |whisperMessageAudioUrlList *Optional*                    |
|whisper_message_audio_file_list                       |OCI.whisperMessageAudioFileList         |whisperMessageAudioFileList *Optional*                   |
|whisper_video_message_selection                       |str                                     |whisperVideoMessageSelection *Optional*                  |
|whisper_message_video_url_list                        |OCI.whisperMessageVideoUrlList          |whisperMessageVideoUrlList *Optional*                    |
|whisper_message_video_file_list                       |OCI.whisperMessageVideoFileList         |whisperMessageVideoFileList *Optional*                   |
|estimated_wait_message_options_modify                 |OCI.estimatedWaitMessageOptionsModify   |estimatedWaitMessageOptionsModify *Optional*             |
</div>


## `GroupCallCenterModifyAnnouncementRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call center's announcement settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                                  |Type                                    |Description                                              |
|------------------------------------------------------|----------------------------------------|---------------------------------------------------------|
|service_user_id                                       |str                                     |serviceUserId                                            |
|play_entrance_message                                 |bool                                    |playEntranceMessage *Optional*                           |
|mandatory_entrance_message                            |bool                                    |mandatoryEntranceMessage *Optional*                      |
|entrance_audio_message_selection                      |str                                     |entranceAudioMessageSelection *Optional*                 |
|entrance_message_audio_url_list                       |OCI.entranceMessageAudioUrlList         |entranceMessageAudioUrlList *Optional*                   |
|entrance_message_audio_file_list                      |OCI.entranceMessageAudioFileList        |entranceMessageAudioFileList *Optional*                  |
|entrance_video_message_selection                      |str                                     |entranceVideoMessageSelection *Optional*                 |
|entrance_message_video_url_list                       |OCI.entranceMessageVideoUrlList         |entranceMessageVideoUrlList *Optional*                   |
|entrance_message_video_file_list                      |OCI.entranceMessageVideoFileList        |entranceMessageVideoFileList *Optional*                  |
|play_periodic_comfort_message                         |bool                                    |playPeriodicComfortMessage *Optional*                    |
|time_between_comfort_messages_seconds                 |int                                     |timeBetweenComfortMessagesSeconds *Optional*             |
|periodic_comfort_audio_message_selection              |str                                     |periodicComfortAudioMessageSelection *Optional*          |
|periodic_comfort_message_audio_url_list               |OCI.periodicComfortMessageAudioUrlList  |periodicComfortMessageAudioUrlList *Optional*            |
|periodic_comfort_message_audio_file_list              |OCI.periodicComfortMessageAudioFileList |periodicComfortMessageAudioFileList *Optional*           |
|periodic_comfort_video_message_selection              |str                                     |periodicComfortVideoMessageSelection *Optional*          |
|periodic_comfort_message_video_url_list               |OCI.periodicComfortMessageVideoUrlList  |periodicComfortMessageVideoUrlList *Optional*            |
|periodic_comfort_message_video_file_list              |OCI.periodicComfortMessageVideoFileList |periodicComfortMessageVideoFileList *Optional*           |
|enable_media_on_hold_for_queued_calls                 |bool                                    |enableMediaOnHoldForQueuedCalls *Optional*               |
|media_on_hold_source                                  |OCI.mediaOnHoldSource                   |mediaOnHoldSource *Optional*                             |
|media_on_hold_use_alternate_source_for_internal_calls |bool                                    |mediaOnHoldUseAlternateSourceForInternalCalls *Optional* |
|media_on_hold_internal_source                         |OCI.mediaOnHoldInternalSource           |mediaOnHoldInternalSource *Optional*                     |
|play_whisper_message                                  |bool                                    |playWhisperMessage *Optional*                            |
|whisper_audio_message_selection                       |str                                     |whisperAudioMessageSelection *Optional*                  |
|whisper_message_audio_url_list                        |OCI.whisperMessageAudioUrlList          |whisperMessageAudioUrlList *Optional*                    |
|whisper_message_audio_file_list                       |OCI.whisperMessageAudioFileList         |whisperMessageAudioFileList *Optional*                   |
|whisper_video_message_selection                       |str                                     |whisperVideoMessageSelection *Optional*                  |
|whisper_message_video_url_list                        |OCI.whisperMessageVideoUrlList          |whisperMessageVideoUrlList *Optional*                    |
|whisper_message_video_file_list                       |OCI.whisperMessageVideoFileList         |whisperMessageVideoFileList *Optional*                   |
|estimated_wait_message_options_modify                 |OCI.estimatedWaitMessageOptionsModify   |estimatedWaitMessageOptionsModify *Optional*             |
</div>


## `GroupCallCenterModifyDNISAnnouncementRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call center DNIS announcement settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                     |Type                                    |Description                                     |
|-----------------------------------------|----------------------------------------|------------------------------------------------|
|dnis_key                                 |OCI.dnisKey                             |dnisKey                                         |
|play_entrance_message                    |bool                                    |playEntranceMessage *Optional*                  |
|mandatory_entrance_message               |bool                                    |mandatoryEntranceMessage *Optional*             |
|entrance_audio_message_selection         |str                                     |entranceAudioMessageSelection *Optional*        |
|entrance_message_audio_url_list          |OCI.entranceMessageAudioUrlList         |entranceMessageAudioUrlList *Optional*          |
|entrance_message_audio_file_list         |OCI.entranceMessageAudioFileList        |entranceMessageAudioFileList *Optional*         |
|entrance_video_message_selection         |str                                     |entranceVideoMessageSelection *Optional*        |
|entrance_message_video_url_list          |OCI.entranceMessageVideoUrlList         |entranceMessageVideoUrlList *Optional*          |
|entrance_message_video_file_list         |OCI.entranceMessageVideoFileList        |entranceMessageVideoFileList *Optional*         |
|play_periodic_comfort_message            |bool                                    |playPeriodicComfortMessage *Optional*           |
|time_between_comfort_messages_seconds    |int                                     |timeBetweenComfortMessagesSeconds *Optional*    |
|periodic_comfort_audio_message_selection |str                                     |periodicComfortAudioMessageSelection *Optional* |
|periodic_comfort_message_audio_url_list  |OCI.periodicComfortMessageAudioUrlList  |periodicComfortMessageAudioUrlList *Optional*   |
|periodic_comfort_message_audio_file_list |OCI.periodicComfortMessageAudioFileList |periodicComfortMessageAudioFileList *Optional*  |
|periodic_comfort_video_message_selection |str                                     |periodicComfortVideoMessageSelection *Optional* |
|periodic_comfort_message_video_url_list  |OCI.periodicComfortMessageVideoUrlList  |periodicComfortMessageVideoUrlList *Optional*   |
|periodic_comfort_message_video_file_list |OCI.periodicComfortMessageVideoFileList |periodicComfortMessageVideoFileList *Optional*  |
|enable_media_on_hold_for_queued_calls    |bool                                    |enableMediaOnHoldForQueuedCalls *Optional*      |
|media_on_hold_source                     |OCI.mediaOnHoldSource                   |mediaOnHoldSource *Optional*                    |
|play_whisper_message                     |bool                                    |playWhisperMessage *Optional*                   |
|whisper_audio_message_selection          |str                                     |whisperAudioMessageSelection *Optional*         |
|whisper_message_audio_url_list           |OCI.whisperMessageAudioUrlList          |whisperMessageAudioUrlList *Optional*           |
|whisper_message_audio_file_list          |OCI.whisperMessageAudioFileList         |whisperMessageAudioFileList *Optional*          |
|whisper_video_message_selection          |str                                     |whisperVideoMessageSelection *Optional*         |
|whisper_message_video_url_list           |OCI.whisperMessageVideoUrlList          |whisperMessageVideoUrlList *Optional*           |
|whisper_message_video_file_list          |OCI.whisperMessageVideoFileList         |whisperMessageVideoFileList *Optional*          |
|estimated_wait_message_options_modify    |OCI.estimatedWaitMessageOptionsModify   |estimatedWaitMessageOptionsModify *Optional*    |
</div>


## `GroupCallCenterModifyDNISAnnouncementRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a call center DNIS announcement settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                                     |Type                                    |Description                                     |
|-----------------------------------------|----------------------------------------|------------------------------------------------|
|dnis_key                                 |OCI.dnisKey                             |dnisKey                                         |
|play_entrance_message                    |bool                                    |playEntranceMessage *Optional*                  |
|mandatory_entrance_message               |bool                                    |mandatoryEntranceMessage *Optional*             |
|entrance_audio_message_selection         |str                                     |entranceAudioMessageSelection *Optional*        |
|entrance_message_audio_url_list          |OCI.entranceMessageAudioUrlList         |entranceMessageAudioUrlList *Optional*          |
|entrance_message_audio_file_list         |OCI.entranceMessageAudioFileList        |entranceMessageAudioFileList *Optional*         |
|entrance_video_message_selection         |str                                     |entranceVideoMessageSelection *Optional*        |
|entrance_message_video_url_list          |OCI.entranceMessageVideoUrlList         |entranceMessageVideoUrlList *Optional*          |
|entrance_message_video_file_list         |OCI.entranceMessageVideoFileList        |entranceMessageVideoFileList *Optional*         |
|play_periodic_comfort_message            |bool                                    |playPeriodicComfortMessage *Optional*           |
|time_between_comfort_messages_seconds    |int                                     |timeBetweenComfortMessagesSeconds *Optional*    |
|periodic_comfort_audio_message_selection |str                                     |periodicComfortAudioMessageSelection *Optional* |
|periodic_comfort_message_audio_url_list  |OCI.periodicComfortMessageAudioUrlList  |periodicComfortMessageAudioUrlList *Optional*   |
|periodic_comfort_message_audio_file_list |OCI.periodicComfortMessageAudioFileList |periodicComfortMessageAudioFileList *Optional*  |
|periodic_comfort_video_message_selection |str                                     |periodicComfortVideoMessageSelection *Optional* |
|periodic_comfort_message_video_url_list  |OCI.periodicComfortMessageVideoUrlList  |periodicComfortMessageVideoUrlList *Optional*   |
|periodic_comfort_message_video_file_list |OCI.periodicComfortMessageVideoFileList |periodicComfortMessageVideoFileList *Optional*  |
|enable_media_on_hold_for_queued_calls    |bool                                    |enableMediaOnHoldForQueuedCalls *Optional*      |
|media_on_hold_source                     |OCI.mediaOnHoldSource                   |mediaOnHoldSource *Optional*                    |
|play_whisper_message                     |bool                                    |playWhisperMessage *Optional*                   |
|whisper_audio_message_selection          |str                                     |whisperAudioMessageSelection *Optional*         |
|whisper_message_audio_url_list           |OCI.whisperMessageAudioUrlList          |whisperMessageAudioUrlList *Optional*           |
|whisper_message_audio_file_list          |OCI.whisperMessageAudioFileList         |whisperMessageAudioFileList *Optional*          |
|whisper_video_message_selection          |str                                     |whisperVideoMessageSelection *Optional*         |
|whisper_message_video_url_list           |OCI.whisperMessageVideoUrlList          |whisperMessageVideoUrlList *Optional*           |
|whisper_message_video_file_list          |OCI.whisperMessageVideoFileList         |whisperMessageVideoFileList *Optional*          |
|estimated_wait_message_options_modify    |OCI.estimatedWaitMessageOptionsModify   |estimatedWaitMessageOptionsModify *Optional*    |
</div>


## `GroupCallParkGetAvailableAlternateRecallUserPagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of hunt groups that are available to select as an alternate recall user.

If the responsePagingControl element is not provided, the paging startIndex will be
set to 1 by default, and the responsePageSize will be set to the maximum
ResponsePageSize by default.  It is possible to search by various criteria to restrict
the number of rows returned.  If no sortOrder is included the response is sorted by
User Id ascending by default.  Multiple search criteria are logically ANDed together
unless the searchCriteriaModeOr option is included.  Then the search criteria are
logically ORed together.

The response is either
`GroupCallParkGetAvailableAlternateRecallUserPagedSortedListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                            |Type                                   |Description                             |
|--------------------------------|---------------------------------------|----------------------------------------|
|service_provider_id             |str                                    |serviceProviderId                       |
|group_id                        |str                                    |groupId                                 |
|response_paging_control         |OCI.responsePagingControl              |responsePagingControl *Optional*        |
|sort_order                      |List[OCI.sortOrder]                    |sortOrder *Optional*                    |
|search_criteria_user_id         |List[OCI.searchCriteriaUserId]         |searchCriteriaUserId *Optional*         |
|search_criteria_user_last_name  |List[OCI.searchCriteriaUserLastName]   |searchCriteriaUserLastName *Optional*   |
|search_criteria_user_first_name |List[OCI.searchCriteriaUserFirstName]  |searchCriteriaUserFirstName *Optional*  |
|search_criteria_dn              |List[OCI.searchCriteriaDn]             |searchCriteriaDn *Optional*             |
|search_criteria_extension       |List[OCI.searchCriteriaExtension]      |searchCriteriaExtension *Optional*      |
|search_criteria_department_name |List[OCI.searchCriteriaDepartmentName] |searchCriteriaDepartmentName *Optional* |
|search_criteria_mode_or         |bool                                   |searchCriteriaModeOr *Optional*         |
</div>


## `GroupCallParkGetAvailableUserPagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of users that can be assigned to a Call Park group.

The available user list for a new Call Park group can be obtained by not setting the
name.  If the responsePagingControl element is not provided, the paging startIndex
will be set to 1 by default, and the responsePageSize will be set to the maximum
ResponsePageSize by default.  It is possible to search by various criteria to restrict
the number of rows returned.  If no sortOrder is included the response is sorted by
User Id ascending by default.  Multiple search criteria are logically ANDed together
unless the searchCriteriaModeOr option is included.  Then the search criteria are
logically ORed together.

The response is either `GroupCallParkGetAvailableUserPagedSortedListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                            |Type                                   |Description                             |
|--------------------------------|---------------------------------------|----------------------------------------|
|service_provider_id             |str                                    |serviceProviderId                       |
|group_id                        |str                                    |groupId                                 |
|name                            |str                                    |name *Optional*                         |
|response_paging_control         |OCI.responsePagingControl              |responsePagingControl *Optional*        |
|sort_order                      |List[OCI.sortOrder]                    |sortOrder *Optional*                    |
|search_criteria_user_id         |List[OCI.searchCriteriaUserId]         |searchCriteriaUserId *Optional*         |
|search_criteria_user_last_name  |List[OCI.searchCriteriaUserLastName]   |searchCriteriaUserLastName *Optional*   |
|search_criteria_user_first_name |List[OCI.searchCriteriaUserFirstName]  |searchCriteriaUserFirstName *Optional*  |
|search_criteria_dn              |List[OCI.searchCriteriaDn]             |searchCriteriaDn *Optional*             |
|search_criteria_extension       |List[OCI.searchCriteriaExtension]      |searchCriteriaExtension *Optional*      |
|search_criteria_department_name |List[OCI.searchCriteriaDepartmentName] |searchCriteriaDepartmentName *Optional* |
|search_criteria_email_address   |List[OCI.searchCriteriaEmailAddress]   |searchCriteriaEmailAddress *Optional*   |
|search_criteria_mode_or         |bool                                   |searchCriteriaModeOr *Optional*         |
</div>


## `GroupCallPickupGetAvailableUserPagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of users that can be assigned to a Call Pickup group.

The available user list for a new Call Pickup group can be obtained by not setting the
name.  If the responsePagingControl element is not provided, the paging startIndex
will be set to 1 by default, and the responsePageSize will be set to the maximum
ResponsePageSize by default.  It is possible to search by various criteria to restrict
the number of rows returned.  If no sortOrder is included the response is sorted by
User Id ascending by default.  Multiple search criteria are logically ANDed together
unless the searchCriteriaModeOr option is included.  Then the search criteria are
logically ORed together.

The response is either `GroupCallPickupGetAvailableUserPagedSortedListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                            |Type                                   |Description                             |
|--------------------------------|---------------------------------------|----------------------------------------|
|service_provider_id             |str                                    |serviceProviderId                       |
|group_id                        |str                                    |groupId                                 |
|name                            |str                                    |name *Optional*                         |
|response_paging_control         |OCI.responsePagingControl              |responsePagingControl *Optional*        |
|sort_order                      |List[OCI.sortOrder]                    |sortOrder *Optional*                    |
|search_criteria_user_id         |List[OCI.searchCriteriaUserId]         |searchCriteriaUserId *Optional*         |
|search_criteria_user_last_name  |List[OCI.searchCriteriaUserLastName]   |searchCriteriaUserLastName *Optional*   |
|search_criteria_user_first_name |List[OCI.searchCriteriaUserFirstName]  |searchCriteriaUserFirstName *Optional*  |
|search_criteria_dn              |List[OCI.searchCriteriaDn]             |searchCriteriaDn *Optional*             |
|search_criteria_extension       |List[OCI.searchCriteriaExtension]      |searchCriteriaExtension *Optional*      |
|search_criteria_department_name |List[OCI.searchCriteriaDepartmentName] |searchCriteriaDepartmentName *Optional* |
|search_criteria_email_address   |List[OCI.searchCriteriaEmailAddress]   |searchCriteriaEmailAddress *Optional*   |
|search_criteria_mode_or         |bool                                   |searchCriteriaModeOr *Optional*         |
</div>


## `GroupCallPickupGetInstancePagedSortedRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Gets a Call Pickup group.

If the responsePagingControl element is not provided, the paging startIndex will be
set to 1 by default, and the responsePageSize will be set to the maximum
ResponsePageSize by default.  It is possible to search by various criteria to restrict
the number of rows returned.  Multiple search criteria are logically ANDed together
unless the searchCriteriaModeOr option is included.  Then the search criteria are
logically ORed together.  If no sortOrder is included the response is sorted by User
Id ascending by default.

The response is either `GroupCallPickupGetInstancePagedSortedResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                            |Type                                   |Description                             |
|--------------------------------|---------------------------------------|----------------------------------------|
|service_provider_id             |str                                    |serviceProviderId                       |
|group_id                        |str                                    |groupId                                 |
|name                            |str                                    |name                                    |
|response_paging_control         |OCI.responsePagingControl              |responsePagingControl *Optional*        |
|sort_order                      |List[OCI.sortOrder]                    |sortOrder *Optional*                    |
|search_criteria_user_id         |List[OCI.searchCriteriaUserId]         |searchCriteriaUserId *Optional*         |
|search_criteria_user_last_name  |List[OCI.searchCriteriaUserLastName]   |searchCriteriaUserLastName *Optional*   |
|search_criteria_user_first_name |List[OCI.searchCriteriaUserFirstName]  |searchCriteriaUserFirstName *Optional*  |
|search_criteria_dn              |List[OCI.searchCriteriaDn]             |searchCriteriaDn *Optional*             |
|search_criteria_extension       |List[OCI.searchCriteriaExtension]      |searchCriteriaExtension *Optional*      |
|search_criteria_department_name |List[OCI.searchCriteriaDepartmentName] |searchCriteriaDepartmentName *Optional* |
|search_criteria_email_address   |List[OCI.searchCriteriaEmailAddress]   |searchCriteriaEmailAddress *Optional*   |
|search_criteria_mode_or         |bool                                   |searchCriteriaModeOr *Optional*         |
</div>


## `GroupCollaborateBridgeConsolidatedModifyInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a Collaborate bridge.

The request fails when the collaborateOwnerUserIdList is included in the request for
the default collaborate bridge.  The request fails when the supportOutdial is included
in the request and the system-level collaborate supportOutdial setting is disabled.
When phone numbers are un-assigned from the user, the unused numbers may be un-
assigned from the group and service provider.  If UnassignPhoneNumbersLevel is set to
'Group', the user's primary phone number, fax number and any alternate numbers, will
be un-assigned from the group if the command is executed by a service provider
administrator or above.  When set to 'Service Provider', they will be un-assigned from
the group and service provider if the command is executed by a provisioning
administrator or above.  When omitted, the number(s) will be left assigned to the
group.  An `ErrorResponse()` will be returned if any number cannot be unassigned
because of insufficient privilege.  If the phoneNumber has not been assigned to the
group and addPhoneNumberToGroup is set to true, it will be added to group if needed if
the command is executed by a service provider administrator and above.  The command
will fail otherwise.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                              |Type                           |Description                               |
|----------------------------------|-------------------------------|------------------------------------------|
|service_user_id                   |str                            |serviceUserId                             |
|unassign_phone_numbers            |str                            |unassignPhoneNumbers *Optional*           |
|add_phone_number_to_group         |bool                           |addPhoneNumberToGroup *Optional*          |
|service_instance_profile          |OCI.serviceInstanceProfile     |serviceInstanceProfile *Optional*         |
|maximum_bridge_participants       |OCI.maximumBridgeParticipants  |maximumBridgeParticipants *Optional*      |
|network_class_of_service          |str                            |networkClassOfService *Optional*          |
|max_collaborate_room_participants |int                            |maxCollaborateRoomParticipants *Optional* |
|support_outdial                   |bool                           |supportOutdial *Optional*                 |
|collaborate_owner_user_id_list    |OCI.collaborateOwnerUserIdList |collaborateOwnerUserIdList *Optional*     |
|service_list                      |OCI.serviceList                |serviceList *Optional*                    |
</div>


## `GroupCollaborateBridgeGetAvailableUserPagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of users with the Collaborate – Audio service assigned that can be assigned
to a collaborate bridge.

For an Enterprise Group this will include all users in the group’s enterprise.  The
searchCriteriaGroupId parameter is only applicable for enterprise groups.  If no
sortOrder is included the response is sorted by Last Name ascending by default.  A
limitation to the search by DN activation exists when the Number Activation mode is
set to Off.  In this case DNs not assigned to users are never returned by queries with
the "dnActivationSearchCriteria" included.  Multiple search criteria are logically
ANDed together unless the searchCriteriaModeOr option is included.  Then the search
criteria are logically ORed together.

The response is either
`GroupCollaborateBridgeGetAvailableUserPagedSortedListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                                |Type                                   |Description                                |
|------------------------------------|---------------------------------------|-------------------------------------------|
|service_provider_id                 |str                                    |serviceProviderId                          |
|group_id                            |str                                    |groupId                                    |
|response_paging_control             |OCI.responsePagingControl              |responsePagingControl *Optional*           |
|sort_order                          |List[OCI.sortOrder]                    |sortOrder *Optional*                       |
|search_criteria_user_last_name      |List[OCI.searchCriteriaUserLastName]   |searchCriteriaUserLastName *Optional*      |
|search_criteria_user_first_name     |List[OCI.searchCriteriaUserFirstName]  |searchCriteriaUserFirstName *Optional*     |
|search_criteria_department_name     |List[OCI.searchCriteriaDepartmentName] |searchCriteriaDepartmentName *Optional*    |
|search_criteria_group_id            |List[OCI.searchCriteriaGroupId]        |searchCriteriaGroupId *Optional*           |
|search_criteria_user_id             |List[OCI.searchCriteriaUserId]         |searchCriteriaUserId *Optional*            |
|search_criteria_dn                  |List[OCI.searchCriteriaDn]             |searchCriteriaDn *Optional*                |
|search_criteria_extension           |List[OCI.searchCriteriaExtension]      |searchCriteriaExtension *Optional*         |
|search_criteria_exact_dn_activation |OCI.searchCriteriaExactDnActivation    |searchCriteriaExactDnActivation *Optional* |
|search_criteria_mode_or             |bool                                   |searchCriteriaModeOr *Optional*            |
</div>


## `GroupCollaborateBridgeGetInstancePagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of collaborate bridges within a group.

The response is either `GroupCollaborateBridgeGetInstancePagedSortedListResponse()` or
`ErrorResponse()`. If the responsePagingControl element is not provided, the paging
startIndex will be set to 1 by default, and the responsePageSize will be set to the
maximum responsePageSize by default.  If no sortOrder is included the response is
sorted by Name ascending by default.  . Multiple search criteria are logically ANDed
together unless the searchCriteriaModeOr option is included.  Then the search criteria
are logically ORed together.

**Attributes:**

|Name                                |Type                                   |Description                                |
|------------------------------------|---------------------------------------|-------------------------------------------|
|service_provider_id                 |str                                    |serviceProviderId                          |
|group_id                            |str                                    |groupId                                    |
|response_paging_control             |OCI.responsePagingControl              |responsePagingControl *Optional*           |
|sort_order                          |List[OCI.sortOrder]                    |sortOrder *Optional*                       |
|search_criteria_user_last_name      |List[OCI.searchCriteriaUserLastName]   |searchCriteriaUserLastName *Optional*      |
|search_criteria_department_name     |List[OCI.searchCriteriaDepartmentName] |searchCriteriaDepartmentName *Optional*    |
|search_criteria_user_id             |List[OCI.searchCriteriaUserId]         |searchCriteriaUserId *Optional*            |
|search_criteria_dn                  |List[OCI.searchCriteriaDn]             |searchCriteriaDn *Optional*                |
|search_criteria_extension           |List[OCI.searchCriteriaExtension]      |searchCriteriaExtension *Optional*         |
|search_criteria_exact_dn_activation |OCI.searchCriteriaExactDnActivation    |searchCriteriaExactDnActivation *Optional* |
|search_criteria_mode_or             |bool                                   |searchCriteriaModeOr *Optional*            |
</div>


## `GroupDnGetAssignmentPagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get the list of assigned and unassigned DNs in a group.

Each DN can be assigned to a user and/or department.  Ranges of DNs with identical
assignment and activation properties are coalesced to a single table row entry.  Dns
assigned to the IMRN pool are not listed in the response.  If the
responsePagingControl element is not provided, the paging startIndex will be set to 1
by default, and the responsePageSize will be set to the maximum ResponsePageSize by
default.  If no sortOrder is included the response is sorted by Phone Number by
default.  Multiple search criteria are logically ANDed together unless the
searchCriteriaModeOr option is included.  Then the search criterion are logically ORed
together.  The department in both the search criteria and sort by fields refer to the
department to which the dn belongs.  A limitation to the search by DN activation
exists when the Number Activation mode is set to Off.  In this case DNs not assigned
to users are never returned by queries with the "dnActivationSearchCriteria" included.

The response is either a `GroupDnGetAssignmentPagedSortedListResponse()` or an
`ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                   |Description                                  |
|--------------------------------------|---------------------------------------|---------------------------------------------|
|service_provider_id                   |str                                    |serviceProviderId                            |
|group_id                              |str                                    |groupId                                      |
|response_paging_control               |OCI.responsePagingControl              |responsePagingControl *Optional*             |
|sort_order                            |List[OCI.sortOrder]                    |sortOrder *Optional*                         |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]             |searchCriteriaDn *Optional*                  |
|search_criteria_department_name       |List[OCI.searchCriteriaDepartmentName] |searchCriteriaDepartmentName *Optional*      |
|search_criteria_exact_dn_activation   |OCI.searchCriteriaExactDnActivation    |searchCriteriaExactDnActivation *Optional*   |
|search_criteria_exact_dn_availability |OCI.searchCriteriaExactDnAvailability  |searchCriteriaExactDnAvailability *Optional* |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]         |searchCriteriaUserId *Optional*              |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName]  |searchCriteriaUserFirstName *Optional*       |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]   |searchCriteriaUserLastName *Optional*        |
|search_criteria_exact_user_type       |List[OCI.searchCriteriaExactUserType]  |searchCriteriaExactUserType *Optional*       |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]      |searchCriteriaExtension *Optional*           |
|search_criteria_email_address         |List[OCI.searchCriteriaEmailAddress]   |searchCriteriaEmailAddress *Optional*        |
|search_criteria_mode_or               |bool                                   |searchCriteriaModeOr *Optional*              |
</div>


## `GroupFlexibleSeatingHostModifyInstanceRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a flexible seating host instance.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                     |Type                       |Description                       |
|-------------------------|---------------------------|----------------------------------|
|service_user_id          |str                        |serviceUserId                     |
|service_instance_profile |OCI.serviceInstanceProfile |serviceInstanceProfile *Optional* |
|access_device_endpoint   |OCI.accessDeviceEndpoint   |accessDeviceEndpoint *Optional*   |
|network_class_of_service |str                        |networkClassOfService *Optional*  |
</div>


## `GroupGetListInServiceProviderPagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the list of groups in a service provider or enterprise.

If no sortOrder is included, the response is sorted by Group Id ascending by default.

The response is either a `GroupGetListInServiceProviderPagedSortedListResponse()` or
an `ErrorResponse()`. If the responsePagingControl element is not provided, the paging
startIndex will be set to 1 by default, and the responsePageSize will be set to the
maximum responsePageSize by default.  Multiple search criteria are logically ANDed
together unless the searchCriteriaModeOr option is included.  Then the search criteria
are logically ORed together.

**Attributes:**

|Name                       |Type                              |Description                        |
|---------------------------|----------------------------------|-----------------------------------|
|service_provider_id        |str                               |serviceProviderId                  |
|response_paging_control    |OCI.responsePagingControl         |responsePagingControl *Optional*   |
|sort_order                 |List[OCI.sortOrder]               |sortOrder *Optional*               |
|search_criteria_group_id   |List[OCI.searchCriteriaGroupId]   |searchCriteriaGroupId *Optional*   |
|search_criteria_group_name |List[OCI.searchCriteriaGroupName] |searchCriteriaGroupName *Optional* |
|search_criteria_mode_or    |bool                              |searchCriteriaModeOr *Optional*    |
</div>


## `GroupHuntGroupConsolidatedModifyInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a Hunt Group instance.

When phone numbers are un-assigned from the user, the unused numbers may be un-
assigned from the group and service provider.  If UnassignPhoneNumbersLevel is set to
'Group', the user's primary phone number, fax number and any alternate numbers, will
be un-assigned from the group if the command is executed by a service provider
administrator or above.  When set to 'Service Provider', they will be un-assigned from
the group and service provider if the command is executed by a provisioning
administrator or above.  When omitted, the number(s) will be left assigned to the
group.  An `ErrorResponse()` will be returned if any number cannot be unassigned
because of insufficient privilege.  If the phoneNumber has not been assigned to the
group and addPhoneNumberToGroup is set to true, it will be added to group if needed if
the command is executed by a service provider administrator and above.  The command
will fail otherwise.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in AS data mode: useSystemHuntGroupCLIDSetting
includeHuntGroupNameInCLID

**Attributes:**

|Name                                                                              |Type                                      |Description                                                                      |
|----------------------------------------------------------------------------------|------------------------------------------|---------------------------------------------------------------------------------|
|service_user_id                                                                   |str                                       |serviceUserId                                                                    |
|unassign_phone_numbers                                                            |str                                       |unassignPhoneNumbers *Optional*                                                  |
|add_phone_number_to_group                                                         |bool                                      |addPhoneNumberToGroup *Optional*                                                 |
|service_instance_profile                                                          |OCI.serviceInstanceProfile                |serviceInstanceProfile *Optional*                                                |
|policy                                                                            |str                                       |policy *Optional*                                                                |
|hunt_after_no_answer                                                              |bool                                      |huntAfterNoAnswer *Optional*                                                     |
|no_answer_number_of_rings                                                         |int                                       |noAnswerNumberOfRings *Optional*                                                 |
|forward_after_timeout                                                             |bool                                      |forwardAfterTimeout *Optional*                                                   |
|forward_timeout_seconds                                                           |int                                       |forwardTimeoutSeconds *Optional*                                                 |
|forward_to_phone_number                                                           |str                                       |forwardToPhoneNumber *Optional*                                                  |
|agent_user_id_list                                                                |OCI.agentUserIdList                       |agentUserIdList *Optional*                                                       |
|agent_weight_list                                                                 |OCI.agentWeightList                       |agentWeightList *Optional*                                                       |
|allow_call_waiting_for_agents                                                     |bool                                      |allowCallWaitingForAgents *Optional*                                             |
|use_system_hunt_group_clid_setting                                                |bool                                      |useSystemHuntGroupCLIDSetting *Optional*                                         |
|include_hunt_group_name_in_clid                                                   |bool                                      |includeHuntGroupNameInCLID *Optional*                                            |
|enable_not_reachable_forwarding                                                   |bool                                      |enableNotReachableForwarding *Optional*                                          |
|not_reachable_forward_to_phone_number                                             |str                                       |notReachableForwardToPhoneNumber *Optional*                                      |
|make_busy_when_not_reachable                                                      |bool                                      |makeBusyWhenNotReachable *Optional*                                              |
|allow_members_to_control_group_busy                                               |bool                                      |allowMembersToControlGroupBusy *Optional*                                        |
|enable_group_busy                                                                 |bool                                      |enableGroupBusy *Optional*                                                       |
|apply_group_busy_when_terminating_to_agent                                        |bool                                      |applyGroupBusyWhenTerminatingToAgent *Optional*                                  |
|network_class_of_service                                                          |str                                       |networkClassOfService *Optional*                                                 |
|service_list                                                                      |OCI.serviceList                           |serviceList *Optional*                                                           |
|is_active                                                                         |bool                                      |isActive *Optional*                                                              |
|directory_number_hunting_agent_user_id_list                                       |OCI.directoryNumberHuntingAgentUserIdList |directoryNumberHuntingAgentUserIdList *Optional*                                 |
|directory_number_hunting_use_terminate_call_to_agent_first                        |bool                                      |directoryNumberHuntingUseTerminateCallToAgentFirst *Optional*                    |
|directory_number_hunting_use_original_agent_services_for_busy_and_no_answer_calls |bool                                      |directoryNumberHuntingUseOriginalAgentServicesForBusyAndNoAnswerCalls *Optional* |
</div>


## `GroupHuntGroupGetAvailableUserPagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of users that can be assigned to a Hunt Group group.

Searching for users by group only makes sense when the hunt group is part of an
Enterprise.  A limitation to the search by DN activation exists when the Number
Activation mode is set to Off.  In this case DNs not assigned to users are never
returned by queries with the "dnActivationSearchCriteria" included.

The response is either `GroupHuntGroupGetAvailableUserPagedSortedListResponse()` or
`ErrorResponse()`. If no sortOrder is included, the response is sorted by User Id
ascending by default.  If the responsePagingControl element is not provided, the
paging startIndex will be set to 1 by default, and the responsePageSize will be set to
the maximum responsePageSize by default.  Multiple search criteria are logically ANDed
together unless the searchCriteriaModeOr option is included.  Then the search criteria
are logically ORed together.

**Attributes:**

|Name                                |Type                                   |Description                                |
|------------------------------------|---------------------------------------|-------------------------------------------|
|service_provider_id                 |str                                    |serviceProviderId                          |
|group_id                            |str                                    |groupId                                    |
|response_paging_control             |OCI.responsePagingControl              |responsePagingControl *Optional*           |
|sort_order                          |List[OCI.sortOrder]                    |sortOrder *Optional*                       |
|search_criteria_user_last_name      |List[OCI.searchCriteriaUserLastName]   |searchCriteriaUserLastName *Optional*      |
|search_criteria_user_first_name     |List[OCI.searchCriteriaUserFirstName]  |searchCriteriaUserFirstName *Optional*     |
|search_criteria_department_name     |List[OCI.searchCriteriaDepartmentName] |searchCriteriaDepartmentName *Optional*    |
|search_criteria_group_id            |List[OCI.searchCriteriaGroupId]        |searchCriteriaGroupId *Optional*           |
|search_criteria_user_id             |List[OCI.searchCriteriaUserId]         |searchCriteriaUserId *Optional*            |
|search_criteria_dn                  |List[OCI.searchCriteriaDn]             |searchCriteriaDn *Optional*                |
|search_criteria_extension           |List[OCI.searchCriteriaExtension]      |searchCriteriaExtension *Optional*         |
|search_criteria_exact_dn_activation |OCI.searchCriteriaExactDnActivation    |searchCriteriaExactDnActivation *Optional* |
|search_criteria_mode_or             |bool                                   |searchCriteriaModeOr *Optional*            |
</div>


## `GroupHuntGroupGetInstancePagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of Hunt Group instances within a group.

The response is either `GroupHuntGroupGetInstancePagedSortedListResponse()` or
`ErrorResponse()`. It is possible to get the instances within a specified department.
The department in both the search criteria and sort by fields refer to the department
to which the dn belongs.  If no sortOrder is included, the response is sorted by User
Id ascending by default.  If the responsePagingControl element is not provided, the
paging startIndex will be set to 1 by default, and the responsePageSize will be set to
the maximum responsePageSize by default.  Multiple search criteria are logically ANDed
together unless the searchCriteriaModeOr option is included.  Then the search criteria
are logically ORed together.

**Attributes:**

|Name                                |Type                                   |Description                                |
|------------------------------------|---------------------------------------|-------------------------------------------|
|service_provider_id                 |str                                    |serviceProviderId                          |
|group_id                            |str                                    |groupId                                    |
|response_paging_control             |OCI.responsePagingControl              |responsePagingControl *Optional*           |
|sort_order                          |List[OCI.sortOrder]                    |sortOrder *Optional*                       |
|search_criteria_user_last_name      |List[OCI.searchCriteriaUserLastName]   |searchCriteriaUserLastName *Optional*      |
|search_criteria_department_name     |List[OCI.searchCriteriaDepartmentName] |searchCriteriaDepartmentName *Optional*    |
|search_criteria_user_id             |List[OCI.searchCriteriaUserId]         |searchCriteriaUserId *Optional*            |
|search_criteria_dn                  |List[OCI.searchCriteriaDn]             |searchCriteriaDn *Optional*                |
|search_criteria_extension           |List[OCI.searchCriteriaExtension]      |searchCriteriaExtension *Optional*         |
|search_criteria_exact_dn_activation |OCI.searchCriteriaExactDnActivation    |searchCriteriaExactDnActivation *Optional* |
|search_criteria_service_status      |OCI.searchCriteriaServiceStatus        |searchCriteriaServiceStatus *Optional*     |
|search_criteria_mode_or             |bool                                   |searchCriteriaModeOr *Optional*            |
</div>


## `GroupOutgoingCallingPlanDigitPlanCallMeNowModifyListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Call Me Now call permissions for digit patterns for a group default and
it's departments.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type                            |Description                      |
|-----------------------|--------------------------------|---------------------------------|
|service_provider_id    |str                             |serviceProviderId                |
|group_id               |str                             |groupId                          |
|group_permissions      |OCI.groupPermissions            |groupPermissions *Optional*      |
|department_permissions |List[OCI.departmentPermissions] |departmentPermissions *Optional* |
</div>


## `GroupOutgoingCallingPlanDigitPlanOriginatingModifyListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the originating permissions for digit patterns for a group default and it's
departments.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type                            |Description                      |
|-----------------------|--------------------------------|---------------------------------|
|service_provider_id    |str                             |serviceProviderId                |
|group_id               |str                             |groupId                          |
|group_permissions      |OCI.groupPermissions            |groupPermissions *Optional*      |
|department_permissions |List[OCI.departmentPermissions] |departmentPermissions *Optional* |
</div>


## `GroupOutgoingCallingPlanDigitPlanRedirectingModifyListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the redirecting permissions for digit patterns for a group default and it's
departments.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type                            |Description                      |
|-----------------------|--------------------------------|---------------------------------|
|service_provider_id    |str                             |serviceProviderId                |
|group_id               |str                             |groupId                          |
|group_permissions      |OCI.groupPermissions            |groupPermissions *Optional*      |
|department_permissions |List[OCI.departmentPermissions] |departmentPermissions *Optional* |
</div>


## `GroupOutgoingCallingPlanPinholeDigitPlanCallMeNowModifyListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the Call Me Now permissions for Pinhole digit patterns for a group default and
its departments.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type                            |Description                      |
|-----------------------|--------------------------------|---------------------------------|
|service_provider_id    |str                             |serviceProviderId                |
|group_id               |str                             |groupId                          |
|group_permissions      |OCI.groupPermissions            |groupPermissions *Optional*      |
|department_permissions |List[OCI.departmentPermissions] |departmentPermissions *Optional* |
</div>


## `GroupOutgoingCallingPlanPinholeDigitPlanOriginatingModifyListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the originating permissions for Pinhole digit patterns for a group default and
its departments.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type                            |Description                      |
|-----------------------|--------------------------------|---------------------------------|
|service_provider_id    |str                             |serviceProviderId                |
|group_id               |str                             |groupId                          |
|group_permissions      |OCI.groupPermissions            |groupPermissions *Optional*      |
|department_permissions |List[OCI.departmentPermissions] |departmentPermissions *Optional* |
</div>


## `GroupOutgoingCallingPlanPinholeDigitPlanRedirectingModifyListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the redirecting permissions for Pinhole digit patterns for a group default and
its departments.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                   |Type                            |Description                      |
|-----------------------|--------------------------------|---------------------------------|
|service_provider_id    |str                             |serviceProviderId                |
|group_id               |str                             |groupId                          |
|group_permissions      |OCI.groupPermissions            |groupPermissions *Optional*      |
|department_permissions |List[OCI.departmentPermissions] |departmentPermissions *Optional* |
</div>


## `GroupPhoneDirectoryGetPagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a table containing the phone directory for a group.

The directory includes all users in the group and all entries in the group common
phone list.  If the specified group is part of an enterprise, the directory includes
all users in the enterprise and all entries in the enterprise common phone list and
the common phone list of the specified group.  If the specified group is part of a
service provider, the directory includes all users in the group and all entries in the
common phone list of the specified group.  If the responsePagingControl element is not
provided, the paging startIndex will be set to 1 by default, and the responsePageSize
will be set to the maximum ResponsePageSize by default.  It is possible to search by
various criteria to restrict the number of rows returned.  If no sortOrder is included
the response is sorted by User Id ascending with a secondary sort by User Last Name
ascending by default.  Multiple search criteria are logically ANDed together unless
the searchCriteriaModeOr option is included.  Then the search criteria are logically
ORed together.  `ErrorResponse()` is returned if searchCriteriaExactUserGroup or
searchCriteriaExactUserDepartment have multiple entries and searchCriteriaModeOr is
not included.  The following elements are only used in AS data mode and ignored in
Amplify and XS data mode: "sortByImpId" "searchCriteriaImpId"

The response is either `GroupPhoneDirectoryGetPagedSortedListResponse()` or
`ErrorResponse()`.

**Attributes:**

|Name                                  |Type                                      |Description                                  |
|--------------------------------------|------------------------------------------|---------------------------------------------|
|service_provider_id                   |str                                       |serviceProviderId                            |
|group_id                              |str                                       |groupId                                      |
|is_extended_info_requested            |bool                                      |isExtendedInfoRequested                      |
|response_paging_control               |OCI.responsePagingControl                 |responsePagingControl *Optional*             |
|sort_order                            |List[OCI.sortOrder]                       |sortOrder *Optional*                         |
|search_criteria_user_last_name        |List[OCI.searchCriteriaUserLastName]      |searchCriteriaUserLastName *Optional*        |
|search_criteria_user_first_name       |List[OCI.searchCriteriaUserFirstName]     |searchCriteriaUserFirstName *Optional*       |
|search_criteria_dn                    |List[OCI.searchCriteriaDn]                |searchCriteriaDn *Optional*                  |
|search_criteria_group_location_code   |List[OCI.searchCriteriaGroupLocationCode] |searchCriteriaGroupLocationCode *Optional*   |
|search_criteria_extension             |List[OCI.searchCriteriaExtension]         |searchCriteriaExtension *Optional*           |
|search_criteria_mobile_phone_number   |List[OCI.searchCriteriaMobilePhoneNumber] |searchCriteriaMobilePhoneNumber *Optional*   |
|search_criteria_email_address         |List[OCI.searchCriteriaEmailAddress]      |searchCriteriaEmailAddress *Optional*        |
|search_criteria_exact_user_department |OCI.searchCriteriaExactUserDepartment     |searchCriteriaExactUserDepartment *Optional* |
|search_criteria_department_name       |List[OCI.searchCriteriaDepartmentName]    |searchCriteriaDepartmentName *Optional*      |
|search_criteria_exact_user_group      |OCI.searchCriteriaExactUserGroup          |searchCriteriaExactUserGroup *Optional*      |
|search_criteria_yahoo_id              |List[OCI.searchCriteriaYahooId]           |searchCriteriaYahooId *Optional*             |
|search_criteria_user_id               |List[OCI.searchCriteriaUserId]            |searchCriteriaUserId *Optional*              |
|search_criteria_imp_id                |List[OCI.searchCriteriaImpId]             |searchCriteriaImpId *Optional*               |
|search_criteria_mode_or               |bool                                      |searchCriteriaModeOr *Optional*              |
</div>


## `GroupRoutePointModifyAnnouncementRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a route point's announcement settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                 |Type                  |Description                  |
|---------------------|----------------------|-----------------------------|
|service_user_id      |str                   |serviceUserId                |
|media_on_hold_source |OCI.mediaOnHoldSource |mediaOnHoldSource *Optional* |
</div>


## `GroupRoutePointModifyAnnouncementRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a route point's announcement settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                 |Type                  |Description                  |
|---------------------|----------------------|-----------------------------|
|service_user_id      |str                   |serviceUserId                |
|media_on_hold_source |OCI.mediaOnHoldSource |mediaOnHoldSource *Optional* |
</div>


## `GroupRoutePointModifyDNISAnnouncementRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a route point DNIS announcement settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                 |Type                  |Description                  |
|---------------------|----------------------|-----------------------------|
|dnis_key             |OCI.dnisKey           |dnisKey                      |
|media_on_hold_source |OCI.mediaOnHoldSource |mediaOnHoldSource *Optional* |
</div>


## `GroupRoutePointModifyDNISAnnouncementRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify a route point DNIS announcement settings.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                 |Type                  |Description                  |
|---------------------|----------------------|-----------------------------|
|dnis_key             |OCI.dnisKey           |dnisKey                      |
|media_on_hold_source |OCI.mediaOnHoldSource |mediaOnHoldSource *Optional* |
</div>


## `ServiceProviderAdminGetPagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Get a list of service provider administrators.

The response is either a `ServiceProviderAdminGetPagedSortedListResponse()` or an
`ErrorResponse()`. If no sortOrder is included, the response is sorted by
Administrator ID ascending by default.  If the responsePagingControl element is not
provided, the paging startIndex will be set to 1 by default, and the responsePageSize
will be set to the maximum responsePageSize by default.  Multiple search criteria are
logically ANDed together unless the searchCriteriaModeOr option is included.  Then the
search criteria are logically ORed together.

**Attributes:**

|Name                                              |Type                                                  |Description                                            |
|--------------------------------------------------|------------------------------------------------------|-------------------------------------------------------|
|service_provider_id                               |str                                                   |serviceProviderId                                      |
|response_paging_control                           |OCI.responsePagingControl                             |responsePagingControl *Optional*                       |
|sort_order                                        |List[OCI.sortOrder]                                   |sortOrder *Optional*                                   |
|search_criteria_admin_id                          |List[OCI.searchCriteriaAdminId]                       |searchCriteriaAdminId *Optional*                       |
|search_criteria_admin_last_name                   |List[OCI.searchCriteriaAdminLastName]                 |searchCriteriaAdminLastName *Optional*                 |
|search_criteria_admin_first_name                  |List[OCI.searchCriteriaAdminFirstName]                |searchCriteriaAdminFirstName *Optional*                |
|search_criteria_exact_service_provider_admin_type |List[OCI.searchCriteriaExactServiceProviderAdminType] |searchCriteriaExactServiceProviderAdminType *Optional* |
|search_criteria_language                          |List[OCI.searchCriteriaLanguage]                      |searchCriteriaLanguage *Optional*                      |
|search_criteria_mode_or                           |bool                                                  |searchCriteriaModeOr *Optional*                        |
</div>


## `ServiceProviderGetPagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request a list of service providers and/or enterprises in the system.

The response is either a `ServiceProviderGetPagedSortedListResponse()` or an
`ErrorResponse()`. If reseller administrator sends the request,
searchCriteriaResellerId is ignored.  Service providers/enterprise within the
administrator's reseller meeting the search criteria are returned.  If the
responsePagingControl element is not provided, the paging startIndex will be set to 1
by default, and the responsePageSize will be set to the maximum responsePageSize by
default.  If no sortOrder is included, the response is sorted by Service Provider Id
ascending by default.  Multiple search criteria are logically ANDed together unless
the searchCriteriaModeOr option is included.  Then the search criteria are logically
ORed together.

**Attributes:**

|Name                                    |Type                                        |Description                                    |
|----------------------------------------|--------------------------------------------|-----------------------------------------------|
|response_paging_control                 |OCI.responsePagingControl                   |responsePagingControl *Optional*               |
|sort_order                              |List[OCI.sortOrder]                         |sortOrder *Optional*                           |
|search_criteria_service_provider_id     |List[OCI.searchCriteriaServiceProviderId]   |searchCriteriaServiceProviderId *Optional*     |
|search_criteria_service_provider_name   |List[OCI.searchCriteriaServiceProviderName] |searchCriteriaServiceProviderName *Optional*   |
|search_criteria_exact_organization_type |OCI.searchCriteriaExactOrganizationType     |searchCriteriaExactOrganizationType *Optional* |
|search_criteria_reseller_id             |List[OCI.searchCriteriaResellerId]          |searchCriteriaResellerId *Optional*            |
|search_criteria_mode_or                 |bool                                        |searchCriteriaModeOr *Optional*                |
</div>


## `SystemSIPDeviceTypeAddRequest14sp6`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`.

Replaced By : `SystemSIPDeviceTypeAddRequest15()`

**Attributes:**

|Name                                       |Type                 |Description                          |
|-------------------------------------------|---------------------|-------------------------------------|
|device_type                                |str                  |deviceType                           |
|number_of_ports                            |OCI.numberOfPorts    |numberOfPorts                        |
|profile                                    |str                  |profile                              |
|registration_capable                       |bool                 |registrationCapable                  |
|is_conference_device                       |bool                 |isConferenceDevice                   |
|is_mobility_manager_device                 |bool                 |isMobilityManagerDevice              |
|is_music_on_hold_device                    |bool                 |isMusicOnHoldDevice                  |
|rfc3264_hold                               |bool                 |RFC3264Hold                          |
|is_trusted                                 |bool                 |isTrusted                            |
|e164_capable                               |bool                 |E164Capable                          |
|route_advance                              |bool                 |routeAdvance                         |
|forwarding_override                        |bool                 |forwardingOverride                   |
|wireless_integration                       |bool                 |wirelessIntegration                  |
|web_based_config_url                       |str                  |webBasedConfigURL *Optional*         |
|is_video_capable                           |bool                 |isVideoCapable                       |
|pbx_integration                            |bool                 |PBXIntegration                       |
|use_business_trunking_contact              |bool                 |useBusinessTrunkingContact           |
|static_registration_capable                |bool                 |staticRegistrationCapable            |
|cpe_device_options                         |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*          |
|early_media_support                        |str                  |earlyMediaSupport                    |
|authenticate_refer                         |bool                 |authenticateRefer                    |
|auto_config_soft_client                    |bool                 |autoConfigSoftClient                 |
|authentication_mode                        |str                  |authenticationMode                   |
|tdm_overlay                                |bool                 |tdmOverlay                           |
|supports_broad_works_info_for_call_waiting |bool                 |supportsBroadWorksINFOForCallWaiting |
</div>


## `SystemSIPDeviceTypeAddRequest15`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`.

Replaced By : `SystemSIPDeviceTypeAddRequest16()`

**Attributes:**

|Name                                   |Type                 |Description                       |
|---------------------------------------|---------------------|----------------------------------|
|device_type                            |str                  |deviceType                        |
|number_of_ports                        |OCI.numberOfPorts    |numberOfPorts                     |
|profile                                |str                  |profile                           |
|registration_capable                   |bool                 |registrationCapable               |
|is_conference_device                   |bool                 |isConferenceDevice                |
|is_mobility_manager_device             |bool                 |isMobilityManagerDevice           |
|is_music_on_hold_device                |bool                 |isMusicOnHoldDevice               |
|rfc3264_hold                           |bool                 |RFC3264Hold                       |
|is_trusted                             |bool                 |isTrusted                         |
|e164_capable                           |bool                 |E164Capable                       |
|route_advance                          |bool                 |routeAdvance                      |
|forwarding_override                    |bool                 |forwardingOverride                |
|wireless_integration                   |bool                 |wirelessIntegration               |
|web_based_config_url                   |str                  |webBasedConfigURL *Optional*      |
|is_video_capable                       |bool                 |isVideoCapable                    |
|pbx_integration                        |bool                 |PBXIntegration                    |
|use_business_trunking_contact          |bool                 |useBusinessTrunkingContact        |
|static_registration_capable            |bool                 |staticRegistrationCapable         |
|cpe_device_options                     |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*       |
|early_media_support                    |str                  |earlyMediaSupport                 |
|authenticate_refer                     |bool                 |authenticateRefer                 |
|auto_config_soft_client                |bool                 |autoConfigSoftClient              |
|authentication_mode                    |str                  |authenticationMode                |
|tdm_overlay                            |bool                 |tdmOverlay                        |
|requires_broad_works_call_waiting_tone |bool                 |requiresBroadWorksCallWaitingTone |
|requires_mwi_subscription              |bool                 |requiresMWISubscription           |
|use_history_info_header_on_access_side |bool                 |useHistoryInfoHeaderOnAccessSide  |
</div>


## `SystemSIPDeviceTypeAddRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by:
`SystemSIPDeviceTypeAddRequest16sp1()`

**Attributes:**

|Name                                   |Type                 |Description                       |
|---------------------------------------|---------------------|----------------------------------|
|device_type                            |str                  |deviceType                        |
|number_of_ports                        |OCI.numberOfPorts    |numberOfPorts                     |
|profile                                |str                  |profile                           |
|registration_capable                   |bool                 |registrationCapable               |
|is_conference_device                   |bool                 |isConferenceDevice                |
|is_mobility_manager_device             |bool                 |isMobilityManagerDevice           |
|is_music_on_hold_device                |bool                 |isMusicOnHoldDevice               |
|rfc3264_hold                           |bool                 |RFC3264Hold                       |
|is_trusted                             |bool                 |isTrusted                         |
|e164_capable                           |bool                 |E164Capable                       |
|route_advance                          |bool                 |routeAdvance                      |
|forwarding_override                    |bool                 |forwardingOverride                |
|wireless_integration                   |bool                 |wirelessIntegration               |
|web_based_config_url                   |str                  |webBasedConfigURL *Optional*      |
|is_video_capable                       |bool                 |isVideoCapable                    |
|pbx_integration                        |bool                 |PBXIntegration                    |
|use_business_trunking_contact          |bool                 |useBusinessTrunkingContact        |
|static_registration_capable            |bool                 |staticRegistrationCapable         |
|cpe_device_options                     |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*       |
|early_media_support                    |str                  |earlyMediaSupport                 |
|authenticate_refer                     |bool                 |authenticateRefer                 |
|auto_config_soft_client                |bool                 |autoConfigSoftClient              |
|authentication_mode                    |str                  |authenticationMode                |
|requires_broad_works_digit_collection  |bool                 |requiresBroadWorksDigitCollection |
|requires_broad_works_call_waiting_tone |bool                 |requiresBroadWorksCallWaitingTone |
|requires_mwi_subscription              |bool                 |requiresMWISubscription           |
|use_history_info_header_on_access_side |bool                 |useHistoryInfoHeaderOnAccessSide  |
|advice_of_charge_capable               |bool                 |adviceOfChargeCapable             |
</div>


## `SystemSIPDeviceTypeAddRequest16sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by:
`SystemSIPDeviceTypeAddRequest17()`

**Attributes:**

|Name                                   |Type                 |Description                       |
|---------------------------------------|---------------------|----------------------------------|
|device_type                            |str                  |deviceType                        |
|number_of_ports                        |OCI.numberOfPorts    |numberOfPorts                     |
|profile                                |str                  |profile                           |
|registration_capable                   |bool                 |registrationCapable               |
|is_conference_device                   |bool                 |isConferenceDevice                |
|is_mobility_manager_device             |bool                 |isMobilityManagerDevice           |
|is_music_on_hold_device                |bool                 |isMusicOnHoldDevice               |
|rfc3264_hold                           |bool                 |RFC3264Hold                       |
|is_trusted                             |bool                 |isTrusted                         |
|e164_capable                           |bool                 |E164Capable                       |
|route_advance                          |bool                 |routeAdvance                      |
|forwarding_override                    |bool                 |forwardingOverride                |
|wireless_integration                   |bool                 |wirelessIntegration               |
|web_based_config_url                   |str                  |webBasedConfigURL *Optional*      |
|is_video_capable                       |bool                 |isVideoCapable                    |
|pbx_integration                        |bool                 |PBXIntegration                    |
|use_business_trunking_contact          |bool                 |useBusinessTrunkingContact        |
|static_registration_capable            |bool                 |staticRegistrationCapable         |
|cpe_device_options                     |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*       |
|early_media_support                    |str                  |earlyMediaSupport                 |
|authenticate_refer                     |bool                 |authenticateRefer                 |
|auto_config_soft_client                |bool                 |autoConfigSoftClient              |
|authentication_mode                    |str                  |authenticationMode                |
|requires_broad_works_digit_collection  |bool                 |requiresBroadWorksDigitCollection |
|requires_broad_works_call_waiting_tone |bool                 |requiresBroadWorksCallWaitingTone |
|requires_mwi_subscription              |bool                 |requiresMWISubscription           |
|use_history_info_header_on_access_side |bool                 |useHistoryInfoHeaderOnAccessSide  |
|advice_of_charge_capable               |bool                 |adviceOfChargeCapable             |
|reset_event                            |str                  |resetEvent *Optional*             |
</div>


## `SystemSIPDeviceTypeAddRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                   |Type                 |Description                       |
|---------------------------------------|---------------------|----------------------------------|
|device_type                            |str                  |deviceType                        |
|number_of_ports                        |OCI.numberOfPorts    |numberOfPorts                     |
|profile                                |str                  |profile                           |
|registration_capable                   |bool                 |registrationCapable               |
|is_conference_device                   |bool                 |isConferenceDevice                |
|is_mobility_manager_device             |bool                 |isMobilityManagerDevice           |
|is_music_on_hold_device                |bool                 |isMusicOnHoldDevice               |
|rfc3264_hold                           |bool                 |RFC3264Hold                       |
|is_trusted                             |bool                 |isTrusted                         |
|e164_capable                           |bool                 |E164Capable                       |
|route_advance                          |bool                 |routeAdvance                      |
|forwarding_override                    |bool                 |forwardingOverride                |
|wireless_integration                   |bool                 |wirelessIntegration               |
|web_based_config_url                   |str                  |webBasedConfigURL *Optional*      |
|is_video_capable                       |bool                 |isVideoCapable                    |
|pbx_integration                        |bool                 |PBXIntegration                    |
|static_registration_capable            |bool                 |staticRegistrationCapable         |
|cpe_device_options                     |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*       |
|early_media_support                    |str                  |earlyMediaSupport                 |
|authenticate_refer                     |bool                 |authenticateRefer                 |
|auto_config_soft_client                |bool                 |autoConfigSoftClient              |
|authentication_mode                    |str                  |authenticationMode                |
|requires_broad_works_digit_collection  |bool                 |requiresBroadWorksDigitCollection |
|requires_broad_works_call_waiting_tone |bool                 |requiresBroadWorksCallWaitingTone |
|requires_mwi_subscription              |bool                 |requiresMWISubscription           |
|use_history_info_header_on_access_side |bool                 |useHistoryInfoHeaderOnAccessSide  |
|advice_of_charge_capable               |bool                 |adviceOfChargeCapable             |
|reset_event                            |str                  |resetEvent *Optional*             |
|support_call_center_mime_type          |bool                 |supportCallCenterMIMEType         |
|trunk_mode                             |str                  |trunkMode                         |
|add_p_called_party_id                  |bool                 |addPCalledPartyId                 |
</div>


## `SystemSIPDeviceTypeAddRequest17sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by:
`SystemSIPDeviceTypeAddRequest18()`

**Attributes:**

|Name                                     |Type                 |Description                          |
|-----------------------------------------|---------------------|-------------------------------------|
|device_type                              |str                  |deviceType                           |
|number_of_ports                          |OCI.numberOfPorts    |numberOfPorts                        |
|profile                                  |str                  |profile                              |
|registration_capable                     |bool                 |registrationCapable                  |
|is_conference_device                     |bool                 |isConferenceDevice                   |
|is_mobility_manager_device               |bool                 |isMobilityManagerDevice              |
|is_music_on_hold_device                  |bool                 |isMusicOnHoldDevice                  |
|rfc3264_hold                             |bool                 |RFC3264Hold                          |
|is_trusted                               |bool                 |isTrusted                            |
|e164_capable                             |bool                 |E164Capable                          |
|route_advance                            |bool                 |routeAdvance                         |
|forwarding_override                      |bool                 |forwardingOverride                   |
|wireless_integration                     |bool                 |wirelessIntegration                  |
|web_based_config_url                     |str                  |webBasedConfigURL *Optional*         |
|is_video_capable                         |bool                 |isVideoCapable                       |
|pbx_integration                          |bool                 |PBXIntegration                       |
|static_registration_capable              |bool                 |staticRegistrationCapable            |
|cpe_device_options                       |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*          |
|early_media_support                      |str                  |earlyMediaSupport                    |
|authenticate_refer                       |bool                 |authenticateRefer                    |
|auto_config_soft_client                  |bool                 |autoConfigSoftClient                 |
|authentication_mode                      |str                  |authenticationMode                   |
|requires_broad_works_digit_collection    |bool                 |requiresBroadWorksDigitCollection    |
|requires_broad_works_call_waiting_tone   |bool                 |requiresBroadWorksCallWaitingTone    |
|requires_mwi_subscription                |bool                 |requiresMWISubscription              |
|use_history_info_header_on_access_side   |bool                 |useHistoryInfoHeaderOnAccessSide     |
|advice_of_charge_capable                 |bool                 |adviceOfChargeCapable                |
|reset_event                              |str                  |resetEvent *Optional*                |
|support_call_center_mime_type            |bool                 |supportCallCenterMIMEType            |
|trunk_mode                               |str                  |trunkMode                            |
|add_p_called_party_id                    |bool                 |addPCalledPartyId                    |
|support_identity_in_update_and_re_invite |bool                 |supportIdentityInUpdateAndReInvite   |
|unscreened_presentation_identity_policy  |str                  |unscreenedPresentationIdentityPolicy |
</div>


## `SystemSIPDeviceTypeAddRequest18`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in XS data mode: enable3G4GContinuity Replaced by:
`SystemSIPDeviceTypeAddRequest19()`

**Attributes:**

|Name                                     |Type                 |Description                          |
|-----------------------------------------|---------------------|-------------------------------------|
|device_type                              |str                  |deviceType                           |
|number_of_ports                          |OCI.numberOfPorts    |numberOfPorts                        |
|profile                                  |str                  |profile                              |
|registration_capable                     |bool                 |registrationCapable                  |
|is_conference_device                     |bool                 |isConferenceDevice                   |
|is_mobility_manager_device               |bool                 |isMobilityManagerDevice              |
|is_music_on_hold_device                  |bool                 |isMusicOnHoldDevice                  |
|rfc3264_hold                             |bool                 |RFC3264Hold                          |
|is_trusted                               |bool                 |isTrusted                            |
|e164_capable                             |bool                 |E164Capable                          |
|route_advance                            |bool                 |routeAdvance                         |
|forwarding_override                      |bool                 |forwardingOverride                   |
|wireless_integration                     |bool                 |wirelessIntegration                  |
|web_based_config_url                     |str                  |webBasedConfigURL *Optional*         |
|is_video_capable                         |bool                 |isVideoCapable                       |
|pbx_integration                          |bool                 |PBXIntegration                       |
|static_registration_capable              |bool                 |staticRegistrationCapable            |
|cpe_device_options                       |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*          |
|early_media_support                      |str                  |earlyMediaSupport                    |
|authenticate_refer                       |bool                 |authenticateRefer                    |
|auto_config_soft_client                  |bool                 |autoConfigSoftClient                 |
|authentication_mode                      |str                  |authenticationMode                   |
|requires_broad_works_digit_collection    |bool                 |requiresBroadWorksDigitCollection    |
|requires_broad_works_call_waiting_tone   |bool                 |requiresBroadWorksCallWaitingTone    |
|requires_mwi_subscription                |bool                 |requiresMWISubscription              |
|use_history_info_header_on_access_side   |bool                 |useHistoryInfoHeaderOnAccessSide     |
|advice_of_charge_capable                 |bool                 |adviceOfChargeCapable                |
|reset_event                              |str                  |resetEvent *Optional*                |
|support_call_center_mime_type            |bool                 |supportCallCenterMIMEType            |
|trunk_mode                               |str                  |trunkMode                            |
|add_p_called_party_id                    |bool                 |addPCalledPartyId                    |
|support_identity_in_update_and_re_invite |bool                 |supportIdentityInUpdateAndReInvite   |
|unscreened_presentation_identity_policy  |str                  |unscreenedPresentationIdentityPolicy |
|enable3_g4_g_continuity                  |bool                 |enable3G4GContinuity                 |
|support_emergency_disconnect_control     |bool                 |supportEmergencyDisconnectControl    |
|device_type_configuration_option         |str                  |deviceTypeConfigurationOption        |
</div>


## `SystemSIPDeviceTypeAddRequest18sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in XS data mode: enable3G4GContinuity, use value "false" in AS
data mode The following elements are only used in AS data mode:
holdAnnouncementMethod, use value "useInactive" in XS data mode The following element
values are only applicable in AS data mode: holdNormalization=useRfc3264Hold will
raise an error in XS data mode

**Attributes:**

|Name                                     |Type                 |Description                          |
|-----------------------------------------|---------------------|-------------------------------------|
|device_type                              |str                  |deviceType                           |
|number_of_ports                          |OCI.numberOfPorts    |numberOfPorts                        |
|profile                                  |str                  |profile                              |
|registration_capable                     |bool                 |registrationCapable                  |
|is_conference_device                     |bool                 |isConferenceDevice                   |
|is_mobility_manager_device               |bool                 |isMobilityManagerDevice              |
|is_music_on_hold_device                  |bool                 |isMusicOnHoldDevice                  |
|hold_normalization                       |str                  |holdNormalization                    |
|hold_announcement_method                 |str                  |holdAnnouncementMethod               |
|is_trusted                               |bool                 |isTrusted                            |
|e164_capable                             |bool                 |E164Capable                          |
|route_advance                            |bool                 |routeAdvance                         |
|forwarding_override                      |bool                 |forwardingOverride                   |
|wireless_integration                     |bool                 |wirelessIntegration                  |
|web_based_config_url                     |str                  |webBasedConfigURL *Optional*         |
|is_video_capable                         |bool                 |isVideoCapable                       |
|pbx_integration                          |bool                 |PBXIntegration                       |
|static_registration_capable              |bool                 |staticRegistrationCapable            |
|cpe_device_options                       |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*          |
|early_media_support                      |str                  |earlyMediaSupport                    |
|authenticate_refer                       |bool                 |authenticateRefer                    |
|auto_config_soft_client                  |bool                 |autoConfigSoftClient                 |
|authentication_mode                      |str                  |authenticationMode                   |
|requires_broad_works_digit_collection    |bool                 |requiresBroadWorksDigitCollection    |
|requires_broad_works_call_waiting_tone   |bool                 |requiresBroadWorksCallWaitingTone    |
|requires_mwi_subscription                |bool                 |requiresMWISubscription              |
|use_history_info_header_on_access_side   |bool                 |useHistoryInfoHeaderOnAccessSide     |
|advice_of_charge_capable                 |bool                 |adviceOfChargeCapable                |
|reset_event                              |str                  |resetEvent *Optional*                |
|support_call_center_mime_type            |bool                 |supportCallCenterMIMEType            |
|trunk_mode                               |str                  |trunkMode                            |
|add_p_called_party_id                    |bool                 |addPCalledPartyId                    |
|support_identity_in_update_and_re_invite |bool                 |supportIdentityInUpdateAndReInvite   |
|unscreened_presentation_identity_policy  |str                  |unscreenedPresentationIdentityPolicy |
|enable3_g4_g_continuity                  |bool                 |enable3G4GContinuity                 |
|support_emergency_disconnect_control     |bool                 |supportEmergencyDisconnectControl    |
|device_type_configuration_option         |str                  |deviceTypeConfigurationOption        |
</div>


## `SystemSIPDeviceTypeAddRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in XS data mode: enable3G4GContinuity, use value "false" in AS
data mode The following elements are only used in AS data mode:
holdAnnouncementMethod, use value "useInactive" in XS data mode supportRFC3398, use
value "false" in XS data mode The following element values are only applicable in AS
data mode: holdNormalization=useRfc3264Hold will raise an error in XS data mode
Replaced by: `SystemSIPDeviceTypeAddRequest19sp1()`

**Attributes:**

|Name                                     |Type                 |Description                          |
|-----------------------------------------|---------------------|-------------------------------------|
|device_type                              |str                  |deviceType                           |
|number_of_ports                          |OCI.numberOfPorts    |numberOfPorts                        |
|profile                                  |str                  |profile                              |
|registration_capable                     |bool                 |registrationCapable                  |
|is_conference_device                     |bool                 |isConferenceDevice                   |
|is_mobility_manager_device               |bool                 |isMobilityManagerDevice              |
|is_music_on_hold_device                  |bool                 |isMusicOnHoldDevice                  |
|hold_normalization                       |str                  |holdNormalization                    |
|hold_announcement_method                 |str                  |holdAnnouncementMethod               |
|is_trusted                               |bool                 |isTrusted                            |
|e164_capable                             |bool                 |E164Capable                          |
|route_advance                            |bool                 |routeAdvance                         |
|forwarding_override                      |bool                 |forwardingOverride                   |
|wireless_integration                     |bool                 |wirelessIntegration                  |
|web_based_config_url                     |str                  |webBasedConfigURL *Optional*         |
|is_video_capable                         |bool                 |isVideoCapable                       |
|pbx_integration                          |bool                 |PBXIntegration                       |
|static_registration_capable              |bool                 |staticRegistrationCapable            |
|cpe_device_options                       |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*          |
|early_media_support                      |str                  |earlyMediaSupport                    |
|authenticate_refer                       |bool                 |authenticateRefer                    |
|auto_config_soft_client                  |bool                 |autoConfigSoftClient                 |
|authentication_mode                      |str                  |authenticationMode                   |
|requires_broad_works_digit_collection    |bool                 |requiresBroadWorksDigitCollection    |
|requires_broad_works_call_waiting_tone   |bool                 |requiresBroadWorksCallWaitingTone    |
|requires_mwi_subscription                |bool                 |requiresMWISubscription              |
|use_history_info_header_on_access_side   |bool                 |useHistoryInfoHeaderOnAccessSide     |
|advice_of_charge_capable                 |bool                 |adviceOfChargeCapable                |
|reset_event                              |str                  |resetEvent *Optional*                |
|support_call_center_mime_type            |bool                 |supportCallCenterMIMEType            |
|trunk_mode                               |str                  |trunkMode                            |
|add_p_called_party_id                    |bool                 |addPCalledPartyId                    |
|support_identity_in_update_and_re_invite |bool                 |supportIdentityInUpdateAndReInvite   |
|unscreened_presentation_identity_policy  |str                  |unscreenedPresentationIdentityPolicy |
|enable3_g4_g_continuity                  |bool                 |enable3G4GContinuity                 |
|support_emergency_disconnect_control     |bool                 |supportEmergencyDisconnectControl    |
|device_type_configuration_option         |str                  |deviceTypeConfigurationOption        |
|support_rfc3398                          |bool                 |supportRFC3398                       |
|static_line_ordering                     |bool                 |staticLineOrdering                   |
</div>


## `SystemSIPDeviceTypeAddRequest19sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in XS data mode: enable3G4GContinuity, use value "false" in AS
data mode The following elements are only used in AS data mode:
holdAnnouncementMethod, use value "useInactive" in XS data mode supportRFC3398, use
value "false" in XS data mode bypassMediaTreatment, use value "false" in XS data mode
The following element values are only applicable in AS data mode:
holdNormalization=useRfc3264Hold will raise an error in XS data mode Replaced by:
`SystemSIPDeviceTypeAddRequest20()`

**Attributes:**

|Name                                     |Type                 |Description                          |
|-----------------------------------------|---------------------|-------------------------------------|
|device_type                              |str                  |deviceType                           |
|number_of_ports                          |OCI.numberOfPorts    |numberOfPorts                        |
|profile                                  |str                  |profile                              |
|registration_capable                     |bool                 |registrationCapable                  |
|is_conference_device                     |bool                 |isConferenceDevice                   |
|is_mobility_manager_device               |bool                 |isMobilityManagerDevice              |
|is_music_on_hold_device                  |bool                 |isMusicOnHoldDevice                  |
|hold_normalization                       |str                  |holdNormalization                    |
|hold_announcement_method                 |str                  |holdAnnouncementMethod               |
|is_trusted                               |bool                 |isTrusted                            |
|e164_capable                             |bool                 |E164Capable                          |
|route_advance                            |bool                 |routeAdvance                         |
|forwarding_override                      |bool                 |forwardingOverride                   |
|wireless_integration                     |bool                 |wirelessIntegration                  |
|web_based_config_url                     |str                  |webBasedConfigURL *Optional*         |
|is_video_capable                         |bool                 |isVideoCapable                       |
|pbx_integration                          |bool                 |PBXIntegration                       |
|static_registration_capable              |bool                 |staticRegistrationCapable            |
|cpe_device_options                       |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*          |
|early_media_support                      |str                  |earlyMediaSupport                    |
|authenticate_refer                       |bool                 |authenticateRefer                    |
|auto_config_soft_client                  |bool                 |autoConfigSoftClient                 |
|authentication_mode                      |str                  |authenticationMode                   |
|requires_broad_works_digit_collection    |bool                 |requiresBroadWorksDigitCollection    |
|requires_broad_works_call_waiting_tone   |bool                 |requiresBroadWorksCallWaitingTone    |
|requires_mwi_subscription                |bool                 |requiresMWISubscription              |
|use_history_info_header_on_access_side   |bool                 |useHistoryInfoHeaderOnAccessSide     |
|advice_of_charge_capable                 |bool                 |adviceOfChargeCapable                |
|reset_event                              |str                  |resetEvent *Optional*                |
|support_call_center_mime_type            |bool                 |supportCallCenterMIMEType            |
|trunk_mode                               |str                  |trunkMode                            |
|add_p_called_party_id                    |bool                 |addPCalledPartyId                    |
|support_identity_in_update_and_re_invite |bool                 |supportIdentityInUpdateAndReInvite   |
|unscreened_presentation_identity_policy  |str                  |unscreenedPresentationIdentityPolicy |
|enable3_g4_g_continuity                  |bool                 |enable3G4GContinuity                 |
|support_emergency_disconnect_control     |bool                 |supportEmergencyDisconnectControl    |
|device_type_configuration_option         |str                  |deviceTypeConfigurationOption        |
|support_rfc3398                          |bool                 |supportRFC3398                       |
|static_line_ordering                     |bool                 |staticLineOrdering                   |
|bypass_media_treatment                   |bool                 |bypassMediaTreatment                 |
</div>


## `SystemSIPDeviceTypeAddRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in XS data mode: enable3G4GContinuity, use value "false" in AS
data mode The following elements are only used in AS data mode:
holdAnnouncementMethod, use value "useInactive" in XS data mode supportRFC3398, use
value "false" in XS data mode supportClientSessionInfo, use value "false" in XS data
mode supportCallInfoConferenceSubscriptionURI, use value "false" in XS data mode
supportRemotePartyInfo, use value "false" in XS data mode The following element values
are only applicable in AS data mode: holdNormalization=useRfc3264Hold will raise an
error in XS data mode

**Attributes:**

|Name                                          |Type                 |Description                              |
|----------------------------------------------|---------------------|-----------------------------------------|
|device_type                                   |str                  |deviceType                               |
|number_of_ports                               |OCI.numberOfPorts    |numberOfPorts                            |
|profile                                       |str                  |profile                                  |
|registration_capable                          |bool                 |registrationCapable                      |
|is_conference_device                          |bool                 |isConferenceDevice                       |
|is_mobility_manager_device                    |bool                 |isMobilityManagerDevice                  |
|is_music_on_hold_device                       |bool                 |isMusicOnHoldDevice                      |
|hold_normalization                            |str                  |holdNormalization                        |
|hold_announcement_method                      |str                  |holdAnnouncementMethod                   |
|is_trusted                                    |bool                 |isTrusted                                |
|e164_capable                                  |bool                 |E164Capable                              |
|route_advance                                 |bool                 |routeAdvance                             |
|forwarding_override                           |bool                 |forwardingOverride                       |
|wireless_integration                          |bool                 |wirelessIntegration                      |
|web_based_config_url                          |str                  |webBasedConfigURL *Optional*             |
|is_video_capable                              |bool                 |isVideoCapable                           |
|pbx_integration                               |bool                 |PBXIntegration                           |
|static_registration_capable                   |bool                 |staticRegistrationCapable                |
|cpe_device_options                            |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*              |
|early_media_support                           |str                  |earlyMediaSupport                        |
|authenticate_refer                            |bool                 |authenticateRefer                        |
|auto_config_soft_client                       |bool                 |autoConfigSoftClient                     |
|authentication_mode                           |str                  |authenticationMode                       |
|requires_broad_works_digit_collection         |bool                 |requiresBroadWorksDigitCollection        |
|requires_broad_works_call_waiting_tone        |bool                 |requiresBroadWorksCallWaitingTone        |
|requires_mwi_subscription                     |bool                 |requiresMWISubscription                  |
|use_history_info_header_on_access_side        |bool                 |useHistoryInfoHeaderOnAccessSide         |
|advice_of_charge_capable                      |bool                 |adviceOfChargeCapable                    |
|reset_event                                   |str                  |resetEvent *Optional*                    |
|support_call_center_mime_type                 |bool                 |supportCallCenterMIMEType                |
|trunk_mode                                    |str                  |trunkMode                                |
|add_p_called_party_id                         |bool                 |addPCalledPartyId                        |
|support_identity_in_update_and_re_invite      |bool                 |supportIdentityInUpdateAndReInvite       |
|unscreened_presentation_identity_policy       |str                  |unscreenedPresentationIdentityPolicy     |
|enable3_g4_g_continuity                       |bool                 |enable3G4GContinuity                     |
|support_emergency_disconnect_control          |bool                 |supportEmergencyDisconnectControl        |
|device_type_configuration_option              |str                  |deviceTypeConfigurationOption            |
|support_rfc3398                               |bool                 |supportRFC3398                           |
|static_line_ordering                          |bool                 |staticLineOrdering                       |
|support_client_session_info                   |bool                 |supportClientSessionInfo                 |
|support_call_info_conference_subscription_uri |bool                 |supportCallInfoConferenceSubscriptionURI |
|support_remote_party_info                     |bool                 |supportRemotePartyInfo                   |
|support_visual_device_management              |bool                 |supportVisualDeviceManagement            |
|bypass_media_treatment                        |bool                 |bypassMediaTreatment                     |
</div>


## `SystemSIPDeviceTypeAddRequest20sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in HSS data mode: enable3G4GContinuity, use value "false" in AS
data mode The following logic applies to these elements: macInCert macInNonRequestURI
The two elements are mutually exclusive.  When both are set to true, the command
fails.  The following elements are only used in AS data mode: holdAnnouncementMethod,
use value "useInactive" in HSS data mode supportRFC3398, use value "false" in HSS data
mode supportClientSessionInfo, use value "false" in HSS data mode
supportCallInfoConferenceSubscriptionURI, use value "false" in HSS data mode
supportRemotePartyInfo, use value "false" in HSS data mode The following element
values are only applicable in AS data mode: holdNormalization=useRfc3264Hold will
raise an error in HSS data mode Replaced by: SystemSIPDeviceTypeAddRequest21sp1V2.

**Attributes:**

|Name                                          |Type                 |Description                              |
|----------------------------------------------|---------------------|-----------------------------------------|
|device_type                                   |str                  |deviceType                               |
|number_of_ports                               |OCI.numberOfPorts    |numberOfPorts                            |
|profile                                       |str                  |profile                                  |
|registration_capable                          |bool                 |registrationCapable                      |
|is_conference_device                          |bool                 |isConferenceDevice                       |
|is_mobility_manager_device                    |bool                 |isMobilityManagerDevice                  |
|is_music_on_hold_device                       |bool                 |isMusicOnHoldDevice                      |
|hold_normalization                            |str                  |holdNormalization                        |
|hold_announcement_method                      |str                  |holdAnnouncementMethod                   |
|is_trusted                                    |bool                 |isTrusted                                |
|e164_capable                                  |bool                 |E164Capable                              |
|route_advance                                 |bool                 |routeAdvance                             |
|forwarding_override                           |bool                 |forwardingOverride                       |
|wireless_integration                          |bool                 |wirelessIntegration                      |
|web_based_config_url                          |str                  |webBasedConfigURL *Optional*             |
|is_video_capable                              |bool                 |isVideoCapable                           |
|pbx_integration                               |bool                 |PBXIntegration                           |
|static_registration_capable                   |bool                 |staticRegistrationCapable                |
|cpe_device_options                            |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*              |
|early_media_support                           |str                  |earlyMediaSupport                        |
|authenticate_refer                            |bool                 |authenticateRefer                        |
|auto_config_soft_client                       |bool                 |autoConfigSoftClient                     |
|authentication_mode                           |str                  |authenticationMode                       |
|requires_broad_works_digit_collection         |bool                 |requiresBroadWorksDigitCollection        |
|requires_broad_works_call_waiting_tone        |bool                 |requiresBroadWorksCallWaitingTone        |
|requires_mwi_subscription                     |bool                 |requiresMWISubscription                  |
|use_history_info_header_on_access_side        |bool                 |useHistoryInfoHeaderOnAccessSide         |
|advice_of_charge_capable                      |bool                 |adviceOfChargeCapable                    |
|reset_event                                   |str                  |resetEvent *Optional*                    |
|support_call_center_mime_type                 |bool                 |supportCallCenterMIMEType                |
|trunk_mode                                    |str                  |trunkMode                                |
|add_p_called_party_id                         |bool                 |addPCalledPartyId                        |
|support_identity_in_update_and_re_invite      |bool                 |supportIdentityInUpdateAndReInvite       |
|unscreened_presentation_identity_policy       |str                  |unscreenedPresentationIdentityPolicy     |
|enable3_g4_g_continuity                       |bool                 |enable3G4GContinuity                     |
|support_emergency_disconnect_control          |bool                 |supportEmergencyDisconnectControl        |
|device_type_configuration_option              |str                  |deviceTypeConfigurationOption            |
|support_rfc3398                               |bool                 |supportRFC3398                           |
|static_line_ordering                          |bool                 |staticLineOrdering                       |
|support_client_session_info                   |bool                 |supportClientSessionInfo                 |
|support_call_info_conference_subscription_uri |bool                 |supportCallInfoConferenceSubscriptionURI |
|support_remote_party_info                     |bool                 |supportRemotePartyInfo                   |
|support_visual_device_management              |bool                 |supportVisualDeviceManagement            |
|bypass_media_treatment                        |bool                 |bypassMediaTreatment                     |
</div>


## `SystemSIPDeviceTypeAddRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in XS data mode: enhancedForICS, use value "false" in AS data
mode supports3G4GContinuity, use value "false" in AS data mode publishesOwnPresence,
use value "false" in AS data mode The following elements are only used in AS data
mode: holdAnnouncementMethod, use value "useInactive" in XS data mode supportRFC3398,
use value "false" in XS data mode supportClientSessionInfo, use value "false" in XS
data mode supportCallInfoConferenceSubscriptionURI, use value "false" in XS data mode
supportRemotePartyInfo, use value "false" in XS data mode bypassMediaTreatment, use
value "false" in XS data mode supportCauseParameter, use value "false" in XS data mode
The following element values are only applicable in AS data mode:
holdNormalization=useRfc3264Hold will raise an error in XS data mode The following
elements are only used in AS data mode and ignored in XS data mode:
supportCauseParameter Replaced by: `SystemSIPDeviceTypeAddRequest21sp1()`

**Attributes:**

|Name                                          |Type                 |Description                              |
|----------------------------------------------|---------------------|-----------------------------------------|
|device_type                                   |str                  |deviceType                               |
|number_of_ports                               |OCI.numberOfPorts    |numberOfPorts                            |
|profile                                       |str                  |profile                                  |
|registration_capable                          |bool                 |registrationCapable                      |
|is_conference_device                          |bool                 |isConferenceDevice                       |
|is_mobility_manager_device                    |bool                 |isMobilityManagerDevice                  |
|is_music_on_hold_device                       |bool                 |isMusicOnHoldDevice                      |
|hold_normalization                            |str                  |holdNormalization                        |
|hold_announcement_method                      |str                  |holdAnnouncementMethod                   |
|is_trusted                                    |bool                 |isTrusted                                |
|e164_capable                                  |bool                 |E164Capable                              |
|route_advance                                 |bool                 |routeAdvance                             |
|forwarding_override                           |bool                 |forwardingOverride                       |
|wireless_integration                          |bool                 |wirelessIntegration                      |
|web_based_config_url                          |str                  |webBasedConfigURL *Optional*             |
|is_video_capable                              |bool                 |isVideoCapable                           |
|pbx_integration                               |bool                 |PBXIntegration                           |
|static_registration_capable                   |bool                 |staticRegistrationCapable                |
|cpe_device_options                            |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*              |
|early_media_support                           |str                  |earlyMediaSupport                        |
|authenticate_refer                            |bool                 |authenticateRefer                        |
|auto_config_soft_client                       |bool                 |autoConfigSoftClient                     |
|authentication_mode                           |str                  |authenticationMode                       |
|requires_broad_works_digit_collection         |bool                 |requiresBroadWorksDigitCollection        |
|requires_broad_works_call_waiting_tone        |bool                 |requiresBroadWorksCallWaitingTone        |
|requires_mwi_subscription                     |bool                 |requiresMWISubscription                  |
|use_history_info_header_on_access_side        |bool                 |useHistoryInfoHeaderOnAccessSide         |
|advice_of_charge_capable                      |bool                 |adviceOfChargeCapable                    |
|reset_event                                   |str                  |resetEvent *Optional*                    |
|support_call_center_mime_type                 |bool                 |supportCallCenterMIMEType                |
|trunk_mode                                    |str                  |trunkMode                                |
|add_p_called_party_id                         |bool                 |addPCalledPartyId                        |
|support_identity_in_update_and_re_invite      |bool                 |supportIdentityInUpdateAndReInvite       |
|unscreened_presentation_identity_policy       |str                  |unscreenedPresentationIdentityPolicy     |
|enhanced_for_ics                              |bool                 |enhancedForICS                           |
|support_emergency_disconnect_control          |bool                 |supportEmergencyDisconnectControl        |
|device_type_configuration_option              |str                  |deviceTypeConfigurationOption            |
|support_rfc3398                               |bool                 |supportRFC3398                           |
|static_line_ordering                          |bool                 |staticLineOrdering                       |
|support_client_session_info                   |bool                 |supportClientSessionInfo                 |
|support_call_info_conference_subscription_uri |bool                 |supportCallInfoConferenceSubscriptionURI |
|support_remote_party_info                     |bool                 |supportRemotePartyInfo                   |
|support_visual_device_management              |bool                 |supportVisualDeviceManagement            |
|bypass_media_treatment                        |bool                 |bypassMediaTreatment                     |
|supports3_g4_g_continuity                     |bool                 |supports3G4GContinuity                   |
|publishes_own_presence                        |bool                 |publishesOwnPresence                     |
|support_cause_parameter                       |bool                 |supportCauseParameter                    |
</div>


## `SystemSIPDeviceTypeAddRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in XS data mode: enhancedForICS, use value "false" in AS data
mode supports3G4GContinuity, use value "false" in AS data mode publishesOwnPresence,
use value "false" in AS data mode locationNetwork, use value "Fixed" in AS data mode
The following elements are only used in AS data mode: holdAnnouncementMethod, use
value "useInactive" in XS data mode supportRFC3398, use value "false" in XS data mode
supportClientSessionInfo, use value "false" in XS data mode
supportCallInfoConferenceSubscriptionURI, use value "false" in XS data mode
supportRemotePartyInfo, use value "false" in XS data mode bypassMediaTreatment, use
value "false" in XS data mode supportCauseParameter, use value "false" in XS data mode
The following element values are only applicable in AS data mode:
holdNormalization=useRfc3264Hold will raise an error in XS data mode The following
elements are only used in AS data mode and ignored in XS data mode:
supportCauseParameter Replaced by: SystemSIPDeviceTypeAddRequest21Sp1V2

**Attributes:**

|Name                                          |Type                 |Description                              |
|----------------------------------------------|---------------------|-----------------------------------------|
|device_type                                   |str                  |deviceType                               |
|number_of_ports                               |OCI.numberOfPorts    |numberOfPorts                            |
|profile                                       |str                  |profile                                  |
|registration_capable                          |bool                 |registrationCapable                      |
|is_conference_device                          |bool                 |isConferenceDevice                       |
|is_mobility_manager_device                    |bool                 |isMobilityManagerDevice                  |
|is_music_on_hold_device                       |bool                 |isMusicOnHoldDevice                      |
|hold_normalization                            |str                  |holdNormalization                        |
|hold_announcement_method                      |str                  |holdAnnouncementMethod                   |
|is_trusted                                    |bool                 |isTrusted                                |
|e164_capable                                  |bool                 |E164Capable                              |
|route_advance                                 |bool                 |routeAdvance                             |
|forwarding_override                           |bool                 |forwardingOverride                       |
|wireless_integration                          |bool                 |wirelessIntegration                      |
|web_based_config_url                          |str                  |webBasedConfigURL *Optional*             |
|is_video_capable                              |bool                 |isVideoCapable                           |
|pbx_integration                               |bool                 |PBXIntegration                           |
|static_registration_capable                   |bool                 |staticRegistrationCapable                |
|cpe_device_options                            |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*              |
|early_media_support                           |str                  |earlyMediaSupport                        |
|authenticate_refer                            |bool                 |authenticateRefer                        |
|auto_config_soft_client                       |bool                 |autoConfigSoftClient                     |
|authentication_mode                           |str                  |authenticationMode                       |
|requires_broad_works_digit_collection         |bool                 |requiresBroadWorksDigitCollection        |
|requires_broad_works_call_waiting_tone        |bool                 |requiresBroadWorksCallWaitingTone        |
|requires_mwi_subscription                     |bool                 |requiresMWISubscription                  |
|use_history_info_header_on_access_side        |bool                 |useHistoryInfoHeaderOnAccessSide         |
|advice_of_charge_capable                      |bool                 |adviceOfChargeCapable                    |
|reset_event                                   |str                  |resetEvent *Optional*                    |
|support_call_center_mime_type                 |bool                 |supportCallCenterMIMEType                |
|trunk_mode                                    |str                  |trunkMode                                |
|add_p_called_party_id                         |bool                 |addPCalledPartyId                        |
|support_identity_in_update_and_re_invite      |bool                 |supportIdentityInUpdateAndReInvite       |
|unscreened_presentation_identity_policy       |str                  |unscreenedPresentationIdentityPolicy     |
|enhanced_for_ics                              |bool                 |enhancedForICS                           |
|support_emergency_disconnect_control          |bool                 |supportEmergencyDisconnectControl        |
|device_type_configuration_option              |str                  |deviceTypeConfigurationOption            |
|support_rfc3398                               |bool                 |supportRFC3398                           |
|static_line_ordering                          |bool                 |staticLineOrdering                       |
|support_client_session_info                   |bool                 |supportClientSessionInfo                 |
|support_call_info_conference_subscription_uri |bool                 |supportCallInfoConferenceSubscriptionURI |
|support_remote_party_info                     |bool                 |supportRemotePartyInfo                   |
|support_visual_device_management              |bool                 |supportVisualDeviceManagement            |
|bypass_media_treatment                        |bool                 |bypassMediaTreatment                     |
|supports3_g4_g_continuity                     |bool                 |supports3G4GContinuity                   |
|publishes_own_presence                        |bool                 |publishesOwnPresence                     |
|support_cause_parameter                       |bool                 |supportCauseParameter                    |
|location_network                              |str                  |locationNetwork                          |
</div>


## `SystemSIPDeviceTypeAddRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`. When the optional
element resellerId is specified, the device type created is at reseller level.  Device
type name should be unique through out the system including all the reseller level
device types.  The following elements are only used in the XS data mode and ignored in
the AS data mode: enhancedForICS supports3G4GContinuity publishesOwnPresence, use
value "false" in AS data mode locationNetwork, use value "Fixed" in AS data mode The
following elements are only used in AS data mode and ignored in the XS data mode:
supportRFC3398, use value "false" in XS data mode supportClientSessionInfo, use value
"false" in XS data mode supportCallInfoConferenceSubscriptionURI, use value "false" in
XS data mode supportRemotePartyInfo, use value "false" in XS data mode
bypassMediaTreatment, use value "false" in XS data mode supportCauseParameter, use
value "false" in XS data mode resellerId The following values for element profile are
only used in AS data mode and an error is returned in the XS data mode: Non-
intelligent Device Addressing Intelligent Device Addressing The following logic
applies to these elements: macInCert macInNonRequestURI The two elements are mutually
exclusive.  When both are set to true, the command fails.  Deprecated by:
`SystemSIPDeviceTypeAddRequest22V2()`

**Attributes:**

|Name                                          |Type                 |Description                              |
|----------------------------------------------|---------------------|-----------------------------------------|
|device_type                                   |str                  |deviceType                               |
|number_of_ports                               |OCI.numberOfPorts    |numberOfPorts                            |
|profile                                       |str                  |profile                                  |
|registration_capable                          |bool                 |registrationCapable                      |
|is_conference_device                          |bool                 |isConferenceDevice                       |
|is_mobility_manager_device                    |bool                 |isMobilityManagerDevice                  |
|is_music_on_hold_device                       |bool                 |isMusicOnHoldDevice                      |
|hold_normalization                            |str                  |holdNormalization                        |
|hold_announcement_method                      |str                  |holdAnnouncementMethod                   |
|is_trusted                                    |bool                 |isTrusted                                |
|e164_capable                                  |bool                 |E164Capable                              |
|route_advance                                 |bool                 |routeAdvance                             |
|forwarding_override                           |bool                 |forwardingOverride                       |
|wireless_integration                          |bool                 |wirelessIntegration                      |
|web_based_config_url                          |str                  |webBasedConfigURL *Optional*             |
|is_video_capable                              |bool                 |isVideoCapable                           |
|pbx_integration                               |bool                 |PBXIntegration                           |
|static_registration_capable                   |bool                 |staticRegistrationCapable                |
|cpe_device_options                            |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*              |
|early_media_support                           |str                  |earlyMediaSupport                        |
|authenticate_refer                            |bool                 |authenticateRefer                        |
|auto_config_soft_client                       |bool                 |autoConfigSoftClient                     |
|authentication_mode                           |str                  |authenticationMode                       |
|requires_broad_works_digit_collection         |bool                 |requiresBroadWorksDigitCollection        |
|requires_broad_works_call_waiting_tone        |bool                 |requiresBroadWorksCallWaitingTone        |
|requires_mwi_subscription                     |bool                 |requiresMWISubscription                  |
|use_history_info_header_on_access_side        |bool                 |useHistoryInfoHeaderOnAccessSide         |
|advice_of_charge_capable                      |bool                 |adviceOfChargeCapable                    |
|reset_event                                   |str                  |resetEvent *Optional*                    |
|support_call_center_mime_type                 |bool                 |supportCallCenterMIMEType                |
|trunk_mode                                    |str                  |trunkMode                                |
|add_p_called_party_id                         |bool                 |addPCalledPartyId                        |
|support_identity_in_update_and_re_invite      |bool                 |supportIdentityInUpdateAndReInvite       |
|unscreened_presentation_identity_policy       |str                  |unscreenedPresentationIdentityPolicy     |
|enhanced_for_ics                              |bool                 |enhancedForICS                           |
|support_emergency_disconnect_control          |bool                 |supportEmergencyDisconnectControl        |
|device_type_configuration_option              |str                  |deviceTypeConfigurationOption            |
|support_rfc3398                               |bool                 |supportRFC3398                           |
|static_line_ordering                          |bool                 |staticLineOrdering                       |
|support_client_session_info                   |bool                 |supportClientSessionInfo                 |
|support_call_info_conference_subscription_uri |bool                 |supportCallInfoConferenceSubscriptionURI |
|support_remote_party_info                     |bool                 |supportRemotePartyInfo                   |
|support_visual_device_management              |bool                 |supportVisualDeviceManagement            |
|bypass_media_treatment                        |bool                 |bypassMediaTreatment                     |
|supports3_g4_g_continuity                     |bool                 |supports3G4GContinuity                   |
|publishes_own_presence                        |bool                 |publishesOwnPresence                     |
|support_cause_parameter                       |bool                 |supportCauseParameter                    |
|location_network                              |str                  |locationNetwork                          |
|reseller_id                                   |str                  |resellerId *Optional*                    |
</div>


## `SystemSIPDeviceTypeAddRequest22V10`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`. When the optional
element resellerId is specified, the device type created is at reseller level.  Device
type name should be unique through out the system including all the reseller level
device types.  The following elements are only used in the XS data mode and ignored in
the AS data mode: enhancedForICS, use value "false" in AS data mode
supports3G4GContinuity, use value "false" in AS data mode publishesOwnPresence, use
value "false" in AS data mode locationNetwork, use value "Fixed" in AS data mode
allowTerminationBasedOnICSI, use value "false" in AS data mode roamingMode, use value
"None" in AS data mode The following elements are only used in AS data mode and
ignored in the XS data mode: supportClientSessionInfo, use value "false" in XS data
mode supportCallInfoConferenceSubscriptionURI, use value "false" in XS data mode
supportRemotePartyInfo, use value "false" in XS data mode
supportVisualDeviceManagementRedirectLink, use value "false" in XS data mode
bypassMediaTreatment, use value "false" in XS data mode supportCauseParameter, use
value "false" in XS data mode resellerId supportVisualDeviceManagementAPI, use value
"false" in XS data mode deviceCategory verstatInPAIHeader, use value "false" in XS
data mode verstatInFromHeader, use value "false" in XS data mode The following values
for element profile are only used in AS data mode and an error is returned in the XS
data mode: SignalingAddressType=Non-intelligent Device Addressing
SignalingAddressType=Intelligent Device Addressing The following logic applies to
these elements: macInCert macInNonRequestURI The two elements are mutually exclusive.
When both are set to true, the command fails.  Replaced by:
`SystemSIPDeviceTypeAddRequest23V7()`.

**Attributes:**

|Name                                           |Type                 |Description                                 |
|-----------------------------------------------|---------------------|--------------------------------------------|
|device_type                                    |str                  |deviceType                                  |
|number_of_ports                                |OCI.numberOfPorts    |numberOfPorts                               |
|profile                                        |str                  |profile                                     |
|registration_capable                           |bool                 |registrationCapable                         |
|is_conference_device                           |bool                 |isConferenceDevice                          |
|is_mobility_manager_device                     |bool                 |isMobilityManagerDevice                     |
|is_music_on_hold_device                        |bool                 |isMusicOnHoldDevice                         |
|hold_normalization                             |str                  |holdNormalization                           |
|hold_announcement_method                       |str                  |holdAnnouncementMethod                      |
|is_trusted                                     |bool                 |isTrusted                                   |
|e164_capable                                   |bool                 |E164Capable                                 |
|route_advance                                  |bool                 |routeAdvance                                |
|forwarding_override                            |bool                 |forwardingOverride                          |
|wireless_integration                           |bool                 |wirelessIntegration                         |
|web_based_config_url                           |str                  |webBasedConfigURL *Optional*                |
|is_video_capable                               |bool                 |isVideoCapable                              |
|pbx_integration                                |bool                 |PBXIntegration                              |
|static_registration_capable                    |bool                 |staticRegistrationCapable                   |
|cpe_device_options                             |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                 |
|early_media_support                            |str                  |earlyMediaSupport                           |
|authenticate_refer                             |bool                 |authenticateRefer                           |
|auto_config_soft_client                        |bool                 |autoConfigSoftClient                        |
|authentication_mode                            |str                  |authenticationMode                          |
|requires_broad_works_digit_collection          |bool                 |requiresBroadWorksDigitCollection           |
|requires_broad_works_call_waiting_tone         |bool                 |requiresBroadWorksCallWaitingTone           |
|requires_mwi_subscription                      |bool                 |requiresMWISubscription                     |
|use_history_info_header_on_access_side         |bool                 |useHistoryInfoHeaderOnAccessSide            |
|advice_of_charge_capable                       |bool                 |adviceOfChargeCapable                       |
|reset_event                                    |str                  |resetEvent *Optional*                       |
|reset_string                                   |str                  |resetString *Optional*                      |
|support_call_center_mime_type                  |bool                 |supportCallCenterMIMEType                   |
|trunk_mode                                     |str                  |trunkMode                                   |
|add_p_called_party_id                          |bool                 |addPCalledPartyId                           |
|support_identity_in_update_and_re_invite       |bool                 |supportIdentityInUpdateAndReInvite          |
|unscreened_presentation_identity_policy        |str                  |unscreenedPresentationIdentityPolicy        |
|enhanced_for_ics                               |bool                 |enhancedForICS                              |
|support_emergency_disconnect_control           |bool                 |supportEmergencyDisconnectControl           |
|device_type_configuration_option               |str                  |deviceTypeConfigurationOption               |
|support_rfc3398                                |bool                 |supportRFC3398                              |
|static_line_ordering                           |bool                 |staticLineOrdering                          |
|support_client_session_info                    |bool                 |supportClientSessionInfo                    |
|support_call_info_conference_subscription_uri  |bool                 |supportCallInfoConferenceSubscriptionURI    |
|support_remote_party_info                      |bool                 |supportRemotePartyInfo                      |
|support_visual_device_management_redirect_link |bool                 |supportVisualDeviceManagementRedirectLink   |
|bypass_media_treatment                         |bool                 |bypassMediaTreatment                        |
|supports3_g4_g_continuity                      |bool                 |supports3G4GContinuity                      |
|publishes_own_presence                         |bool                 |publishesOwnPresence                        |
|support_cause_parameter                        |bool                 |supportCauseParameter                       |
|location_network                               |str                  |locationNetwork                             |
|reseller_id                                    |str                  |resellerId *Optional*                       |
|allow_termination_based_on_icsi                |bool                 |allowTerminationBasedOnICSI                 |
|roaming_mode                                   |str                  |roamingMode                                 |
|support_visual_device_management_api           |bool                 |supportVisualDeviceManagementAPI *Optional* |
|device_category                                |str                  |deviceCategory *Optional*                   |
|verstat_in_pai_header                          |bool                 |verstatInPAIHeader *Optional*               |
|verstat_in_from_header                         |bool                 |verstatInFromHeader *Optional*              |
</div>


## `SystemSIPDeviceTypeAddRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`. When the optional
element resellerId is specified, the device type created is at reseller level.  Device
type name should be unique through out the system including all the reseller level
device types.  The following elements are only used in the XS data mode and ignored in
the AS data mode: enhancedForICS supports3G4GContinuity publishesOwnPresence, use
value "false" in AS data mode locationNetwork, use value "Fixed" in AS data mode
allowTerminationBasedOnICSI, use value "false" in AS data mode roamingMode, use value
"None" in AS data mode The following elements are only used in AS data mode and
ignored in the XS data mode: supportRFC3398, use value "false" in XS data mode
supportClientSessionInfo, use value "false" in XS data mode
supportCallInfoConferenceSubscriptionURI, use value "false" in XS data mode
supportRemotePartyInfo, use value "false" in XS data mode bypassMediaTreatment, use
value "false" in XS data mode supportCauseParameter, use value "false" in XS data mode
resellerId The following values for element profile are only used in AS data mode and
an error is returned in the XS data mode: Non-intelligent Device Addressing
Intelligent Device Addressing The following logic applies to these elements: macInCert
macInNonRequestURI The two elements are mutually exclusive.  When both are set to
true, the command fails.  Deprecated by `SystemSIPDeviceTypeAddRequest22V3()`

**Attributes:**

|Name                                          |Type                 |Description                              |
|----------------------------------------------|---------------------|-----------------------------------------|
|device_type                                   |str                  |deviceType                               |
|number_of_ports                               |OCI.numberOfPorts    |numberOfPorts                            |
|profile                                       |str                  |profile                                  |
|registration_capable                          |bool                 |registrationCapable                      |
|is_conference_device                          |bool                 |isConferenceDevice                       |
|is_mobility_manager_device                    |bool                 |isMobilityManagerDevice                  |
|is_music_on_hold_device                       |bool                 |isMusicOnHoldDevice                      |
|hold_normalization                            |str                  |holdNormalization                        |
|hold_announcement_method                      |str                  |holdAnnouncementMethod                   |
|is_trusted                                    |bool                 |isTrusted                                |
|e164_capable                                  |bool                 |E164Capable                              |
|route_advance                                 |bool                 |routeAdvance                             |
|forwarding_override                           |bool                 |forwardingOverride                       |
|wireless_integration                          |bool                 |wirelessIntegration                      |
|web_based_config_url                          |str                  |webBasedConfigURL *Optional*             |
|is_video_capable                              |bool                 |isVideoCapable                           |
|pbx_integration                               |bool                 |PBXIntegration                           |
|static_registration_capable                   |bool                 |staticRegistrationCapable                |
|cpe_device_options                            |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*              |
|early_media_support                           |str                  |earlyMediaSupport                        |
|authenticate_refer                            |bool                 |authenticateRefer                        |
|auto_config_soft_client                       |bool                 |autoConfigSoftClient                     |
|authentication_mode                           |str                  |authenticationMode                       |
|requires_broad_works_digit_collection         |bool                 |requiresBroadWorksDigitCollection        |
|requires_broad_works_call_waiting_tone        |bool                 |requiresBroadWorksCallWaitingTone        |
|requires_mwi_subscription                     |bool                 |requiresMWISubscription                  |
|use_history_info_header_on_access_side        |bool                 |useHistoryInfoHeaderOnAccessSide         |
|advice_of_charge_capable                      |bool                 |adviceOfChargeCapable                    |
|reset_event                                   |str                  |resetEvent *Optional*                    |
|support_call_center_mime_type                 |bool                 |supportCallCenterMIMEType                |
|trunk_mode                                    |str                  |trunkMode                                |
|add_p_called_party_id                         |bool                 |addPCalledPartyId                        |
|support_identity_in_update_and_re_invite      |bool                 |supportIdentityInUpdateAndReInvite       |
|unscreened_presentation_identity_policy       |str                  |unscreenedPresentationIdentityPolicy     |
|enhanced_for_ics                              |bool                 |enhancedForICS                           |
|support_emergency_disconnect_control          |bool                 |supportEmergencyDisconnectControl        |
|device_type_configuration_option              |str                  |deviceTypeConfigurationOption            |
|support_rfc3398                               |bool                 |supportRFC3398                           |
|static_line_ordering                          |bool                 |staticLineOrdering                       |
|support_client_session_info                   |bool                 |supportClientSessionInfo                 |
|support_call_info_conference_subscription_uri |bool                 |supportCallInfoConferenceSubscriptionURI |
|support_remote_party_info                     |bool                 |supportRemotePartyInfo                   |
|support_visual_device_management              |bool                 |supportVisualDeviceManagement            |
|bypass_media_treatment                        |bool                 |bypassMediaTreatment                     |
|supports3_g4_g_continuity                     |bool                 |supports3G4GContinuity                   |
|publishes_own_presence                        |bool                 |publishesOwnPresence                     |
|support_cause_parameter                       |bool                 |supportCauseParameter                    |
|location_network                              |str                  |locationNetwork                          |
|allow_termination_based_on_icsi               |bool                 |allowTerminationBasedOnICSI              |
|roaming_mode                                  |str                  |roamingMode                              |
|reseller_id                                   |str                  |resellerId *Optional*                    |
</div>


## `SystemSIPDeviceTypeAddRequest22V3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`. When the optional
element resellerId is specified, the device type created is at reseller level.  Device
type name should be unique through out the system including all the reseller level
device types.  The following elements are only used in the XS data mode and ignored in
the AS data mode: enhancedForICS, use value "false" in AS data mode
supports3G4GContinuity, use value "false" in AS data mode publishesOwnPresence, use
value "false" in AS data mode locationNetwork, use value "Fixed" in AS data mode
allowTerminationBasedOnICSI, use value "false" in AS data mode roamingMode, use value
"None" in AS data mode The following elements are only used in AS data mode and
ignored in the XS data mode: supportClientSessionInfo, use value "false" in XS data
mode supportCallInfoConferenceSubscriptionURI, use value "false" in XS data mode
supportRemotePartyInfo, use value "false" in XS data mode
supportVisualDeviceManagement, use value "false" in XS data mode bypassMediaTreatment,
use value "false" in XS data mode supportCauseParameter, use value "false" in XS data
mode resellerId The following values for element profile are only used in AS data mode
and an error is returned in the XS data mode: SignalingAddressType=Non-intelligent
Device Addressing SignalingAddressType=Intelligent Device Addressing The following
logic applies to these elements: macInCert macInNonRequestURI The two elements are
mutually exclusive.  When both are set to true, the command fails.

**Attributes:**

|Name                                          |Type                 |Description                              |
|----------------------------------------------|---------------------|-----------------------------------------|
|device_type                                   |str                  |deviceType                               |
|number_of_ports                               |OCI.numberOfPorts    |numberOfPorts                            |
|profile                                       |str                  |profile                                  |
|registration_capable                          |bool                 |registrationCapable                      |
|is_conference_device                          |bool                 |isConferenceDevice                       |
|is_mobility_manager_device                    |bool                 |isMobilityManagerDevice                  |
|is_music_on_hold_device                       |bool                 |isMusicOnHoldDevice                      |
|hold_normalization                            |str                  |holdNormalization                        |
|hold_announcement_method                      |str                  |holdAnnouncementMethod                   |
|is_trusted                                    |bool                 |isTrusted                                |
|e164_capable                                  |bool                 |E164Capable                              |
|route_advance                                 |bool                 |routeAdvance                             |
|forwarding_override                           |bool                 |forwardingOverride                       |
|wireless_integration                          |bool                 |wirelessIntegration                      |
|web_based_config_url                          |str                  |webBasedConfigURL *Optional*             |
|is_video_capable                              |bool                 |isVideoCapable                           |
|pbx_integration                               |bool                 |PBXIntegration                           |
|static_registration_capable                   |bool                 |staticRegistrationCapable                |
|cpe_device_options                            |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*              |
|early_media_support                           |str                  |earlyMediaSupport                        |
|authenticate_refer                            |bool                 |authenticateRefer                        |
|auto_config_soft_client                       |bool                 |autoConfigSoftClient                     |
|authentication_mode                           |str                  |authenticationMode                       |
|requires_broad_works_digit_collection         |bool                 |requiresBroadWorksDigitCollection        |
|requires_broad_works_call_waiting_tone        |bool                 |requiresBroadWorksCallWaitingTone        |
|requires_mwi_subscription                     |bool                 |requiresMWISubscription                  |
|use_history_info_header_on_access_side        |bool                 |useHistoryInfoHeaderOnAccessSide         |
|advice_of_charge_capable                      |bool                 |adviceOfChargeCapable                    |
|reset_event                                   |str                  |resetEvent *Optional*                    |
|support_call_center_mime_type                 |bool                 |supportCallCenterMIMEType                |
|trunk_mode                                    |str                  |trunkMode                                |
|add_p_called_party_id                         |bool                 |addPCalledPartyId                        |
|support_identity_in_update_and_re_invite      |bool                 |supportIdentityInUpdateAndReInvite       |
|unscreened_presentation_identity_policy       |str                  |unscreenedPresentationIdentityPolicy     |
|enhanced_for_ics                              |bool                 |enhancedForICS                           |
|support_emergency_disconnect_control          |bool                 |supportEmergencyDisconnectControl        |
|device_type_configuration_option              |str                  |deviceTypeConfigurationOption            |
|support_rfc3398                               |bool                 |supportRFC3398                           |
|static_line_ordering                          |bool                 |staticLineOrdering                       |
|support_client_session_info                   |bool                 |supportClientSessionInfo                 |
|support_call_info_conference_subscription_uri |bool                 |supportCallInfoConferenceSubscriptionURI |
|support_remote_party_info                     |bool                 |supportRemotePartyInfo                   |
|support_visual_device_management              |bool                 |supportVisualDeviceManagement            |
|bypass_media_treatment                        |bool                 |bypassMediaTreatment                     |
|supports3_g4_g_continuity                     |bool                 |supports3G4GContinuity                   |
|publishes_own_presence                        |bool                 |publishesOwnPresence                     |
|support_cause_parameter                       |bool                 |supportCauseParameter                    |
|location_network                              |str                  |locationNetwork                          |
|reseller_id                                   |str                  |resellerId *Optional*                    |
|allow_termination_based_on_icsi               |bool                 |allowTerminationBasedOnICSI              |
|roaming_mode                                  |str                  |roamingMode                              |
</div>


## `SystemSIPDeviceTypeAddRequest22V4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`. When the optional
element resellerId is specified, the device type created is at reseller level.  Device
type name should be unique through out the system including all the reseller level
device types.  The following elements are only used in the XS data mode and ignored in
the AS data mode: enhancedForICS, use value "false" in AS data mode
supports3G4GContinuity, use value "false" in AS data mode publishesOwnPresence, use
value "false" in AS data mode locationNetwork, use value "Fixed" in AS data mode
allowTerminationBasedOnICSI, use value "false" in AS data mode roamingMode, use value
"None" in AS data mode The following elements are only used in AS data mode and
ignored in the XS data mode: supportClientSessionInfo, use value "false" in XS data
mode supportCallInfoConferenceSubscriptionURI, use value "false" in XS data mode
supportRemotePartyInfo, use value "false" in XS data mode
supportVisualDeviceManagement, use value "false" in XS data mode bypassMediaTreatment,
use value "false" in XS data mode supportCauseParameter, use value "false" in XS data
mode resellerId The following values for element profile are only used in AS data mode
and an error is returned in the XS data mode: SignalingAddressType=Non-intelligent
Device Addressing SignalingAddressType=Intelligent Device Addressing The following
logic applies to these elements: macInCert macInNonRequestURI The two elements are
mutually exclusive.  When both are set to true, the command fails.

Replaced By: `SystemSIPDeviceTypeAddRequest23()`

**Attributes:**

|Name                                          |Type                 |Description                              |
|----------------------------------------------|---------------------|-----------------------------------------|
|device_type                                   |str                  |deviceType                               |
|number_of_ports                               |OCI.numberOfPorts    |numberOfPorts                            |
|profile                                       |str                  |profile                                  |
|registration_capable                          |bool                 |registrationCapable                      |
|is_conference_device                          |bool                 |isConferenceDevice                       |
|is_mobility_manager_device                    |bool                 |isMobilityManagerDevice                  |
|is_music_on_hold_device                       |bool                 |isMusicOnHoldDevice                      |
|hold_normalization                            |str                  |holdNormalization                        |
|hold_announcement_method                      |str                  |holdAnnouncementMethod                   |
|is_trusted                                    |bool                 |isTrusted                                |
|e164_capable                                  |bool                 |E164Capable                              |
|route_advance                                 |bool                 |routeAdvance                             |
|forwarding_override                           |bool                 |forwardingOverride                       |
|wireless_integration                          |bool                 |wirelessIntegration                      |
|web_based_config_url                          |str                  |webBasedConfigURL *Optional*             |
|is_video_capable                              |bool                 |isVideoCapable                           |
|pbx_integration                               |bool                 |PBXIntegration                           |
|static_registration_capable                   |bool                 |staticRegistrationCapable                |
|cpe_device_options                            |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*              |
|early_media_support                           |str                  |earlyMediaSupport                        |
|authenticate_refer                            |bool                 |authenticateRefer                        |
|auto_config_soft_client                       |bool                 |autoConfigSoftClient                     |
|authentication_mode                           |str                  |authenticationMode                       |
|requires_broad_works_digit_collection         |bool                 |requiresBroadWorksDigitCollection        |
|requires_broad_works_call_waiting_tone        |bool                 |requiresBroadWorksCallWaitingTone        |
|requires_mwi_subscription                     |bool                 |requiresMWISubscription                  |
|use_history_info_header_on_access_side        |bool                 |useHistoryInfoHeaderOnAccessSide         |
|advice_of_charge_capable                      |bool                 |adviceOfChargeCapable                    |
|reset_event                                   |str                  |resetEvent *Optional*                    |
|support_call_center_mime_type                 |bool                 |supportCallCenterMIMEType                |
|trunk_mode                                    |str                  |trunkMode                                |
|add_p_called_party_id                         |bool                 |addPCalledPartyId                        |
|support_identity_in_update_and_re_invite      |bool                 |supportIdentityInUpdateAndReInvite       |
|unscreened_presentation_identity_policy       |str                  |unscreenedPresentationIdentityPolicy     |
|enhanced_for_ics                              |bool                 |enhancedForICS                           |
|support_emergency_disconnect_control          |bool                 |supportEmergencyDisconnectControl        |
|device_type_configuration_option              |str                  |deviceTypeConfigurationOption            |
|support_rfc3398                               |bool                 |supportRFC3398                           |
|static_line_ordering                          |bool                 |staticLineOrdering                       |
|support_client_session_info                   |bool                 |supportClientSessionInfo                 |
|support_call_info_conference_subscription_uri |bool                 |supportCallInfoConferenceSubscriptionURI |
|support_remote_party_info                     |bool                 |supportRemotePartyInfo                   |
|support_visual_device_management              |bool                 |supportVisualDeviceManagement            |
|bypass_media_treatment                        |bool                 |bypassMediaTreatment                     |
|supports3_g4_g_continuity                     |bool                 |supports3G4GContinuity                   |
|publishes_own_presence                        |bool                 |publishesOwnPresence                     |
|support_cause_parameter                       |bool                 |supportCauseParameter                    |
|location_network                              |str                  |locationNetwork                          |
|reseller_id                                   |str                  |resellerId *Optional*                    |
|allow_termination_based_on_icsi               |bool                 |allowTerminationBasedOnICSI              |
|roaming_mode                                  |str                  |roamingMode                              |
</div>


## `SystemSIPDeviceTypeAddRequest22V5`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`. When the optional
element resellerId is specified, the device type created is at reseller level.  Device
type name should be unique through out the system including all the reseller level
device types.  The following elements are only used in the XS data mode and ignored in
the AS data mode: enhancedForICS, use value "false" in AS data mode
supports3G4GContinuity, use value "false" in AS data mode publishesOwnPresence, use
value "false" in AS data mode locationNetwork, use value "Fixed" in AS data mode
allowTerminationBasedOnICSI, use value "false" in AS data mode roamingMode, use value
"None" in AS data mode The following elements are only used in AS data mode and
ignored in the XS data mode: supportClientSessionInfo, use value "false" in XS data
mode supportCallInfoConferenceSubscriptionURI, use value "false" in XS data mode
supportRemotePartyInfo, use value "false" in XS data mode
supportVisualDeviceManagement, use value "false" in XS data mode bypassMediaTreatment,
use value "false" in XS data mode supportCauseParameter, use value "false" in XS data
mode resellerId The following values for element profile are only used in AS data mode
and an error is returned in the XS data mode: SignalingAddressType=Non-intelligent
Device Addressing SignalingAddressType=Intelligent Device Addressing The following
logic applies to these elements: macInCert macInNonRequestURI The two elements are
mutually exclusive.  When both are set to true, the command fails.  Deprecated by:
`SystemSIPDeviceTypeAddRequest23V2()`

**Attributes:**

|Name                                          |Type                 |Description                              |
|----------------------------------------------|---------------------|-----------------------------------------|
|device_type                                   |str                  |deviceType                               |
|number_of_ports                               |OCI.numberOfPorts    |numberOfPorts                            |
|profile                                       |str                  |profile                                  |
|registration_capable                          |bool                 |registrationCapable                      |
|is_conference_device                          |bool                 |isConferenceDevice                       |
|is_mobility_manager_device                    |bool                 |isMobilityManagerDevice                  |
|is_music_on_hold_device                       |bool                 |isMusicOnHoldDevice                      |
|hold_normalization                            |str                  |holdNormalization                        |
|hold_announcement_method                      |str                  |holdAnnouncementMethod                   |
|is_trusted                                    |bool                 |isTrusted                                |
|e164_capable                                  |bool                 |E164Capable                              |
|route_advance                                 |bool                 |routeAdvance                             |
|forwarding_override                           |bool                 |forwardingOverride                       |
|wireless_integration                          |bool                 |wirelessIntegration                      |
|web_based_config_url                          |str                  |webBasedConfigURL *Optional*             |
|is_video_capable                              |bool                 |isVideoCapable                           |
|pbx_integration                               |bool                 |PBXIntegration                           |
|static_registration_capable                   |bool                 |staticRegistrationCapable                |
|cpe_device_options                            |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*              |
|early_media_support                           |str                  |earlyMediaSupport                        |
|authenticate_refer                            |bool                 |authenticateRefer                        |
|auto_config_soft_client                       |bool                 |autoConfigSoftClient                     |
|authentication_mode                           |str                  |authenticationMode                       |
|requires_broad_works_digit_collection         |bool                 |requiresBroadWorksDigitCollection        |
|requires_broad_works_call_waiting_tone        |bool                 |requiresBroadWorksCallWaitingTone        |
|requires_mwi_subscription                     |bool                 |requiresMWISubscription                  |
|use_history_info_header_on_access_side        |bool                 |useHistoryInfoHeaderOnAccessSide         |
|advice_of_charge_capable                      |bool                 |adviceOfChargeCapable                    |
|reset_event                                   |str                  |resetEvent *Optional*                    |
|support_call_center_mime_type                 |bool                 |supportCallCenterMIMEType                |
|trunk_mode                                    |str                  |trunkMode                                |
|add_p_called_party_id                         |bool                 |addPCalledPartyId                        |
|support_identity_in_update_and_re_invite      |bool                 |supportIdentityInUpdateAndReInvite       |
|unscreened_presentation_identity_policy       |str                  |unscreenedPresentationIdentityPolicy     |
|enhanced_for_ics                              |bool                 |enhancedForICS                           |
|support_emergency_disconnect_control          |bool                 |supportEmergencyDisconnectControl        |
|device_type_configuration_option              |str                  |deviceTypeConfigurationOption            |
|support_rfc3398                               |bool                 |supportRFC3398                           |
|static_line_ordering                          |bool                 |staticLineOrdering                       |
|support_client_session_info                   |bool                 |supportClientSessionInfo                 |
|support_call_info_conference_subscription_uri |bool                 |supportCallInfoConferenceSubscriptionURI |
|support_remote_party_info                     |bool                 |supportRemotePartyInfo                   |
|support_visual_device_management              |bool                 |supportVisualDeviceManagement            |
|bypass_media_treatment                        |bool                 |bypassMediaTreatment                     |
|supports3_g4_g_continuity                     |bool                 |supports3G4GContinuity                   |
|publishes_own_presence                        |bool                 |publishesOwnPresence                     |
|support_cause_parameter                       |bool                 |supportCauseParameter                    |
|location_network                              |str                  |locationNetwork                          |
|reseller_id                                   |str                  |resellerId *Optional*                    |
|allow_termination_based_on_icsi               |bool                 |allowTerminationBasedOnICSI              |
|roaming_mode                                  |str                  |roamingMode                              |
</div>


## `SystemSIPDeviceTypeAddRequest22V6`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`. When the optional
element resellerId is specified, the device type created is at reseller level.  Device
type name should be unique through out the system including all the reseller level
device types.  The following elements are only used in the XS data mode and ignored in
the AS data mode: enhancedForICS, use value "false" in AS data mode
supports3G4GContinuity, use value "false" in AS data mode publishesOwnPresence, use
value "false" in AS data mode locationNetwork, use value "Fixed" in AS data mode
allowTerminationBasedOnICSI, use value "false" in AS data mode roamingMode, use value
"None" in AS data mode The following elements are only used in AS data mode and
ignored in the XS data mode: supportClientSessionInfo, use value "false" in XS data
mode supportCallInfoConferenceSubscriptionURI, use value "false" in XS data mode
supportRemotePartyInfo, use value "false" in XS data mode
supportVisualDeviceManagementRedirectLink, use value "false" in XS data mode
bypassMediaTreatment, use value "false" in XS data mode supportCauseParameter, use
value "false" in XS data mode resellerId supportVisualDeviceManagementAPI, use value
"false" in XS data mode deviceCategory The following values for element profile are
only used in AS data mode and an error is returned in the XS data mode:
SignalingAddressType=Non-intelligent Device Addressing
SignalingAddressType=Intelligent Device Addressing The following logic applies to
these elements: macInCert macInNonRequestURI The two elements are mutually exclusive.
When both are set to true, the command fails.  Deprecated by:
`SystemSIPDeviceTypeAddRequest23V3()` in AS data mode

**Attributes:**

|Name                                           |Type                 |Description                                 |
|-----------------------------------------------|---------------------|--------------------------------------------|
|device_type                                    |str                  |deviceType                                  |
|number_of_ports                                |OCI.numberOfPorts    |numberOfPorts                               |
|profile                                        |str                  |profile                                     |
|registration_capable                           |bool                 |registrationCapable                         |
|is_conference_device                           |bool                 |isConferenceDevice                          |
|is_mobility_manager_device                     |bool                 |isMobilityManagerDevice                     |
|is_music_on_hold_device                        |bool                 |isMusicOnHoldDevice                         |
|hold_normalization                             |str                  |holdNormalization                           |
|hold_announcement_method                       |str                  |holdAnnouncementMethod                      |
|is_trusted                                     |bool                 |isTrusted                                   |
|e164_capable                                   |bool                 |E164Capable                                 |
|route_advance                                  |bool                 |routeAdvance                                |
|forwarding_override                            |bool                 |forwardingOverride                          |
|wireless_integration                           |bool                 |wirelessIntegration                         |
|web_based_config_url                           |str                  |webBasedConfigURL *Optional*                |
|is_video_capable                               |bool                 |isVideoCapable                              |
|pbx_integration                                |bool                 |PBXIntegration                              |
|static_registration_capable                    |bool                 |staticRegistrationCapable                   |
|cpe_device_options                             |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                 |
|early_media_support                            |str                  |earlyMediaSupport                           |
|authenticate_refer                             |bool                 |authenticateRefer                           |
|auto_config_soft_client                        |bool                 |autoConfigSoftClient                        |
|authentication_mode                            |str                  |authenticationMode                          |
|requires_broad_works_digit_collection          |bool                 |requiresBroadWorksDigitCollection           |
|requires_broad_works_call_waiting_tone         |bool                 |requiresBroadWorksCallWaitingTone           |
|requires_mwi_subscription                      |bool                 |requiresMWISubscription                     |
|use_history_info_header_on_access_side         |bool                 |useHistoryInfoHeaderOnAccessSide            |
|advice_of_charge_capable                       |bool                 |adviceOfChargeCapable                       |
|reset_event                                    |str                  |resetEvent *Optional*                       |
|support_call_center_mime_type                  |bool                 |supportCallCenterMIMEType                   |
|trunk_mode                                     |str                  |trunkMode                                   |
|add_p_called_party_id                          |bool                 |addPCalledPartyId                           |
|support_identity_in_update_and_re_invite       |bool                 |supportIdentityInUpdateAndReInvite          |
|unscreened_presentation_identity_policy        |str                  |unscreenedPresentationIdentityPolicy        |
|enhanced_for_ics                               |bool                 |enhancedForICS                              |
|support_emergency_disconnect_control           |bool                 |supportEmergencyDisconnectControl           |
|device_type_configuration_option               |str                  |deviceTypeConfigurationOption               |
|support_rfc3398                                |bool                 |supportRFC3398                              |
|static_line_ordering                           |bool                 |staticLineOrdering                          |
|support_client_session_info                    |bool                 |supportClientSessionInfo                    |
|support_call_info_conference_subscription_uri  |bool                 |supportCallInfoConferenceSubscriptionURI    |
|support_remote_party_info                      |bool                 |supportRemotePartyInfo                      |
|support_visual_device_management_redirect_link |bool                 |supportVisualDeviceManagementRedirectLink   |
|bypass_media_treatment                         |bool                 |bypassMediaTreatment                        |
|supports3_g4_g_continuity                      |bool                 |supports3G4GContinuity                      |
|publishes_own_presence                         |bool                 |publishesOwnPresence                        |
|support_cause_parameter                        |bool                 |supportCauseParameter                       |
|location_network                               |str                  |locationNetwork                             |
|reseller_id                                    |str                  |resellerId *Optional*                       |
|allow_termination_based_on_icsi                |bool                 |allowTerminationBasedOnICSI                 |
|roaming_mode                                   |str                  |roamingMode                                 |
|support_visual_device_management_api           |bool                 |supportVisualDeviceManagementAPI *Optional* |
|device_category                                |str                  |deviceCategory *Optional*                   |
</div>


## `SystemSIPDeviceTypeAddRequest22V7`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`. When the optional
element resellerId is specified, the device type created is at reseller level.  Device
type name should be unique through out the system including all the reseller level
device types.  The following elements are only used in the XS data mode and ignored in
the AS data mode: enhancedForICS, use value "false" in AS data mode
supports3G4GContinuity, use value "false" in AS data mode publishesOwnPresence, use
value "false" in AS data mode locationNetwork, use value "Fixed" in AS data mode
allowTerminationBasedOnICSI, use value "false" in AS data mode roamingMode, use value
"None" in AS data mode The following elements are only used in AS data mode and
ignored in the XS data mode: supportClientSessionInfo, use value "false" in XS data
mode supportCallInfoConferenceSubscriptionURI, use value "false" in XS data mode
supportRemotePartyInfo, use value "false" in XS data mode
supportVisualDeviceManagementRedirectLink, use value "false" in XS data mode
bypassMediaTreatment, use value "false" in XS data mode supportCauseParameter, use
value "false" in XS data mode resellerId supportVisualDeviceManagementAPI, use value
"false" in XS data mode deviceCategory The following values for element profile are
only used in AS data mode and an error is returned in the XS data mode:
SignalingAddressType=Non-intelligent Device Addressing
SignalingAddressType=Intelligent Device Addressing The following logic applies to
these elements: macInCert macInNonRequestURI The two elements are mutually exclusive.
When both are set to true, the command fails.

Replaced By: `SystemSIPDeviceTypeAddRequest23V4()`

**Attributes:**

|Name                                           |Type                 |Description                                 |
|-----------------------------------------------|---------------------|--------------------------------------------|
|device_type                                    |str                  |deviceType                                  |
|number_of_ports                                |OCI.numberOfPorts    |numberOfPorts                               |
|profile                                        |str                  |profile                                     |
|registration_capable                           |bool                 |registrationCapable                         |
|is_conference_device                           |bool                 |isConferenceDevice                          |
|is_mobility_manager_device                     |bool                 |isMobilityManagerDevice                     |
|is_music_on_hold_device                        |bool                 |isMusicOnHoldDevice                         |
|hold_normalization                             |str                  |holdNormalization                           |
|hold_announcement_method                       |str                  |holdAnnouncementMethod                      |
|is_trusted                                     |bool                 |isTrusted                                   |
|e164_capable                                   |bool                 |E164Capable                                 |
|route_advance                                  |bool                 |routeAdvance                                |
|forwarding_override                            |bool                 |forwardingOverride                          |
|wireless_integration                           |bool                 |wirelessIntegration                         |
|web_based_config_url                           |str                  |webBasedConfigURL *Optional*                |
|is_video_capable                               |bool                 |isVideoCapable                              |
|pbx_integration                                |bool                 |PBXIntegration                              |
|static_registration_capable                    |bool                 |staticRegistrationCapable                   |
|cpe_device_options                             |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                 |
|early_media_support                            |str                  |earlyMediaSupport                           |
|authenticate_refer                             |bool                 |authenticateRefer                           |
|auto_config_soft_client                        |bool                 |autoConfigSoftClient                        |
|authentication_mode                            |str                  |authenticationMode                          |
|requires_broad_works_digit_collection          |bool                 |requiresBroadWorksDigitCollection           |
|requires_broad_works_call_waiting_tone         |bool                 |requiresBroadWorksCallWaitingTone           |
|requires_mwi_subscription                      |bool                 |requiresMWISubscription                     |
|use_history_info_header_on_access_side         |bool                 |useHistoryInfoHeaderOnAccessSide            |
|advice_of_charge_capable                       |bool                 |adviceOfChargeCapable                       |
|reset_event                                    |str                  |resetEvent *Optional*                       |
|support_call_center_mime_type                  |bool                 |supportCallCenterMIMEType                   |
|trunk_mode                                     |str                  |trunkMode                                   |
|add_p_called_party_id                          |bool                 |addPCalledPartyId                           |
|support_identity_in_update_and_re_invite       |bool                 |supportIdentityInUpdateAndReInvite          |
|unscreened_presentation_identity_policy        |str                  |unscreenedPresentationIdentityPolicy        |
|enhanced_for_ics                               |bool                 |enhancedForICS                              |
|support_emergency_disconnect_control           |bool                 |supportEmergencyDisconnectControl           |
|device_type_configuration_option               |str                  |deviceTypeConfigurationOption               |
|support_rfc3398                                |bool                 |supportRFC3398                              |
|static_line_ordering                           |bool                 |staticLineOrdering                          |
|support_client_session_info                    |bool                 |supportClientSessionInfo                    |
|support_call_info_conference_subscription_uri  |bool                 |supportCallInfoConferenceSubscriptionURI    |
|support_remote_party_info                      |bool                 |supportRemotePartyInfo                      |
|support_visual_device_management_redirect_link |bool                 |supportVisualDeviceManagementRedirectLink   |
|bypass_media_treatment                         |bool                 |bypassMediaTreatment                        |
|supports3_g4_g_continuity                      |bool                 |supports3G4GContinuity                      |
|publishes_own_presence                         |bool                 |publishesOwnPresence                        |
|support_cause_parameter                        |bool                 |supportCauseParameter                       |
|location_network                               |str                  |locationNetwork                             |
|reseller_id                                    |str                  |resellerId *Optional*                       |
|allow_termination_based_on_icsi                |bool                 |allowTerminationBasedOnICSI                 |
|roaming_mode                                   |str                  |roamingMode                                 |
|support_visual_device_management_api           |bool                 |supportVisualDeviceManagementAPI *Optional* |
|device_category                                |str                  |deviceCategory *Optional*                   |
</div>


## `SystemSIPDeviceTypeAddRequest22V8`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`. When the optional
element resellerId is specified, the device type created is at reseller level.  Device
type name should be unique through out the system including all the reseller level
device types.  The following elements are only used in the XS data mode and ignored in
the AS data mode: enhancedForICS, use value "false" in AS data mode
supports3G4GContinuity, use value "false" in AS data mode publishesOwnPresence, use
value "false" in AS data mode locationNetwork, use value "Fixed" in AS data mode
allowTerminationBasedOnICSI, use value "false" in AS data mode roamingMode, use value
"None" in AS data mode The following elements are only used in AS data mode and
ignored in the XS data mode: supportClientSessionInfo, use value "false" in XS data
mode supportCallInfoConferenceSubscriptionURI, use value "false" in XS data mode
supportRemotePartyInfo, use value "false" in XS data mode
supportVisualDeviceManagementRedirectLink, use value "false" in XS data mode
bypassMediaTreatment, use value "false" in XS data mode supportCauseParameter, use
value "false" in XS data mode resellerId supportVisualDeviceManagementAPI, use value
"false" in XS data mode deviceCategory verstatInPAIHeader, use value "false" in XS
data mode verstatInFromHeader, use value "false" in XS data mode The following values
for element profile are only used in AS data mode and an error is returned in the XS
data mode: SignalingAddressType=Non-intelligent Device Addressing
SignalingAddressType=Intelligent Device Addressing The following logic applies to
these elements: macInCert macInNonRequestURI The two elements are mutually exclusive.
When both are set to true, the command fails.  Replaced by
`SystemSIPDeviceTypeAddRequest23V5()`.

**Attributes:**

|Name                                           |Type                 |Description                                 |
|-----------------------------------------------|---------------------|--------------------------------------------|
|device_type                                    |str                  |deviceType                                  |
|number_of_ports                                |OCI.numberOfPorts    |numberOfPorts                               |
|profile                                        |str                  |profile                                     |
|registration_capable                           |bool                 |registrationCapable                         |
|is_conference_device                           |bool                 |isConferenceDevice                          |
|is_mobility_manager_device                     |bool                 |isMobilityManagerDevice                     |
|is_music_on_hold_device                        |bool                 |isMusicOnHoldDevice                         |
|hold_normalization                             |str                  |holdNormalization                           |
|hold_announcement_method                       |str                  |holdAnnouncementMethod                      |
|is_trusted                                     |bool                 |isTrusted                                   |
|e164_capable                                   |bool                 |E164Capable                                 |
|route_advance                                  |bool                 |routeAdvance                                |
|forwarding_override                            |bool                 |forwardingOverride                          |
|wireless_integration                           |bool                 |wirelessIntegration                         |
|web_based_config_url                           |str                  |webBasedConfigURL *Optional*                |
|is_video_capable                               |bool                 |isVideoCapable                              |
|pbx_integration                                |bool                 |PBXIntegration                              |
|static_registration_capable                    |bool                 |staticRegistrationCapable                   |
|cpe_device_options                             |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                 |
|early_media_support                            |str                  |earlyMediaSupport                           |
|authenticate_refer                             |bool                 |authenticateRefer                           |
|auto_config_soft_client                        |bool                 |autoConfigSoftClient                        |
|authentication_mode                            |str                  |authenticationMode                          |
|requires_broad_works_digit_collection          |bool                 |requiresBroadWorksDigitCollection           |
|requires_broad_works_call_waiting_tone         |bool                 |requiresBroadWorksCallWaitingTone           |
|requires_mwi_subscription                      |bool                 |requiresMWISubscription                     |
|use_history_info_header_on_access_side         |bool                 |useHistoryInfoHeaderOnAccessSide            |
|advice_of_charge_capable                       |bool                 |adviceOfChargeCapable                       |
|reset_event                                    |str                  |resetEvent *Optional*                       |
|support_call_center_mime_type                  |bool                 |supportCallCenterMIMEType                   |
|trunk_mode                                     |str                  |trunkMode                                   |
|add_p_called_party_id                          |bool                 |addPCalledPartyId                           |
|support_identity_in_update_and_re_invite       |bool                 |supportIdentityInUpdateAndReInvite          |
|unscreened_presentation_identity_policy        |str                  |unscreenedPresentationIdentityPolicy        |
|enhanced_for_ics                               |bool                 |enhancedForICS                              |
|support_emergency_disconnect_control           |bool                 |supportEmergencyDisconnectControl           |
|device_type_configuration_option               |str                  |deviceTypeConfigurationOption               |
|support_rfc3398                                |bool                 |supportRFC3398                              |
|static_line_ordering                           |bool                 |staticLineOrdering                          |
|support_client_session_info                    |bool                 |supportClientSessionInfo                    |
|support_call_info_conference_subscription_uri  |bool                 |supportCallInfoConferenceSubscriptionURI    |
|support_remote_party_info                      |bool                 |supportRemotePartyInfo                      |
|support_visual_device_management_redirect_link |bool                 |supportVisualDeviceManagementRedirectLink   |
|bypass_media_treatment                         |bool                 |bypassMediaTreatment                        |
|supports3_g4_g_continuity                      |bool                 |supports3G4GContinuity                      |
|publishes_own_presence                         |bool                 |publishesOwnPresence                        |
|support_cause_parameter                        |bool                 |supportCauseParameter                       |
|location_network                               |str                  |locationNetwork                             |
|reseller_id                                    |str                  |resellerId *Optional*                       |
|allow_termination_based_on_icsi                |bool                 |allowTerminationBasedOnICSI                 |
|roaming_mode                                   |str                  |roamingMode                                 |
|support_visual_device_management_api           |bool                 |supportVisualDeviceManagementAPI *Optional* |
|device_category                                |str                  |deviceCategory *Optional*                   |
|verstat_in_pai_header                          |bool                 |verstatInPAIHeader *Optional*               |
|verstat_in_from_header                         |bool                 |verstatInFromHeader *Optional*              |
</div>


## `SystemSIPDeviceTypeAddRequest22V9`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`. When the optional
element resellerId is specified, the device type created is at reseller level.  Device
type name should be unique through out the system including all the reseller level
device types.  The following elements are only used in the XS data mode and ignored in
the AS data mode: enhancedForICS, use value "false" in AS data mode
supports3G4GContinuity, use value "false" in AS data mode publishesOwnPresence, use
value "false" in AS data mode locationNetwork, use value "Fixed" in AS data mode
allowTerminationBasedOnICSI, use value "false" in AS data mode roamingMode, use value
"None" in AS data mode The following elements are only used in AS data mode and
ignored in the XS data mode: supportClientSessionInfo, use value "false" in XS data
mode supportCallInfoConferenceSubscriptionURI, use value "false" in XS data mode
supportRemotePartyInfo, use value "false" in XS data mode
supportVisualDeviceManagementRedirectLink, use value "false" in XS data mode
bypassMediaTreatment, use value "false" in XS data mode supportCauseParameter, use
value "false" in XS data mode resellerId supportVisualDeviceManagementAPI, use value
"false" in XS data mode deviceCategory verstatInPAIHeader, use value "false" in XS
data mode verstatInFromHeader, use value "false" in XS data mode The following values
for element profile are only used in AS data mode and an error is returned in the XS
data mode: SignalingAddressType=Non-intelligent Device Addressing
SignalingAddressType=Intelligent Device Addressing The following logic applies to
these elements: macInCert macInNonRequestURI The two elements are mutually exclusive.
When both are set to true, the command fails.  Replaced by
`SystemSIPDeviceTypeAddRequest23V6()`.

**Attributes:**

|Name                                           |Type                 |Description                                 |
|-----------------------------------------------|---------------------|--------------------------------------------|
|device_type                                    |str                  |deviceType                                  |
|number_of_ports                                |OCI.numberOfPorts    |numberOfPorts                               |
|profile                                        |str                  |profile                                     |
|registration_capable                           |bool                 |registrationCapable                         |
|is_conference_device                           |bool                 |isConferenceDevice                          |
|is_mobility_manager_device                     |bool                 |isMobilityManagerDevice                     |
|is_music_on_hold_device                        |bool                 |isMusicOnHoldDevice                         |
|hold_normalization                             |str                  |holdNormalization                           |
|hold_announcement_method                       |str                  |holdAnnouncementMethod                      |
|is_trusted                                     |bool                 |isTrusted                                   |
|e164_capable                                   |bool                 |E164Capable                                 |
|route_advance                                  |bool                 |routeAdvance                                |
|forwarding_override                            |bool                 |forwardingOverride                          |
|wireless_integration                           |bool                 |wirelessIntegration                         |
|web_based_config_url                           |str                  |webBasedConfigURL *Optional*                |
|is_video_capable                               |bool                 |isVideoCapable                              |
|pbx_integration                                |bool                 |PBXIntegration                              |
|static_registration_capable                    |bool                 |staticRegistrationCapable                   |
|cpe_device_options                             |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                 |
|early_media_support                            |str                  |earlyMediaSupport                           |
|authenticate_refer                             |bool                 |authenticateRefer                           |
|auto_config_soft_client                        |bool                 |autoConfigSoftClient                        |
|authentication_mode                            |str                  |authenticationMode                          |
|requires_broad_works_digit_collection          |bool                 |requiresBroadWorksDigitCollection           |
|requires_broad_works_call_waiting_tone         |bool                 |requiresBroadWorksCallWaitingTone           |
|requires_mwi_subscription                      |bool                 |requiresMWISubscription                     |
|use_history_info_header_on_access_side         |bool                 |useHistoryInfoHeaderOnAccessSide            |
|advice_of_charge_capable                       |bool                 |adviceOfChargeCapable                       |
|reset_event                                    |str                  |resetEvent *Optional*                       |
|support_call_center_mime_type                  |bool                 |supportCallCenterMIMEType                   |
|trunk_mode                                     |str                  |trunkMode                                   |
|add_p_called_party_id                          |bool                 |addPCalledPartyId                           |
|support_identity_in_update_and_re_invite       |bool                 |supportIdentityInUpdateAndReInvite          |
|unscreened_presentation_identity_policy        |str                  |unscreenedPresentationIdentityPolicy        |
|enhanced_for_ics                               |bool                 |enhancedForICS                              |
|support_emergency_disconnect_control           |bool                 |supportEmergencyDisconnectControl           |
|device_type_configuration_option               |str                  |deviceTypeConfigurationOption               |
|support_rfc3398                                |bool                 |supportRFC3398                              |
|static_line_ordering                           |bool                 |staticLineOrdering                          |
|support_client_session_info                    |bool                 |supportClientSessionInfo                    |
|support_call_info_conference_subscription_uri  |bool                 |supportCallInfoConferenceSubscriptionURI    |
|support_remote_party_info                      |bool                 |supportRemotePartyInfo                      |
|support_visual_device_management_redirect_link |bool                 |supportVisualDeviceManagementRedirectLink   |
|bypass_media_treatment                         |bool                 |bypassMediaTreatment                        |
|supports3_g4_g_continuity                      |bool                 |supports3G4GContinuity                      |
|publishes_own_presence                         |bool                 |publishesOwnPresence                        |
|support_cause_parameter                        |bool                 |supportCauseParameter                       |
|location_network                               |str                  |locationNetwork                             |
|reseller_id                                    |str                  |resellerId *Optional*                       |
|allow_termination_based_on_icsi                |bool                 |allowTerminationBasedOnICSI                 |
|roaming_mode                                   |str                  |roamingMode                                 |
|support_visual_device_management_api           |bool                 |supportVisualDeviceManagementAPI *Optional* |
|device_category                                |str                  |deviceCategory *Optional*                   |
|verstat_in_pai_header                          |bool                 |verstatInPAIHeader *Optional*               |
|verstat_in_from_header                         |bool                 |verstatInFromHeader *Optional*              |
</div>


## `SystemSIPDeviceTypeAddRequest23`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`. When the optional
element resellerId is specified, the device type created is at reseller level.  Device
type name should be unique through out the system including all the reseller level
device types.  The following elements are only used in the XS data mode and ignored in
the AS data mode: enhancedForICS, use value "false" in AS data mode
supports3G4GContinuity, use value "false" in AS data mode publishesOwnPresence, use
value "false" in AS data mode locationNetwork, use value "Fixed" in AS data mode
allowTerminationBasedOnICSI, use value "false" in AS data mode roamingMode, use value
"None" in AS data mode The following elements are only used in AS data mode and
ignored in the XS data mode: supportClientSessionInfo, use value "false" in XS data
mode supportCallInfoConferenceSubscriptionURI, use value "false" in XS data mode
supportRemotePartyInfo, use value "false" in XS data mode
supportVisualDeviceManagement, use value "false" in XS data mode bypassMediaTreatment,
use value "false" in XS data mode supportCauseParameter, use value "false" in XS data
mode supportCallingPartyCategoryInOutboundFromHeader, use value "true" in XS data mode
resellerId The following values for element profile are only used in AS data mode and
an error is returned in the XS data mode: SignalingAddressType=Non-intelligent Device
Addressing SignalingAddressType=Intelligent Device Addressing The following logic
applies to these elements: macInCert macInNonRequestURI The two elements are mutually
exclusive.  When both are set to true, the command fails.  Deprecated by:
`SystemSIPDeviceTypeAddRequest23V2()`

**Attributes:**

|Name                                                   |Type                 |Description                                     |
|-------------------------------------------------------|---------------------|------------------------------------------------|
|device_type                                            |str                  |deviceType                                      |
|number_of_ports                                        |OCI.numberOfPorts    |numberOfPorts                                   |
|profile                                                |str                  |profile                                         |
|registration_capable                                   |bool                 |registrationCapable                             |
|is_conference_device                                   |bool                 |isConferenceDevice                              |
|is_mobility_manager_device                             |bool                 |isMobilityManagerDevice                         |
|is_music_on_hold_device                                |bool                 |isMusicOnHoldDevice                             |
|hold_normalization                                     |str                  |holdNormalization                               |
|hold_announcement_method                               |str                  |holdAnnouncementMethod                          |
|is_trusted                                             |bool                 |isTrusted                                       |
|e164_capable                                           |bool                 |E164Capable                                     |
|route_advance                                          |bool                 |routeAdvance                                    |
|forwarding_override                                    |bool                 |forwardingOverride                              |
|wireless_integration                                   |bool                 |wirelessIntegration                             |
|web_based_config_url                                   |str                  |webBasedConfigURL *Optional*                    |
|is_video_capable                                       |bool                 |isVideoCapable                                  |
|pbx_integration                                        |bool                 |PBXIntegration                                  |
|static_registration_capable                            |bool                 |staticRegistrationCapable                       |
|cpe_device_options                                     |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                     |
|early_media_support                                    |str                  |earlyMediaSupport                               |
|authenticate_refer                                     |bool                 |authenticateRefer                               |
|auto_config_soft_client                                |bool                 |autoConfigSoftClient                            |
|authentication_mode                                    |str                  |authenticationMode                              |
|requires_broad_works_digit_collection                  |bool                 |requiresBroadWorksDigitCollection               |
|requires_broad_works_call_waiting_tone                 |bool                 |requiresBroadWorksCallWaitingTone               |
|requires_mwi_subscription                              |bool                 |requiresMWISubscription                         |
|use_history_info_header_on_access_side                 |bool                 |useHistoryInfoHeaderOnAccessSide                |
|advice_of_charge_capable                               |bool                 |adviceOfChargeCapable                           |
|reset_event                                            |str                  |resetEvent *Optional*                           |
|support_call_center_mime_type                          |bool                 |supportCallCenterMIMEType                       |
|trunk_mode                                             |str                  |trunkMode                                       |
|add_p_called_party_id                                  |bool                 |addPCalledPartyId                               |
|support_identity_in_update_and_re_invite               |bool                 |supportIdentityInUpdateAndReInvite              |
|unscreened_presentation_identity_policy                |str                  |unscreenedPresentationIdentityPolicy            |
|enhanced_for_ics                                       |bool                 |enhancedForICS                                  |
|support_emergency_disconnect_control                   |bool                 |supportEmergencyDisconnectControl               |
|device_type_configuration_option                       |str                  |deviceTypeConfigurationOption                   |
|support_rfc3398                                        |bool                 |supportRFC3398                                  |
|static_line_ordering                                   |bool                 |staticLineOrdering                              |
|support_client_session_info                            |bool                 |supportClientSessionInfo                        |
|support_call_info_conference_subscription_uri          |bool                 |supportCallInfoConferenceSubscriptionURI        |
|support_remote_party_info                              |bool                 |supportRemotePartyInfo                          |
|support_visual_device_management                       |bool                 |supportVisualDeviceManagement                   |
|bypass_media_treatment                                 |bool                 |bypassMediaTreatment                            |
|supports3_g4_g_continuity                              |bool                 |supports3G4GContinuity                          |
|publishes_own_presence                                 |bool                 |publishesOwnPresence                            |
|support_cause_parameter                                |bool                 |supportCauseParameter                           |
|location_network                                       |str                  |locationNetwork                                 |
|reseller_id                                            |str                  |resellerId *Optional*                           |
|allow_termination_based_on_icsi                        |bool                 |allowTerminationBasedOnICSI                     |
|roaming_mode                                           |str                  |roamingMode                                     |
|support_calling_party_category_in_outbound_from_header |bool                 |supportCallingPartyCategoryInOutboundFromHeader |
</div>


## `SystemSIPDeviceTypeAddRequest23V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`. When the optional
element resellerId is specified, the device type created is at reseller level.  Device
type name should be unique through out the system including all the reseller level
device types.  The following elements are only used in the XS data mode and ignored in
the AS data mode: enhancedForICS, use value "false" in AS data mode
supports3G4GContinuity, use value "false" in AS data mode publishesOwnPresence, use
value "false" in AS data mode locationNetwork, use value "Fixed" in AS data mode
allowTerminationBasedOnICSI, use value "false" in AS data mode roamingMode, use value
"None" in AS data mode The following elements are only used in AS data mode and
ignored in the XS data mode: supportClientSessionInfo, use value "false" in XS data
mode supportCallInfoConferenceSubscriptionURI, use value "false" in XS data mode
supportRemotePartyInfo, use value "false" in XS data mode
supportVisualDeviceManagement, use value "false" in XS data mode bypassMediaTreatment,
use value "false" in XS data mode supportCauseParameter, use value "false" in XS data
mode supportCallingPartyCategoryInOutboundFromHeader, use value "true" in XS data mode
resellerId The following values for element profile are only used in AS data mode and
an error is returned in the XS data mode: SignalingAddressType=Non-intelligent Device
Addressing SignalingAddressType=Intelligent Device Addressing The following logic
applies to these elements: macInCert macInNonRequestURI The two elements are mutually
exclusive.  When both are set to true, the command fails.

**Attributes:**

|Name                                                   |Type                 |Description                                     |
|-------------------------------------------------------|---------------------|------------------------------------------------|
|device_type                                            |str                  |deviceType                                      |
|number_of_ports                                        |OCI.numberOfPorts    |numberOfPorts                                   |
|profile                                                |str                  |profile                                         |
|registration_capable                                   |bool                 |registrationCapable                             |
|is_conference_device                                   |bool                 |isConferenceDevice                              |
|is_mobility_manager_device                             |bool                 |isMobilityManagerDevice                         |
|is_music_on_hold_device                                |bool                 |isMusicOnHoldDevice                             |
|hold_normalization                                     |str                  |holdNormalization                               |
|hold_announcement_method                               |str                  |holdAnnouncementMethod                          |
|is_trusted                                             |bool                 |isTrusted                                       |
|e164_capable                                           |bool                 |E164Capable                                     |
|route_advance                                          |bool                 |routeAdvance                                    |
|forwarding_override                                    |bool                 |forwardingOverride                              |
|wireless_integration                                   |bool                 |wirelessIntegration                             |
|web_based_config_url                                   |str                  |webBasedConfigURL *Optional*                    |
|is_video_capable                                       |bool                 |isVideoCapable                                  |
|pbx_integration                                        |bool                 |PBXIntegration                                  |
|static_registration_capable                            |bool                 |staticRegistrationCapable                       |
|cpe_device_options                                     |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                     |
|early_media_support                                    |str                  |earlyMediaSupport                               |
|authenticate_refer                                     |bool                 |authenticateRefer                               |
|auto_config_soft_client                                |bool                 |autoConfigSoftClient                            |
|authentication_mode                                    |str                  |authenticationMode                              |
|requires_broad_works_digit_collection                  |bool                 |requiresBroadWorksDigitCollection               |
|requires_broad_works_call_waiting_tone                 |bool                 |requiresBroadWorksCallWaitingTone               |
|requires_mwi_subscription                              |bool                 |requiresMWISubscription                         |
|use_history_info_header_on_access_side                 |bool                 |useHistoryInfoHeaderOnAccessSide                |
|advice_of_charge_capable                               |bool                 |adviceOfChargeCapable                           |
|reset_event                                            |str                  |resetEvent *Optional*                           |
|support_call_center_mime_type                          |bool                 |supportCallCenterMIMEType                       |
|trunk_mode                                             |str                  |trunkMode                                       |
|add_p_called_party_id                                  |bool                 |addPCalledPartyId                               |
|support_identity_in_update_and_re_invite               |bool                 |supportIdentityInUpdateAndReInvite              |
|unscreened_presentation_identity_policy                |str                  |unscreenedPresentationIdentityPolicy            |
|enhanced_for_ics                                       |bool                 |enhancedForICS                                  |
|support_emergency_disconnect_control                   |bool                 |supportEmergencyDisconnectControl               |
|device_type_configuration_option                       |str                  |deviceTypeConfigurationOption                   |
|support_rfc3398                                        |bool                 |supportRFC3398                                  |
|static_line_ordering                                   |bool                 |staticLineOrdering                              |
|support_client_session_info                            |bool                 |supportClientSessionInfo                        |
|support_call_info_conference_subscription_uri          |bool                 |supportCallInfoConferenceSubscriptionURI        |
|support_remote_party_info                              |bool                 |supportRemotePartyInfo                          |
|support_visual_device_management                       |bool                 |supportVisualDeviceManagement                   |
|bypass_media_treatment                                 |bool                 |bypassMediaTreatment                            |
|supports3_g4_g_continuity                              |bool                 |supports3G4GContinuity                          |
|publishes_own_presence                                 |bool                 |publishesOwnPresence                            |
|support_cause_parameter                                |bool                 |supportCauseParameter                           |
|location_network                                       |str                  |locationNetwork                                 |
|reseller_id                                            |str                  |resellerId *Optional*                           |
|allow_termination_based_on_icsi                        |bool                 |allowTerminationBasedOnICSI                     |
|roaming_mode                                           |str                  |roamingMode                                     |
|support_calling_party_category_in_outbound_from_header |bool                 |supportCallingPartyCategoryInOutboundFromHeader |
</div>


## `SystemSIPDeviceTypeAddRequest23V3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`. When the optional
element resellerId is specified, the device type created is at reseller level.  Device
type name should be unique through out the system including all the reseller level
device types.  The following elements are only used in the XS data mode and ignored in
the AS data mode: enhancedForICS, use value "false" in AS data mode
supports3G4GContinuity, use value "false" in AS data mode publishesOwnPresence, use
value "false" in AS data mode locationNetwork, use value "Fixed" in AS data mode
allowTerminationBasedOnICSI, use value "false" in AS data mode roamingMode, use value
"None" in AS data mode The following elements are only used in AS data mode and
ignored in the XS data mode: supportClientSessionInfo, use value "false" in XS data
mode supportCallInfoConferenceSubscriptionURI, use value "false" in XS data mode
supportRemotePartyInfo, use value "false" in XS data mode
supportVisualDeviceManagementRedirectLink, use value "false" in XS data mode
bypassMediaTreatment, use value "false" in XS data mode supportCauseParameter, use
value "false" in XS data mode supportCallingPartyCategoryInOutboundFromHeader, use
value "true" in XS data mode resellerId supportVisualDeviceManagementAPI, use value
"false" in XS data mode deviceCategory The following values for element profile are
only used in AS data mode and an error is returned in the XS data mode:
SignalingAddressType=Non-intelligent Device Addressing
SignalingAddressType=Intelligent Device Addressing The following logic applies to
these elements: macInCert macInNonRequestURI The two elements are mutually exclusive.
When both are set to true, the command fails.

Replaced By: `SystemSIPDeviceTypeAddRequest23V4()`

**Attributes:**

|Name                                                   |Type                 |Description                                     |
|-------------------------------------------------------|---------------------|------------------------------------------------|
|device_type                                            |str                  |deviceType                                      |
|number_of_ports                                        |OCI.numberOfPorts    |numberOfPorts                                   |
|profile                                                |str                  |profile                                         |
|registration_capable                                   |bool                 |registrationCapable                             |
|is_conference_device                                   |bool                 |isConferenceDevice                              |
|is_mobility_manager_device                             |bool                 |isMobilityManagerDevice                         |
|is_music_on_hold_device                                |bool                 |isMusicOnHoldDevice                             |
|hold_normalization                                     |str                  |holdNormalization                               |
|hold_announcement_method                               |str                  |holdAnnouncementMethod                          |
|is_trusted                                             |bool                 |isTrusted                                       |
|e164_capable                                           |bool                 |E164Capable                                     |
|route_advance                                          |bool                 |routeAdvance                                    |
|forwarding_override                                    |bool                 |forwardingOverride                              |
|wireless_integration                                   |bool                 |wirelessIntegration                             |
|web_based_config_url                                   |str                  |webBasedConfigURL *Optional*                    |
|is_video_capable                                       |bool                 |isVideoCapable                                  |
|pbx_integration                                        |bool                 |PBXIntegration                                  |
|static_registration_capable                            |bool                 |staticRegistrationCapable                       |
|cpe_device_options                                     |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                     |
|early_media_support                                    |str                  |earlyMediaSupport                               |
|authenticate_refer                                     |bool                 |authenticateRefer                               |
|auto_config_soft_client                                |bool                 |autoConfigSoftClient                            |
|authentication_mode                                    |str                  |authenticationMode                              |
|requires_broad_works_digit_collection                  |bool                 |requiresBroadWorksDigitCollection               |
|requires_broad_works_call_waiting_tone                 |bool                 |requiresBroadWorksCallWaitingTone               |
|requires_mwi_subscription                              |bool                 |requiresMWISubscription                         |
|use_history_info_header_on_access_side                 |bool                 |useHistoryInfoHeaderOnAccessSide                |
|advice_of_charge_capable                               |bool                 |adviceOfChargeCapable                           |
|reset_event                                            |str                  |resetEvent *Optional*                           |
|support_call_center_mime_type                          |bool                 |supportCallCenterMIMEType                       |
|trunk_mode                                             |str                  |trunkMode                                       |
|add_p_called_party_id                                  |bool                 |addPCalledPartyId                               |
|support_identity_in_update_and_re_invite               |bool                 |supportIdentityInUpdateAndReInvite              |
|unscreened_presentation_identity_policy                |str                  |unscreenedPresentationIdentityPolicy            |
|enhanced_for_ics                                       |bool                 |enhancedForICS                                  |
|support_emergency_disconnect_control                   |bool                 |supportEmergencyDisconnectControl               |
|device_type_configuration_option                       |str                  |deviceTypeConfigurationOption                   |
|support_rfc3398                                        |bool                 |supportRFC3398                                  |
|static_line_ordering                                   |bool                 |staticLineOrdering                              |
|support_client_session_info                            |bool                 |supportClientSessionInfo                        |
|support_call_info_conference_subscription_uri          |bool                 |supportCallInfoConferenceSubscriptionURI        |
|support_remote_party_info                              |bool                 |supportRemotePartyInfo                          |
|support_visual_device_management_redirect_link         |bool                 |supportVisualDeviceManagementRedirectLink       |
|bypass_media_treatment                                 |bool                 |bypassMediaTreatment                            |
|supports3_g4_g_continuity                              |bool                 |supports3G4GContinuity                          |
|publishes_own_presence                                 |bool                 |publishesOwnPresence                            |
|support_cause_parameter                                |bool                 |supportCauseParameter                           |
|location_network                                       |str                  |locationNetwork                                 |
|reseller_id                                            |str                  |resellerId *Optional*                           |
|allow_termination_based_on_icsi                        |bool                 |allowTerminationBasedOnICSI                     |
|roaming_mode                                           |str                  |roamingMode                                     |
|support_calling_party_category_in_outbound_from_header |bool                 |supportCallingPartyCategoryInOutboundFromHeader |
|support_visual_device_management_api                   |bool                 |supportVisualDeviceManagementAPI *Optional*     |
|device_category                                        |str                  |deviceCategory *Optional*                       |
</div>


## `SystemSIPDeviceTypeAddRequest23V4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`. When the optional
element resellerId is specified, the device type created is at reseller level.  Device
type name should be unique through out the system including all the reseller level
device types.  The following elements are only used in the XS data mode and ignored in
the AS data mode: enhancedForICS, use value "false" in AS data mode
supports3G4GContinuity, use value "false" in AS data mode publishesOwnPresence, use
value "false" in AS data mode locationNetwork, use value "Fixed" in AS data mode
allowTerminationBasedOnICSI, use value "false" in AS data mode roamingMode, use value
"None" in AS data mode The following elements are only used in AS data mode and
ignored in the XS data mode: supportClientSessionInfo, use value "false" in XS data
mode supportCallInfoConferenceSubscriptionURI, use value "false" in XS data mode
supportRemotePartyInfo, use value "false" in XS data mode
supportVisualDeviceManagementRedirectLink, use value "false" in XS data mode
bypassMediaTreatment, use value "false" in XS data mode supportCauseParameter, use
value "false" in XS data mode supportCallingPartyCategoryInOutboundFromHeader, use
value "true" in XS data mode resellerId supportVisualDeviceManagementAPI, use value
"false" in XS data mode deviceCategory The following values for element profile are
only used in AS data mode and an error is returned in the XS data mode:
SignalingAddressType=Non-intelligent Device Addressing
SignalingAddressType=Intelligent Device Addressing The following logic applies to
these elements: macInCert macInNonRequestURI The two elements are mutually exclusive.
When both are set to true, the command fails.  Replaced by
`SystemSIPDeviceTypeAddRequest23V5()`

**Attributes:**

|Name                                                   |Type                 |Description                                     |
|-------------------------------------------------------|---------------------|------------------------------------------------|
|device_type                                            |str                  |deviceType                                      |
|number_of_ports                                        |OCI.numberOfPorts    |numberOfPorts                                   |
|profile                                                |str                  |profile                                         |
|registration_capable                                   |bool                 |registrationCapable                             |
|is_conference_device                                   |bool                 |isConferenceDevice                              |
|is_mobility_manager_device                             |bool                 |isMobilityManagerDevice                         |
|is_music_on_hold_device                                |bool                 |isMusicOnHoldDevice                             |
|hold_normalization                                     |str                  |holdNormalization                               |
|hold_announcement_method                               |str                  |holdAnnouncementMethod                          |
|is_trusted                                             |bool                 |isTrusted                                       |
|e164_capable                                           |bool                 |E164Capable                                     |
|route_advance                                          |bool                 |routeAdvance                                    |
|forwarding_override                                    |bool                 |forwardingOverride                              |
|wireless_integration                                   |bool                 |wirelessIntegration                             |
|web_based_config_url                                   |str                  |webBasedConfigURL *Optional*                    |
|is_video_capable                                       |bool                 |isVideoCapable                                  |
|pbx_integration                                        |bool                 |PBXIntegration                                  |
|static_registration_capable                            |bool                 |staticRegistrationCapable                       |
|cpe_device_options                                     |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                     |
|early_media_support                                    |str                  |earlyMediaSupport                               |
|authenticate_refer                                     |bool                 |authenticateRefer                               |
|auto_config_soft_client                                |bool                 |autoConfigSoftClient                            |
|authentication_mode                                    |str                  |authenticationMode                              |
|requires_broad_works_digit_collection                  |bool                 |requiresBroadWorksDigitCollection               |
|requires_broad_works_call_waiting_tone                 |bool                 |requiresBroadWorksCallWaitingTone               |
|requires_mwi_subscription                              |bool                 |requiresMWISubscription                         |
|use_history_info_header_on_access_side                 |bool                 |useHistoryInfoHeaderOnAccessSide                |
|advice_of_charge_capable                               |bool                 |adviceOfChargeCapable                           |
|reset_event                                            |str                  |resetEvent *Optional*                           |
|support_call_center_mime_type                          |bool                 |supportCallCenterMIMEType                       |
|trunk_mode                                             |str                  |trunkMode                                       |
|add_p_called_party_id                                  |bool                 |addPCalledPartyId                               |
|support_identity_in_update_and_re_invite               |bool                 |supportIdentityInUpdateAndReInvite              |
|unscreened_presentation_identity_policy                |str                  |unscreenedPresentationIdentityPolicy            |
|enhanced_for_ics                                       |bool                 |enhancedForICS                                  |
|support_emergency_disconnect_control                   |bool                 |supportEmergencyDisconnectControl               |
|device_type_configuration_option                       |str                  |deviceTypeConfigurationOption                   |
|support_rfc3398                                        |bool                 |supportRFC3398                                  |
|static_line_ordering                                   |bool                 |staticLineOrdering                              |
|support_client_session_info                            |bool                 |supportClientSessionInfo                        |
|support_call_info_conference_subscription_uri          |bool                 |supportCallInfoConferenceSubscriptionURI        |
|support_remote_party_info                              |bool                 |supportRemotePartyInfo                          |
|support_visual_device_management_redirect_link         |bool                 |supportVisualDeviceManagementRedirectLink       |
|bypass_media_treatment                                 |bool                 |bypassMediaTreatment                            |
|supports3_g4_g_continuity                              |bool                 |supports3G4GContinuity                          |
|publishes_own_presence                                 |bool                 |publishesOwnPresence                            |
|support_cause_parameter                                |bool                 |supportCauseParameter                           |
|location_network                                       |str                  |locationNetwork                                 |
|reseller_id                                            |str                  |resellerId *Optional*                           |
|allow_termination_based_on_icsi                        |bool                 |allowTerminationBasedOnICSI                     |
|roaming_mode                                           |str                  |roamingMode                                     |
|support_calling_party_category_in_outbound_from_header |bool                 |supportCallingPartyCategoryInOutboundFromHeader |
|support_visual_device_management_api                   |bool                 |supportVisualDeviceManagementAPI *Optional*     |
|device_category                                        |str                  |deviceCategory *Optional*                       |
|add_to_file_server                                     |bool                 |addToFileServer *Optional*                      |
</div>


## `SystemSIPDeviceTypeAddRequest23V5`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`. When the optional
element resellerId is specified, the device type created is at reseller level.  Device
type name should be unique through out the system including all the reseller level
device types.  The following elements are only used in the XS data mode and ignored in
the AS data mode: enhancedForICS, use value "false" in AS data mode
supports3G4GContinuity, use value "false" in AS data mode publishesOwnPresence, use
value "false" in AS data mode locationNetwork, use value "Fixed" in AS data mode
allowTerminationBasedOnICSI, use value "false" in AS data mode roamingMode, use value
"None" in AS data mode The following elements are only used in AS data mode and
ignored in the XS data mode: supportClientSessionInfo, use value "false" in XS data
mode supportCallInfoConferenceSubscriptionURI, use value "false" in XS data mode
supportRemotePartyInfo, use value "false" in XS data mode
supportVisualDeviceManagementRedirectLink, use value "false" in XS data mode
bypassMediaTreatment, use value "false" in XS data mode supportCauseParameter, use
value "false" in XS data mode supportCallingPartyCategoryInOutboundFromHeader, use
value "true" in XS data mode resellerId supportVisualDeviceManagementAPI, use value
"false" in XS data mode deviceCategory verstatInPAIHeader verstatInFromHeader The
following values for element profile are only used in AS data mode and an error is
returned in the XS data mode: SignalingAddressType=Non-intelligent Device Addressing
SignalingAddressType=Intelligent Device Addressing The following logic applies to
these elements: macInCert macInNonRequestURI The two elements are mutually exclusive.
When both are set to true, the command fails.  Replaced by
`SystemSIPDeviceTypeAddRequest23V6()`

**Attributes:**

|Name                                                   |Type                 |Description                                     |
|-------------------------------------------------------|---------------------|------------------------------------------------|
|device_type                                            |str                  |deviceType                                      |
|number_of_ports                                        |OCI.numberOfPorts    |numberOfPorts                                   |
|profile                                                |str                  |profile                                         |
|registration_capable                                   |bool                 |registrationCapable                             |
|is_conference_device                                   |bool                 |isConferenceDevice                              |
|is_mobility_manager_device                             |bool                 |isMobilityManagerDevice                         |
|is_music_on_hold_device                                |bool                 |isMusicOnHoldDevice                             |
|hold_normalization                                     |str                  |holdNormalization                               |
|hold_announcement_method                               |str                  |holdAnnouncementMethod                          |
|is_trusted                                             |bool                 |isTrusted                                       |
|e164_capable                                           |bool                 |E164Capable                                     |
|route_advance                                          |bool                 |routeAdvance                                    |
|forwarding_override                                    |bool                 |forwardingOverride                              |
|wireless_integration                                   |bool                 |wirelessIntegration                             |
|web_based_config_url                                   |str                  |webBasedConfigURL *Optional*                    |
|is_video_capable                                       |bool                 |isVideoCapable                                  |
|pbx_integration                                        |bool                 |PBXIntegration                                  |
|static_registration_capable                            |bool                 |staticRegistrationCapable                       |
|cpe_device_options                                     |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                     |
|early_media_support                                    |str                  |earlyMediaSupport                               |
|authenticate_refer                                     |bool                 |authenticateRefer                               |
|auto_config_soft_client                                |bool                 |autoConfigSoftClient                            |
|authentication_mode                                    |str                  |authenticationMode                              |
|requires_broad_works_digit_collection                  |bool                 |requiresBroadWorksDigitCollection               |
|requires_broad_works_call_waiting_tone                 |bool                 |requiresBroadWorksCallWaitingTone               |
|requires_mwi_subscription                              |bool                 |requiresMWISubscription                         |
|use_history_info_header_on_access_side                 |bool                 |useHistoryInfoHeaderOnAccessSide                |
|advice_of_charge_capable                               |bool                 |adviceOfChargeCapable                           |
|reset_event                                            |str                  |resetEvent *Optional*                           |
|support_call_center_mime_type                          |bool                 |supportCallCenterMIMEType                       |
|trunk_mode                                             |str                  |trunkMode                                       |
|add_p_called_party_id                                  |bool                 |addPCalledPartyId                               |
|support_identity_in_update_and_re_invite               |bool                 |supportIdentityInUpdateAndReInvite              |
|unscreened_presentation_identity_policy                |str                  |unscreenedPresentationIdentityPolicy            |
|enhanced_for_ics                                       |bool                 |enhancedForICS                                  |
|support_emergency_disconnect_control                   |bool                 |supportEmergencyDisconnectControl               |
|device_type_configuration_option                       |str                  |deviceTypeConfigurationOption                   |
|support_rfc3398                                        |bool                 |supportRFC3398                                  |
|static_line_ordering                                   |bool                 |staticLineOrdering                              |
|support_client_session_info                            |bool                 |supportClientSessionInfo                        |
|support_call_info_conference_subscription_uri          |bool                 |supportCallInfoConferenceSubscriptionURI        |
|support_remote_party_info                              |bool                 |supportRemotePartyInfo                          |
|support_visual_device_management_redirect_link         |bool                 |supportVisualDeviceManagementRedirectLink       |
|bypass_media_treatment                                 |bool                 |bypassMediaTreatment                            |
|supports3_g4_g_continuity                              |bool                 |supports3G4GContinuity                          |
|publishes_own_presence                                 |bool                 |publishesOwnPresence                            |
|support_cause_parameter                                |bool                 |supportCauseParameter                           |
|location_network                                       |str                  |locationNetwork                                 |
|reseller_id                                            |str                  |resellerId *Optional*                           |
|allow_termination_based_on_icsi                        |bool                 |allowTerminationBasedOnICSI                     |
|roaming_mode                                           |str                  |roamingMode                                     |
|support_calling_party_category_in_outbound_from_header |bool                 |supportCallingPartyCategoryInOutboundFromHeader |
|support_visual_device_management_api                   |bool                 |supportVisualDeviceManagementAPI *Optional*     |
|device_category                                        |str                  |deviceCategory *Optional*                       |
|add_to_file_server                                     |bool                 |addToFileServer *Optional*                      |
|verstat_in_pai_header                                  |bool                 |verstatInPAIHeader *Optional*                   |
|verstat_in_from_header                                 |bool                 |verstatInFromHeader *Optional*                  |
</div>


## `SystemSIPDeviceTypeAddRequest23V6`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`. When the optional
element resellerId is specified, the device type created is at reseller level.  Device
type name should be unique through out the system including all the reseller level
device types.  The following elements are only used in the XS data mode and ignored in
the AS data mode: enhancedForICS, use value "false" in AS data mode
supports3G4GContinuity, use value "false" in AS data mode publishesOwnPresence, use
value "false" in AS data mode locationNetwork, use value "Fixed" in AS data mode
allowTerminationBasedOnICSI, use value "false" in AS data mode roamingMode, use value
"None" in AS data mode The following elements are only used in AS data mode and
ignored in the XS data mode: supportClientSessionInfo, use value "false" in XS data
mode supportCallInfoConferenceSubscriptionURI, use value "false" in XS data mode
supportRemotePartyInfo, use value "false" in XS data mode
supportVisualDeviceManagementRedirectLink, use value "false" in XS data mode
bypassMediaTreatment, use value "false" in XS data mode supportCauseParameter, use
value "false" in XS data mode supportCallingPartyCategoryInOutboundFromHeader, use
value "true" in XS data mode resellerId supportVisualDeviceManagementAPI, use value
"false" in XS data mode deviceCategory verstatInPAIHeader verstatInFromHeader The
following values for element profile are only used in AS data mode and an error is
returned in the XS data mode: SignalingAddressType=Non-intelligent Device Addressing
SignalingAddressType=Intelligent Device Addressing The following logic applies to
these elements: macInCert macInNonRequestURI The two elements are mutually exclusive.
When both are set to true, the command fails.  Replaced by:
`SystemSIPDeviceTypeAddRequest23V7()` in AS mode.

**Attributes:**

|Name                                                   |Type                 |Description                                     |
|-------------------------------------------------------|---------------------|------------------------------------------------|
|device_type                                            |str                  |deviceType                                      |
|number_of_ports                                        |OCI.numberOfPorts    |numberOfPorts                                   |
|profile                                                |str                  |profile                                         |
|registration_capable                                   |bool                 |registrationCapable                             |
|is_conference_device                                   |bool                 |isConferenceDevice                              |
|is_mobility_manager_device                             |bool                 |isMobilityManagerDevice                         |
|is_music_on_hold_device                                |bool                 |isMusicOnHoldDevice                             |
|hold_normalization                                     |str                  |holdNormalization                               |
|hold_announcement_method                               |str                  |holdAnnouncementMethod                          |
|is_trusted                                             |bool                 |isTrusted                                       |
|e164_capable                                           |bool                 |E164Capable                                     |
|route_advance                                          |bool                 |routeAdvance                                    |
|forwarding_override                                    |bool                 |forwardingOverride                              |
|wireless_integration                                   |bool                 |wirelessIntegration                             |
|web_based_config_url                                   |str                  |webBasedConfigURL *Optional*                    |
|is_video_capable                                       |bool                 |isVideoCapable                                  |
|pbx_integration                                        |bool                 |PBXIntegration                                  |
|static_registration_capable                            |bool                 |staticRegistrationCapable                       |
|cpe_device_options                                     |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                     |
|early_media_support                                    |str                  |earlyMediaSupport                               |
|authenticate_refer                                     |bool                 |authenticateRefer                               |
|auto_config_soft_client                                |bool                 |autoConfigSoftClient                            |
|authentication_mode                                    |str                  |authenticationMode                              |
|requires_broad_works_digit_collection                  |bool                 |requiresBroadWorksDigitCollection               |
|requires_broad_works_call_waiting_tone                 |bool                 |requiresBroadWorksCallWaitingTone               |
|requires_mwi_subscription                              |bool                 |requiresMWISubscription                         |
|use_history_info_header_on_access_side                 |bool                 |useHistoryInfoHeaderOnAccessSide                |
|advice_of_charge_capable                               |bool                 |adviceOfChargeCapable                           |
|reset_event                                            |str                  |resetEvent *Optional*                           |
|support_call_center_mime_type                          |bool                 |supportCallCenterMIMEType                       |
|trunk_mode                                             |str                  |trunkMode                                       |
|add_p_called_party_id                                  |bool                 |addPCalledPartyId                               |
|support_identity_in_update_and_re_invite               |bool                 |supportIdentityInUpdateAndReInvite              |
|unscreened_presentation_identity_policy                |str                  |unscreenedPresentationIdentityPolicy            |
|enhanced_for_ics                                       |bool                 |enhancedForICS                                  |
|support_emergency_disconnect_control                   |bool                 |supportEmergencyDisconnectControl               |
|device_type_configuration_option                       |str                  |deviceTypeConfigurationOption                   |
|support_rfc3398                                        |bool                 |supportRFC3398                                  |
|static_line_ordering                                   |bool                 |staticLineOrdering                              |
|support_client_session_info                            |bool                 |supportClientSessionInfo                        |
|support_call_info_conference_subscription_uri          |bool                 |supportCallInfoConferenceSubscriptionURI        |
|support_remote_party_info                              |bool                 |supportRemotePartyInfo                          |
|support_visual_device_management_redirect_link         |bool                 |supportVisualDeviceManagementRedirectLink       |
|bypass_media_treatment                                 |bool                 |bypassMediaTreatment                            |
|supports3_g4_g_continuity                              |bool                 |supports3G4GContinuity                          |
|publishes_own_presence                                 |bool                 |publishesOwnPresence                            |
|support_cause_parameter                                |bool                 |supportCauseParameter                           |
|location_network                                       |str                  |locationNetwork                                 |
|reseller_id                                            |str                  |resellerId *Optional*                           |
|allow_termination_based_on_icsi                        |bool                 |allowTerminationBasedOnICSI                     |
|roaming_mode                                           |str                  |roamingMode                                     |
|support_calling_party_category_in_outbound_from_header |bool                 |supportCallingPartyCategoryInOutboundFromHeader |
|support_visual_device_management_api                   |bool                 |supportVisualDeviceManagementAPI *Optional*     |
|device_category                                        |str                  |deviceCategory *Optional*                       |
|verstat_in_pai_header                                  |bool                 |verstatInPAIHeader *Optional*                   |
|verstat_in_from_header                                 |bool                 |verstatInFromHeader *Optional*                  |
</div>


## `SystemSIPDeviceTypeAddRequest23V7`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`. When the optional
element resellerId is specified, the device type created is at reseller level.  Device
type name should be unique through out the system including all the reseller level
device types.  The following elements are only used in the XS data mode and ignored in
the AS data mode: enhancedForICS, use value "false" in AS data mode
supports3G4GContinuity, use value "false" in AS data mode publishesOwnPresence, use
value "false" in AS data mode locationNetwork, use value "Fixed" in AS data mode
allowTerminationBasedOnICSI, use value "false" in AS data mode roamingMode, use value
"None" in AS data mode The following elements are only used in AS data mode and
ignored in the XS data mode: supportClientSessionInfo, use value "false" in XS data
mode supportCallInfoConferenceSubscriptionURI, use value "false" in XS data mode
supportRemotePartyInfo, use value "false" in XS data mode
supportVisualDeviceManagementRedirectLink, use value "false" in XS data mode
bypassMediaTreatment, use value "false" in XS data mode supportCauseParameter, use
value "false" in XS data mode resellerId supportVisualDeviceManagementAPI, use value
"false" in XS data mode deviceCategory verstatInPAIHeader, use value "false" in XS
data mode verstatInFromHeader, use value "false" in XS data mode The following values
for element profile are only used in AS data mode and an error is returned in the XS
data mode: SignalingAddressType=Non-intelligent Device Addressing
SignalingAddressType=Intelligent Device Addressing The following logic applies to
these elements: macInCert macInNonRequestURI The two elements are mutually exclusive.
When both are set to true, the command fails.

**Attributes:**

|Name                                                   |Type                 |Description                                     |
|-------------------------------------------------------|---------------------|------------------------------------------------|
|device_type                                            |str                  |deviceType                                      |
|number_of_ports                                        |OCI.numberOfPorts    |numberOfPorts                                   |
|profile                                                |str                  |profile                                         |
|registration_capable                                   |bool                 |registrationCapable                             |
|is_conference_device                                   |bool                 |isConferenceDevice                              |
|is_mobility_manager_device                             |bool                 |isMobilityManagerDevice                         |
|is_music_on_hold_device                                |bool                 |isMusicOnHoldDevice                             |
|hold_normalization                                     |str                  |holdNormalization                               |
|hold_announcement_method                               |str                  |holdAnnouncementMethod                          |
|is_trusted                                             |bool                 |isTrusted                                       |
|e164_capable                                           |bool                 |E164Capable                                     |
|route_advance                                          |bool                 |routeAdvance                                    |
|forwarding_override                                    |bool                 |forwardingOverride                              |
|wireless_integration                                   |bool                 |wirelessIntegration                             |
|web_based_config_url                                   |str                  |webBasedConfigURL *Optional*                    |
|is_video_capable                                       |bool                 |isVideoCapable                                  |
|pbx_integration                                        |bool                 |PBXIntegration                                  |
|static_registration_capable                            |bool                 |staticRegistrationCapable                       |
|cpe_device_options                                     |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                     |
|early_media_support                                    |str                  |earlyMediaSupport                               |
|authenticate_refer                                     |bool                 |authenticateRefer                               |
|auto_config_soft_client                                |bool                 |autoConfigSoftClient                            |
|authentication_mode                                    |str                  |authenticationMode                              |
|requires_broad_works_digit_collection                  |bool                 |requiresBroadWorksDigitCollection               |
|requires_broad_works_call_waiting_tone                 |bool                 |requiresBroadWorksCallWaitingTone               |
|requires_mwi_subscription                              |bool                 |requiresMWISubscription                         |
|use_history_info_header_on_access_side                 |bool                 |useHistoryInfoHeaderOnAccessSide                |
|advice_of_charge_capable                               |bool                 |adviceOfChargeCapable                           |
|reset_event                                            |str                  |resetEvent *Optional*                           |
|reset_string                                           |str                  |resetString *Optional*                          |
|support_call_center_mime_type                          |bool                 |supportCallCenterMIMEType                       |
|trunk_mode                                             |str                  |trunkMode                                       |
|add_p_called_party_id                                  |bool                 |addPCalledPartyId                               |
|support_identity_in_update_and_re_invite               |bool                 |supportIdentityInUpdateAndReInvite              |
|unscreened_presentation_identity_policy                |str                  |unscreenedPresentationIdentityPolicy            |
|enhanced_for_ics                                       |bool                 |enhancedForICS                                  |
|support_emergency_disconnect_control                   |bool                 |supportEmergencyDisconnectControl               |
|device_type_configuration_option                       |str                  |deviceTypeConfigurationOption                   |
|support_rfc3398                                        |bool                 |supportRFC3398                                  |
|static_line_ordering                                   |bool                 |staticLineOrdering                              |
|support_client_session_info                            |bool                 |supportClientSessionInfo                        |
|support_call_info_conference_subscription_uri          |bool                 |supportCallInfoConferenceSubscriptionURI        |
|support_remote_party_info                              |bool                 |supportRemotePartyInfo                          |
|support_visual_device_management_redirect_link         |bool                 |supportVisualDeviceManagementRedirectLink       |
|bypass_media_treatment                                 |bool                 |bypassMediaTreatment                            |
|supports3_g4_g_continuity                              |bool                 |supports3G4GContinuity                          |
|publishes_own_presence                                 |bool                 |publishesOwnPresence                            |
|support_cause_parameter                                |bool                 |supportCauseParameter                           |
|location_network                                       |str                  |locationNetwork                                 |
|reseller_id                                            |str                  |resellerId *Optional*                           |
|allow_termination_based_on_icsi                        |bool                 |allowTerminationBasedOnICSI                     |
|roaming_mode                                           |str                  |roamingMode                                     |
|support_calling_party_category_in_outbound_from_header |bool                 |supportCallingPartyCategoryInOutboundFromHeader |
|support_visual_device_management_api                   |bool                 |supportVisualDeviceManagementAPI *Optional*     |
|device_category                                        |str                  |deviceCategory *Optional*                       |
|add_to_file_server                                     |bool                 |addToFileServer *Optional*                      |
|verstat_in_pai_header                                  |bool                 |verstatInPAIHeader *Optional*                   |
|verstat_in_from_header                                 |bool                 |verstatInFromHeader *Optional*                  |
</div>


## `SystemSIPDeviceTypeModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a sip device type.

The following elements are not changeable: numberOfPorts SignalingAddressType
isConferenceDevice isMusicOnHoldDevice

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                          |Type                 |Description                           |
|------------------------------|---------------------|--------------------------------------|
|device_type                   |str                  |deviceType                            |
|is_obsolete                   |bool                 |isObsolete *Optional*                 |
|registration_capable          |bool                 |registrationCapable *Optional*        |
|authentication_override       |bool                 |authenticationOverride *Optional*     |
|rfc3264_hold                  |bool                 |RFC3264Hold *Optional*                |
|is_trusted                    |bool                 |isTrusted *Optional*                  |
|e164_capable                  |bool                 |E164Capable *Optional*                |
|route_advance                 |bool                 |routeAdvance *Optional*               |
|forwarding_override           |bool                 |forwardingOverride *Optional*         |
|wireless_integration          |bool                 |wirelessIntegration *Optional*        |
|web_based_config_url          |str                  |webBasedConfigURL *Optional*          |
|is_video_capable              |bool                 |isVideoCapable *Optional*             |
|pbx_integration               |bool                 |PBXIntegration *Optional*             |
|use_business_trunking_contact |bool                 |useBusinessTrunkingContact *Optional* |
|static_registration_capable   |bool                 |staticRegistrationCapable *Optional*  |
|cpe_device_options            |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*           |
|early_media_support           |str                  |earlyMediaSupport *Optional*          |
</div>


## `SystemSIPDeviceTypeModifyRequest14sp2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a sip device type.

The following elements are not changeable: numberOfPorts SignalingAddressType
isConferenceDevice isMusicOnHoldDevice isMobilityManagerDevice

The response is either `SuccessResponse()` or `ErrorResponse()`.

Replaced By : `SystemSIPDeviceTypeModifyRequest15()`

**Attributes:**

|Name                                       |Type                 |Description                                     |
|-------------------------------------------|---------------------|------------------------------------------------|
|device_type                                |str                  |deviceType                                      |
|is_obsolete                                |bool                 |isObsolete *Optional*                           |
|registration_capable                       |bool                 |registrationCapable *Optional*                  |
|rfc3264_hold                               |bool                 |RFC3264Hold *Optional*                          |
|is_trusted                                 |bool                 |isTrusted *Optional*                            |
|e164_capable                               |bool                 |E164Capable *Optional*                          |
|route_advance                              |bool                 |routeAdvance *Optional*                         |
|forwarding_override                        |bool                 |forwardingOverride *Optional*                   |
|wireless_integration                       |bool                 |wirelessIntegration *Optional*                  |
|web_based_config_url                       |str                  |webBasedConfigURL *Optional*                    |
|is_video_capable                           |bool                 |isVideoCapable *Optional*                       |
|pbx_integration                            |bool                 |PBXIntegration *Optional*                       |
|use_business_trunking_contact              |bool                 |useBusinessTrunkingContact *Optional*           |
|static_registration_capable                |bool                 |staticRegistrationCapable *Optional*            |
|cpe_device_options                         |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                     |
|early_media_support                        |str                  |earlyMediaSupport *Optional*                    |
|authenticate_refer                         |bool                 |authenticateRefer *Optional*                    |
|auto_config_soft_client                    |bool                 |autoConfigSoftClient *Optional*                 |
|authentication_mode                        |str                  |authenticationMode *Optional*                   |
|tdm_overlay                                |bool                 |tdmOverlay *Optional*                           |
|supports_broad_works_info_for_call_waiting |bool                 |supportsBroadWorksINFOForCallWaiting *Optional* |
</div>


## `SystemSIPDeviceTypeModifyRequest15`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a sip device type.

The following elements are not changeable: numberOfPorts SignalingAddressType
isConferenceDevice isMusicOnHoldDevice isMobilityManagerDevice

The response is either `SuccessResponse()` or `ErrorResponse()`.

Replaced By : `SystemSIPDeviceTypeModifyRequest16()`

**Attributes:**

|Name                                   |Type                 |Description                                  |
|---------------------------------------|---------------------|---------------------------------------------|
|device_type                            |str                  |deviceType                                   |
|is_obsolete                            |bool                 |isObsolete *Optional*                        |
|registration_capable                   |bool                 |registrationCapable *Optional*               |
|rfc3264_hold                           |bool                 |RFC3264Hold *Optional*                       |
|is_trusted                             |bool                 |isTrusted *Optional*                         |
|e164_capable                           |bool                 |E164Capable *Optional*                       |
|route_advance                          |bool                 |routeAdvance *Optional*                      |
|forwarding_override                    |bool                 |forwardingOverride *Optional*                |
|wireless_integration                   |bool                 |wirelessIntegration *Optional*               |
|web_based_config_url                   |str                  |webBasedConfigURL *Optional*                 |
|is_video_capable                       |bool                 |isVideoCapable *Optional*                    |
|pbx_integration                        |bool                 |PBXIntegration *Optional*                    |
|use_business_trunking_contact          |bool                 |useBusinessTrunkingContact *Optional*        |
|static_registration_capable            |bool                 |staticRegistrationCapable *Optional*         |
|cpe_device_options                     |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                  |
|early_media_support                    |str                  |earlyMediaSupport *Optional*                 |
|authenticate_refer                     |bool                 |authenticateRefer *Optional*                 |
|auto_config_soft_client                |bool                 |autoConfigSoftClient *Optional*              |
|authentication_mode                    |str                  |authenticationMode *Optional*                |
|tdm_overlay                            |bool                 |tdmOverlay *Optional*                        |
|requires_broad_works_call_waiting_tone |bool                 |requiresBroadWorksCallWaitingTone *Optional* |
|requires_mwi_subscription              |bool                 |requiresMWISubscription *Optional*           |
|use_history_info_header_on_access_side |bool                 |useHistoryInfoHeaderOnAccessSide *Optional*  |
</div>


## `SystemSIPDeviceTypeModifyRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a sip device type.

The following elements are not changeable: numberOfPorts SignalingAddressType
isConferenceDevice isMusicOnHoldDevice isMobilityManagerDevice

The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by:
`SystemSIPDeviceTypeModifyRequest16sp1()`

**Attributes:**

|Name                                   |Type                 |Description                                  |
|---------------------------------------|---------------------|---------------------------------------------|
|device_type                            |str                  |deviceType                                   |
|is_obsolete                            |bool                 |isObsolete *Optional*                        |
|registration_capable                   |bool                 |registrationCapable *Optional*               |
|rfc3264_hold                           |bool                 |RFC3264Hold *Optional*                       |
|is_trusted                             |bool                 |isTrusted *Optional*                         |
|e164_capable                           |bool                 |E164Capable *Optional*                       |
|route_advance                          |bool                 |routeAdvance *Optional*                      |
|forwarding_override                    |bool                 |forwardingOverride *Optional*                |
|wireless_integration                   |bool                 |wirelessIntegration *Optional*               |
|web_based_config_url                   |str                  |webBasedConfigURL *Optional*                 |
|is_video_capable                       |bool                 |isVideoCapable *Optional*                    |
|pbx_integration                        |bool                 |PBXIntegration *Optional*                    |
|use_business_trunking_contact          |bool                 |useBusinessTrunkingContact *Optional*        |
|static_registration_capable            |bool                 |staticRegistrationCapable *Optional*         |
|cpe_device_options                     |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                  |
|early_media_support                    |str                  |earlyMediaSupport *Optional*                 |
|authenticate_refer                     |bool                 |authenticateRefer *Optional*                 |
|auto_config_soft_client                |bool                 |autoConfigSoftClient *Optional*              |
|authentication_mode                    |str                  |authenticationMode *Optional*                |
|requires_broad_works_digit_collection  |bool                 |requiresBroadWorksDigitCollection *Optional* |
|requires_broad_works_call_waiting_tone |bool                 |requiresBroadWorksCallWaitingTone *Optional* |
|requires_mwi_subscription              |bool                 |requiresMWISubscription *Optional*           |
|use_history_info_header_on_access_side |bool                 |useHistoryInfoHeaderOnAccessSide *Optional*  |
|advice_of_charge_capable               |bool                 |adviceOfChargeCapable *Optional*             |
</div>


## `SystemSIPDeviceTypeModifyRequest16sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a sip device type.

The following elements are not changeable: numberOfPorts SignalingAddressType
isConferenceDevice isMusicOnHoldDevice isMobilityManagerDevice

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                   |Type                 |Description                                  |
|---------------------------------------|---------------------|---------------------------------------------|
|device_type                            |str                  |deviceType                                   |
|is_obsolete                            |bool                 |isObsolete *Optional*                        |
|registration_capable                   |bool                 |registrationCapable *Optional*               |
|rfc3264_hold                           |bool                 |RFC3264Hold *Optional*                       |
|is_trusted                             |bool                 |isTrusted *Optional*                         |
|e164_capable                           |bool                 |E164Capable *Optional*                       |
|route_advance                          |bool                 |routeAdvance *Optional*                      |
|forwarding_override                    |bool                 |forwardingOverride *Optional*                |
|wireless_integration                   |bool                 |wirelessIntegration *Optional*               |
|web_based_config_url                   |str                  |webBasedConfigURL *Optional*                 |
|is_video_capable                       |bool                 |isVideoCapable *Optional*                    |
|pbx_integration                        |bool                 |PBXIntegration *Optional*                    |
|use_business_trunking_contact          |bool                 |useBusinessTrunkingContact *Optional*        |
|static_registration_capable            |bool                 |staticRegistrationCapable *Optional*         |
|cpe_device_options                     |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                  |
|early_media_support                    |str                  |earlyMediaSupport *Optional*                 |
|authenticate_refer                     |bool                 |authenticateRefer *Optional*                 |
|auto_config_soft_client                |bool                 |autoConfigSoftClient *Optional*              |
|authentication_mode                    |str                  |authenticationMode *Optional*                |
|requires_broad_works_digit_collection  |bool                 |requiresBroadWorksDigitCollection *Optional* |
|requires_broad_works_call_waiting_tone |bool                 |requiresBroadWorksCallWaitingTone *Optional* |
|requires_mwi_subscription              |bool                 |requiresMWISubscription *Optional*           |
|use_history_info_header_on_access_side |bool                 |useHistoryInfoHeaderOnAccessSide *Optional*  |
|advice_of_charge_capable               |bool                 |adviceOfChargeCapable *Optional*             |
|reset_event                            |str                  |resetEvent *Optional*                        |
|support_call_center_mime_type          |bool                 |supportCallCenterMIMEType *Optional*         |
</div>


## `SystemSIPDeviceTypeModifyRequest17`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a sip device type.

The following elements are not changeable: numberOfPorts SignalingAddressType
isConferenceDevice isMusicOnHoldDevice isMobilityManagerDevice

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in XS data mode: enable3G4GContinuity Replaced by:
`SystemSIPDeviceTypeModifyRequest19()`

**Attributes:**

|Name                                     |Type                 |Description                                     |
|-----------------------------------------|---------------------|------------------------------------------------|
|device_type                              |str                  |deviceType                                      |
|is_obsolete                              |bool                 |isObsolete *Optional*                           |
|registration_capable                     |bool                 |registrationCapable *Optional*                  |
|rfc3264_hold                             |bool                 |RFC3264Hold *Optional*                          |
|is_trusted                               |bool                 |isTrusted *Optional*                            |
|e164_capable                             |bool                 |E164Capable *Optional*                          |
|route_advance                            |bool                 |routeAdvance *Optional*                         |
|forwarding_override                      |bool                 |forwardingOverride *Optional*                   |
|wireless_integration                     |bool                 |wirelessIntegration *Optional*                  |
|web_based_config_url                     |str                  |webBasedConfigURL *Optional*                    |
|is_video_capable                         |bool                 |isVideoCapable *Optional*                       |
|pbx_integration                          |bool                 |PBXIntegration *Optional*                       |
|static_registration_capable              |bool                 |staticRegistrationCapable *Optional*            |
|cpe_device_options                       |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                     |
|early_media_support                      |str                  |earlyMediaSupport *Optional*                    |
|authenticate_refer                       |bool                 |authenticateRefer *Optional*                    |
|auto_config_soft_client                  |bool                 |autoConfigSoftClient *Optional*                 |
|authentication_mode                      |str                  |authenticationMode *Optional*                   |
|requires_broad_works_digit_collection    |bool                 |requiresBroadWorksDigitCollection *Optional*    |
|requires_broad_works_call_waiting_tone   |bool                 |requiresBroadWorksCallWaitingTone *Optional*    |
|requires_mwi_subscription                |bool                 |requiresMWISubscription *Optional*              |
|use_history_info_header_on_access_side   |bool                 |useHistoryInfoHeaderOnAccessSide *Optional*     |
|advice_of_charge_capable                 |bool                 |adviceOfChargeCapable *Optional*                |
|reset_event                              |str                  |resetEvent *Optional*                           |
|support_call_center_mime_type            |bool                 |supportCallCenterMIMEType *Optional*            |
|trunk_mode                               |str                  |trunkMode *Optional*                            |
|add_p_called_party_id                    |bool                 |addPCalledPartyId *Optional*                    |
|support_identity_in_update_and_re_invite |bool                 |supportIdentityInUpdateAndReInvite *Optional*   |
|unscreened_presentation_identity_policy  |str                  |unscreenedPresentationIdentityPolicy *Optional* |
|enable3_g4_g_continuity                  |bool                 |enable3G4GContinuity *Optional*                 |
|support_emergency_disconnect_control     |bool                 |supportEmergencyDisconnectControl *Optional*    |
</div>


## `SystemSIPDeviceTypeModifyRequest18sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are not changeable: numberOfPorts SignalingAddressType isConferenceDevice
isMusicOnHoldDevice isMobilityManagerDevice deviceTypeConfigurationOption
staticLineOrdering The following elements are only used in XS data mode:
enable3G4GContinuity allowTerminationBasedOnICSI The following elements are only used
in AS data mode: holdAnnouncementMethod supportRFC3398 supportClientSessionInfo
supportCallInfoConferenceSubscriptionURI supportRemotePartyInfo The following element
values are only applicable in AS data mode: holdNormalization=useRfc3264Hold will
raise an error in XS data mode

**Attributes:**

|Name                                          |Type                 |Description                                         |
|----------------------------------------------|---------------------|----------------------------------------------------|
|device_type                                   |str                  |deviceType                                          |
|is_obsolete                                   |bool                 |isObsolete *Optional*                               |
|registration_capable                          |bool                 |registrationCapable *Optional*                      |
|hold_normalization                            |str                  |holdNormalization *Optional*                        |
|hold_announcement_method                      |str                  |holdAnnouncementMethod *Optional*                   |
|is_trusted                                    |bool                 |isTrusted *Optional*                                |
|e164_capable                                  |bool                 |E164Capable *Optional*                              |
|route_advance                                 |bool                 |routeAdvance *Optional*                             |
|forwarding_override                           |bool                 |forwardingOverride *Optional*                       |
|wireless_integration                          |bool                 |wirelessIntegration *Optional*                      |
|web_based_config_url                          |str                  |webBasedConfigURL *Optional*                        |
|is_video_capable                              |bool                 |isVideoCapable *Optional*                           |
|pbx_integration                               |bool                 |PBXIntegration *Optional*                           |
|static_registration_capable                   |bool                 |staticRegistrationCapable *Optional*                |
|cpe_device_options                            |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                         |
|early_media_support                           |str                  |earlyMediaSupport *Optional*                        |
|authenticate_refer                            |bool                 |authenticateRefer *Optional*                        |
|auto_config_soft_client                       |bool                 |autoConfigSoftClient *Optional*                     |
|authentication_mode                           |str                  |authenticationMode *Optional*                       |
|requires_broad_works_digit_collection         |bool                 |requiresBroadWorksDigitCollection *Optional*        |
|requires_broad_works_call_waiting_tone        |bool                 |requiresBroadWorksCallWaitingTone *Optional*        |
|requires_mwi_subscription                     |bool                 |requiresMWISubscription *Optional*                  |
|use_history_info_header_on_access_side        |bool                 |useHistoryInfoHeaderOnAccessSide *Optional*         |
|advice_of_charge_capable                      |bool                 |adviceOfChargeCapable *Optional*                    |
|reset_event                                   |str                  |resetEvent *Optional*                               |
|support_call_center_mime_type                 |bool                 |supportCallCenterMIMEType *Optional*                |
|trunk_mode                                    |str                  |trunkMode *Optional*                                |
|add_p_called_party_id                         |bool                 |addPCalledPartyId *Optional*                        |
|support_identity_in_update_and_re_invite      |bool                 |supportIdentityInUpdateAndReInvite *Optional*       |
|unscreened_presentation_identity_policy       |str                  |unscreenedPresentationIdentityPolicy *Optional*     |
|enable3_g4_g_continuity                       |bool                 |enable3G4GContinuity *Optional*                     |
|support_emergency_disconnect_control          |bool                 |supportEmergencyDisconnectControl *Optional*        |
|support_rfc3398                               |bool                 |supportRFC3398 *Optional*                           |
|support_client_session_info                   |bool                 |supportClientSessionInfo *Optional*                 |
|support_call_info_conference_subscription_uri |bool                 |supportCallInfoConferenceSubscriptionURI *Optional* |
|support_remote_party_info                     |bool                 |supportRemotePartyInfo *Optional*                   |
|support_visual_device_management              |bool                 |supportVisualDeviceManagement *Optional*            |
|bypass_media_treatment                        |bool                 |bypassMediaTreatment *Optional*                     |
|allow_termination_based_on_icsi               |bool                 |allowTerminationBasedOnICSI *Optional*              |
</div>


## `SystemSIPDeviceTypeModifyRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are not changeable: numberOfPorts SignalingAddressType isConferenceDevice
isMusicOnHoldDevice isMobilityManagerDevice deviceTypeConfigurationOption
staticLineOrdering The following elements are only used in AS data mode and ignored in
XS data mode: holdAnnouncementMethod supportRFC3398 supportClientSessionInfo
supportCallInfoConferenceSubscriptionURI supportRemotePartyInfo
supportVisualDeviceManagement bypassMediaTreatment supportCauseParameter The following
elements are only used in XS data mode and ignored in AS mode: enhancedForICS
supports3G4GContinuity publishesOwnPresence locationNetwork roamingMode The following
logic applies to these elements: macInCert macInNonRequestURI The two elements are
mutually exclusive.  When both are set to true, the command fails.  When macInCert is
set to true, macInNonRequestURI will be reset to false.  When macInNonRequestURI is
set to true, macInCert will be reset to false.  Replaced by:
`SystemSIPDeviceTypeModifyRequest22()`

**Attributes:**

|Name                                          |Type                 |Description                                         |
|----------------------------------------------|---------------------|----------------------------------------------------|
|device_type                                   |str                  |deviceType                                          |
|is_obsolete                                   |bool                 |isObsolete *Optional*                               |
|registration_capable                          |bool                 |registrationCapable *Optional*                      |
|hold_normalization                            |str                  |holdNormalization *Optional*                        |
|hold_announcement_method                      |str                  |holdAnnouncementMethod *Optional*                   |
|is_trusted                                    |bool                 |isTrusted *Optional*                                |
|e164_capable                                  |bool                 |E164Capable *Optional*                              |
|route_advance                                 |bool                 |routeAdvance *Optional*                             |
|forwarding_override                           |bool                 |forwardingOverride *Optional*                       |
|wireless_integration                          |bool                 |wirelessIntegration *Optional*                      |
|web_based_config_url                          |str                  |webBasedConfigURL *Optional*                        |
|is_video_capable                              |bool                 |isVideoCapable *Optional*                           |
|pbx_integration                               |bool                 |PBXIntegration *Optional*                           |
|static_registration_capable                   |bool                 |staticRegistrationCapable *Optional*                |
|cpe_device_options                            |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                         |
|early_media_support                           |str                  |earlyMediaSupport *Optional*                        |
|authenticate_refer                            |bool                 |authenticateRefer *Optional*                        |
|auto_config_soft_client                       |bool                 |autoConfigSoftClient *Optional*                     |
|authentication_mode                           |str                  |authenticationMode *Optional*                       |
|requires_broad_works_digit_collection         |bool                 |requiresBroadWorksDigitCollection *Optional*        |
|requires_broad_works_call_waiting_tone        |bool                 |requiresBroadWorksCallWaitingTone *Optional*        |
|requires_mwi_subscription                     |bool                 |requiresMWISubscription *Optional*                  |
|use_history_info_header_on_access_side        |bool                 |useHistoryInfoHeaderOnAccessSide *Optional*         |
|advice_of_charge_capable                      |bool                 |adviceOfChargeCapable *Optional*                    |
|reset_event                                   |str                  |resetEvent *Optional*                               |
|support_call_center_mime_type                 |bool                 |supportCallCenterMIMEType *Optional*                |
|trunk_mode                                    |str                  |trunkMode *Optional*                                |
|add_p_called_party_id                         |bool                 |addPCalledPartyId *Optional*                        |
|support_identity_in_update_and_re_invite      |bool                 |supportIdentityInUpdateAndReInvite *Optional*       |
|unscreened_presentation_identity_policy       |str                  |unscreenedPresentationIdentityPolicy *Optional*     |
|enhanced_for_ics                              |bool                 |enhancedForICS *Optional*                           |
|support_emergency_disconnect_control          |bool                 |supportEmergencyDisconnectControl *Optional*        |
|support_rfc3398                               |bool                 |supportRFC3398 *Optional*                           |
|support_client_session_info                   |bool                 |supportClientSessionInfo *Optional*                 |
|support_call_info_conference_subscription_uri |bool                 |supportCallInfoConferenceSubscriptionURI *Optional* |
|support_remote_party_info                     |bool                 |supportRemotePartyInfo *Optional*                   |
|support_visual_device_management              |bool                 |supportVisualDeviceManagement *Optional*            |
|bypass_media_treatment                        |bool                 |bypassMediaTreatment *Optional*                     |
|supports3_g4_g_continuity                     |bool                 |supports3G4GContinuity *Optional*                   |
|publishes_own_presence                        |bool                 |publishesOwnPresence *Optional*                     |
|support_cause_parameter                       |bool                 |supportCauseParameter *Optional*                    |
|location_network                              |str                  |locationNetwork *Optional*                          |
|roaming_mode                                  |str                  |roamingMode *Optional*                              |
</div>


## `SystemSIPDeviceTypeModifyRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are not changeable: numberOfPorts SignalingAddressType isConferenceDevice
isMusicOnHoldDevice isMobilityManagerDevice deviceTypeConfigurationOption
staticLineOrdering The following elements are only used in AS data mode and ignored in
XS data mode: supportClientSessionInfo supportCallInfoConferenceSubscriptionURI
supportRemotePartyInfo supportVisualDeviceManagement bypassMediaTreatment
supportCauseParameter The following elements are only used in XS data mode and ignored
in AS mode: enhancedForICS supports3G4GContinuity publishesOwnPresence locationNetwork
allowTerminationBasedOnICSI roamingMode The following logic applies to these elements:
macInCert macInNonRequestURI The two elements are mutually exclusive.  When both are
set to true, the command fails.  When macInCert is set to true, macInNonRequestURI
will be reset to false.  When macInNonRequestURI is set to true, macInCert will be
reset to false.

**Attributes:**

|Name                                          |Type                 |Description                                         |
|----------------------------------------------|---------------------|----------------------------------------------------|
|device_type                                   |str                  |deviceType                                          |
|is_obsolete                                   |bool                 |isObsolete *Optional*                               |
|registration_capable                          |bool                 |registrationCapable *Optional*                      |
|hold_normalization                            |str                  |holdNormalization *Optional*                        |
|hold_announcement_method                      |str                  |holdAnnouncementMethod *Optional*                   |
|is_trusted                                    |bool                 |isTrusted *Optional*                                |
|e164_capable                                  |bool                 |E164Capable *Optional*                              |
|route_advance                                 |bool                 |routeAdvance *Optional*                             |
|forwarding_override                           |bool                 |forwardingOverride *Optional*                       |
|wireless_integration                          |bool                 |wirelessIntegration *Optional*                      |
|web_based_config_url                          |str                  |webBasedConfigURL *Optional*                        |
|is_video_capable                              |bool                 |isVideoCapable *Optional*                           |
|pbx_integration                               |bool                 |PBXIntegration *Optional*                           |
|static_registration_capable                   |bool                 |staticRegistrationCapable *Optional*                |
|cpe_device_options                            |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                         |
|early_media_support                           |str                  |earlyMediaSupport *Optional*                        |
|authenticate_refer                            |bool                 |authenticateRefer *Optional*                        |
|auto_config_soft_client                       |bool                 |autoConfigSoftClient *Optional*                     |
|authentication_mode                           |str                  |authenticationMode *Optional*                       |
|requires_broad_works_digit_collection         |bool                 |requiresBroadWorksDigitCollection *Optional*        |
|requires_broad_works_call_waiting_tone        |bool                 |requiresBroadWorksCallWaitingTone *Optional*        |
|requires_mwi_subscription                     |bool                 |requiresMWISubscription *Optional*                  |
|use_history_info_header_on_access_side        |bool                 |useHistoryInfoHeaderOnAccessSide *Optional*         |
|advice_of_charge_capable                      |bool                 |adviceOfChargeCapable *Optional*                    |
|reset_event                                   |str                  |resetEvent *Optional*                               |
|support_call_center_mime_type                 |bool                 |supportCallCenterMIMEType *Optional*                |
|trunk_mode                                    |str                  |trunkMode *Optional*                                |
|add_p_called_party_id                         |bool                 |addPCalledPartyId *Optional*                        |
|support_identity_in_update_and_re_invite      |bool                 |supportIdentityInUpdateAndReInvite *Optional*       |
|unscreened_presentation_identity_policy       |str                  |unscreenedPresentationIdentityPolicy *Optional*     |
|enhanced_for_ics                              |bool                 |enhancedForICS *Optional*                           |
|support_emergency_disconnect_control          |bool                 |supportEmergencyDisconnectControl *Optional*        |
|support_rfc3398                               |bool                 |supportRFC3398 *Optional*                           |
|support_client_session_info                   |bool                 |supportClientSessionInfo *Optional*                 |
|support_call_info_conference_subscription_uri |bool                 |supportCallInfoConferenceSubscriptionURI *Optional* |
|support_remote_party_info                     |bool                 |supportRemotePartyInfo *Optional*                   |
|support_visual_device_management              |bool                 |supportVisualDeviceManagement *Optional*            |
|bypass_media_treatment                        |bool                 |bypassMediaTreatment *Optional*                     |
|supports3_g4_g_continuity                     |bool                 |supports3G4GContinuity *Optional*                   |
|publishes_own_presence                        |bool                 |publishesOwnPresence *Optional*                     |
|support_cause_parameter                       |bool                 |supportCauseParameter *Optional*                    |
|location_network                              |str                  |locationNetwork *Optional*                          |
|allow_termination_based_on_icsi               |bool                 |allowTerminationBasedOnICSI *Optional*              |
|roaming_mode                                  |str                  |roamingMode *Optional*                              |
</div>


## `SystemSIPDeviceTypeModifyRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are not changeable: numberOfPorts SignalingAddressType isConferenceDevice
isMusicOnHoldDevice isMobilityManagerDevice deviceTypeConfigurationOption
staticLineOrdering The following elements are only used in AS data mode and ignored in
XS data mode: supportClientSessionInfo supportCallInfoConferenceSubscriptionURI
supportRemotePartyInfo supportVisualDeviceManagement bypassMediaTreatment
supportCauseParameter supportCallingPartyCategoryInOutboundFromHeader The following
elements are only used in XS data mode and ignored in AS mode: enhancedForICS
supports3G4GContinuity publishesOwnPresence locationNetwork
allowTerminationBasedOnICSI roamingMode The following logic applies to these elements:
macInCert macInNonRequestURI The two elements are mutually exclusive.  When both are
set to true, the command fails.  When macInCert is set to true, macInNonRequestURI
will be reset to false.  When macInNonRequestURI is set to true, macInCert will be
reset to false.  Replaced by: `SystemSIPDeviceTypeModifyRequest22V3()` in AS data
mode.

**Attributes:**

|Name                                                   |Type                 |Description                                                |
|-------------------------------------------------------|---------------------|-----------------------------------------------------------|
|device_type                                            |str                  |deviceType                                                 |
|is_obsolete                                            |bool                 |isObsolete *Optional*                                      |
|registration_capable                                   |bool                 |registrationCapable *Optional*                             |
|hold_normalization                                     |str                  |holdNormalization *Optional*                               |
|hold_announcement_method                               |str                  |holdAnnouncementMethod *Optional*                          |
|is_trusted                                             |bool                 |isTrusted *Optional*                                       |
|e164_capable                                           |bool                 |E164Capable *Optional*                                     |
|route_advance                                          |bool                 |routeAdvance *Optional*                                    |
|forwarding_override                                    |bool                 |forwardingOverride *Optional*                              |
|wireless_integration                                   |bool                 |wirelessIntegration *Optional*                             |
|web_based_config_url                                   |str                  |webBasedConfigURL *Optional*                               |
|is_video_capable                                       |bool                 |isVideoCapable *Optional*                                  |
|pbx_integration                                        |bool                 |PBXIntegration *Optional*                                  |
|static_registration_capable                            |bool                 |staticRegistrationCapable *Optional*                       |
|cpe_device_options                                     |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                                |
|early_media_support                                    |str                  |earlyMediaSupport *Optional*                               |
|authenticate_refer                                     |bool                 |authenticateRefer *Optional*                               |
|auto_config_soft_client                                |bool                 |autoConfigSoftClient *Optional*                            |
|authentication_mode                                    |str                  |authenticationMode *Optional*                              |
|requires_broad_works_digit_collection                  |bool                 |requiresBroadWorksDigitCollection *Optional*               |
|requires_broad_works_call_waiting_tone                 |bool                 |requiresBroadWorksCallWaitingTone *Optional*               |
|requires_mwi_subscription                              |bool                 |requiresMWISubscription *Optional*                         |
|use_history_info_header_on_access_side                 |bool                 |useHistoryInfoHeaderOnAccessSide *Optional*                |
|advice_of_charge_capable                               |bool                 |adviceOfChargeCapable *Optional*                           |
|reset_event                                            |str                  |resetEvent *Optional*                                      |
|support_call_center_mime_type                          |bool                 |supportCallCenterMIMEType *Optional*                       |
|trunk_mode                                             |str                  |trunkMode *Optional*                                       |
|add_p_called_party_id                                  |bool                 |addPCalledPartyId *Optional*                               |
|support_identity_in_update_and_re_invite               |bool                 |supportIdentityInUpdateAndReInvite *Optional*              |
|unscreened_presentation_identity_policy                |str                  |unscreenedPresentationIdentityPolicy *Optional*            |
|enhanced_for_ics                                       |bool                 |enhancedForICS *Optional*                                  |
|support_emergency_disconnect_control                   |bool                 |supportEmergencyDisconnectControl *Optional*               |
|support_rfc3398                                        |bool                 |supportRFC3398 *Optional*                                  |
|support_client_session_info                            |bool                 |supportClientSessionInfo *Optional*                        |
|support_call_info_conference_subscription_uri          |bool                 |supportCallInfoConferenceSubscriptionURI *Optional*        |
|support_remote_party_info                              |bool                 |supportRemotePartyInfo *Optional*                          |
|support_visual_device_management                       |bool                 |supportVisualDeviceManagement *Optional*                   |
|bypass_media_treatment                                 |bool                 |bypassMediaTreatment *Optional*                            |
|supports3_g4_g_continuity                              |bool                 |supports3G4GContinuity *Optional*                          |
|publishes_own_presence                                 |bool                 |publishesOwnPresence *Optional*                            |
|support_cause_parameter                                |bool                 |supportCauseParameter *Optional*                           |
|location_network                                       |str                  |locationNetwork *Optional*                                 |
|allow_termination_based_on_icsi                        |bool                 |allowTerminationBasedOnICSI *Optional*                     |
|roaming_mode                                           |str                  |roamingMode *Optional*                                     |
|support_calling_party_category_in_outbound_from_header |bool                 |supportCallingPartyCategoryInOutboundFromHeader *Optional* |
</div>


## `SystemSIPDeviceTypeModifyRequest22V3`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are not changeable: numberOfPorts SignalingAddressType isConferenceDevice
isMusicOnHoldDevice isMobilityManagerDevice deviceTypeConfigurationOption
staticLineOrdering The following elements are only used in AS data mode and ignored in
XS data mode: supportClientSessionInfo supportCallInfoConferenceSubscriptionURI
supportRemotePartyInfo supportVisualDeviceManagementRedirectLink bypassMediaTreatment
supportCauseParameter supportCallingPartyCategoryInOutboundFromHeader
supportVisualDeviceManagementAPI deviceCategory The following elements are only used
in XS data mode and ignored in AS mode: enhancedForICS supports3G4GContinuity
publishesOwnPresence locationNetwork allowTerminationBasedOnICSI roamingMode The
following logic applies to these elements: macInCert macInNonRequestURI The two
elements are mutually exclusive.  When both are set to true, the command fails.  When
macInCert is set to true, macInNonRequestURI will be reset to false.  When
macInNonRequestURI is set to true, macInCert will be reset to false.

Replaced By: `SystemSIPDeviceTypeModifyRequest22V4()`

**Attributes:**

|Name                                                   |Type                 |Description                                                |
|-------------------------------------------------------|---------------------|-----------------------------------------------------------|
|device_type                                            |str                  |deviceType                                                 |
|is_obsolete                                            |bool                 |isObsolete *Optional*                                      |
|registration_capable                                   |bool                 |registrationCapable *Optional*                             |
|hold_normalization                                     |str                  |holdNormalization *Optional*                               |
|hold_announcement_method                               |str                  |holdAnnouncementMethod *Optional*                          |
|is_trusted                                             |bool                 |isTrusted *Optional*                                       |
|e164_capable                                           |bool                 |E164Capable *Optional*                                     |
|route_advance                                          |bool                 |routeAdvance *Optional*                                    |
|forwarding_override                                    |bool                 |forwardingOverride *Optional*                              |
|wireless_integration                                   |bool                 |wirelessIntegration *Optional*                             |
|web_based_config_url                                   |str                  |webBasedConfigURL *Optional*                               |
|is_video_capable                                       |bool                 |isVideoCapable *Optional*                                  |
|pbx_integration                                        |bool                 |PBXIntegration *Optional*                                  |
|static_registration_capable                            |bool                 |staticRegistrationCapable *Optional*                       |
|cpe_device_options                                     |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                                |
|early_media_support                                    |str                  |earlyMediaSupport *Optional*                               |
|authenticate_refer                                     |bool                 |authenticateRefer *Optional*                               |
|auto_config_soft_client                                |bool                 |autoConfigSoftClient *Optional*                            |
|authentication_mode                                    |str                  |authenticationMode *Optional*                              |
|requires_broad_works_digit_collection                  |bool                 |requiresBroadWorksDigitCollection *Optional*               |
|requires_broad_works_call_waiting_tone                 |bool                 |requiresBroadWorksCallWaitingTone *Optional*               |
|requires_mwi_subscription                              |bool                 |requiresMWISubscription *Optional*                         |
|use_history_info_header_on_access_side                 |bool                 |useHistoryInfoHeaderOnAccessSide *Optional*                |
|advice_of_charge_capable                               |bool                 |adviceOfChargeCapable *Optional*                           |
|reset_event                                            |str                  |resetEvent *Optional*                                      |
|support_call_center_mime_type                          |bool                 |supportCallCenterMIMEType *Optional*                       |
|trunk_mode                                             |str                  |trunkMode *Optional*                                       |
|add_p_called_party_id                                  |bool                 |addPCalledPartyId *Optional*                               |
|support_identity_in_update_and_re_invite               |bool                 |supportIdentityInUpdateAndReInvite *Optional*              |
|unscreened_presentation_identity_policy                |str                  |unscreenedPresentationIdentityPolicy *Optional*            |
|enhanced_for_ics                                       |bool                 |enhancedForICS *Optional*                                  |
|support_emergency_disconnect_control                   |bool                 |supportEmergencyDisconnectControl *Optional*               |
|support_rfc3398                                        |bool                 |supportRFC3398 *Optional*                                  |
|support_client_session_info                            |bool                 |supportClientSessionInfo *Optional*                        |
|support_call_info_conference_subscription_uri          |bool                 |supportCallInfoConferenceSubscriptionURI *Optional*        |
|support_remote_party_info                              |bool                 |supportRemotePartyInfo *Optional*                          |
|support_visual_device_management_redirect_link         |bool                 |supportVisualDeviceManagementRedirectLink *Optional*       |
|bypass_media_treatment                                 |bool                 |bypassMediaTreatment *Optional*                            |
|supports3_g4_g_continuity                              |bool                 |supports3G4GContinuity *Optional*                          |
|publishes_own_presence                                 |bool                 |publishesOwnPresence *Optional*                            |
|support_cause_parameter                                |bool                 |supportCauseParameter *Optional*                           |
|location_network                                       |str                  |locationNetwork *Optional*                                 |
|allow_termination_based_on_icsi                        |bool                 |allowTerminationBasedOnICSI *Optional*                     |
|roaming_mode                                           |str                  |roamingMode *Optional*                                     |
|support_calling_party_category_in_outbound_from_header |bool                 |supportCallingPartyCategoryInOutboundFromHeader *Optional* |
|support_visual_device_management_api                   |bool                 |supportVisualDeviceManagementAPI *Optional*                |
|device_category                                        |str                  |deviceCategory *Optional*                                  |
</div>


## `SystemSIPDeviceTypeModifyRequest22V4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are not changeable: numberOfPorts SignalingAddressType isConferenceDevice
isMusicOnHoldDevice isMobilityManagerDevice deviceTypeConfigurationOption
staticLineOrdering The following elements are only used in AS data mode and ignored in
XS data mode: supportClientSessionInfo supportCallInfoConferenceSubscriptionURI
supportRemotePartyInfo supportVisualDeviceManagementRedirectLink bypassMediaTreatment
supportCauseParameter supportCallingPartyCategoryInOutboundFromHeader
supportVisualDeviceManagementAPI deviceCategory verstatInPAIHeader verstatInFromHeader
The following elements are only used in XS data mode and ignored in AS mode:
enhancedForICS supports3G4GContinuity publishesOwnPresence locationNetwork
allowTerminationBasedOnICSI roamingMode The following logic applies to these elements:
macInCert macInNonRequestURI The two elements are mutually exclusive.  When both are
set to true, the command fails.  When macInCert is set to true, macInNonRequestURI
will be reset to false.  When macInNonRequestURI is set to true, macInCert will be
reset to false.  Replaced by: `SystemSIPDeviceTypeModifyRequest22V5()`

**Attributes:**

|Name                                                   |Type                 |Description                                                |
|-------------------------------------------------------|---------------------|-----------------------------------------------------------|
|device_type                                            |str                  |deviceType                                                 |
|is_obsolete                                            |bool                 |isObsolete *Optional*                                      |
|registration_capable                                   |bool                 |registrationCapable *Optional*                             |
|hold_normalization                                     |str                  |holdNormalization *Optional*                               |
|hold_announcement_method                               |str                  |holdAnnouncementMethod *Optional*                          |
|is_trusted                                             |bool                 |isTrusted *Optional*                                       |
|e164_capable                                           |bool                 |E164Capable *Optional*                                     |
|route_advance                                          |bool                 |routeAdvance *Optional*                                    |
|forwarding_override                                    |bool                 |forwardingOverride *Optional*                              |
|wireless_integration                                   |bool                 |wirelessIntegration *Optional*                             |
|web_based_config_url                                   |str                  |webBasedConfigURL *Optional*                               |
|is_video_capable                                       |bool                 |isVideoCapable *Optional*                                  |
|pbx_integration                                        |bool                 |PBXIntegration *Optional*                                  |
|static_registration_capable                            |bool                 |staticRegistrationCapable *Optional*                       |
|cpe_device_options                                     |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                                |
|early_media_support                                    |str                  |earlyMediaSupport *Optional*                               |
|authenticate_refer                                     |bool                 |authenticateRefer *Optional*                               |
|auto_config_soft_client                                |bool                 |autoConfigSoftClient *Optional*                            |
|authentication_mode                                    |str                  |authenticationMode *Optional*                              |
|requires_broad_works_digit_collection                  |bool                 |requiresBroadWorksDigitCollection *Optional*               |
|requires_broad_works_call_waiting_tone                 |bool                 |requiresBroadWorksCallWaitingTone *Optional*               |
|requires_mwi_subscription                              |bool                 |requiresMWISubscription *Optional*                         |
|use_history_info_header_on_access_side                 |bool                 |useHistoryInfoHeaderOnAccessSide *Optional*                |
|advice_of_charge_capable                               |bool                 |adviceOfChargeCapable *Optional*                           |
|reset_event                                            |str                  |resetEvent *Optional*                                      |
|support_call_center_mime_type                          |bool                 |supportCallCenterMIMEType *Optional*                       |
|trunk_mode                                             |str                  |trunkMode *Optional*                                       |
|add_p_called_party_id                                  |bool                 |addPCalledPartyId *Optional*                               |
|support_identity_in_update_and_re_invite               |bool                 |supportIdentityInUpdateAndReInvite *Optional*              |
|unscreened_presentation_identity_policy                |str                  |unscreenedPresentationIdentityPolicy *Optional*            |
|enhanced_for_ics                                       |bool                 |enhancedForICS *Optional*                                  |
|support_emergency_disconnect_control                   |bool                 |supportEmergencyDisconnectControl *Optional*               |
|support_rfc3398                                        |bool                 |supportRFC3398 *Optional*                                  |
|support_client_session_info                            |bool                 |supportClientSessionInfo *Optional*                        |
|support_call_info_conference_subscription_uri          |bool                 |supportCallInfoConferenceSubscriptionURI *Optional*        |
|support_remote_party_info                              |bool                 |supportRemotePartyInfo *Optional*                          |
|support_visual_device_management_redirect_link         |bool                 |supportVisualDeviceManagementRedirectLink *Optional*       |
|bypass_media_treatment                                 |bool                 |bypassMediaTreatment *Optional*                            |
|supports3_g4_g_continuity                              |bool                 |supports3G4GContinuity *Optional*                          |
|publishes_own_presence                                 |bool                 |publishesOwnPresence *Optional*                            |
|support_cause_parameter                                |bool                 |supportCauseParameter *Optional*                           |
|location_network                                       |str                  |locationNetwork *Optional*                                 |
|allow_termination_based_on_icsi                        |bool                 |allowTerminationBasedOnICSI *Optional*                     |
|roaming_mode                                           |str                  |roamingMode *Optional*                                     |
|support_calling_party_category_in_outbound_from_header |bool                 |supportCallingPartyCategoryInOutboundFromHeader *Optional* |
|support_visual_device_management_api                   |bool                 |supportVisualDeviceManagementAPI *Optional*                |
|device_category                                        |str                  |deviceCategory *Optional*                                  |
|verstat_in_pai_header                                  |bool                 |verstatInPAIHeader *Optional*                              |
|verstat_in_from_header                                 |bool                 |verstatInFromHeader *Optional*                             |
</div>


## `SystemSIPDeviceTypeModifyRequest22V5`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a sip device type.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are not changeable: numberOfPorts SignalingAddressType isConferenceDevice
isMusicOnHoldDevice isMobilityManagerDevice deviceTypeConfigurationOption
staticLineOrdering The following elements are only used in AS data mode and ignored in
XS data mode: supportClientSessionInfo supportCallInfoConferenceSubscriptionURI
supportRemotePartyInfo supportVisualDeviceManagementRedirectLink bypassMediaTreatment
supportCauseParameter supportCallingPartyCategoryInOutboundFromHeader
supportVisualDeviceManagementAPI deviceCategory verstatInPAIHeader verstatInFromHeader
The following elements are only used in XS data mode and ignored in AS mode:
enhancedForICS supports3G4GContinuity publishesOwnPresence locationNetwork
allowTerminationBasedOnICSI roamingMode The following logic applies to these elements:
macInCert macInNonRequestURI The two elements are mutually exclusive.  When both are
set to true, the command fails.  When macInCert is set to true, macInNonRequestURI
will be reset to false.  When macInNonRequestURI is set to true, macInCert will be
reset to false.

**Attributes:**

|Name                                                   |Type                 |Description                                                |
|-------------------------------------------------------|---------------------|-----------------------------------------------------------|
|device_type                                            |str                  |deviceType                                                 |
|is_obsolete                                            |bool                 |isObsolete *Optional*                                      |
|registration_capable                                   |bool                 |registrationCapable *Optional*                             |
|hold_normalization                                     |str                  |holdNormalization *Optional*                               |
|hold_announcement_method                               |str                  |holdAnnouncementMethod *Optional*                          |
|is_trusted                                             |bool                 |isTrusted *Optional*                                       |
|e164_capable                                           |bool                 |E164Capable *Optional*                                     |
|route_advance                                          |bool                 |routeAdvance *Optional*                                    |
|forwarding_override                                    |bool                 |forwardingOverride *Optional*                              |
|wireless_integration                                   |bool                 |wirelessIntegration *Optional*                             |
|web_based_config_url                                   |str                  |webBasedConfigURL *Optional*                               |
|is_video_capable                                       |bool                 |isVideoCapable *Optional*                                  |
|pbx_integration                                        |bool                 |PBXIntegration *Optional*                                  |
|static_registration_capable                            |bool                 |staticRegistrationCapable *Optional*                       |
|cpe_device_options                                     |OCI.cpeDeviceOptions |cpeDeviceOptions *Optional*                                |
|early_media_support                                    |str                  |earlyMediaSupport *Optional*                               |
|authenticate_refer                                     |bool                 |authenticateRefer *Optional*                               |
|auto_config_soft_client                                |bool                 |autoConfigSoftClient *Optional*                            |
|authentication_mode                                    |str                  |authenticationMode *Optional*                              |
|requires_broad_works_digit_collection                  |bool                 |requiresBroadWorksDigitCollection *Optional*               |
|requires_broad_works_call_waiting_tone                 |bool                 |requiresBroadWorksCallWaitingTone *Optional*               |
|requires_mwi_subscription                              |bool                 |requiresMWISubscription *Optional*                         |
|use_history_info_header_on_access_side                 |bool                 |useHistoryInfoHeaderOnAccessSide *Optional*                |
|advice_of_charge_capable                               |bool                 |adviceOfChargeCapable *Optional*                           |
|reset_event                                            |str                  |resetEvent *Optional*                                      |
|reset_string                                           |str                  |resetString *Optional*                                     |
|support_call_center_mime_type                          |bool                 |supportCallCenterMIMEType *Optional*                       |
|trunk_mode                                             |str                  |trunkMode *Optional*                                       |
|add_p_called_party_id                                  |bool                 |addPCalledPartyId *Optional*                               |
|support_identity_in_update_and_re_invite               |bool                 |supportIdentityInUpdateAndReInvite *Optional*              |
|unscreened_presentation_identity_policy                |str                  |unscreenedPresentationIdentityPolicy *Optional*            |
|enhanced_for_ics                                       |bool                 |enhancedForICS *Optional*                                  |
|support_emergency_disconnect_control                   |bool                 |supportEmergencyDisconnectControl *Optional*               |
|support_rfc3398                                        |bool                 |supportRFC3398 *Optional*                                  |
|support_client_session_info                            |bool                 |supportClientSessionInfo *Optional*                        |
|support_call_info_conference_subscription_uri          |bool                 |supportCallInfoConferenceSubscriptionURI *Optional*        |
|support_remote_party_info                              |bool                 |supportRemotePartyInfo *Optional*                          |
|support_visual_device_management_redirect_link         |bool                 |supportVisualDeviceManagementRedirectLink *Optional*       |
|bypass_media_treatment                                 |bool                 |bypassMediaTreatment *Optional*                            |
|supports3_g4_g_continuity                              |bool                 |supports3G4GContinuity *Optional*                          |
|publishes_own_presence                                 |bool                 |publishesOwnPresence *Optional*                            |
|support_cause_parameter                                |bool                 |supportCauseParameter *Optional*                           |
|location_network                                       |str                  |locationNetwork *Optional*                                 |
|allow_termination_based_on_icsi                        |bool                 |allowTerminationBasedOnICSI *Optional*                     |
|roaming_mode                                           |str                  |roamingMode *Optional*                                     |
|support_calling_party_category_in_outbound_from_header |bool                 |supportCallingPartyCategoryInOutboundFromHeader *Optional* |
|support_visual_device_management_api                   |bool                 |supportVisualDeviceManagementAPI *Optional*                |
|device_category                                        |str                  |deviceCategory *Optional*                                  |
|verstat_in_pai_header                                  |bool                 |verstatInPAIHeader *Optional*                              |
|verstat_in_from_header                                 |bool                 |verstatInFromHeader *Optional*                             |
</div>


## `UserAddRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a user.

The domain is required in the userId.  The password is not required if external
authentication is enabled.  The following elements are only used in AS data mode and
will fail in XS data mode: trunkAddressing The following elements are only used in AS
data mode and ignored in XS data mode: nameDialingName alternateUserId The following
elements are only used in XS data mode and ignored in AS data mode: allowVideo

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements can only be used by a system administrator:. allowVideo alternateUserId The
following elements can only be used by a provisioning administrator:. alternateUserId
The response is either `SuccessResponse()` or `ErrorResponse()`. Replaced by:
`UserAddRequest22V2()` in AS data mode.

**Attributes:**

|Name                         |Type                      |Description                         |
|-----------------------------|--------------------------|------------------------------------|
|service_provider_id          |str                       |serviceProviderId                   |
|group_id                     |str                       |groupId                             |
|user_id                      |str                       |userId                              |
|last_name                    |str                       |lastName                            |
|first_name                   |str                       |firstName                           |
|calling_line_id_last_name    |str                       |callingLineIdLastName               |
|calling_line_id_first_name   |str                       |callingLineIdFirstName              |
|name_dialing_name            |OCI.nameDialingName       |nameDialingName *Optional*          |
|hiragana_last_name           |str                       |hiraganaLastName *Optional*         |
|hiragana_first_name          |str                       |hiraganaFirstName *Optional*        |
|phone_number                 |str                       |phoneNumber *Optional*              |
|extension                    |str                       |extension *Optional*                |
|calling_line_id_phone_number |str                       |callingLineIdPhoneNumber *Optional* |
|password                     |str                       |password *Optional*                 |
|department                   |OCI.department            |department *Optional*               |
|language                     |str                       |language *Optional*                 |
|time_zone                    |str                       |timeZone *Optional*                 |
|alias                        |List[str]                 |alias *Optional*                    |
|access_device_endpoint       |OCI.accessDeviceEndpoint  |accessDeviceEndpoint *Optional*     |
|trunk_addressing             |OCI.trunkAddressing       |trunkAddressing *Optional*          |
|title                        |str                       |title *Optional*                    |
|pager_phone_number           |str                       |pagerPhoneNumber *Optional*         |
|mobile_phone_number          |str                       |mobilePhoneNumber *Optional*        |
|email_address                |str                       |emailAddress *Optional*             |
|yahoo_id                     |str                       |yahooId *Optional*                  |
|address_location             |str                       |addressLocation *Optional*          |
|address                      |OCI.address               |address *Optional*                  |
|network_class_of_service     |str                       |networkClassOfService *Optional*    |
|alternate_user_id            |List[OCI.alternateUserId] |alternateUserId *Optional*          |
</div>


## `UserAddRequest22V2`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to add a user.

The domain is required in the userId.  The password is not required if external
authentication is enabled.  The following elements are only used in AS data mode and
will fail in XS data mode: trunkAddressing The following elements are only used in AS
data mode and ignored in XS data mode: nameDialingName alternateUserId The following
elements are only used in XS data mode and ignored in AS data mode: allowVideo

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements can only be used by a system administrator:. allowVideo alternateUserId The
following elements can only be used by a provisioning administrator:. alternateUserId
The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                         |Type                      |Description                         |
|-----------------------------|--------------------------|------------------------------------|
|service_provider_id          |str                       |serviceProviderId                   |
|group_id                     |str                       |groupId                             |
|user_id                      |str                       |userId                              |
|last_name                    |str                       |lastName                            |
|first_name                   |str                       |firstName                           |
|calling_line_id_last_name    |str                       |callingLineIdLastName               |
|calling_line_id_first_name   |str                       |callingLineIdFirstName              |
|name_dialing_name            |OCI.nameDialingName       |nameDialingName *Optional*          |
|hiragana_last_name           |str                       |hiraganaLastName *Optional*         |
|hiragana_first_name          |str                       |hiraganaFirstName *Optional*        |
|phone_number                 |str                       |phoneNumber *Optional*              |
|extension                    |str                       |extension *Optional*                |
|calling_line_id_phone_number |str                       |callingLineIdPhoneNumber *Optional* |
|password                     |str                       |password *Optional*                 |
|department                   |OCI.department            |department *Optional*               |
|language                     |str                       |language *Optional*                 |
|time_zone                    |str                       |timeZone *Optional*                 |
|alias                        |List[str]                 |alias *Optional*                    |
|access_device_endpoint       |OCI.accessDeviceEndpoint  |accessDeviceEndpoint *Optional*     |
|trunk_addressing             |OCI.trunkAddressing       |trunkAddressing *Optional*          |
|title                        |str                       |title *Optional*                    |
|pager_phone_number           |str                       |pagerPhoneNumber *Optional*         |
|mobile_phone_number          |str                       |mobilePhoneNumber *Optional*        |
|email_address                |str                       |emailAddress *Optional*             |
|yahoo_id                     |str                       |yahooId *Optional*                  |
|address_location             |str                       |addressLocation *Optional*          |
|address                      |OCI.address               |address *Optional*                  |
|network_class_of_service     |str                       |networkClassOfService *Optional*    |
|alternate_user_id            |List[OCI.alternateUserId] |alternateUserId *Optional*          |
</div>


## `UserCallCenterEnhancedReportingScheduledReportModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a call center reporting scheduled report created by a supervisor.

The response is either a `SuccessResponse()` or an `ErrorResponse()`. The startDate
element is adjusted to the first occurrence of the recurrent schedule that comes at or
after startDate.

**Attributes:**

|Name                               |Type                              |Description                                |
|-----------------------------------|----------------------------------|-------------------------------------------|
|supervisor_user_id                 |str                               |supervisorUserId                           |
|name                               |str                               |name                                       |
|new_name                           |str                               |newName *Optional*                         |
|description                        |str                               |description *Optional*                     |
|schedule                           |OCI.schedule                      |schedule *Optional*                        |
|sampling_period                    |str                               |samplingPeriod *Optional*                  |
|start_day_of_week                  |str                               |startDayOfWeek *Optional*                  |
|report_time_zone                   |str                               |reportTimeZone *Optional*                  |
|report_date_format                 |str                               |reportDateFormat *Optional*                |
|report_time_format                 |str                               |reportTimeFormat *Optional*                |
|report_interval                    |OCI.reportInterval                |reportInterval *Optional*                  |
|report_format                      |str                               |reportFormat *Optional*                    |
|agent                              |OCI.agent                         |agent *Optional*                           |
|call_center                        |OCI.callCenter                    |callCenter *Optional*                      |
|dnis                               |OCI.dnis                          |dnis *Optional*                            |
|call_completion_threshold_seconds  |int                               |callCompletionThresholdSeconds *Optional*  |
|short_duration_threshold_seconds   |int                               |shortDurationThresholdSeconds *Optional*   |
|service_level_threshold_seconds    |OCI.serviceLevelThresholdSeconds  |serviceLevelThresholdSeconds *Optional*    |
|service_level_inclusions           |OCI.serviceLevelInclusions        |serviceLevelInclusions *Optional*          |
|service_level_objective_percentage |int                               |serviceLevelObjectivePercentage *Optional* |
|abandoned_call_threshold_seconds   |OCI.abandonedCallThresholdSeconds |abandonedCallThresholdSeconds *Optional*   |
|email_address                      |OCI.emailAddress                  |emailAddress *Optional*                    |
</div>


## `UserConsolidatedAddRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
The response is either `SuccessResponse()` or `ErrorResponse()`.

In AS and Amplify Data Mode: The group user limit will be increased by one if needed.
The group will be added if it does not exist and if the command is executed by a
Service Provider level administrator or above.  If the group needs to be created, the
groupProperties element must be set or the request will fail.  The groupProperties
element will be ignored if the group already exists.  If the domain has not been
assigned to the group, it will be added to group if the command is executed by a
Service provider level administrator or above.  If the domain has not been assigned to
the service provider, it will be added to the service provider if the command is
executed by a Provisioning level administrator or above.  The command will fail
otherwise.  If the phoneNumber has not been assigned to the group and
addPhoneNumberToGroup is set to true, it will be added to group if the command is
executed by a service provider administrator or above and the number is already
assigned to the service provider.  The command will fail otherwise.  The password is
not required if external authentication is enabled.  Alternate user ids can be added
by a group level administrator or above.  When
sharedCallAppearanceAccessDeviceEndpoint element is included and the Shared Call
Appearance is not included in the service/service pack of the request or in the "new
user template", the request will fail.  The userService/servicePack will be authorized
to the group if it has not been authorized to the group if the command is executed by
a Service Provider level administrator or above.  The command will fail otherwise.
The authorizedQuantity will be set to unlimited if not present.  When
thirdPartyVoiceMail elements are included and the Third Party Voice Mail Support
service is not included in the service/service pack of the request or in the "new user
template", the request will fail.  When sipAuthenticationData element is included and
the Authentication service is not included in the service/service pack of the request
or in the "new user template", the request will fail.  In XS data mode: only the
System level administrator has the authorization level to execute the command.  The
group will be added if it does not exist.  If the group needs to be created, the
groupProperties element must be set or the request will fail.  The groupProperties
element will be ignored if the group already exists.  If the phoneNumber has not been
assigned to the group, it will be added to group and service provider if needed.  When
sharedCallAppearanceAccessDeviceEndpoint element is included and the Shared Call
Appearance is not included in the service/service pack of the request, the request
will fail.  The following elements are ignored in XS data mode: addPhoneNumberToGroup
nameDialingName alternateUserId passcode trunkAddressing
thirdPartyVoiceMailServerSelection thirdPartyVoiceMailServerUserServer
thirdPartyVoiceMailServerMailboxIdType thirdPartyVoiceMailMailboxURL
sipAuthenticationData Replaced by: `UserConsolidatedAddRequest22()` in AS data mode.

**Attributes:**

|Name                                          |Type                                               |Description                                         |
|----------------------------------------------|---------------------------------------------------|----------------------------------------------------|
|service_provider_id                           |str                                                |serviceProviderId *Optional*                        |
|group_id                                      |str                                                |groupId *Optional*                                  |
|group_external_id                             |str                                                |groupExternalId *Optional*                          |
|group_properties                              |OCI.groupProperties                                |groupProperties *Optional*                          |
|user_id                                       |str                                                |userId                                              |
|user_external_id                              |str                                                |userExternalId *Optional*                           |
|add_phone_number_to_group                     |bool                                               |addPhoneNumberToGroup *Optional*                    |
|last_name                                     |str                                                |lastName                                            |
|first_name                                    |str                                                |firstName                                           |
|calling_line_id_last_name                     |str                                                |callingLineIdLastName                               |
|calling_line_id_first_name                    |str                                                |callingLineIdFirstName                              |
|name_dialing_name                             |OCI.nameDialingName                                |nameDialingName *Optional*                          |
|hiragana_last_name                            |str                                                |hiraganaLastName *Optional*                         |
|hiragana_first_name                           |str                                                |hiraganaFirstName *Optional*                        |
|phone_number                                  |str                                                |phoneNumber *Optional*                              |
|alternate_user_id                             |List[OCI.alternateUserId]                          |alternateUserId *Optional*                          |
|extension                                     |str                                                |extension *Optional*                                |
|calling_line_id_phone_number                  |str                                                |callingLineIdPhoneNumber *Optional*                 |
|password                                      |str                                                |password *Optional*                                 |
|passcode                                      |str                                                |passcode *Optional*                                 |
|department                                    |OCI.department                                     |department *Optional*                               |
|language                                      |str                                                |language *Optional*                                 |
|time_zone                                     |str                                                |timeZone *Optional*                                 |
|alias                                         |List[str]                                          |alias *Optional*                                    |
|access_device_endpoint                        |OCI.accessDeviceEndpoint                           |accessDeviceEndpoint *Optional*                     |
|trunk_addressing                              |OCI.trunkAddressing                                |trunkAddressing *Optional*                          |
|shared_call_appearance_access_device_endpoint |List[OCI.sharedCallAppearanceAccessDeviceEndpoint] |sharedCallAppearanceAccessDeviceEndpoint *Optional* |
|title                                         |str                                                |title *Optional*                                    |
|pager_phone_number                            |str                                                |pagerPhoneNumber *Optional*                         |
|mobile_phone_number                           |str                                                |mobilePhoneNumber *Optional*                        |
|email_address                                 |str                                                |emailAddress *Optional*                             |
|yahoo_id                                      |str                                                |yahooId *Optional*                                  |
|address_location                              |str                                                |addressLocation *Optional*                          |
|address                                       |OCI.address                                        |address *Optional*                                  |
|network_class_of_service                      |str                                                |networkClassOfService *Optional*                    |
|user_service                                  |List[OCI.userService]                              |userService *Optional*                              |
|service_pack                                  |List[OCI.servicePack]                              |servicePack *Optional*                              |
|third_party_voice_mail_server_selection       |str                                                |thirdPartyVoiceMailServerSelection *Optional*       |
|third_party_voice_mail_server_user_server     |str                                                |thirdPartyVoiceMailServerUserServer *Optional*      |
|third_party_voice_mail_server_mailbox_id_type |str                                                |thirdPartyVoiceMailServerMailboxIdType *Optional*   |
|third_party_voice_mail_mailbox_url            |str                                                |thirdPartyVoiceMailMailboxURL *Optional*            |
|sip_authentication_data                       |OCI.sipAuthenticationData                          |sipAuthenticationData *Optional*                    |
</div>


## `UserConsolidatedAddRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
The response is either `SuccessResponse()` or `ErrorResponse()`.

In AS and Amplify Data Mode: The group user limit will be increased by one if needed.
The group will be added if it does not exist and if the command is executed by a
Service Provider level administrator or above.  If the group needs to be created, the
groupProperties element must be set or the request will fail.  The groupProperties
element will be ignored if the group already exists.  If the domain has not been
assigned to the group, it will be added to group if the command is executed by a
Service provider level administrator or above.  If the domain has not been assigned to
the service provider, it will be added to the service provider if the command is
executed by a Provisioning level administrator or above.  The command will fail
otherwise.  If the phoneNumber has not been assigned to the group and
addPhoneNumberToGroup is set to true, it will be added to group if the command is
executed by a service provider administrator or above and the number is already
assigned to the service provider.  The command will fail otherwise.  The password is
not required if external authentication is enabled.  Alternate user ids can be added
by a group level administrator or above.  When
sharedCallAppearanceAccessDeviceEndpoint element is included and the Shared Call
Appearance is not included in the service/service pack of the request or in the "new
user template", the request will fail.  The userService/servicePack will be authorized
to the group if it has not been authorized to the group if the command is executed by
a Service Provider level administrator or above.  The command will fail otherwise.
The authorizedQuantity will be set to unlimited if not present.  When
thirdPartyVoiceMail elements are included and the Third Party Voice Mail Support
service is not included in the service/service pack of the request or in the "new user
template", the request will fail.  When sipAuthenticationData element is included and
the Authentication service is not included in the service/service pack of the request
or in the "new user template", the request will fail.  In XS data mode: only the
System level administrator has the authorization level to execute the command.  The
group will be added if it does not exist.  If the group needs to be created, the
groupProperties element must be set or the request will fail.  The groupProperties
element will be ignored if the group already exists.  If the phoneNumber has not been
assigned to the group, it will be added to group and service provider if needed.  When
sharedCallAppearanceAccessDeviceEndpoint element is included and the Shared Call
Appearance is not included in the service/service pack of the request, the request
will fail.  The following elements are ignored in XS data mode: addPhoneNumberToGroup
nameDialingName alternateUserId passcode trunkAddressing
thirdPartyVoiceMailServerSelection thirdPartyVoiceMailServerUserServer
thirdPartyVoiceMailServerMailboxIdType thirdPartyVoiceMailMailboxURL
sipAuthenticationData

**Attributes:**

|Name                                          |Type                                               |Description                                         |
|----------------------------------------------|---------------------------------------------------|----------------------------------------------------|
|service_provider_id                           |str                                                |serviceProviderId *Optional*                        |
|group_id                                      |str                                                |groupId *Optional*                                  |
|group_external_id                             |str                                                |groupExternalId *Optional*                          |
|group_properties                              |OCI.groupProperties                                |groupProperties *Optional*                          |
|user_id                                       |str                                                |userId                                              |
|user_external_id                              |str                                                |userExternalId *Optional*                           |
|add_phone_number_to_group                     |bool                                               |addPhoneNumberToGroup *Optional*                    |
|last_name                                     |str                                                |lastName                                            |
|first_name                                    |str                                                |firstName                                           |
|calling_line_id_last_name                     |str                                                |callingLineIdLastName                               |
|calling_line_id_first_name                    |str                                                |callingLineIdFirstName                              |
|name_dialing_name                             |OCI.nameDialingName                                |nameDialingName *Optional*                          |
|hiragana_last_name                            |str                                                |hiraganaLastName *Optional*                         |
|hiragana_first_name                           |str                                                |hiraganaFirstName *Optional*                        |
|phone_number                                  |str                                                |phoneNumber *Optional*                              |
|alternate_user_id                             |List[OCI.alternateUserId]                          |alternateUserId *Optional*                          |
|extension                                     |str                                                |extension *Optional*                                |
|calling_line_id_phone_number                  |str                                                |callingLineIdPhoneNumber *Optional*                 |
|password                                      |str                                                |password *Optional*                                 |
|passcode                                      |str                                                |passcode *Optional*                                 |
|department                                    |OCI.department                                     |department *Optional*                               |
|language                                      |str                                                |language *Optional*                                 |
|time_zone                                     |str                                                |timeZone *Optional*                                 |
|alias                                         |List[str]                                          |alias *Optional*                                    |
|access_device_endpoint                        |OCI.accessDeviceEndpoint                           |accessDeviceEndpoint *Optional*                     |
|trunk_addressing                              |OCI.trunkAddressing                                |trunkAddressing *Optional*                          |
|shared_call_appearance_access_device_endpoint |List[OCI.sharedCallAppearanceAccessDeviceEndpoint] |sharedCallAppearanceAccessDeviceEndpoint *Optional* |
|title                                         |str                                                |title *Optional*                                    |
|pager_phone_number                            |str                                                |pagerPhoneNumber *Optional*                         |
|mobile_phone_number                           |str                                                |mobilePhoneNumber *Optional*                        |
|email_address                                 |str                                                |emailAddress *Optional*                             |
|yahoo_id                                      |str                                                |yahooId *Optional*                                  |
|address_location                              |str                                                |addressLocation *Optional*                          |
|address                                       |OCI.address                                        |address *Optional*                                  |
|network_class_of_service                      |str                                                |networkClassOfService *Optional*                    |
|user_service                                  |List[OCI.userService]                              |userService *Optional*                              |
|service_pack                                  |List[OCI.servicePack]                              |servicePack *Optional*                              |
|third_party_voice_mail_server_selection       |str                                                |thirdPartyVoiceMailServerSelection *Optional*       |
|third_party_voice_mail_server_user_server     |str                                                |thirdPartyVoiceMailServerUserServer *Optional*      |
|third_party_voice_mail_server_mailbox_id_type |str                                                |thirdPartyVoiceMailServerMailboxIdType *Optional*   |
|third_party_voice_mail_mailbox_url            |str                                                |thirdPartyVoiceMailMailboxURL *Optional*            |
|sip_authentication_data                       |OCI.sipAuthenticationData                          |sipAuthenticationData *Optional*                    |
</div>


## `UserConsolidatedModifyRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a user.

If deleteExistingDevices is set to true, when the devices for the main endpoint or SCA
service are changed, devices with no more endpoint will be deleted if the command is
executed with the correct priviledge.  Group administrator or above running this
command can delete any group level devices.  Service provider administrator or above
can delete any service provider and group devices.  Provisioning administrator or
above can delete any devices.  An `ErrorResponse()` will be returned if any device
cannot be deleted because of insufficient privilege.  When phone numbers are un-
assigned from the user, the unused numbers may be un-assigned from the group and
service provider.  If UnassignPhoneNumbersLevel is set to 'Group', the user's primary
phone number, fax number and any alternate numbers, will be un-assigned from the group
if the command is executed by a service provider administrator or above.  When set to
'Service Provider', they will be un-assigned from the group and service provider if
the command is executed by a provisioning administrator or above.  When omitted, the
number(s) will be left assigned to the group.  An `ErrorResponse()` will be returned
if any number cannot be unassigned because of insufficient privilege.  If the
phoneNumber has not been assigned to the group and addPhoneNumberToGroup is set to
true, it will be added to group if needed if the command is executed by a service
provider administrator and above.  The command will fail otherwise.  Alternate user
ids can be added by a group level administrator or above.  The password is not
required if external authentication is enabled.  When
sharedCallAppearanceAccessDeviceEndpoint element is included and the Shared Call
Appearance service is not assigned after this request, the request will fail.  The
userService/servicePackwill be authorized to the group if it has not been authorized
to the group and the command is excuted by a service provider administrator.  The
request will fail otherwise.  If not present, the authorizedQuantity will be set to
unlimited if allowed.  If any of the third party voice mail elements are included but
the service is not assigned after this request, the request will fail.  If the sip
authentication elements are included but the SPI Authentication service is not
assigned after this request, the request will fail.  If the impPassword element is
included but the Integrated IMP service is not assigned after this request, the
request will fail.  The following elements are ignored in XS data mode:
nameDialingName alternateUserIdList passcode trunkAddressing
thirdPartyVoiceMailServerSelection thirdPartyVoiceMailServerUserServer
thirdPartyVoiceMailServerMailboxIdType thirdPartyVoiceMailMailboxURL
sipAuthenticationData newUserExternalId

The response is either `SuccxessResponse()` or `ErrorResponse()`. Replaced by:
`UserConsolidatedModifyRequest22()`

**Attributes:**

|Name                                               |Type                                             |Description                                             |
|---------------------------------------------------|-------------------------------------------------|--------------------------------------------------------|
|user_id                                            |str                                              |userId                                                  |
|delete_existing_devices                            |bool                                             |deleteExistingDevices *Optional*                        |
|unassign_phone_numbers                             |str                                              |unassignPhoneNumbers *Optional*                         |
|add_phone_number_to_group                          |bool                                             |addPhoneNumberToGroup *Optional*                        |
|new_user_id                                        |str                                              |newUserId *Optional*                                    |
|last_name                                          |str                                              |lastName *Optional*                                     |
|first_name                                         |str                                              |firstName *Optional*                                    |
|calling_line_id_last_name                          |str                                              |callingLineIdLastName *Optional*                        |
|calling_line_id_first_name                         |str                                              |callingLineIdFirstName *Optional*                       |
|name_dialing_name                                  |OCI.nameDialingName                              |nameDialingName *Optional*                              |
|hiragana_last_name                                 |str                                              |hiraganaLastName *Optional*                             |
|hiragana_first_name                                |str                                              |hiraganaFirstName *Optional*                            |
|phone_number                                       |str                                              |phoneNumber *Optional*                                  |
|alternate_user_id_list                             |OCI.alternateUserIdList                          |alternateUserIdList *Optional*                          |
|extension                                          |str                                              |extension *Optional*                                    |
|calling_line_id_phone_number                       |str                                              |callingLineIdPhoneNumber *Optional*                     |
|old_password                                       |str                                              |oldPassword *Optional*                                  |
|new_password                                       |str                                              |newPassword *Optional*                                  |
|department                                         |OCI.department                                   |department *Optional*                                   |
|language                                           |str                                              |language *Optional*                                     |
|time_zone                                          |str                                              |timeZone *Optional*                                     |
|sip_alias_list                                     |OCI.sipAliasList                                 |sipAliasList *Optional*                                 |
|endpoint                                           |OCI.endpoint                                     |endpoint *Optional*                                     |
|shared_call_appearance_access_device_endpoint_list |OCI.sharedCallAppearanceAccessDeviceEndpointList |sharedCallAppearanceAccessDeviceEndpointList *Optional* |
|title                                              |str                                              |title *Optional*                                        |
|pager_phone_number                                 |str                                              |pagerPhoneNumber *Optional*                             |
|mobile_phone_number                                |str                                              |mobilePhoneNumber *Optional*                            |
|email_address                                      |str                                              |emailAddress *Optional*                                 |
|yahoo_id                                           |str                                              |yahooId *Optional*                                      |
|address_location                                   |str                                              |addressLocation *Optional*                              |
|address                                            |OCI.address                                      |address *Optional*                                      |
|network_class_of_service                           |str                                              |networkClassOfService *Optional*                        |
|user_service_list                                  |OCI.userServiceList                              |userServiceList *Optional*                              |
|service_pack_list                                  |OCI.servicePackList                              |servicePackList *Optional*                              |
|third_party_voice_mail_server_selection            |str                                              |thirdPartyVoiceMailServerSelection *Optional*           |
|third_party_voice_mail_server_user_server          |str                                              |thirdPartyVoiceMailServerUserServer *Optional*          |
|third_party_voice_mail_server_mailbox_id_type      |str                                              |thirdPartyVoiceMailServerMailboxIdType *Optional*       |
|third_party_voice_mail_mailbox_url                 |str                                              |thirdPartyVoiceMailMailboxURL *Optional*                |
|sip_authentication_user_name                       |str                                              |sipAuthenticationUserName *Optional*                    |
|new_sip_authentication_password                    |str                                              |newSipAuthenticationPassword *Optional*                 |
|old_sip_authentication_password                    |str                                              |OldSipAuthenticationPassword *Optional*                 |
|new_passcode                                       |str                                              |newPasscode *Optional*                                  |
|old_passcode                                       |str                                              |oldPasscode *Optional*                                  |
|imp_password                                       |str                                              |impPassword *Optional*                                  |
|new_user_external_id                               |str                                              |newUserExternalId *Optional*                            |
</div>


## `UserConsolidatedModifyRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify a user.

If deleteExistingDevices is set to true, when the devices for the main endpoint or SCA
service are changed, devices with no more endpoint will be deleted if the command is
executed with the correct privilege.  Group administrator or above running this
command can delete any group level devices.  Service provider administrator or above
can delete any service provider and group devices.  Provisioning administrator or
above can delete any devices.  An `ErrorResponse()` will be returned if any device
cannot be deleted because of insufficient privilege.  When phone numbers are un-
assigned from the user, the unused numbers may be un-assigned from the group and
service provider.  If UnassignPhoneNumbersLevel is set to 'Group', the user's primary
phone number, fax number and any alternate numbers, will be un-assigned from the group
if the command is executed by a service provider administrator or above.  When set to
'Service Provider', they will be un-assigned from the group and service provider if
the command is executed by a provisioning administrator or above.  When omitted, the
number(s) will be left assigned to the group.  An `ErrorResponse()` will be returned
if any number cannot be unassigned because of insufficient privilege.  If the
phoneNumber has not been assigned to the group and addPhoneNumberToGroup is set to
true, it will be added to group if needed if the command is executed by a service
provider administrator and above.  The command will fail otherwise.  Alternate user
ids can be added by a group level administrator or above.  The password is not
required if external authentication is enabled.  When
sharedCallAppearanceAccessDeviceEndpoint element is included and the Shared Call
Appearance service is not assigned after this request, the request will fail.  The
userService/servicePackwill be authorized to the group if it has not been authorized
to the group and the command is excuted by a service provider administrator.  The
request will fail otherwise.  If not present, the authorizedQuantity will be set to
unlimited if allowed.  If any of the third party voice mail elements are included but
the service is not assigned after this request, the request will fail.  If the sip
authentication elements are included but the SPI Authentication service is not
assigned after this request, the request will fail.  If the impPassword element is
included but the Integrated IMP service is not assigned after this request, the
request will fail.  The following elements are ignored in XS data mode:
nameDialingName alternateUserIdList passcode trunkAddressing
thirdPartyVoiceMailServerSelection thirdPartyVoiceMailServerUserServer
thirdPartyVoiceMailServerMailboxIdType thirdPartyVoiceMailMailboxURL
sipAuthenticationData newUserExternalId

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                                               |Type                                             |Description                                             |
|---------------------------------------------------|-------------------------------------------------|--------------------------------------------------------|
|user_id                                            |str                                              |userId                                                  |
|delete_existing_devices                            |bool                                             |deleteExistingDevices *Optional*                        |
|unassign_phone_numbers                             |str                                              |unassignPhoneNumbers *Optional*                         |
|add_phone_number_to_group                          |bool                                             |addPhoneNumberToGroup *Optional*                        |
|new_user_id                                        |str                                              |newUserId *Optional*                                    |
|last_name                                          |str                                              |lastName *Optional*                                     |
|first_name                                         |str                                              |firstName *Optional*                                    |
|calling_line_id_last_name                          |str                                              |callingLineIdLastName *Optional*                        |
|calling_line_id_first_name                         |str                                              |callingLineIdFirstName *Optional*                       |
|name_dialing_name                                  |OCI.nameDialingName                              |nameDialingName *Optional*                              |
|hiragana_last_name                                 |str                                              |hiraganaLastName *Optional*                             |
|hiragana_first_name                                |str                                              |hiraganaFirstName *Optional*                            |
|phone_number                                       |str                                              |phoneNumber *Optional*                                  |
|alternate_user_id_list                             |OCI.alternateUserIdList                          |alternateUserIdList *Optional*                          |
|extension                                          |str                                              |extension *Optional*                                    |
|calling_line_id_phone_number                       |str                                              |callingLineIdPhoneNumber *Optional*                     |
|old_password                                       |str                                              |oldPassword *Optional*                                  |
|new_password                                       |str                                              |newPassword *Optional*                                  |
|department                                         |OCI.department                                   |department *Optional*                                   |
|language                                           |str                                              |language *Optional*                                     |
|time_zone                                          |str                                              |timeZone *Optional*                                     |
|sip_alias_list                                     |OCI.sipAliasList                                 |sipAliasList *Optional*                                 |
|endpoint                                           |OCI.endpoint                                     |endpoint *Optional*                                     |
|shared_call_appearance_access_device_endpoint_list |OCI.sharedCallAppearanceAccessDeviceEndpointList |sharedCallAppearanceAccessDeviceEndpointList *Optional* |
|title                                              |str                                              |title *Optional*                                        |
|pager_phone_number                                 |str                                              |pagerPhoneNumber *Optional*                             |
|mobile_phone_number                                |str                                              |mobilePhoneNumber *Optional*                            |
|email_address                                      |str                                              |emailAddress *Optional*                                 |
|yahoo_id                                           |str                                              |yahooId *Optional*                                      |
|address_location                                   |str                                              |addressLocation *Optional*                              |
|address                                            |OCI.address                                      |address *Optional*                                      |
|network_class_of_service                           |str                                              |networkClassOfService *Optional*                        |
|user_service_list                                  |OCI.userServiceList                              |userServiceList *Optional*                              |
|service_pack_list                                  |OCI.servicePackList                              |servicePackList *Optional*                              |
|third_party_voice_mail_server_selection            |str                                              |thirdPartyVoiceMailServerSelection *Optional*           |
|third_party_voice_mail_server_user_server          |str                                              |thirdPartyVoiceMailServerUserServer *Optional*          |
|third_party_voice_mail_server_mailbox_id_type      |str                                              |thirdPartyVoiceMailServerMailboxIdType *Optional*       |
|third_party_voice_mail_mailbox_url                 |str                                              |thirdPartyVoiceMailMailboxURL *Optional*                |
|sip_authentication_user_name                       |str                                              |sipAuthenticationUserName *Optional*                    |
|new_sip_authentication_password                    |str                                              |newSipAuthenticationPassword *Optional*                 |
|old_sip_authentication_password                    |str                                              |OldSipAuthenticationPassword *Optional*                 |
|new_passcode                                       |str                                              |newPasscode *Optional*                                  |
|old_passcode                                       |str                                              |oldPasscode *Optional*                                  |
|imp_password                                       |str                                              |impPassword *Optional*                                  |
|new_user_external_id                               |str                                              |newUserExternalId *Optional*                            |
</div>


## `UserEnhancedCallLogsGetListRequest17sp4`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request user's call logs.

If the callLogType is not specified, all types of calls logs (placed, received,
missed) are returned.  The filters "dateTimeRange", "numberFilter",
"redirectedNumberFilter", accountAuthorizationCodeFilter" and ""subscriberType" are
ignored if call logs are stored in CDS. When "ReceivedOrMissed" is specified as
"callLogType" and call logs are stored in CDS, all call logs including placed will be
returned.  It is possible to restrict the number of rows returned using
responsePagingControl.  If responsePagingControl is not specified, the value of
Enhanced Call Logs system parameter maxNonPagedResponseSize will control the maximum
number of call logs can be returned.

The response is either a `UserEnhancedCallLogsGetListResponse17sp4()` or an
`ErrorResponse()`. Replaced by UserEnhancedCallLogsGetListRequest17sp4V2. Originally
deprecated in release 20.

**Attributes:**

|Name                              |Type                               |Description                               |
|----------------------------------|-----------------------------------|------------------------------------------|
|user_id                           |str                                |userId                                    |
|call_log_type                     |str                                |callLogType *Optional*                    |
|date_time_range                   |OCI.dateTimeRange                  |dateTimeRange                             |
|number_filter                     |OCI.numberFilter                   |numberFilter *Optional*                   |
|redirected_number_filter          |OCI.redirectedNumberFilter         |redirectedNumberFilter *Optional*         |
|account_authorization_code_filter |OCI.accountAuthorizationCodeFilter |accountAuthorizationCodeFilter *Optional* |
|subscriber_type                   |str                                |subscriberType *Optional*                 |
|response_paging_control           |OCI.responsePagingControl          |responsePagingControl *Optional*          |
</div>


## `UserEnhancedCallLogsGetListRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request user's call logs.

If the callLogType is not specified, all types of calls logs (placed, received,
missed) are returned.  The filters "dateTimeRange", "numberFilter",
"redirectedNumberFilter", "accountAuthorizationCodeFilter"
"callAuthorizationCodeFilter" and "subscriberType" are ignored if call logs are stored
in CDS. When "ReceivedOrMissed" is specified as "callLogType" and call logs are stored
in CDS, all call logs including placed will be returned.  It is possible to restrict
the number of rows returned using responsePagingControl.  If responsePagingControl is
not specified, the value of Enhanced Call Logs system parameter
maxNonPagedResponseSize will control the maximum number of call logs can be returned.

The response is either a `UserEnhancedCallLogsGetListResponse20()` or an
`ErrorResponse()`. The following elements are only used in AS data mode and not
returned in XS data mode: callAuthorizationCodeFilter

**Attributes:**

|Name                              |Type                               |Description                               |
|----------------------------------|-----------------------------------|------------------------------------------|
|user_id                           |str                                |userId                                    |
|call_log_type                     |str                                |callLogType *Optional*                    |
|date_time_range                   |OCI.dateTimeRange                  |dateTimeRange                             |
|number_filter                     |OCI.numberFilter                   |numberFilter *Optional*                   |
|redirected_number_filter          |OCI.redirectedNumberFilter         |redirectedNumberFilter *Optional*         |
|account_authorization_code_filter |OCI.accountAuthorizationCodeFilter |accountAuthorizationCodeFilter *Optional* |
|call_authorization_code_filter    |OCI.callAuthorizationCodeFilter    |callAuthorizationCodeFilter *Optional*    |
|subscriber_type                   |str                                |subscriberType *Optional*                 |
|response_paging_control           |OCI.responsePagingControl          |responsePagingControl *Optional*          |
</div>


## `UserEnhancedCallLogsGetListRequest20sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request user's call logs.

If the callLogType is not specified, all types of calls logs (placed, received,
missed) are returned.  The filters "dateTimeRange", "numberFilter",
"redirectedNumberFilter", "accountAuthorizationCodeFilter"
"callAuthorizationCodeFilter" and "subscriberType" are ignored if call logs are stored
in CDS. When "ReceivedOrMissed" is specified as "callLogType" and call logs are stored
in CDS, all call logs including placed will be returned.  It is possible to restrict
the number of rows returned using responsePagingControl.  If responsePagingControl is
not specified, the value of Enhanced Call Logs system parameter
maxNonPagedResponseSize will control the maximum number of call logs can be returned.

The response is either a `UserEnhancedCallLogsGetListResponse20sp1()` or an
`ErrorResponse()`. The following elements are only used in AS data mode:
callAuthorizationCodeFilter callSecurityClassification

**Attributes:**

|Name                              |Type                               |Description                               |
|----------------------------------|-----------------------------------|------------------------------------------|
|user_id                           |str                                |userId                                    |
|call_log_type                     |str                                |callLogType *Optional*                    |
|date_time_range                   |OCI.dateTimeRange                  |dateTimeRange                             |
|number_filter                     |OCI.numberFilter                   |numberFilter *Optional*                   |
|redirected_number_filter          |OCI.redirectedNumberFilter         |redirectedNumberFilter *Optional*         |
|account_authorization_code_filter |OCI.accountAuthorizationCodeFilter |accountAuthorizationCodeFilter *Optional* |
|call_authorization_code_filter    |OCI.callAuthorizationCodeFilter    |callAuthorizationCodeFilter *Optional*    |
|subscriber_type                   |str                                |subscriberType *Optional*                 |
|response_paging_control           |OCI.responsePagingControl          |responsePagingControl *Optional*          |
</div>


## `UserEnhancedCallLogsGetListRequest21`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request user's call logs.

If the callLogType is not specified, all types of calls logs (placed, received,
missed) are returned.  The filters "dateTimeRange", "numberFilter",
"redirectedNumberFilter", "accountAuthorizationCodeFilter"
"callAuthorizationCodeFilter" and "subscriberType" are ignored if call logs are stored
in CDS. When "ReceivedOrMissed" is specified as "callLogType" and call logs are stored
in CDS, all call logs including placed will be returned.  It is possible to restrict
the number of rows returned using responsePagingControl.  If responsePagingControl is
not specified, the value of Enhanced Call Logs system parameter
maxNonPagedResponseSize will control the maximum number of call logs can be returned.

The response is either a `UserEnhancedCallLogsGetListResponse21()` or an
`ErrorResponse()`. The following elements are only used in AS data mode and not
returned in XS data mode: callAuthorizationCodeFilter Replaced by:
UserEnhancedCallLogsGetListRequest21Sp1 in AS data mode

**Attributes:**

|Name                              |Type                               |Description                               |
|----------------------------------|-----------------------------------|------------------------------------------|
|user_id                           |str                                |userId                                    |
|call_log_type                     |str                                |callLogType *Optional*                    |
|date_time_range                   |OCI.dateTimeRange                  |dateTimeRange                             |
|number_filter                     |OCI.numberFilter                   |numberFilter *Optional*                   |
|redirected_number_filter          |OCI.redirectedNumberFilter         |redirectedNumberFilter *Optional*         |
|account_authorization_code_filter |OCI.accountAuthorizationCodeFilter |accountAuthorizationCodeFilter *Optional* |
|call_authorization_code_filter    |OCI.callAuthorizationCodeFilter    |callAuthorizationCodeFilter *Optional*    |
|subscriber_type                   |str                                |subscriberType *Optional*                 |
|response_paging_control           |OCI.responsePagingControl          |responsePagingControl *Optional*          |
</div>


## `UserEnhancedCallLogsGetListRequest21sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request user's call logs.

If the callLogType is not specified, all types of calls logs (placed, received,
missed) are returned.  The filters "dateTimeRange", "numberFilter",
"redirectedNumberFilter", "accountAuthorizationCodeFilter"
"callAuthorizationCodeFilter" and "subscriberType" are ignored if call logs are stored
in CDS. When "ReceivedOrMissed" is specified as "callLogType" and call logs are stored
in CDS, all call logs including placed will be returned.  It is possible to restrict
the number of rows returned using responsePagingControl.  If responsePagingControl is
not specified, the value of Enhanced Call Logs system parameter
maxNonPagedResponseSize will control the maximum number of call logs can be returned.

The response is either a `UserEnhancedCallLogsGetListResponse21sp1()` or an
`ErrorResponse()`. The following elements are only used in AS data mode and ignored in
XS data mode: callAuthorizationCodeFilter Replaced by:
UserEnhancedCallLogsGetListRequest21Sp1V2 in AS data mode

**Attributes:**

|Name                              |Type                               |Description                               |
|----------------------------------|-----------------------------------|------------------------------------------|
|user_id                           |str                                |userId                                    |
|call_log_type                     |str                                |callLogType *Optional*                    |
|date_time_range                   |OCI.dateTimeRange                  |dateTimeRange                             |
|number_filter                     |OCI.numberFilter                   |numberFilter *Optional*                   |
|redirected_number_filter          |OCI.redirectedNumberFilter         |redirectedNumberFilter *Optional*         |
|account_authorization_code_filter |OCI.accountAuthorizationCodeFilter |accountAuthorizationCodeFilter *Optional* |
|call_authorization_code_filter    |OCI.callAuthorizationCodeFilter    |callAuthorizationCodeFilter *Optional*    |
|subscriber_type                   |str                                |subscriberType *Optional*                 |
|response_paging_control           |OCI.responsePagingControl          |responsePagingControl *Optional*          |
</div>


## `UserEnhancedCallLogsGetListRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request user's call logs.

If the callLogType is not specified, all types of calls logs (placed, received,
missed) are returned.  The filters "dateTimeRange", "numberFilter",
"redirectedNumberFilter", "accountAuthorizationCodeFilter"
"callAuthorizationCodeFilter" and "subscriberType" are ignored if call logs are stored
in CDS. When "ReceivedOrMissed" is specified as "callLogType" and call logs are stored
in CDS, all call logs including placed will be returned.  It is possible to restrict
the number of rows returned using responsePagingControl.  If responsePagingControl is
not specified, the value of Enhanced Call Logs system parameter
maxNonPagedResponseSize will control the maximum number of call logs can be returned.

The response is either a `UserEnhancedCallLogsGetListResponse22()` or an
`ErrorResponse()`. The following elements are only used in AS data mode and ignored in
XS data mode: callAuthorizationCodeFilter

**Attributes:**

|Name                              |Type                               |Description                               |
|----------------------------------|-----------------------------------|------------------------------------------|
|user_id                           |str                                |userId                                    |
|call_log_type                     |str                                |callLogType *Optional*                    |
|date_time_range                   |OCI.dateTimeRange                  |dateTimeRange                             |
|number_filter                     |OCI.numberFilter                   |numberFilter *Optional*                   |
|redirected_number_filter          |OCI.redirectedNumberFilter         |redirectedNumberFilter *Optional*         |
|account_authorization_code_filter |OCI.accountAuthorizationCodeFilter |accountAuthorizationCodeFilter *Optional* |
|call_authorization_code_filter    |OCI.callAuthorizationCodeFilter    |callAuthorizationCodeFilter *Optional*    |
|subscriber_type                   |str                                |subscriberType *Optional*                 |
|response_paging_control           |OCI.responsePagingControl          |responsePagingControl *Optional*          |
</div>


## `UserEnhancedCallLogsGetListRequest23`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request user's call logs.

If the callLogType is not specified, all types of calls logs (placed, received,
missed) are returned.  The filters "dateTimeRange", "numberFilter",
"redirectedNumberFilter", "accountAuthorizationCodeFilter"
"callAuthorizationCodeFilter" and "subscriberType" are ignored if call logs are stored
in CDS. When "ReceivedOrMissed" is specified as "callLogType" and call logs are stored
in CDS, all call logs including placed will be returned.  It is possible to restrict
the number of rows returned using responsePagingControl.  If responsePagingControl is
not specified, the value of Enhanced Call Logs system parameter
maxNonPagedResponseSize will control the maximum number of call logs can be returned.

The response is either a `UserEnhancedCallLogsGetListResponse23()` or an
`ErrorResponse()`. The following elements are only used in AS data mode and ignored in
XS data mode: callAuthorizationCodeFilter

**Attributes:**

|Name                              |Type                               |Description                               |
|----------------------------------|-----------------------------------|------------------------------------------|
|user_id                           |str                                |userId                                    |
|call_log_type                     |str                                |callLogType *Optional*                    |
|date_time_range                   |OCI.dateTimeRange                  |dateTimeRange                             |
|number_filter                     |OCI.numberFilter                   |numberFilter *Optional*                   |
|redirected_number_filter          |OCI.redirectedNumberFilter         |redirectedNumberFilter *Optional*         |
|account_authorization_code_filter |OCI.accountAuthorizationCodeFilter |accountAuthorizationCodeFilter *Optional* |
|call_authorization_code_filter    |OCI.callAuthorizationCodeFilter    |callAuthorizationCodeFilter *Optional*    |
|subscriber_type                   |str                                |subscriberType *Optional*                 |
|response_paging_control           |OCI.responsePagingControl          |responsePagingControl *Optional*          |
</div>


## `UserFlexibleSeatingGuestModifyRequest22`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Modify the user level data associated with flexible seating guest.

accessDeviceEndpoint can only be configured by group or a higher level administrator.
The request fails if isActive is set to false and the guest is associated to a host.
The request fails when enableAssociationLimit, associationLimitHours,
unlockPhonePINCode are changed when the guest is associated to a host.  The request
fails when accessDeviceEndpoint is set in the request when the guest is associated to
a host.

The response is either a `SuccessResponse()` or an `ErrorResponse()`.

**Attributes:**

|Name                     |Type                     |Description                       |
|-------------------------|-------------------------|----------------------------------|
|user_id                  |str                      |userId                            |
|is_active                |bool                     |isActive *Optional*               |
|enable_association_limit |bool                     |enableAssociationLimit *Optional* |
|association_limit_hours  |int                      |associationLimitHours *Optional*  |
|unlock_phone_pin_code    |str                      |unlockPhonePINCode *Optional*     |
|access_device_endpoint   |OCI.accessDeviceEndpoint |accessDeviceEndpoint *Optional*   |
|host_user_id             |str                      |hostUserId *Optional*             |
</div>


## `UserGetListInGroupPagedSortedListRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request the list of users in a group.

The response is either a `UserGetListInGroupPagedSortedListResponse()` or an
`ErrorResponse()`. If the responsePagingControl element is not provided, the paging
startIndex will be set to 1 by default, and the responsePageSize will be set to the
maximum ResponsePageSize by default.  It is possible to search by various criteria to
restrict the number of rows returned.  If no sortOrder is included the response is
sorted by User Id ascending by default.  A limitation to the search by DN activation
exists when the Number Activation mode is set to Off.  In this case DNs not assigned
to users are never returned by queries with the "dnActivationSearchCriteria" included.
Multiple search criteria are logically ANDed together unless the searchCriteriaModeOr
option is included.  Then the search criteria are logically ORed together.  The
following elements are used in AS data mode and ignored in XS data mode:
groupExternalId

**Attributes:**

|Name                                      |Type                                    |Description                                    |
|------------------------------------------|----------------------------------------|-----------------------------------------------|
|service_provider_id                       |str                                     |serviceProviderId *Optional*                   |
|group_id                                  |str                                     |groupId *Optional*                             |
|group_external_id                         |str                                     |groupExternalId *Optional*                     |
|response_paging_control                   |OCI.responsePagingControl               |responsePagingControl *Optional*               |
|sort_order                                |List[OCI.sortOrder]                     |sortOrder *Optional*                           |
|search_criteria_user_last_name            |List[OCI.searchCriteriaUserLastName]    |searchCriteriaUserLastName *Optional*          |
|search_criteria_user_first_name           |List[OCI.searchCriteriaUserFirstName]   |searchCriteriaUserFirstName *Optional*         |
|search_criteria_dn                        |List[OCI.searchCriteriaDn]              |searchCriteriaDn *Optional*                    |
|search_criteria_email_address             |List[OCI.searchCriteriaEmailAddress]    |searchCriteriaEmailAddress *Optional*          |
|search_criteria_department_name           |List[OCI.searchCriteriaDepartmentName]  |searchCriteriaDepartmentName *Optional*        |
|search_criteria_exact_user_in_trunk_group |OCI.searchCriteriaExactUserInTrunkGroup |searchCriteriaExactUserInTrunkGroup *Optional* |
|search_criteria_user_id                   |List[OCI.searchCriteriaUserId]          |searchCriteriaUserId *Optional*                |
|search_criteria_extension                 |List[OCI.searchCriteriaExtension]       |searchCriteriaExtension *Optional*             |
|search_criteria_exact_dn_activation       |OCI.searchCriteriaExactDnActivation     |searchCriteriaExactDnActivation *Optional*     |
|search_criteria_mode_or                   |bool                                    |searchCriteriaModeOr *Optional*                |
</div>


## `GroupAutoAttendantAddInstanceRequest14`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Auto Attendant instance to a group.

The domain is required in the serviceUserId.

The response is either `SuccessResponse()` or `ErrorResponse()`.

Replaced By: `GroupAutoAttendantAddInstanceRequest16()`

**Attributes:**

|Name                     |Type                       |Description                    |
|-------------------------|---------------------------|-------------------------------|
|service_provider_id      |str                        |serviceProviderId              |
|group_id                 |str                        |groupId                        |
|service_user_id          |str                        |serviceUserId                  |
|service_instance_profile |OCI.serviceInstanceProfile |serviceInstanceProfile         |
|enable_video             |bool                       |enableVideo                    |
|business_hours           |str                        |businessHours *Optional*       |
|holiday_schedule_name    |str                        |holidayScheduleName *Optional* |
|extension_dialing_scope  |str                        |extensionDialingScope          |
|name_dialing_scope       |str                        |nameDialingScope               |
|name_dialing_entries     |str                        |nameDialingEntries             |
|business_hours_menu      |OCI.businessHoursMenu      |businessHoursMenu *Optional*   |
|after_hours_menu         |OCI.afterHoursMenu         |afterHoursMenu *Optional*      |
</div>


## `GroupAutoAttendantAddInstanceRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Auto Attendant instance to a group.

The domain is required in the serviceUserId.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                     |Type                       |Description                    |
|-------------------------|---------------------------|-------------------------------|
|service_provider_id      |str                        |serviceProviderId              |
|group_id                 |str                        |groupId                        |
|service_user_id          |str                        |serviceUserId                  |
|service_instance_profile |OCI.serviceInstanceProfile |serviceInstanceProfile         |
|enable_video             |bool                       |enableVideo                    |
|business_hours           |str                        |businessHours *Optional*       |
|holiday_schedule_name    |str                        |holidayScheduleName *Optional* |
|extension_dialing_scope  |str                        |extensionDialingScope          |
|name_dialing_scope       |str                        |nameDialingScope               |
|name_dialing_entries     |str                        |nameDialingEntries             |
|business_hours_menu      |OCI.businessHoursMenu      |businessHoursMenu *Optional*   |
|after_hours_menu         |OCI.afterHoursMenu         |afterHoursMenu *Optional*      |
</div>


## `GroupAutoAttendantAddInstanceRequest17sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Auto Attendant instance to a group.

The domain is required in the serviceUserId.  Only Group and Enterprise level
schedules are accepted.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                     |Type                       |Description                  |
|-------------------------|---------------------------|-----------------------------|
|service_provider_id      |str                        |serviceProviderId            |
|group_id                 |str                        |groupId                      |
|service_user_id          |str                        |serviceUserId                |
|service_instance_profile |OCI.serviceInstanceProfile |serviceInstanceProfile       |
|enable_video             |bool                       |enableVideo                  |
|business_hours           |OCI.businessHours          |businessHours *Optional*     |
|holiday_schedule         |OCI.holidaySchedule        |holidaySchedule *Optional*   |
|extension_dialing_scope  |str                        |extensionDialingScope        |
|name_dialing_scope       |str                        |nameDialingScope             |
|name_dialing_entries     |str                        |nameDialingEntries           |
|business_hours_menu      |OCI.businessHoursMenu      |businessHoursMenu *Optional* |
|after_hours_menu         |OCI.afterHoursMenu         |afterHoursMenu *Optional*    |
</div>


## `GroupAutoAttendantAddInstanceRequest19`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Auto Attendant instance to a group.

The domain is required in the serviceUserId.  Only Group and Enterprise level
schedules are accepted.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in AS data mode: type, use value "Basic" in XS data mode The
following elements are only used in AS data mode and ignored in XS data mode:
holidayMenu The following elements are only valid for Standard Auto Attendants:
holidayMenu Replaced by: `GroupAutoAttendantAddInstanceRequest20()` in AS data mode

**Attributes:**

|Name                     |Type                       |Description                      |
|-------------------------|---------------------------|---------------------------------|
|service_provider_id      |str                        |serviceProviderId                |
|group_id                 |str                        |groupId                          |
|service_user_id          |str                        |serviceUserId                    |
|service_instance_profile |OCI.serviceInstanceProfile |serviceInstanceProfile           |
|type                     |str                        |type                             |
|enable_video             |bool                       |enableVideo                      |
|business_hours           |OCI.businessHours          |businessHours *Optional*         |
|holiday_schedule         |OCI.holidaySchedule        |holidaySchedule *Optional*       |
|extension_dialing_scope  |str                        |extensionDialingScope            |
|name_dialing_scope       |str                        |nameDialingScope                 |
|name_dialing_entries     |str                        |nameDialingEntries               |
|business_hours_menu      |OCI.businessHoursMenu      |businessHoursMenu *Optional*     |
|after_hours_menu         |OCI.afterHoursMenu         |afterHoursMenu *Optional*        |
|holiday_menu             |OCI.holidayMenu            |holidayMenu *Optional*           |
|network_class_of_service |str                        |networkClassOfService *Optional* |
</div>


## `GroupAutoAttendantAddInstanceRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Auto Attendant instance to a group.

The domain is required in the serviceUserId.  Only Group and Enterprise level
schedules are accepted.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in AS data mode: type, use AutoAttendantType.BASIC in XS mode.
holidayMenu.  The following elements are only valid for Standard Auto Attendants:
holidayMenu

**Attributes:**

|Name                        |Type                       |Description                      |
|----------------------------|---------------------------|---------------------------------|
|service_provider_id         |str                        |serviceProviderId                |
|group_id                    |str                        |groupId                          |
|service_user_id             |str                        |serviceUserId                    |
|service_instance_profile    |OCI.serviceInstanceProfile |serviceInstanceProfile           |
|type                        |str                        |type                             |
|first_digit_timeout_seconds |int                        |firstDigitTimeoutSeconds         |
|enable_video                |bool                       |enableVideo                      |
|business_hours              |OCI.businessHours          |businessHours *Optional*         |
|holiday_schedule            |OCI.holidaySchedule        |holidaySchedule *Optional*       |
|extension_dialing_scope     |str                        |extensionDialingScope            |
|name_dialing_scope          |str                        |nameDialingScope                 |
|name_dialing_entries        |str                        |nameDialingEntries               |
|business_hours_menu         |OCI.businessHoursMenu      |businessHoursMenu *Optional*     |
|after_hours_menu            |OCI.afterHoursMenu         |afterHoursMenu *Optional*        |
|holiday_menu                |OCI.holidayMenu            |holidayMenu *Optional*           |
|network_class_of_service    |str                        |networkClassOfService *Optional* |
</div>


## `GroupAutoAttendantConsolidatedAddInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Add a Auto Attendant instance to a group and assign services to the Auto Attendant.

The domain is required in the serviceUserId.  Only Group and Enterprise level
schedules are accepted.

The response is either `SuccessResponse()` or `ErrorResponse()`. If the phoneNumber
has not been assigned to the group and addPhoneNumberToGroup is set to true, it will
be added to group if the command is executed by a service provider administrator or
above and the number is already assigned to the service provider.  The command will
fail otherwise.  The following elements are only used in AS data mode: type, use
AutoAttendantType.BASIC in XS mode.  holidayMenu.  The following elements are only
valid for Standard Auto Attendants: holidayMenu

**Attributes:**

|Name                        |Type                       |Description                      |
|----------------------------|---------------------------|---------------------------------|
|service_provider_id         |str                        |serviceProviderId                |
|group_id                    |str                        |groupId                          |
|service_user_id             |str                        |serviceUserId                    |
|add_phone_number_to_group   |bool                       |addPhoneNumberToGroup *Optional* |
|service_instance_profile    |OCI.serviceInstanceProfile |serviceInstanceProfile           |
|type                        |str                        |type                             |
|first_digit_timeout_seconds |int                        |firstDigitTimeoutSeconds         |
|enable_video                |bool                       |enableVideo                      |
|business_hours              |OCI.businessHours          |businessHours *Optional*         |
|holiday_schedule            |OCI.holidaySchedule        |holidaySchedule *Optional*       |
|extension_dialing_scope     |str                        |extensionDialingScope            |
|name_dialing_scope          |str                        |nameDialingScope                 |
|name_dialing_entries        |str                        |nameDialingEntries               |
|business_hours_menu         |OCI.businessHoursMenu      |businessHoursMenu *Optional*     |
|after_hours_menu            |OCI.afterHoursMenu         |afterHoursMenu *Optional*        |
|holiday_menu                |OCI.holidayMenu            |holidayMenu *Optional*           |
|network_class_of_service    |str                        |networkClassOfService *Optional* |
|service                     |List[OCI.service]          |service *Optional*               |
|is_active                   |bool                       |isActive                         |
</div>


## `GroupAutoAttendantConsolidatedModifyInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify an Auto Attendant instance and assign services to the Auto
Attendant.

Only Group and Enterprise level schedules are accepted.

The response is either `SuccessResponse()` or `ErrorResponse()`. When phone numbers
are un-assigned from the user, the unused numbers may be un-assigned from the group
and service provider.  If UnassignPhoneNumbersLevel is set to 'Group', the user's
primary phone number, fax number and any alternate numbers, will be un-assigned from
the group if the command is executed by a service provider administrator or above.
When set to 'Service Provider', they will be un-assigned from the group and service
provider if the command is executed by a provisioning administrator or above.  When
omitted, the number(s) will be left assigned to the group.  An `ErrorResponse()` will
be returned if any number cannot be unassigned because of insufficient privilege.  If
the phoneNumber has not been assigned to the group and addPhoneNumberToGroup is set to
true, it will be added to group if needed if the command is executed by a service
provider administrator and above.  The command will fail otherwise.  The following
elements are only used in AS data mode: holidayMenu.  The following elements are only
valid for Standard Auto Attendants: holidayMenu

**Attributes:**

|Name                        |Type                       |Description                         |
|----------------------------|---------------------------|------------------------------------|
|service_user_id             |str                        |serviceUserId                       |
|unassign_phone_numbers      |str                        |unassignPhoneNumbers *Optional*     |
|add_phone_number_to_group   |bool                       |addPhoneNumberToGroup *Optional*    |
|service_instance_profile    |OCI.serviceInstanceProfile |serviceInstanceProfile *Optional*   |
|first_digit_timeout_seconds |int                        |firstDigitTimeoutSeconds *Optional* |
|enable_video                |bool                       |enableVideo *Optional*              |
|business_hours              |OCI.businessHours          |businessHours *Optional*            |
|holiday_schedule            |OCI.holidaySchedule        |holidaySchedule *Optional*          |
|extension_dialing_scope     |str                        |extensionDialingScope *Optional*    |
|name_dialing_scope          |str                        |nameDialingScope *Optional*         |
|name_dialing_entries        |str                        |nameDialingEntries *Optional*       |
|business_hours_menu         |OCI.businessHoursMenu      |businessHoursMenu *Optional*        |
|after_hours_menu            |OCI.afterHoursMenu         |afterHoursMenu *Optional*           |
|holiday_menu                |OCI.holidayMenu            |holidayMenu *Optional*              |
|network_class_of_service    |str                        |networkClassOfService *Optional*    |
|service_list                |OCI.serviceList            |serviceList *Optional*              |
|is_active                   |bool                       |isActive *Optional*                 |
</div>


## `GroupAutoAttendantModifyInstanceRequest`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify an Auto Attendant instance.

The response is either `SuccessResponse()` or `ErrorResponse()`.

Replaced By: `GroupAutoAttendantModifyInstanceRequest16()`

**Attributes:**

|Name                     |Type                       |Description                       |
|-------------------------|---------------------------|----------------------------------|
|service_user_id          |str                        |serviceUserId                     |
|service_instance_profile |OCI.serviceInstanceProfile |serviceInstanceProfile *Optional* |
|enable_video             |bool                       |enableVideo *Optional*            |
|business_hours           |str                        |businessHours *Optional*          |
|holiday_schedule_name    |str                        |holidayScheduleName *Optional*    |
|extension_dialing_scope  |str                        |extensionDialingScope *Optional*  |
|name_dialing_scope       |str                        |nameDialingScope *Optional*       |
|name_dialing_entries     |str                        |nameDialingEntries *Optional*     |
|business_hours_menu      |OCI.businessHoursMenu      |businessHoursMenu *Optional*      |
|after_hours_menu         |OCI.afterHoursMenu         |afterHoursMenu *Optional*         |
</div>


## `GroupAutoAttendantModifyInstanceRequest16`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify an Auto Attendant instance.

The response is either `SuccessResponse()` or `ErrorResponse()`.

**Attributes:**

|Name                     |Type                       |Description                       |
|-------------------------|---------------------------|----------------------------------|
|service_user_id          |str                        |serviceUserId                     |
|service_instance_profile |OCI.serviceInstanceProfile |serviceInstanceProfile *Optional* |
|enable_video             |bool                       |enableVideo *Optional*            |
|business_hours           |str                        |businessHours *Optional*          |
|holiday_schedule_name    |str                        |holidayScheduleName *Optional*    |
|extension_dialing_scope  |str                        |extensionDialingScope *Optional*  |
|name_dialing_scope       |str                        |nameDialingScope *Optional*       |
|name_dialing_entries     |str                        |nameDialingEntries *Optional*     |
|business_hours_menu      |OCI.businessHoursMenu      |businessHoursMenu *Optional*      |
|after_hours_menu         |OCI.afterHoursMenu         |afterHoursMenu *Optional*         |
</div>


## `GroupAutoAttendantModifyInstanceRequest17sp1`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify an Auto Attendant instance.

Only Group and Enterprise level schedules are accepted.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in AS data mode and not returned in XS data mode: holidayMenu.
The following elementsare only valid for Standard Auto Attendants: holidayMenu
Replaced by: `GroupAutoAttendantModifyInstanceRequest20()` in AS data mode

**Attributes:**

|Name                        |Type                       |Description                         |
|----------------------------|---------------------------|------------------------------------|
|service_user_id             |str                        |serviceUserId                       |
|service_instance_profile    |OCI.serviceInstanceProfile |serviceInstanceProfile *Optional*   |
|first_digit_timeout_seconds |int                        |firstDigitTimeoutSeconds *Optional* |
|enable_video                |bool                       |enableVideo *Optional*              |
|business_hours              |OCI.businessHours          |businessHours *Optional*            |
|holiday_schedule            |OCI.holidaySchedule        |holidaySchedule *Optional*          |
|extension_dialing_scope     |str                        |extensionDialingScope *Optional*    |
|name_dialing_scope          |str                        |nameDialingScope *Optional*         |
|name_dialing_entries        |str                        |nameDialingEntries *Optional*       |
|business_hours_menu         |OCI.businessHoursMenu      |businessHoursMenu *Optional*        |
|after_hours_menu            |OCI.afterHoursMenu         |afterHoursMenu *Optional*           |
|holiday_menu                |OCI.holidayMenu            |holidayMenu *Optional*              |
|network_class_of_service    |str                        |networkClassOfService *Optional*    |
</div>


## `GroupAutoAttendantModifyInstanceRequest20`([`OCIRequest`](/broadworks_ocip/api/base/#broadworks_ocip.base.OCIRequest))

<div class="doc-contents" markdown="1">
Request to modify an Auto Attendant instance.

Only Group and Enterprise level schedules are accepted.

The response is either `SuccessResponse()` or `ErrorResponse()`. The following
elements are only used in AS data mode: holidayMenu.  The following elements are only
valid for Standard Auto Attendants: holidayMenu

**Attributes:**

|Name                        |Type                       |Description                         |
|----------------------------|---------------------------|------------------------------------|
|service_user_id             |str                        |serviceUserId                       |
|service_instance_profile    |OCI.serviceInstanceProfile |serviceInstanceProfile *Optional*   |
|first_digit_timeout_seconds |int                        |firstDigitTimeoutSeconds *Optional* |
|enable_video                |bool                       |enableVideo *Optional*              |
|business_hours              |OCI.businessHours          |businessHours *Optional*            |
|holiday_schedule            |OCI.holidaySchedule        |holidaySchedule *Optional*          |
|extension_dialing_scope     |str                        |extensionDialingScope *Optional*    |
|name_dialing_scope          |str                        |nameDialingScope *Optional*         |
|name_dialing_entries        |str                        |nameDialingEntries *Optional*       |
|business_hours_menu         |OCI.businessHoursMenu      |businessHoursMenu *Optional*        |
|after_hours_menu            |OCI.afterHoursMenu         |afterHoursMenu *Optional*           |
|holiday_menu                |OCI.holidayMenu            |holidayMenu *Optional*              |
|network_class_of_service    |str                        |networkClassOfService *Optional*    |
</div>
